/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_d0ih(Libderiv_t *, prim_data *);

  /* Computes derivatives of (d0|ih) integrals */

void d1hrr_order_d0ih(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[2][6][11] = int_stack + 0;
 Libderiv->deriv_classes[2][7][11] = int_stack + 168;
 Libderiv->deriv_classes[2][8][11] = int_stack + 384;
 Libderiv->deriv_classes[2][9][11] = int_stack + 654;
 Libderiv->deriv_classes[2][10][11] = int_stack + 984;
 Libderiv->deriv_classes[2][11][11] = int_stack + 1380;
 Libderiv->deriv_classes[2][6][10] = int_stack + 1848;
 Libderiv->deriv_classes[2][7][10] = int_stack + 2016;
 Libderiv->deriv_classes[2][8][10] = int_stack + 2232;
 Libderiv->deriv_classes[2][9][10] = int_stack + 2502;
 Libderiv->deriv_classes[2][10][10] = int_stack + 2832;
 Libderiv->deriv_classes[2][11][10] = int_stack + 3228;
 Libderiv->deriv_classes[2][6][9] = int_stack + 3696;
 Libderiv->deriv_classes[2][7][9] = int_stack + 3864;
 Libderiv->deriv_classes[2][8][9] = int_stack + 4080;
 Libderiv->deriv_classes[2][9][9] = int_stack + 4350;
 Libderiv->deriv_classes[2][10][9] = int_stack + 4680;
 Libderiv->deriv_classes[2][11][9] = int_stack + 5076;
 Libderiv->deriv_classes[2][6][8] = int_stack + 5544;
 Libderiv->deriv_classes[2][7][8] = int_stack + 5712;
 Libderiv->deriv_classes[2][8][8] = int_stack + 5928;
 Libderiv->deriv_classes[2][9][8] = int_stack + 6198;
 Libderiv->deriv_classes[2][10][8] = int_stack + 6528;
 Libderiv->deriv_classes[2][11][8] = int_stack + 6924;
 Libderiv->deriv_classes[2][6][7] = int_stack + 7392;
 Libderiv->deriv_classes[2][7][7] = int_stack + 7560;
 Libderiv->deriv_classes[2][8][7] = int_stack + 7776;
 Libderiv->deriv_classes[2][9][7] = int_stack + 8046;
 Libderiv->deriv_classes[2][10][7] = int_stack + 8376;
 Libderiv->deriv_classes[2][11][7] = int_stack + 8772;
 Libderiv->dvrr_classes[2][6] = int_stack + 9240;
 Libderiv->deriv_classes[2][6][6] = int_stack + 9408;
 Libderiv->dvrr_classes[2][7] = int_stack + 9576;
 Libderiv->deriv_classes[2][7][6] = int_stack + 9792;
 Libderiv->dvrr_classes[2][8] = int_stack + 10008;
 Libderiv->deriv_classes[2][8][6] = int_stack + 10278;
 Libderiv->dvrr_classes[2][9] = int_stack + 10548;
 Libderiv->deriv_classes[2][9][6] = int_stack + 10878;
 Libderiv->dvrr_classes[2][10] = int_stack + 11208;
 Libderiv->deriv_classes[2][10][6] = int_stack + 11604;
 Libderiv->deriv_classes[2][11][6] = int_stack + 12000;
 Libderiv->deriv_classes[2][6][2] = int_stack + 12468;
 Libderiv->deriv_classes[2][7][2] = int_stack + 12636;
 Libderiv->deriv_classes[2][8][2] = int_stack + 12852;
 Libderiv->deriv_classes[2][9][2] = int_stack + 13122;
 Libderiv->deriv_classes[2][10][2] = int_stack + 13452;
 Libderiv->deriv_classes[2][11][2] = int_stack + 13848;
 Libderiv->deriv_classes[2][6][1] = int_stack + 14316;
 Libderiv->deriv_classes[2][7][1] = int_stack + 14484;
 Libderiv->deriv_classes[2][8][1] = int_stack + 14700;
 Libderiv->deriv_classes[2][9][1] = int_stack + 14970;
 Libderiv->deriv_classes[2][10][1] = int_stack + 15300;
 Libderiv->deriv_classes[2][11][1] = int_stack + 15696;
 Libderiv->deriv_classes[2][6][0] = int_stack + 16164;
 Libderiv->deriv_classes[2][7][0] = int_stack + 16332;
 Libderiv->deriv_classes[2][8][0] = int_stack + 16548;
 Libderiv->deriv_classes[2][9][0] = int_stack + 16818;
 Libderiv->deriv_classes[2][10][0] = int_stack + 17148;
 Libderiv->deriv_classes[2][11][0] = int_stack + 17544;
 memset(int_stack,0,144096);

 Libderiv->dvrr_stack = int_stack + 66858;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_d0ih(Libderiv, Data);
   Data++;
 }

 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+18012,int_stack+9576,int_stack+9240,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+18516,int_stack+10008,int_stack+9576,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+19164,int_stack+18516,int_stack+18012,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+20172,int_stack+10548,int_stack+10008,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+20982,int_stack+20172,int_stack+18516,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+22278,int_stack+20982,int_stack+19164,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+23958,int_stack+11208,int_stack+10548,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+24948,int_stack+23958,int_stack+20172,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+26568,int_stack+24948,int_stack+20982,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+28728,int_stack+26568,int_stack+22278,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+31248,int_stack+168,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9240,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+31752,int_stack+384,int_stack+168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9576,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+32400,int_stack+31752,int_stack+31248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18012,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+33408,int_stack+654,int_stack+384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10008,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+34218,int_stack+33408,int_stack+31752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18516,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+35514,int_stack+34218,int_stack+32400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19164,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+31248,int_stack+984,int_stack+654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10548,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+37194,int_stack+31248,int_stack+33408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20172,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+38814,int_stack+37194,int_stack+34218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20982,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+32238,int_stack+38814,int_stack+35514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22278,6);
 /*--- compute (d0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+34758,int_stack+1380,int_stack+984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11208,6);
 /*--- compute (d0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+40974,int_stack+34758,int_stack+31248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23958,6);
 /*--- compute (d0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+42954,int_stack+40974,int_stack+37194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24948,6);
 /*--- compute (d0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+34758,int_stack+42954,int_stack+38814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26568,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+31248,int_stack+2016,int_stack+1848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9240, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+37998,int_stack+2232,int_stack+2016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9576, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+38646,int_stack+37998,int_stack+31248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18012, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+31248,int_stack+2502,int_stack+2232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10008, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+39654,int_stack+31248,int_stack+37998, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18516, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+40950,int_stack+39654,int_stack+38646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19164, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+37998,int_stack+2832,int_stack+2502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10548, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+42630,int_stack+37998,int_stack+31248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20172, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+42630,int_stack+39654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20982, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+44250,int_stack+0,int_stack+40950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22278, 0.0, zero_stack,6);
 /*--- compute (d0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+38988,int_stack+3228,int_stack+2832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11208, 0.0, zero_stack,6);
 /*--- compute (d0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+40176,int_stack+38988,int_stack+37998, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23958, 0.0, zero_stack,6);
 /*--- compute (d0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+46770,int_stack+40176,int_stack+42630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24948, 0.0, zero_stack,6);
 /*--- compute (d0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+37998,int_stack+46770,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26568, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+3864,int_stack+3696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9240, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+504,int_stack+4080,int_stack+3864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9576, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1152,int_stack+504,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18012, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2160,int_stack+4350,int_stack+4080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10008, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2970,int_stack+2160,int_stack+504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18516, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+46770,int_stack+2970,int_stack+1152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19164, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+31248,int_stack+4680,int_stack+4350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10548, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+31248,int_stack+2160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20172, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+41238,int_stack+0,int_stack+2970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20982, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1620,int_stack+41238,int_stack+46770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22278, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+46770,int_stack+5076,int_stack+4680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11208, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+47958,int_stack+46770,int_stack+31248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23958, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+49938,int_stack+47958,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24948, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+52638,int_stack+49938,int_stack+41238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26568, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+41238,int_stack+5712,int_stack+5544, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+41742,int_stack+5928,int_stack+5712, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+42390,int_stack+41742,int_stack+41238, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+43398,int_stack+6198,int_stack+5928, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+43398,int_stack+41742, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+46770,int_stack+0,int_stack+42390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+31248,int_stack+6528,int_stack+6198, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+41238,int_stack+31248,int_stack+43398, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+48450,int_stack+41238,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+55878,int_stack+48450,int_stack+46770, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+46770,int_stack+6924,int_stack+6528, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+50610,int_stack+46770,int_stack+31248, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+4140,int_stack+50610,int_stack+41238, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+58398,int_stack+4140,int_stack+48450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4140,int_stack+7560,int_stack+7392, 0.0, zero_stack, 1.0, int_stack+9240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4644,int_stack+7776,int_stack+7560, 0.0, zero_stack, 1.0, int_stack+9576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5292,int_stack+4644,int_stack+4140, 0.0, zero_stack, 1.0, int_stack+18012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6300,int_stack+8046,int_stack+7776, 0.0, zero_stack, 1.0, int_stack+10008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+41238,int_stack+6300,int_stack+4644, 0.0, zero_stack, 1.0, int_stack+18516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+42534,int_stack+41238,int_stack+5292, 0.0, zero_stack, 1.0, int_stack+19164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+31248,int_stack+8376,int_stack+8046, 0.0, zero_stack, 1.0, int_stack+10548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+31248,int_stack+6300, 0.0, zero_stack, 1.0, int_stack+20172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4140,int_stack+0,int_stack+41238, 0.0, zero_stack, 1.0, int_stack+20982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+46770,int_stack+4140,int_stack+42534, 0.0, zero_stack, 1.0, int_stack+22278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+41238,int_stack+8772,int_stack+8376, 0.0, zero_stack, 1.0, int_stack+11208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+6300,int_stack+41238,int_stack+31248, 0.0, zero_stack, 1.0, int_stack+23958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+41238,int_stack+6300,int_stack+0, 0.0, zero_stack, 1.0, int_stack+24948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+49290,int_stack+41238,int_stack+4140, 0.0, zero_stack, 1.0, int_stack+26568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4140,int_stack+9792,int_stack+9408, 1.0, int_stack+9240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4644,int_stack+10278,int_stack+9792, 1.0, int_stack+9576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5292,int_stack+4644,int_stack+4140, 1.0, int_stack+18012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6300,int_stack+10878,int_stack+10278, 1.0, int_stack+10008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7110,int_stack+6300,int_stack+4644, 1.0, int_stack+18516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8406,int_stack+7110,int_stack+5292, 1.0, int_stack+19164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+31248,int_stack+11604,int_stack+10878, 1.0, int_stack+10548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+31248,int_stack+6300, 1.0, int_stack+20172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+18012,int_stack+0,int_stack+7110, 1.0, int_stack+20982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4140,int_stack+18012,int_stack+8406, 1.0, int_stack+22278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+20172,int_stack+12000,int_stack+11604, 1.0, int_stack+11208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+21360,int_stack+20172,int_stack+31248, 1.0, int_stack+23958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+6660,int_stack+21360,int_stack+0, 1.0, int_stack+24948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+20172,int_stack+6660,int_stack+18012, 1.0, int_stack+26568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+18012,int_stack+12636,int_stack+12468,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+18516,int_stack+12852,int_stack+12636,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+19164,int_stack+18516,int_stack+18012,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6660,int_stack+13122,int_stack+12852,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7470,int_stack+6660,int_stack+18516,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+8766,int_stack+7470,int_stack+19164,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+31248,int_stack+13452,int_stack+13122,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+31248,int_stack+6660,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+18012,int_stack+0,int_stack+7470,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+10446,int_stack+18012,int_stack+8766,6);
 /*--- compute (d0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+6660,int_stack+13848,int_stack+13452,6);
 /*--- compute (d0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+7848,int_stack+6660,int_stack+31248,6);
 /*--- compute (d0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+23412,int_stack+7848,int_stack+0,6);
 /*--- compute (d0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+6660,int_stack+23412,int_stack+18012,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+18012,int_stack+14484,int_stack+14316,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+18516,int_stack+14700,int_stack+14484,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+19164,int_stack+18516,int_stack+18012,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+23412,int_stack+14970,int_stack+14700,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+24222,int_stack+23412,int_stack+18516,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+25518,int_stack+24222,int_stack+19164,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+31248,int_stack+15300,int_stack+14970,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+31248,int_stack+23412,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+18012,int_stack+0,int_stack+24222,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+41238,int_stack+18012,int_stack+25518,6);
 /*--- compute (d0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+23412,int_stack+15696,int_stack+15300,6);
 /*--- compute (d0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+24600,int_stack+23412,int_stack+31248,6);
 /*--- compute (d0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+12966,int_stack+24600,int_stack+0,6);
 /*--- compute (d0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+23412,int_stack+12966,int_stack+18012,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+18012,int_stack+16332,int_stack+16164,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+18516,int_stack+16548,int_stack+16332,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+19164,int_stack+18516,int_stack+18012,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+12966,int_stack+16818,int_stack+16548,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+13776,int_stack+12966,int_stack+18516,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+15072,int_stack+13776,int_stack+19164,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+31248,int_stack+17148,int_stack+16818,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+31248,int_stack+12966,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+18012,int_stack+0,int_stack+13776,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+61638,int_stack+18012,int_stack+15072,6);
 /*--- compute (d0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+12966,int_stack+17544,int_stack+17148,6);
 /*--- compute (d0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+14154,int_stack+12966,int_stack+31248,6);
 /*--- compute (d0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+64158,int_stack+14154,int_stack+0,6);
 /*--- compute (d0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+12966,int_stack+64158,int_stack+18012,6);
 /*--- compute (d0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+16206,int_stack+34758,int_stack+32238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28728,6);
     Libderiv->ABCD[11] = int_stack + 16206;
 /*--- compute (d0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+31248,int_stack+37998,int_stack+44250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28728, 0.0, zero_stack,6);
     Libderiv->ABCD[10] = int_stack + 31248;
 /*--- compute (d0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+34776,int_stack+52638,int_stack+1620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28728, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[9] = int_stack + 34776;
 /*--- compute (d0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+0,int_stack+58398,int_stack+55878, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (d0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+52530,int_stack+49290,int_stack+46770, 0.0, zero_stack, 1.0, int_stack+28728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[7] = int_stack + 52530;
 /*--- compute (d0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+43758,int_stack+20172,int_stack+4140, 1.0, int_stack+28728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[6] = int_stack + 43758;
 /*--- compute (d0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+19734,int_stack+6660,int_stack+10446,6);
     Libderiv->ABCD[2] = int_stack + 19734;
 /*--- compute (d0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+3528,int_stack+23412,int_stack+41238,6);
     Libderiv->ABCD[1] = int_stack + 3528;
 /*--- compute (d0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+7056,int_stack+12966,int_stack+61638,6);
     Libderiv->ABCD[0] = int_stack + 7056;

}
