/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_f0hh(Libderiv_t *, prim_data *);

  /* Computes derivatives of (f0|hh) integrals */

void d1hrr_order_f0hh(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][5][11] = int_stack + 0;
 Libderiv->deriv_classes[3][6][11] = int_stack + 210;
 Libderiv->deriv_classes[3][7][11] = int_stack + 490;
 Libderiv->deriv_classes[3][8][11] = int_stack + 850;
 Libderiv->deriv_classes[3][9][11] = int_stack + 1300;
 Libderiv->deriv_classes[3][10][11] = int_stack + 1850;
 Libderiv->deriv_classes[3][5][10] = int_stack + 2510;
 Libderiv->deriv_classes[3][6][10] = int_stack + 2720;
 Libderiv->deriv_classes[3][7][10] = int_stack + 3000;
 Libderiv->deriv_classes[3][8][10] = int_stack + 3360;
 Libderiv->deriv_classes[3][9][10] = int_stack + 3810;
 Libderiv->deriv_classes[3][10][10] = int_stack + 4360;
 Libderiv->deriv_classes[3][5][9] = int_stack + 5020;
 Libderiv->deriv_classes[3][6][9] = int_stack + 5230;
 Libderiv->deriv_classes[3][7][9] = int_stack + 5510;
 Libderiv->deriv_classes[3][8][9] = int_stack + 5870;
 Libderiv->deriv_classes[3][9][9] = int_stack + 6320;
 Libderiv->deriv_classes[3][10][9] = int_stack + 6870;
 Libderiv->deriv_classes[3][5][8] = int_stack + 7530;
 Libderiv->deriv_classes[3][6][8] = int_stack + 7740;
 Libderiv->deriv_classes[3][7][8] = int_stack + 8020;
 Libderiv->deriv_classes[3][8][8] = int_stack + 8380;
 Libderiv->deriv_classes[3][9][8] = int_stack + 8830;
 Libderiv->deriv_classes[3][10][8] = int_stack + 9380;
 Libderiv->deriv_classes[3][5][7] = int_stack + 10040;
 Libderiv->deriv_classes[3][6][7] = int_stack + 10250;
 Libderiv->deriv_classes[3][7][7] = int_stack + 10530;
 Libderiv->deriv_classes[3][8][7] = int_stack + 10890;
 Libderiv->deriv_classes[3][9][7] = int_stack + 11340;
 Libderiv->deriv_classes[3][10][7] = int_stack + 11890;
 Libderiv->dvrr_classes[3][5] = int_stack + 12550;
 Libderiv->deriv_classes[3][5][6] = int_stack + 12760;
 Libderiv->dvrr_classes[3][6] = int_stack + 12970;
 Libderiv->deriv_classes[3][6][6] = int_stack + 13250;
 Libderiv->dvrr_classes[3][7] = int_stack + 13530;
 Libderiv->deriv_classes[3][7][6] = int_stack + 13890;
 Libderiv->dvrr_classes[3][8] = int_stack + 14250;
 Libderiv->deriv_classes[3][8][6] = int_stack + 14700;
 Libderiv->dvrr_classes[3][9] = int_stack + 15150;
 Libderiv->deriv_classes[3][9][6] = int_stack + 15700;
 Libderiv->deriv_classes[3][10][6] = int_stack + 16250;
 Libderiv->deriv_classes[3][5][2] = int_stack + 16910;
 Libderiv->deriv_classes[3][6][2] = int_stack + 17120;
 Libderiv->deriv_classes[3][7][2] = int_stack + 17400;
 Libderiv->deriv_classes[3][8][2] = int_stack + 17760;
 Libderiv->deriv_classes[3][9][2] = int_stack + 18210;
 Libderiv->deriv_classes[3][10][2] = int_stack + 18760;
 Libderiv->deriv_classes[3][5][1] = int_stack + 19420;
 Libderiv->deriv_classes[3][6][1] = int_stack + 19630;
 Libderiv->deriv_classes[3][7][1] = int_stack + 19910;
 Libderiv->deriv_classes[3][8][1] = int_stack + 20270;
 Libderiv->deriv_classes[3][9][1] = int_stack + 20720;
 Libderiv->deriv_classes[3][10][1] = int_stack + 21270;
 Libderiv->deriv_classes[3][5][0] = int_stack + 21930;
 Libderiv->deriv_classes[3][6][0] = int_stack + 22140;
 Libderiv->deriv_classes[3][7][0] = int_stack + 22420;
 Libderiv->deriv_classes[3][8][0] = int_stack + 22780;
 Libderiv->deriv_classes[3][9][0] = int_stack + 23230;
 Libderiv->deriv_classes[3][10][0] = int_stack + 23780;
 memset(int_stack,0,195520);

 Libderiv->dvrr_stack = int_stack + 89940;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_f0hh(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+24440,int_stack+12970,int_stack+12550,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+25070,int_stack+13530,int_stack+12970,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+25910,int_stack+25070,int_stack+24440,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+27170,int_stack+14250,int_stack+13530,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+28250,int_stack+27170,int_stack+25070,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+29930,int_stack+28250,int_stack+25910,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+32030,int_stack+15150,int_stack+14250,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+33380,int_stack+32030,int_stack+27170,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+35540,int_stack+33380,int_stack+28250,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+38340,int_stack+35540,int_stack+29930,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+41490,int_stack+210,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12550,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+42120,int_stack+490,int_stack+210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12970,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+42960,int_stack+42120,int_stack+41490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24440,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+44220,int_stack+850,int_stack+490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13530,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+45300,int_stack+44220,int_stack+42120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25070,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+46980,int_stack+45300,int_stack+42960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25910,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+41490,int_stack+1300,int_stack+850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14250,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+49080,int_stack+41490,int_stack+44220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27170,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+51240,int_stack+49080,int_stack+45300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28250,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+42840,int_stack+51240,int_stack+46980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29930,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+45990,int_stack+1850,int_stack+1300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15150,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+54040,int_stack+45990,int_stack+41490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32030,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+56740,int_stack+54040,int_stack+49080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33380,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+45990,int_stack+56740,int_stack+51240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35540,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+41490,int_stack+2720,int_stack+2510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12550, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+50190,int_stack+3000,int_stack+2720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12970, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+51030,int_stack+50190,int_stack+41490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24440, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+41490,int_stack+3360,int_stack+3000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13530, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+52290,int_stack+41490,int_stack+50190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25070, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+53970,int_stack+52290,int_stack+51030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25910, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+50190,int_stack+3810,int_stack+3360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14250, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+56070,int_stack+50190,int_stack+41490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27170, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+56070,int_stack+52290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28250, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+58230,int_stack+0,int_stack+53970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29930, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+51540,int_stack+4360,int_stack+3810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15150, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+53190,int_stack+51540,int_stack+50190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32030, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+61380,int_stack+53190,int_stack+56070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33380, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+50190,int_stack+61380,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35540, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+5230,int_stack+5020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12550, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+630,int_stack+5510,int_stack+5230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12970, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1470,int_stack+630,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24440, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2730,int_stack+5870,int_stack+5510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13530, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3810,int_stack+2730,int_stack+630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25070, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+61380,int_stack+3810,int_stack+1470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25910, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+41490,int_stack+6320,int_stack+5870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14250, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+41490,int_stack+2730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27170, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+54390,int_stack+0,int_stack+3810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28250, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2160,int_stack+54390,int_stack+61380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29930, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+61380,int_stack+6870,int_stack+6320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15150, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+63030,int_stack+61380,int_stack+41490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32030, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+65730,int_stack+63030,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33380, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+61380,int_stack+65730,int_stack+54390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35540, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+54390,int_stack+7740,int_stack+7530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+55020,int_stack+8020,int_stack+7740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+55860,int_stack+55020,int_stack+54390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+57120,int_stack+8380,int_stack+8020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+57120,int_stack+55020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+65580,int_stack+0,int_stack+55860, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+41490,int_stack+8830,int_stack+8380, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+54390,int_stack+41490,int_stack+57120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5310,int_stack+54390,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+67680,int_stack+5310,int_stack+65580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+65580,int_stack+9380,int_stack+8830, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+70830,int_stack+65580,int_stack+41490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+73530,int_stack+70830,int_stack+54390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+77130,int_stack+73530,int_stack+5310, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5310,int_stack+10250,int_stack+10040, 0.0, zero_stack, 1.0, int_stack+12550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5940,int_stack+10530,int_stack+10250, 0.0, zero_stack, 1.0, int_stack+12970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6780,int_stack+5940,int_stack+5310, 0.0, zero_stack, 1.0, int_stack+24440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8040,int_stack+10890,int_stack+10530, 0.0, zero_stack, 1.0, int_stack+13530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+9120,int_stack+8040,int_stack+5940, 0.0, zero_stack, 1.0, int_stack+25070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+65580,int_stack+9120,int_stack+6780, 0.0, zero_stack, 1.0, int_stack+25910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+41490,int_stack+11340,int_stack+10890, 0.0, zero_stack, 1.0, int_stack+14250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+41490,int_stack+8040, 0.0, zero_stack, 1.0, int_stack+27170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5310,int_stack+0,int_stack+9120, 0.0, zero_stack, 1.0, int_stack+28250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8110,int_stack+5310,int_stack+65580, 0.0, zero_stack, 1.0, int_stack+29930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+65580,int_stack+11890,int_stack+11340, 0.0, zero_stack, 1.0, int_stack+15150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+54390,int_stack+65580,int_stack+41490, 0.0, zero_stack, 1.0, int_stack+32030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+70830,int_stack+54390,int_stack+0, 0.0, zero_stack, 1.0, int_stack+33380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+81330,int_stack+70830,int_stack+5310, 0.0, zero_stack, 1.0, int_stack+35540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5310,int_stack+13250,int_stack+12760, 1.0, int_stack+12550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5940,int_stack+13890,int_stack+13250, 1.0, int_stack+12970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6780,int_stack+5940,int_stack+5310, 1.0, int_stack+24440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+70830,int_stack+14700,int_stack+13890, 1.0, int_stack+13530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+71910,int_stack+70830,int_stack+5940, 1.0, int_stack+25070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+65580,int_stack+71910,int_stack+6780, 1.0, int_stack+25910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+41490,int_stack+15700,int_stack+14700, 1.0, int_stack+14250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+41490,int_stack+70830, 1.0, int_stack+27170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5310,int_stack+0,int_stack+71910, 1.0, int_stack+28250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+70830,int_stack+5310,int_stack+65580, 1.0, int_stack+29930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+65580,int_stack+16250,int_stack+15700, 1.0, int_stack+15150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+73980,int_stack+65580,int_stack+41490, 1.0, int_stack+32030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+24440,int_stack+73980,int_stack+0, 1.0, int_stack+33380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+28040,int_stack+24440,int_stack+5310, 1.0, int_stack+35540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5310,int_stack+17120,int_stack+16910,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5940,int_stack+17400,int_stack+17120,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6780,int_stack+5940,int_stack+5310,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+24440,int_stack+17760,int_stack+17400,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+25520,int_stack+24440,int_stack+5940,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+65580,int_stack+25520,int_stack+6780,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+41490,int_stack+18210,int_stack+17760,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+41490,int_stack+24440,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5310,int_stack+0,int_stack+25520,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+73980,int_stack+5310,int_stack+65580,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+65580,int_stack+18760,int_stack+18210,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+24440,int_stack+65580,int_stack+41490,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+32240,int_stack+24440,int_stack+0,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+11260,int_stack+32240,int_stack+5310,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5310,int_stack+19630,int_stack+19420,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5940,int_stack+19910,int_stack+19630,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6780,int_stack+5940,int_stack+5310,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+32240,int_stack+20270,int_stack+19910,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+33320,int_stack+32240,int_stack+5940,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+65580,int_stack+33320,int_stack+6780,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+41490,int_stack+20720,int_stack+20270,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+41490,int_stack+32240,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5310,int_stack+0,int_stack+33320,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+32240,int_stack+5310,int_stack+65580,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+65580,int_stack+21270,int_stack+20720,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+35390,int_stack+65580,int_stack+41490,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+24440,int_stack+35390,int_stack+0,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+15460,int_stack+24440,int_stack+5310,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5310,int_stack+22140,int_stack+21930,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5940,int_stack+22420,int_stack+22140,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6780,int_stack+5940,int_stack+5310,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+24440,int_stack+22780,int_stack+22420,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+25520,int_stack+24440,int_stack+5940,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+65580,int_stack+25520,int_stack+6780,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+41490,int_stack+23230,int_stack+22780,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+41490,int_stack+24440,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5310,int_stack+0,int_stack+25520,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+24440,int_stack+5310,int_stack+65580,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+65580,int_stack+23780,int_stack+23230,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+35390,int_stack+65580,int_stack+41490,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+54390,int_stack+35390,int_stack+0,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+19660,int_stack+54390,int_stack+5310,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+85530,int_stack+45990,int_stack+42840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38340,10);
     Libderiv->ABCD[11] = int_stack + 85530;
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+41490,int_stack+50190,int_stack+58230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38340, 0.0, zero_stack,10);
     Libderiv->ABCD[10] = int_stack + 41490;
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+45900,int_stack+61380,int_stack+2160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38340, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[9] = int_stack + 45900;
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+0,int_stack+77130,int_stack+67680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+50310,int_stack+81330,int_stack+8110, 0.0, zero_stack, 1.0, int_stack+38340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[7] = int_stack + 50310;
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+77130,int_stack+28040,int_stack+70830, 1.0, int_stack+38340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[6] = int_stack + 77130;
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+4410,int_stack+11260,int_stack+73980,10);
     Libderiv->ABCD[2] = int_stack + 4410;
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+8820,int_stack+15460,int_stack+32240,10);
     Libderiv->ABCD[1] = int_stack + 8820;
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+13230,int_stack+19660,int_stack+24440,10);
     Libderiv->ABCD[0] = int_stack + 13230;

}
