/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_fdhh(Libderiv_t *, prim_data *);

  /* Computes derivatives of (fd|hh) integrals */

void d1hrr_order_fdhh(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][5][11] = int_stack + 0;
 Libderiv->deriv_classes[3][6][11] = int_stack + 210;
 Libderiv->deriv_classes[3][7][11] = int_stack + 490;
 Libderiv->deriv_classes[3][8][11] = int_stack + 850;
 Libderiv->deriv_classes[3][9][11] = int_stack + 1300;
 Libderiv->deriv_classes[3][10][11] = int_stack + 1850;
 Libderiv->deriv_classes[4][5][11] = int_stack + 2510;
 Libderiv->deriv_classes[4][6][11] = int_stack + 2825;
 Libderiv->deriv_classes[4][7][11] = int_stack + 3245;
 Libderiv->deriv_classes[4][8][11] = int_stack + 3785;
 Libderiv->deriv_classes[4][9][11] = int_stack + 4460;
 Libderiv->deriv_classes[4][10][11] = int_stack + 5285;
 Libderiv->deriv_classes[5][5][11] = int_stack + 6275;
 Libderiv->deriv_classes[5][6][11] = int_stack + 6716;
 Libderiv->deriv_classes[5][7][11] = int_stack + 7304;
 Libderiv->deriv_classes[5][8][11] = int_stack + 8060;
 Libderiv->deriv_classes[5][9][11] = int_stack + 9005;
 Libderiv->deriv_classes[5][10][11] = int_stack + 10160;
 Libderiv->deriv_classes[3][5][10] = int_stack + 11546;
 Libderiv->deriv_classes[3][6][10] = int_stack + 11756;
 Libderiv->deriv_classes[3][7][10] = int_stack + 12036;
 Libderiv->deriv_classes[3][8][10] = int_stack + 12396;
 Libderiv->deriv_classes[3][9][10] = int_stack + 12846;
 Libderiv->deriv_classes[3][10][10] = int_stack + 13396;
 Libderiv->deriv_classes[4][5][10] = int_stack + 14056;
 Libderiv->deriv_classes[4][6][10] = int_stack + 14371;
 Libderiv->deriv_classes[4][7][10] = int_stack + 14791;
 Libderiv->deriv_classes[4][8][10] = int_stack + 15331;
 Libderiv->deriv_classes[4][9][10] = int_stack + 16006;
 Libderiv->deriv_classes[4][10][10] = int_stack + 16831;
 Libderiv->deriv_classes[5][5][10] = int_stack + 17821;
 Libderiv->deriv_classes[5][6][10] = int_stack + 18262;
 Libderiv->deriv_classes[5][7][10] = int_stack + 18850;
 Libderiv->deriv_classes[5][8][10] = int_stack + 19606;
 Libderiv->deriv_classes[5][9][10] = int_stack + 20551;
 Libderiv->deriv_classes[5][10][10] = int_stack + 21706;
 Libderiv->deriv_classes[3][5][9] = int_stack + 23092;
 Libderiv->deriv_classes[3][6][9] = int_stack + 23302;
 Libderiv->deriv_classes[3][7][9] = int_stack + 23582;
 Libderiv->deriv_classes[3][8][9] = int_stack + 23942;
 Libderiv->deriv_classes[3][9][9] = int_stack + 24392;
 Libderiv->deriv_classes[3][10][9] = int_stack + 24942;
 Libderiv->deriv_classes[4][5][9] = int_stack + 25602;
 Libderiv->deriv_classes[4][6][9] = int_stack + 25917;
 Libderiv->deriv_classes[4][7][9] = int_stack + 26337;
 Libderiv->deriv_classes[4][8][9] = int_stack + 26877;
 Libderiv->deriv_classes[4][9][9] = int_stack + 27552;
 Libderiv->deriv_classes[4][10][9] = int_stack + 28377;
 Libderiv->deriv_classes[5][5][9] = int_stack + 29367;
 Libderiv->deriv_classes[5][6][9] = int_stack + 29808;
 Libderiv->deriv_classes[5][7][9] = int_stack + 30396;
 Libderiv->deriv_classes[5][8][9] = int_stack + 31152;
 Libderiv->deriv_classes[5][9][9] = int_stack + 32097;
 Libderiv->deriv_classes[5][10][9] = int_stack + 33252;
 Libderiv->deriv_classes[3][5][8] = int_stack + 34638;
 Libderiv->deriv_classes[3][6][8] = int_stack + 34848;
 Libderiv->deriv_classes[3][7][8] = int_stack + 35128;
 Libderiv->deriv_classes[3][8][8] = int_stack + 35488;
 Libderiv->deriv_classes[3][9][8] = int_stack + 35938;
 Libderiv->deriv_classes[3][10][8] = int_stack + 36488;
 Libderiv->deriv_classes[4][5][8] = int_stack + 37148;
 Libderiv->deriv_classes[4][6][8] = int_stack + 37463;
 Libderiv->deriv_classes[4][7][8] = int_stack + 37883;
 Libderiv->deriv_classes[4][8][8] = int_stack + 38423;
 Libderiv->deriv_classes[4][9][8] = int_stack + 39098;
 Libderiv->deriv_classes[4][10][8] = int_stack + 39923;
 Libderiv->deriv_classes[5][5][8] = int_stack + 40913;
 Libderiv->deriv_classes[5][6][8] = int_stack + 41354;
 Libderiv->deriv_classes[5][7][8] = int_stack + 41942;
 Libderiv->deriv_classes[5][8][8] = int_stack + 42698;
 Libderiv->deriv_classes[5][9][8] = int_stack + 43643;
 Libderiv->deriv_classes[5][10][8] = int_stack + 44798;
 Libderiv->deriv_classes[3][5][7] = int_stack + 46184;
 Libderiv->deriv_classes[3][6][7] = int_stack + 46394;
 Libderiv->deriv_classes[3][7][7] = int_stack + 46674;
 Libderiv->deriv_classes[3][8][7] = int_stack + 47034;
 Libderiv->deriv_classes[3][9][7] = int_stack + 47484;
 Libderiv->deriv_classes[3][10][7] = int_stack + 48034;
 Libderiv->deriv_classes[4][5][7] = int_stack + 48694;
 Libderiv->deriv_classes[4][6][7] = int_stack + 49009;
 Libderiv->deriv_classes[4][7][7] = int_stack + 49429;
 Libderiv->deriv_classes[4][8][7] = int_stack + 49969;
 Libderiv->deriv_classes[4][9][7] = int_stack + 50644;
 Libderiv->deriv_classes[4][10][7] = int_stack + 51469;
 Libderiv->deriv_classes[5][5][7] = int_stack + 52459;
 Libderiv->deriv_classes[5][6][7] = int_stack + 52900;
 Libderiv->deriv_classes[5][7][7] = int_stack + 53488;
 Libderiv->deriv_classes[5][8][7] = int_stack + 54244;
 Libderiv->deriv_classes[5][9][7] = int_stack + 55189;
 Libderiv->deriv_classes[5][10][7] = int_stack + 56344;
 Libderiv->deriv_classes[3][5][6] = int_stack + 57730;
 Libderiv->deriv_classes[3][6][6] = int_stack + 57940;
 Libderiv->deriv_classes[3][7][6] = int_stack + 58220;
 Libderiv->deriv_classes[3][8][6] = int_stack + 58580;
 Libderiv->deriv_classes[3][9][6] = int_stack + 59030;
 Libderiv->deriv_classes[3][10][6] = int_stack + 59580;
 Libderiv->deriv_classes[4][5][6] = int_stack + 60240;
 Libderiv->deriv_classes[4][6][6] = int_stack + 60555;
 Libderiv->deriv_classes[4][7][6] = int_stack + 60975;
 Libderiv->deriv_classes[4][8][6] = int_stack + 61515;
 Libderiv->deriv_classes[4][9][6] = int_stack + 62190;
 Libderiv->deriv_classes[4][10][6] = int_stack + 63015;
 Libderiv->dvrr_classes[5][5] = int_stack + 64005;
 Libderiv->deriv_classes[5][5][6] = int_stack + 64446;
 Libderiv->dvrr_classes[5][6] = int_stack + 64887;
 Libderiv->deriv_classes[5][6][6] = int_stack + 65475;
 Libderiv->dvrr_classes[5][7] = int_stack + 66063;
 Libderiv->deriv_classes[5][7][6] = int_stack + 66819;
 Libderiv->dvrr_classes[5][8] = int_stack + 67575;
 Libderiv->deriv_classes[5][8][6] = int_stack + 68520;
 Libderiv->dvrr_classes[5][9] = int_stack + 69465;
 Libderiv->deriv_classes[5][9][6] = int_stack + 70620;
 Libderiv->deriv_classes[5][10][6] = int_stack + 71775;
 Libderiv->deriv_classes[3][5][2] = int_stack + 73161;
 Libderiv->deriv_classes[3][6][2] = int_stack + 73371;
 Libderiv->deriv_classes[3][7][2] = int_stack + 73651;
 Libderiv->deriv_classes[3][8][2] = int_stack + 74011;
 Libderiv->deriv_classes[3][9][2] = int_stack + 74461;
 Libderiv->deriv_classes[3][10][2] = int_stack + 75011;
 Libderiv->deriv_classes[4][5][2] = int_stack + 75671;
 Libderiv->deriv_classes[4][6][2] = int_stack + 75986;
 Libderiv->deriv_classes[4][7][2] = int_stack + 76406;
 Libderiv->deriv_classes[4][8][2] = int_stack + 76946;
 Libderiv->deriv_classes[4][9][2] = int_stack + 77621;
 Libderiv->deriv_classes[4][10][2] = int_stack + 78446;
 Libderiv->deriv_classes[5][5][2] = int_stack + 79436;
 Libderiv->deriv_classes[5][6][2] = int_stack + 79877;
 Libderiv->deriv_classes[5][7][2] = int_stack + 80465;
 Libderiv->deriv_classes[5][8][2] = int_stack + 81221;
 Libderiv->deriv_classes[5][9][2] = int_stack + 82166;
 Libderiv->deriv_classes[5][10][2] = int_stack + 83321;
 Libderiv->deriv_classes[3][5][1] = int_stack + 84707;
 Libderiv->deriv_classes[3][6][1] = int_stack + 84917;
 Libderiv->deriv_classes[3][7][1] = int_stack + 85197;
 Libderiv->deriv_classes[3][8][1] = int_stack + 85557;
 Libderiv->deriv_classes[3][9][1] = int_stack + 86007;
 Libderiv->deriv_classes[3][10][1] = int_stack + 86557;
 Libderiv->deriv_classes[4][5][1] = int_stack + 87217;
 Libderiv->deriv_classes[4][6][1] = int_stack + 87532;
 Libderiv->deriv_classes[4][7][1] = int_stack + 87952;
 Libderiv->deriv_classes[4][8][1] = int_stack + 88492;
 Libderiv->deriv_classes[4][9][1] = int_stack + 89167;
 Libderiv->deriv_classes[4][10][1] = int_stack + 89992;
 Libderiv->deriv_classes[5][5][1] = int_stack + 90982;
 Libderiv->deriv_classes[5][6][1] = int_stack + 91423;
 Libderiv->deriv_classes[5][7][1] = int_stack + 92011;
 Libderiv->deriv_classes[5][8][1] = int_stack + 92767;
 Libderiv->deriv_classes[5][9][1] = int_stack + 93712;
 Libderiv->deriv_classes[5][10][1] = int_stack + 94867;
 Libderiv->dvrr_classes[3][5] = int_stack + 96253;
 Libderiv->dvrr_classes[3][6] = int_stack + 96463;
 Libderiv->dvrr_classes[3][7] = int_stack + 96743;
 Libderiv->dvrr_classes[3][8] = int_stack + 97103;
 Libderiv->dvrr_classes[3][9] = int_stack + 97553;
 Libderiv->dvrr_classes[3][10] = int_stack + 98103;
 Libderiv->deriv_classes[3][5][0] = int_stack + 98763;
 Libderiv->deriv_classes[3][6][0] = int_stack + 98973;
 Libderiv->deriv_classes[3][7][0] = int_stack + 99253;
 Libderiv->deriv_classes[3][8][0] = int_stack + 99613;
 Libderiv->deriv_classes[3][9][0] = int_stack + 100063;
 Libderiv->deriv_classes[3][10][0] = int_stack + 100613;
 Libderiv->dvrr_classes[4][5] = int_stack + 101273;
 Libderiv->dvrr_classes[4][6] = int_stack + 101588;
 Libderiv->dvrr_classes[4][7] = int_stack + 102008;
 Libderiv->dvrr_classes[4][8] = int_stack + 102548;
 Libderiv->dvrr_classes[4][9] = int_stack + 103223;
 Libderiv->dvrr_classes[4][10] = int_stack + 104048;
 Libderiv->deriv_classes[4][5][0] = int_stack + 105038;
 Libderiv->deriv_classes[4][6][0] = int_stack + 105353;
 Libderiv->deriv_classes[4][7][0] = int_stack + 105773;
 Libderiv->deriv_classes[4][8][0] = int_stack + 106313;
 Libderiv->deriv_classes[4][9][0] = int_stack + 106988;
 Libderiv->deriv_classes[4][10][0] = int_stack + 107813;
 Libderiv->deriv_classes[5][5][0] = int_stack + 108803;
 Libderiv->deriv_classes[5][6][0] = int_stack + 109244;
 Libderiv->deriv_classes[5][7][0] = int_stack + 109832;
 Libderiv->deriv_classes[5][8][0] = int_stack + 110588;
 Libderiv->deriv_classes[5][9][0] = int_stack + 111533;
 Libderiv->deriv_classes[5][10][0] = int_stack + 112688;
 memset(int_stack,0,912592);

 Libderiv->dvrr_stack = int_stack + 422037;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_fdhh(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+114074,int_stack+96463,int_stack+96253,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+114704,int_stack+96743,int_stack+96463,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+115544,int_stack+114704,int_stack+114074,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+116804,int_stack+97103,int_stack+96743,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+117884,int_stack+116804,int_stack+114704,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+119564,int_stack+117884,int_stack+115544,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+121664,int_stack+97553,int_stack+97103,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+123014,int_stack+121664,int_stack+116804,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+125174,int_stack+123014,int_stack+117884,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+127974,int_stack+125174,int_stack+119564,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+131124,int_stack+210,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96253,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+131754,int_stack+490,int_stack+210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96463,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+132594,int_stack+131754,int_stack+131124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114074,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+133854,int_stack+850,int_stack+490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96743,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+134934,int_stack+133854,int_stack+131754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114704,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+136614,int_stack+134934,int_stack+132594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115544,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+131124,int_stack+1300,int_stack+850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97103,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+138714,int_stack+131124,int_stack+133854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116804,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+140874,int_stack+138714,int_stack+134934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117884,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+132474,int_stack+140874,int_stack+136614, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119564,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+135624,int_stack+1850,int_stack+1300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97553,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+143674,int_stack+135624,int_stack+131124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121664,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+146374,int_stack+143674,int_stack+138714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123014,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+135624,int_stack+146374,int_stack+140874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125174,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+139824,int_stack+135624,int_stack+132474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127974,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+131124,int_stack+101588,int_stack+101273,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+132069,int_stack+102008,int_stack+101588,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+133329,int_stack+132069,int_stack+131124,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+135219,int_stack+102548,int_stack+102008,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+136839,int_stack+135219,int_stack+132069,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+144234,int_stack+136839,int_stack+133329,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+147384,int_stack+103223,int_stack+102548,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+149409,int_stack+147384,int_stack+135219,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+152649,int_stack+149409,int_stack+136839,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+156849,int_stack+152649,int_stack+144234,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+2825,int_stack+2510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101273,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+945,int_stack+3245,int_stack+2825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101588,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+161574,int_stack+945,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131124,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+163464,int_stack+3785,int_stack+3245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102008,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+165084,int_stack+163464,int_stack+945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132069,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+165084,int_stack+161574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+133329,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+167604,int_stack+4460,int_stack+3785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102548,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+169629,int_stack+167604,int_stack+163464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135219,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+172869,int_stack+169629,int_stack+165084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136839,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+161574,int_stack+172869,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144234,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+5285,int_stack+4460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103223,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+177069,int_stack+0,int_stack+167604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147384,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+177069,int_stack+169629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149409,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+166299,int_stack+0,int_stack+172869, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152649,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+172599,int_stack+166299,int_stack+161574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156849,15);
 /*--- compute (fp|hh) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+179214,int_stack+172599,int_stack+139824,441);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+161574,int_stack+64887,int_stack+64005,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+162897,int_stack+66063,int_stack+64887,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+164661,int_stack+162897,int_stack+161574,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+167307,int_stack+67575,int_stack+66063,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+167307,int_stack+162897,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+139359,int_stack+0,int_stack+164661,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+169575,int_stack+69465,int_stack+67575,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+192444,int_stack+169575,int_stack+167307,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+196980,int_stack+192444,int_stack+0,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+202860,int_stack+196980,int_stack+139359,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3528,int_stack+6716,int_stack+6275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64005,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4851,int_stack+7304,int_stack+6716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64887,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+209475,int_stack+4851,int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161574,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+212121,int_stack+8060,int_stack+7304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66063,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+214389,int_stack+212121,int_stack+4851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162897,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3528,int_stack+214389,int_stack+209475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164661,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+217917,int_stack+9005,int_stack+8060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67575,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+220752,int_stack+217917,int_stack+212121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167307,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+225288,int_stack+220752,int_stack+214389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+209475,int_stack+225288,int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139359,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3528,int_stack+10160,int_stack+9005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69465,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+231168,int_stack+3528,int_stack+217917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169575,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3528,int_stack+231168,int_stack+220752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192444,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+216090,int_stack+3528,int_stack+225288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196980,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+224910,int_stack+216090,int_stack+209475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202860,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+234171,int_stack+224910,int_stack+172599,441);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+209475,int_stack+11756,int_stack+11546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96253, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+210105,int_stack+12036,int_stack+11756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96463, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+210945,int_stack+210105,int_stack+209475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114074, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+212205,int_stack+12396,int_stack+12036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96743, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+213285,int_stack+212205,int_stack+210105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114704, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+214965,int_stack+213285,int_stack+210945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115544, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+209475,int_stack+12846,int_stack+12396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97103, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+217065,int_stack+209475,int_stack+212205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116804, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+219225,int_stack+217065,int_stack+213285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117884, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+210825,int_stack+219225,int_stack+214965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119564, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+213975,int_stack+13396,int_stack+12846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97553, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+222025,int_stack+213975,int_stack+209475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121664, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+224725,int_stack+222025,int_stack+217065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123014, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+213975,int_stack+224725,int_stack+219225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125174, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+218175,int_stack+213975,int_stack+210825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127974, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+209475,int_stack+14371,int_stack+14056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101273, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+210420,int_stack+14791,int_stack+14371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101588, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+211680,int_stack+210420,int_stack+209475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131124, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+213570,int_stack+15331,int_stack+14791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102008, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+215190,int_stack+213570,int_stack+210420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132069, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+222585,int_stack+215190,int_stack+211680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+133329, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+209475,int_stack+16006,int_stack+15331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102548, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+225735,int_stack+209475,int_stack+213570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135219, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+228975,int_stack+225735,int_stack+215190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136839, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+211500,int_stack+228975,int_stack+222585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144234, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+222585,int_stack+16831,int_stack+16006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103223, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3528,int_stack+222585,int_stack+209475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147384, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+7578,int_stack+3528,int_stack+225735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149409, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+222585,int_stack+7578,int_stack+228975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152649, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3528,int_stack+222585,int_stack+211500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156849, 0.0, zero_stack,15);
 /*--- compute (fp|hh) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+254016,int_stack+3528,int_stack+218175,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10143,int_stack+18262,int_stack+17821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64005, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11466,int_stack+18850,int_stack+18262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64887, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13230,int_stack+11466,int_stack+10143, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161574, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+15876,int_stack+19606,int_stack+18850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66063, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+209475,int_stack+15876,int_stack+11466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162897, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+213003,int_stack+209475,int_stack+13230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164661, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10143,int_stack+20551,int_stack+19606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67575, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+217413,int_stack+10143,int_stack+15876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167307, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12978,int_stack+217413,int_stack+209475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+221949,int_stack+12978,int_stack+213003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139359, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+209475,int_stack+21706,int_stack+20551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69465, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+172410,int_stack+209475,int_stack+10143, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169575, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+209475,int_stack+172410,int_stack+217413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192444, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+267246,int_stack+209475,int_stack+12978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196980, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+209475,int_stack+267246,int_stack+221949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202860, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+267246,int_stack+209475,int_stack+3528,441);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3528,int_stack+23302,int_stack+23092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96253, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4158,int_stack+23582,int_stack+23302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96463, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4998,int_stack+4158,int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114074, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6258,int_stack+23942,int_stack+23582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96743, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7338,int_stack+6258,int_stack+4158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114704, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+9018,int_stack+7338,int_stack+4998, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115544, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3528,int_stack+24392,int_stack+23942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97103, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11118,int_stack+3528,int_stack+6258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116804, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13278,int_stack+11118,int_stack+7338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117884, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4878,int_stack+13278,int_stack+9018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119564, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8028,int_stack+24942,int_stack+24392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97553, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+16078,int_stack+8028,int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121664, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+18778,int_stack+16078,int_stack+11118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123014, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8028,int_stack+18778,int_stack+13278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125174, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+12228,int_stack+8028,int_stack+4878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127974, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3528,int_stack+25917,int_stack+25602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101273, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4473,int_stack+26337,int_stack+25917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101588, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5733,int_stack+4473,int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131124, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7623,int_stack+26877,int_stack+26337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102008, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+9243,int_stack+7623,int_stack+4473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132069, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+16638,int_stack+9243,int_stack+5733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+133329, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3528,int_stack+27552,int_stack+26877, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102548, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+19788,int_stack+3528,int_stack+7623, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135219, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+23028,int_stack+19788,int_stack+9243, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136839, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5553,int_stack+23028,int_stack+16638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144234, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+16638,int_stack+28377,int_stack+27552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103223, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+209475,int_stack+16638,int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147384, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+213525,int_stack+209475,int_stack+19788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149409, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+16638,int_stack+213525,int_stack+23028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152649, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+209475,int_stack+16638,int_stack+5553, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156849, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hh) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+216090,int_stack+209475,int_stack+12228,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+229320,int_stack+29808,int_stack+29367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64005, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+230643,int_stack+30396,int_stack+29808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64887, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3528,int_stack+230643,int_stack+229320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161574, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6174,int_stack+31152,int_stack+30396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66063, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8442,int_stack+6174,int_stack+230643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162897, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+229320,int_stack+8442,int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164661, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+11970,int_stack+32097,int_stack+31152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67575, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+14805,int_stack+11970,int_stack+6174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167307, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+19341,int_stack+14805,int_stack+8442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3528,int_stack+19341,int_stack+229320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139359, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+229320,int_stack+33252,int_stack+32097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69465, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+25221,int_stack+229320,int_stack+11970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169575, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+287091,int_stack+25221,int_stack+14805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192444, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+25221,int_stack+287091,int_stack+19341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196980, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+10143,int_stack+25221,int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202860, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+287091,int_stack+10143,int_stack+209475,441);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+209475,int_stack+34848,int_stack+34638, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+210105,int_stack+35128,int_stack+34848, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+210945,int_stack+210105,int_stack+209475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+212205,int_stack+35488,int_stack+35128, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+213285,int_stack+212205,int_stack+210105, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3528,int_stack+213285,int_stack+210945, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+209475,int_stack+35938,int_stack+35488, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5628,int_stack+209475,int_stack+212205, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7788,int_stack+5628,int_stack+213285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+117884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+210825,int_stack+7788,int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3528,int_stack+36488,int_stack+35938, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97553, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10588,int_stack+3528,int_stack+209475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13288,int_stack+10588,int_stack+5628, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3528,int_stack+13288,int_stack+7788, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+7728,int_stack+3528,int_stack+210825, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3528,int_stack+37463,int_stack+37148, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101273, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4473,int_stack+37883,int_stack+37463, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5733,int_stack+4473,int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+209475,int_stack+38423,int_stack+37883, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+211095,int_stack+209475,int_stack+4473, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12138,int_stack+211095,int_stack+5733, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+133329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3528,int_stack+39098,int_stack+38423, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+15288,int_stack+3528,int_stack+209475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+18528,int_stack+15288,int_stack+211095, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+209475,int_stack+18528,int_stack+12138, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+12138,int_stack+39923,int_stack+39098, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+22728,int_stack+12138,int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+26778,int_stack+22728,int_stack+15288, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149409, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12138,int_stack+26778,int_stack+18528, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+18438,int_stack+12138,int_stack+209475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hh) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+25053,int_stack+18438,int_stack+7728,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+209475,int_stack+41354,int_stack+40913, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+210798,int_stack+41942,int_stack+41354, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+212562,int_stack+210798,int_stack+209475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+161574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3528,int_stack+42698,int_stack+41942, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66063, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5796,int_stack+3528,int_stack+210798, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+9324,int_stack+5796,int_stack+212562, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+164661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+209475,int_stack+43643,int_stack+42698, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13734,int_stack+209475,int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+172410,int_stack+13734,int_stack+5796, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+306936,int_stack+172410,int_stack+9324, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3528,int_stack+44798,int_stack+43643, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6993,int_stack+3528,int_stack+209475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+38283,int_stack+6993,int_stack+13734, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3528,int_stack+38283,int_stack+172410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+313551,int_stack+3528,int_stack+306936, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+322812,int_stack+313551,int_stack+18438,441);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+306936,int_stack+46394,int_stack+46184, 0.0, zero_stack, 1.0, int_stack+96253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+307566,int_stack+46674,int_stack+46394, 0.0, zero_stack, 1.0, int_stack+96463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+308406,int_stack+307566,int_stack+306936, 0.0, zero_stack, 1.0, int_stack+114074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+309666,int_stack+47034,int_stack+46674, 0.0, zero_stack, 1.0, int_stack+96743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+310746,int_stack+309666,int_stack+307566, 0.0, zero_stack, 1.0, int_stack+114704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+312426,int_stack+310746,int_stack+308406, 0.0, zero_stack, 1.0, int_stack+115544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+306936,int_stack+47484,int_stack+47034, 0.0, zero_stack, 1.0, int_stack+97103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+314526,int_stack+306936,int_stack+309666, 0.0, zero_stack, 1.0, int_stack+116804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+316686,int_stack+314526,int_stack+310746, 0.0, zero_stack, 1.0, int_stack+117884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+308286,int_stack+316686,int_stack+312426, 0.0, zero_stack, 1.0, int_stack+119564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+311436,int_stack+48034,int_stack+47484, 0.0, zero_stack, 1.0, int_stack+97553, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+319486,int_stack+311436,int_stack+306936, 0.0, zero_stack, 1.0, int_stack+121664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3528,int_stack+319486,int_stack+314526, 0.0, zero_stack, 1.0, int_stack+123014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+311436,int_stack+3528,int_stack+316686, 0.0, zero_stack, 1.0, int_stack+125174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3528,int_stack+311436,int_stack+308286, 0.0, zero_stack, 1.0, int_stack+127974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7938,int_stack+49009,int_stack+48694, 0.0, zero_stack, 1.0, int_stack+101273, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8883,int_stack+49429,int_stack+49009, 0.0, zero_stack, 1.0, int_stack+101588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10143,int_stack+8883,int_stack+7938, 0.0, zero_stack, 1.0, int_stack+131124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12033,int_stack+49969,int_stack+49429, 0.0, zero_stack, 1.0, int_stack+102008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13653,int_stack+12033,int_stack+8883, 0.0, zero_stack, 1.0, int_stack+132069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+16173,int_stack+13653,int_stack+10143, 0.0, zero_stack, 1.0, int_stack+133329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7938,int_stack+50644,int_stack+49969, 0.0, zero_stack, 1.0, int_stack+102548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+19323,int_stack+7938,int_stack+12033, 0.0, zero_stack, 1.0, int_stack+135219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+306936,int_stack+19323,int_stack+13653, 0.0, zero_stack, 1.0, int_stack+136839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+9963,int_stack+306936,int_stack+16173, 0.0, zero_stack, 1.0, int_stack+144234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+14688,int_stack+51469,int_stack+50644, 0.0, zero_stack, 1.0, int_stack+103223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+311136,int_stack+14688,int_stack+7938, 0.0, zero_stack, 1.0, int_stack+147384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+315186,int_stack+311136,int_stack+19323, 0.0, zero_stack, 1.0, int_stack+149409, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+14688,int_stack+315186,int_stack+306936, 0.0, zero_stack, 1.0, int_stack+152649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+209475,int_stack+14688,int_stack+9963, 0.0, zero_stack, 1.0, int_stack+156849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hh) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+306936,int_stack+209475,int_stack+3528,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3528,int_stack+52900,int_stack+52459, 0.0, zero_stack, 1.0, int_stack+64005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4851,int_stack+53488,int_stack+52900, 0.0, zero_stack, 1.0, int_stack+64887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+320166,int_stack+4851,int_stack+3528, 0.0, zero_stack, 1.0, int_stack+161574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6615,int_stack+54244,int_stack+53488, 0.0, zero_stack, 1.0, int_stack+66063, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8883,int_stack+6615,int_stack+4851, 0.0, zero_stack, 1.0, int_stack+162897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12411,int_stack+8883,int_stack+320166, 0.0, zero_stack, 1.0, int_stack+164661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3528,int_stack+55189,int_stack+54244, 0.0, zero_stack, 1.0, int_stack+67575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+16821,int_stack+3528,int_stack+6615, 0.0, zero_stack, 1.0, int_stack+167307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+172410,int_stack+16821,int_stack+8883, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+38283,int_stack+172410,int_stack+12411, 0.0, zero_stack, 1.0, int_stack+139359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6363,int_stack+56344,int_stack+55189, 0.0, zero_stack, 1.0, int_stack+69465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+9828,int_stack+6363,int_stack+3528, 0.0, zero_stack, 1.0, int_stack+169575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+44898,int_stack+9828,int_stack+16821, 0.0, zero_stack, 1.0, int_stack+192444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3528,int_stack+44898,int_stack+172410, 0.0, zero_stack, 1.0, int_stack+196980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+44898,int_stack+3528,int_stack+38283, 0.0, zero_stack, 1.0, int_stack+202860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3528,int_stack+44898,int_stack+209475,441);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+209475,int_stack+57940,int_stack+57730, 1.0, int_stack+96253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+210105,int_stack+58220,int_stack+57940, 1.0, int_stack+96463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+210945,int_stack+210105,int_stack+209475, 1.0, int_stack+114074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+212205,int_stack+58580,int_stack+58220, 1.0, int_stack+96743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+23373,int_stack+212205,int_stack+210105, 1.0, int_stack+114704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+213285,int_stack+23373,int_stack+210945, 1.0, int_stack+115544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+114074,int_stack+59030,int_stack+58580, 1.0, int_stack+97103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+209475,int_stack+114074,int_stack+212205, 1.0, int_stack+116804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+38283,int_stack+209475,int_stack+23373, 1.0, int_stack+117884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+115424,int_stack+38283,int_stack+213285, 1.0, int_stack+119564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+23373,int_stack+59580,int_stack+59030, 1.0, int_stack+97553, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+118574,int_stack+23373,int_stack+114074, 1.0, int_stack+121664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+211635,int_stack+118574,int_stack+209475, 1.0, int_stack+123014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+41083,int_stack+211635,int_stack+38283, 1.0, int_stack+125174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+209475,int_stack+41083,int_stack+115424, 1.0, int_stack+127974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38283,int_stack+60555,int_stack+60240, 1.0, int_stack+101273, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+39228,int_stack+60975,int_stack+60555, 1.0, int_stack+101588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+40488,int_stack+39228,int_stack+38283, 1.0, int_stack+131124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+42378,int_stack+61515,int_stack+60975, 1.0, int_stack+102008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+43998,int_stack+42378,int_stack+39228, 1.0, int_stack+132069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+46518,int_stack+43998,int_stack+40488, 1.0, int_stack+133329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+131124,int_stack+62190,int_stack+61515, 1.0, int_stack+102548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+38283,int_stack+131124,int_stack+42378, 1.0, int_stack+135219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+49668,int_stack+38283,int_stack+43998, 1.0, int_stack+136839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+133149,int_stack+49668,int_stack+46518, 1.0, int_stack+144234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+41523,int_stack+63015,int_stack+62190, 1.0, int_stack+103223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+43998,int_stack+41523,int_stack+131124, 1.0, int_stack+147384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+53868,int_stack+43998,int_stack+38283, 1.0, int_stack+149409, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+38283,int_stack+53868,int_stack+49668, 1.0, int_stack+152649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+44583,int_stack+38283,int_stack+133149, 1.0, int_stack+156849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hh) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+342657,int_stack+44583,int_stack+209475,441);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+209475,int_stack+65475,int_stack+64446, 1.0, int_stack+64005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+210798,int_stack+66819,int_stack+65475, 1.0, int_stack+64887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+320166,int_stack+210798,int_stack+209475, 1.0, int_stack+161574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+212562,int_stack+68520,int_stack+66819, 1.0, int_stack+66063, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+38283,int_stack+212562,int_stack+210798, 1.0, int_stack+162897, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+51198,int_stack+38283,int_stack+320166, 1.0, int_stack+164661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+161574,int_stack+70620,int_stack+68520, 1.0, int_stack+67575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+55608,int_stack+161574,int_stack+212562, 1.0, int_stack+167307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+209475,int_stack+55608,int_stack+38283, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+60144,int_stack+209475,int_stack+51198, 1.0, int_stack+139359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+51198,int_stack+71775,int_stack+70620, 1.0, int_stack+69465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+38283,int_stack+51198,int_stack+161574, 1.0, int_stack+169575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+161574,int_stack+38283,int_stack+55608, 1.0, int_stack+192444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+169134,int_stack+161574,int_stack+209475, 1.0, int_stack+196980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+192444,int_stack+169134,int_stack+60144, 1.0, int_stack+202860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+51198,int_stack+192444,int_stack+44583,441);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+192444,int_stack+98103,int_stack+97553,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+194094,int_stack+192444,int_stack+121664,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+196794,int_stack+194094,int_stack+123014,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+192444,int_stack+196794,int_stack+125174,10);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+196644,int_stack+192444,int_stack+127974,10);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+192444,int_stack+104048,int_stack+103223,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+201054,int_stack+192444,int_stack+147384,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+205104,int_stack+201054,int_stack+149409,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+161574,int_stack+205104,int_stack+152649,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+201054,int_stack+161574,int_stack+156849,15);
 /*--- compute (fp|hh) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+114074,int_stack+201054,int_stack+196644,441);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+207669,int_stack+73371,int_stack+73161,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+208299,int_stack+73651,int_stack+73371,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+209139,int_stack+208299,int_stack+207669,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+210399,int_stack+74011,int_stack+73651,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+23373,int_stack+210399,int_stack+208299,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+211479,int_stack+23373,int_stack+209139,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+207669,int_stack+74461,int_stack+74011,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+213579,int_stack+207669,int_stack+210399,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+192444,int_stack+213579,int_stack+23373,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+38283,int_stack+192444,int_stack+211479,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+23373,int_stack+75011,int_stack+74461,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+209019,int_stack+23373,int_stack+207669,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+41433,int_stack+209019,int_stack+213579,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+207669,int_stack+41433,int_stack+192444,10);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+41433,int_stack+207669,int_stack+38283,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+38283,int_stack+75986,int_stack+75671,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+39228,int_stack+76406,int_stack+75986,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+207669,int_stack+39228,int_stack+38283,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+209559,int_stack+76946,int_stack+76406,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+211179,int_stack+209559,int_stack+39228,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+38283,int_stack+211179,int_stack+207669,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+213699,int_stack+77621,int_stack+76946,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+192444,int_stack+213699,int_stack+209559,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+45843,int_stack+192444,int_stack+211179,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+207669,int_stack+45843,int_stack+38283,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+38283,int_stack+78446,int_stack+77621,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+71043,int_stack+38283,int_stack+213699,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+127304,int_stack+71043,int_stack+192444,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+71043,int_stack+127304,int_stack+45843,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+127304,int_stack+71043,int_stack+207669,15);
 /*--- compute (fp|hh) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+133919,int_stack+127304,int_stack+41433, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+207669,int_stack+79877,int_stack+79436,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+208992,int_stack+80465,int_stack+79877,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+320166,int_stack+208992,int_stack+207669,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+210756,int_stack+81221,int_stack+80465,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+210756,int_stack+208992,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+71043,int_stack+0,int_stack+320166,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+207669,int_stack+82166,int_stack+81221,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+75453,int_stack+207669,int_stack+210756,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+147149,int_stack+75453,int_stack+0,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+153029,int_stack+147149,int_stack+71043,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+71043,int_stack+83321,int_stack+82166,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+159644,int_stack+71043,int_stack+207669,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+207669,int_stack+159644,int_stack+75453,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+159644,int_stack+207669,int_stack+147149,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+168464,int_stack+159644,int_stack+153029,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+147149,int_stack+168464,int_stack+127304, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+127304,int_stack+84917,int_stack+84707,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+127934,int_stack+85197,int_stack+84917,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+128774,int_stack+127934,int_stack+127304,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+130034,int_stack+85557,int_stack+85197,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+23373,int_stack+130034,int_stack+127934,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+131114,int_stack+23373,int_stack+128774,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+127304,int_stack+86007,int_stack+85557,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+166994,int_stack+127304,int_stack+130034,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+169154,int_stack+166994,int_stack+23373,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+171954,int_stack+169154,int_stack+131114,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+23373,int_stack+86557,int_stack+86007,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+128654,int_stack+23373,int_stack+127304,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+175104,int_stack+128654,int_stack+166994,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+192444,int_stack+175104,int_stack+169154,10);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+166994,int_stack+192444,int_stack+171954,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+192444,int_stack+87532,int_stack+87217,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+193389,int_stack+87952,int_stack+87532,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+194649,int_stack+193389,int_stack+192444,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+171404,int_stack+88492,int_stack+87952,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+173024,int_stack+171404,int_stack+193389,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+175544,int_stack+173024,int_stack+194649,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+192444,int_stack+89167,int_stack+88492,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+127304,int_stack+192444,int_stack+171404,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+207669,int_stack+127304,int_stack+173024,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+71043,int_stack+207669,int_stack+175544,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+171404,int_stack+89992,int_stack+89167,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+173879,int_stack+171404,int_stack+192444,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+75768,int_stack+173879,int_stack+127304,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+127304,int_stack+75768,int_stack+207669,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+207669,int_stack+127304,int_stack+71043,15);
 /*--- compute (fp|hh) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+71043,int_stack+207669,int_stack+166994, 0.0, zero_stack, 1.0, int_stack+196644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+166994,int_stack+91423,int_stack+90982,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+168317,int_stack+92011,int_stack+91423,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+320166,int_stack+168317,int_stack+166994,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+170081,int_stack+92767,int_stack+92011,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+170081,int_stack+168317,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+172349,int_stack+0,int_stack+320166,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+166994,int_stack+93712,int_stack+92767,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+84273,int_stack+166994,int_stack+170081,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+127304,int_stack+84273,int_stack+0,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+38283,int_stack+127304,int_stack+172349,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+94867,int_stack+93712,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+169829,int_stack+0,int_stack+166994,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+88809,int_stack+169829,int_stack+84273,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+166994,int_stack+88809,int_stack+127304,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+84273,int_stack+166994,int_stack+38283,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+355887,int_stack+84273,int_stack+207669, 0.0, zero_stack, 1.0, int_stack+201054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+207669,int_stack+98973,int_stack+98763,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+208299,int_stack+99253,int_stack+98973,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+209139,int_stack+208299,int_stack+207669,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+210399,int_stack+99613,int_stack+99253,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+23373,int_stack+210399,int_stack+208299,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+211479,int_stack+23373,int_stack+209139,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+207669,int_stack+100063,int_stack+99613,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+213579,int_stack+207669,int_stack+210399,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+84273,int_stack+213579,int_stack+23373,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+87073,int_stack+84273,int_stack+211479,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+23373,int_stack+100613,int_stack+100063,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+209019,int_stack+23373,int_stack+207669,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+90223,int_stack+209019,int_stack+213579,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+192444,int_stack+90223,int_stack+84273,10);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+90223,int_stack+192444,int_stack+87073,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+192444,int_stack+105353,int_stack+105038,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+193389,int_stack+105773,int_stack+105353,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+194649,int_stack+193389,int_stack+192444,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+84273,int_stack+106313,int_stack+105773,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+85893,int_stack+84273,int_stack+193389,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+94633,int_stack+85893,int_stack+194649,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+192444,int_stack+106988,int_stack+106313,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+97783,int_stack+192444,int_stack+84273,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+101023,int_stack+97783,int_stack+85893,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+84273,int_stack+101023,int_stack+94633,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+94633,int_stack+107813,int_stack+106988,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+207669,int_stack+94633,int_stack+192444,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+38283,int_stack+207669,int_stack+97783,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+207669,int_stack+38283,int_stack+101023,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+127304,int_stack+207669,int_stack+84273,15);
 /*--- compute (fp|hh) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+94633,int_stack+127304,int_stack+90223, 1.0, int_stack+196644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+84273,int_stack+109244,int_stack+108803,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+85596,int_stack+109832,int_stack+109244,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+320166,int_stack+85596,int_stack+84273,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+87360,int_stack+110588,int_stack+109832,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+87360,int_stack+85596,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+89628,int_stack+0,int_stack+320166,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+84273,int_stack+111533,int_stack+110588,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+207669,int_stack+84273,int_stack+87360,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+38283,int_stack+207669,int_stack+0,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+44163,int_stack+38283,int_stack+89628,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+112688,int_stack+111533,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+87108,int_stack+0,int_stack+84273,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+192444,int_stack+87108,int_stack+207669,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+84273,int_stack+192444,int_stack+38283,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+166994,int_stack+84273,int_stack+44163,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+375732,int_stack+166994,int_stack+127304, 1.0, int_stack+201054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (fd|hh) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+395577,int_stack+234171,int_stack+179214,441);
     Libderiv->ABCD[11] = int_stack + 395577;
 /*--- compute (fd|hh) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+166994,int_stack+267246,int_stack+254016,441);
     Libderiv->ABCD[10] = int_stack + 166994;
 /*--- compute (fd|hh) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+229320,int_stack+287091,int_stack+216090,441);
     Libderiv->ABCD[9] = int_stack + 229320;
 /*--- compute (fd|hh) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+193454,int_stack+322812,int_stack+25053,441);
     Libderiv->ABCD[8] = int_stack + 193454;
 /*--- compute (fd|hh) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+23373,int_stack+3528,int_stack+306936,441);
     Libderiv->ABCD[7] = int_stack + 23373;
 /*--- compute (fd|hh) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+255780,int_stack+51198,int_stack+342657,441);
     Libderiv->ABCD[6] = int_stack + 255780;
 /*--- compute (fd|hh) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+282240,int_stack+147149,int_stack+133919, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[2] = int_stack + 282240;
 /*--- compute (fd|hh) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+127304,int_stack+355887,int_stack+71043, 0.0, zero_stack, 1.0, int_stack+114074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[1] = int_stack + 127304;
 /*--- compute (fd|hh) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+49833,int_stack+375732,int_stack+94633, 1.0, int_stack+114074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[0] = int_stack + 49833;

}
