/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_gdif(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gd|if) integrals */

void d1hrr_order_gdif(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][6][11] = int_stack + 0;
 Libderiv->deriv_classes[4][7][11] = int_stack + 420;
 Libderiv->deriv_classes[4][8][11] = int_stack + 960;
 Libderiv->deriv_classes[4][9][11] = int_stack + 1635;
 Libderiv->deriv_classes[5][6][11] = int_stack + 2460;
 Libderiv->deriv_classes[5][7][11] = int_stack + 3048;
 Libderiv->deriv_classes[5][8][11] = int_stack + 3804;
 Libderiv->deriv_classes[5][9][11] = int_stack + 4749;
 Libderiv->deriv_classes[6][6][11] = int_stack + 5904;
 Libderiv->deriv_classes[6][7][11] = int_stack + 6688;
 Libderiv->deriv_classes[6][8][11] = int_stack + 7696;
 Libderiv->deriv_classes[6][9][11] = int_stack + 8956;
 Libderiv->deriv_classes[4][6][10] = int_stack + 10496;
 Libderiv->deriv_classes[4][7][10] = int_stack + 10916;
 Libderiv->deriv_classes[4][8][10] = int_stack + 11456;
 Libderiv->deriv_classes[4][9][10] = int_stack + 12131;
 Libderiv->deriv_classes[5][6][10] = int_stack + 12956;
 Libderiv->deriv_classes[5][7][10] = int_stack + 13544;
 Libderiv->deriv_classes[5][8][10] = int_stack + 14300;
 Libderiv->deriv_classes[5][9][10] = int_stack + 15245;
 Libderiv->deriv_classes[6][6][10] = int_stack + 16400;
 Libderiv->deriv_classes[6][7][10] = int_stack + 17184;
 Libderiv->deriv_classes[6][8][10] = int_stack + 18192;
 Libderiv->deriv_classes[6][9][10] = int_stack + 19452;
 Libderiv->deriv_classes[4][6][9] = int_stack + 20992;
 Libderiv->deriv_classes[4][7][9] = int_stack + 21412;
 Libderiv->deriv_classes[4][8][9] = int_stack + 21952;
 Libderiv->deriv_classes[4][9][9] = int_stack + 22627;
 Libderiv->deriv_classes[5][6][9] = int_stack + 23452;
 Libderiv->deriv_classes[5][7][9] = int_stack + 24040;
 Libderiv->deriv_classes[5][8][9] = int_stack + 24796;
 Libderiv->deriv_classes[5][9][9] = int_stack + 25741;
 Libderiv->deriv_classes[6][6][9] = int_stack + 26896;
 Libderiv->deriv_classes[6][7][9] = int_stack + 27680;
 Libderiv->deriv_classes[6][8][9] = int_stack + 28688;
 Libderiv->deriv_classes[6][9][9] = int_stack + 29948;
 Libderiv->deriv_classes[4][6][8] = int_stack + 31488;
 Libderiv->deriv_classes[4][7][8] = int_stack + 31908;
 Libderiv->deriv_classes[4][8][8] = int_stack + 32448;
 Libderiv->deriv_classes[4][9][8] = int_stack + 33123;
 Libderiv->deriv_classes[5][6][8] = int_stack + 33948;
 Libderiv->deriv_classes[5][7][8] = int_stack + 34536;
 Libderiv->deriv_classes[5][8][8] = int_stack + 35292;
 Libderiv->deriv_classes[5][9][8] = int_stack + 36237;
 Libderiv->deriv_classes[6][6][8] = int_stack + 37392;
 Libderiv->deriv_classes[6][7][8] = int_stack + 38176;
 Libderiv->deriv_classes[6][8][8] = int_stack + 39184;
 Libderiv->deriv_classes[6][9][8] = int_stack + 40444;
 Libderiv->deriv_classes[4][6][7] = int_stack + 41984;
 Libderiv->deriv_classes[4][7][7] = int_stack + 42404;
 Libderiv->deriv_classes[4][8][7] = int_stack + 42944;
 Libderiv->deriv_classes[4][9][7] = int_stack + 43619;
 Libderiv->deriv_classes[5][6][7] = int_stack + 44444;
 Libderiv->deriv_classes[5][7][7] = int_stack + 45032;
 Libderiv->deriv_classes[5][8][7] = int_stack + 45788;
 Libderiv->deriv_classes[5][9][7] = int_stack + 46733;
 Libderiv->deriv_classes[6][6][7] = int_stack + 47888;
 Libderiv->deriv_classes[6][7][7] = int_stack + 48672;
 Libderiv->deriv_classes[6][8][7] = int_stack + 49680;
 Libderiv->deriv_classes[6][9][7] = int_stack + 50940;
 Libderiv->deriv_classes[4][6][6] = int_stack + 52480;
 Libderiv->deriv_classes[4][7][6] = int_stack + 52900;
 Libderiv->deriv_classes[4][8][6] = int_stack + 53440;
 Libderiv->deriv_classes[4][9][6] = int_stack + 54115;
 Libderiv->deriv_classes[5][6][6] = int_stack + 54940;
 Libderiv->deriv_classes[5][7][6] = int_stack + 55528;
 Libderiv->deriv_classes[5][8][6] = int_stack + 56284;
 Libderiv->deriv_classes[5][9][6] = int_stack + 57229;
 Libderiv->dvrr_classes[6][6] = int_stack + 58384;
 Libderiv->deriv_classes[6][6][6] = int_stack + 59168;
 Libderiv->dvrr_classes[6][7] = int_stack + 59952;
 Libderiv->deriv_classes[6][7][6] = int_stack + 60960;
 Libderiv->dvrr_classes[6][8] = int_stack + 61968;
 Libderiv->deriv_classes[6][8][6] = int_stack + 63228;
 Libderiv->deriv_classes[6][9][6] = int_stack + 64488;
 Libderiv->deriv_classes[4][6][2] = int_stack + 66028;
 Libderiv->deriv_classes[4][7][2] = int_stack + 66448;
 Libderiv->deriv_classes[4][8][2] = int_stack + 66988;
 Libderiv->deriv_classes[4][9][2] = int_stack + 67663;
 Libderiv->deriv_classes[5][6][2] = int_stack + 68488;
 Libderiv->deriv_classes[5][7][2] = int_stack + 69076;
 Libderiv->deriv_classes[5][8][2] = int_stack + 69832;
 Libderiv->deriv_classes[5][9][2] = int_stack + 70777;
 Libderiv->deriv_classes[6][6][2] = int_stack + 71932;
 Libderiv->deriv_classes[6][7][2] = int_stack + 72716;
 Libderiv->deriv_classes[6][8][2] = int_stack + 73724;
 Libderiv->deriv_classes[6][9][2] = int_stack + 74984;
 Libderiv->deriv_classes[4][6][1] = int_stack + 76524;
 Libderiv->deriv_classes[4][7][1] = int_stack + 76944;
 Libderiv->deriv_classes[4][8][1] = int_stack + 77484;
 Libderiv->deriv_classes[4][9][1] = int_stack + 78159;
 Libderiv->deriv_classes[5][6][1] = int_stack + 78984;
 Libderiv->deriv_classes[5][7][1] = int_stack + 79572;
 Libderiv->deriv_classes[5][8][1] = int_stack + 80328;
 Libderiv->deriv_classes[5][9][1] = int_stack + 81273;
 Libderiv->deriv_classes[6][6][1] = int_stack + 82428;
 Libderiv->deriv_classes[6][7][1] = int_stack + 83212;
 Libderiv->deriv_classes[6][8][1] = int_stack + 84220;
 Libderiv->deriv_classes[6][9][1] = int_stack + 85480;
 Libderiv->dvrr_classes[4][6] = int_stack + 87020;
 Libderiv->dvrr_classes[4][7] = int_stack + 87440;
 Libderiv->dvrr_classes[4][8] = int_stack + 87980;
 Libderiv->dvrr_classes[4][9] = int_stack + 88655;
 Libderiv->deriv_classes[4][6][0] = int_stack + 89480;
 Libderiv->deriv_classes[4][7][0] = int_stack + 89900;
 Libderiv->deriv_classes[4][8][0] = int_stack + 90440;
 Libderiv->deriv_classes[4][9][0] = int_stack + 91115;
 Libderiv->dvrr_classes[5][6] = int_stack + 91940;
 Libderiv->dvrr_classes[5][7] = int_stack + 92528;
 Libderiv->dvrr_classes[5][8] = int_stack + 93284;
 Libderiv->dvrr_classes[5][9] = int_stack + 94229;
 Libderiv->deriv_classes[5][6][0] = int_stack + 95384;
 Libderiv->deriv_classes[5][7][0] = int_stack + 95972;
 Libderiv->deriv_classes[5][8][0] = int_stack + 96728;
 Libderiv->deriv_classes[5][9][0] = int_stack + 97673;
 Libderiv->deriv_classes[6][6][0] = int_stack + 98828;
 Libderiv->deriv_classes[6][7][0] = int_stack + 99612;
 Libderiv->deriv_classes[6][8][0] = int_stack + 100620;
 Libderiv->deriv_classes[6][9][0] = int_stack + 101880;
 memset(int_stack,0,827360);

 Libderiv->dvrr_stack = int_stack + 361517;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_gdif(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+103420,int_stack+87440,int_stack+87020,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+104680,int_stack+87980,int_stack+87440,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+106300,int_stack+104680,int_stack+103420,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+108820,int_stack+420,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87020,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+110080,int_stack+960,int_stack+420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87440,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+111700,int_stack+110080,int_stack+108820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103420,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+114220,int_stack+1635,int_stack+960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87980,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+116245,int_stack+114220,int_stack+110080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104680,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+119485,int_stack+116245,int_stack+111700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106300,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+108820,int_stack+92528,int_stack+91940,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+110584,int_stack+93284,int_stack+92528,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+112852,int_stack+110584,int_stack+108820,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+116380,int_stack+3048,int_stack+2460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91940,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+3804,int_stack+3048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92528,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+123685,int_stack+0,int_stack+116380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108820,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+116380,int_stack+4749,int_stack+3804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93284,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+127213,int_stack+116380,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110584,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+127213,int_stack+123685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112852,21);
 /*--- compute (gp|if) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+123685,int_stack+0,int_stack+119485,280);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+116380,int_stack+59952,int_stack+58384,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+118732,int_stack+61968,int_stack+59952,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+136285,int_stack+118732,int_stack+116380,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+140989,int_stack+6688,int_stack+5904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58384,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+143341,int_stack+7696,int_stack+6688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59952,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+146365,int_stack+143341,int_stack+140989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116380,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+151069,int_stack+8956,int_stack+7696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61968,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+154849,int_stack+151069,int_stack+143341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118732,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+160897,int_stack+154849,int_stack+146365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136285,28);
 /*--- compute (hp|if) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+140989,int_stack+160897,int_stack+0,280);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+10916,int_stack+10496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87020, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1260,int_stack+11456,int_stack+10916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87440, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2880,int_stack+1260,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103420, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5400,int_stack+12131,int_stack+11456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87980, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7425,int_stack+5400,int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104680, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+158629,int_stack+7425,int_stack+2880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106300, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+13544,int_stack+12956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91940, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1764,int_stack+14300,int_stack+13544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92528, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4032,int_stack+1764,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108820, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7560,int_stack+15245,int_stack+14300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93284, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10395,int_stack+7560,int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110584, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+162829,int_stack+10395,int_stack+4032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112852, 0.0, zero_stack,21);
 /*--- compute (gp|if) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+0,int_stack+162829,int_stack+158629,280);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+158629,int_stack+17184,int_stack+16400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58384, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12600,int_stack+18192,int_stack+17184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59952, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+168709,int_stack+12600,int_stack+158629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116380, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+158629,int_stack+19452,int_stack+18192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61968, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+173413,int_stack+158629,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118732, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12600,int_stack+173413,int_stack+168709, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136285, 0.0, zero_stack,28);
 /*--- compute (hp|if) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+168709,int_stack+12600,int_stack+162829,280);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12600,int_stack+21412,int_stack+20992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87020, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13860,int_stack+21952,int_stack+21412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87440, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+15480,int_stack+13860,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103420, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+18000,int_stack+22627,int_stack+21952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87980, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+20025,int_stack+18000,int_stack+13860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104680, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+158629,int_stack+20025,int_stack+15480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106300, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12600,int_stack+24040,int_stack+23452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91940, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+14364,int_stack+24796,int_stack+24040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92528, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+16632,int_stack+14364,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108820, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+20160,int_stack+25741,int_stack+24796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93284, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+162829,int_stack+20160,int_stack+14364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110584, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+20160,int_stack+162829,int_stack+16632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112852, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|if) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+186349,int_stack+20160,int_stack+158629,280);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+158629,int_stack+27680,int_stack+26896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58384, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+160981,int_stack+28688,int_stack+27680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59952, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+164005,int_stack+160981,int_stack+158629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116380, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12600,int_stack+29948,int_stack+28688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61968, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+198949,int_stack+12600,int_stack+160981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118732, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+204997,int_stack+198949,int_stack+164005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136285, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|if) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+212837,int_stack+204997,int_stack+20160,280);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+198949,int_stack+31908,int_stack+31488, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+200209,int_stack+32448,int_stack+31908, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+201829,int_stack+200209,int_stack+198949, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+204349,int_stack+33123,int_stack+32448, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+206374,int_stack+204349,int_stack+200209, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12600,int_stack+206374,int_stack+201829, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+198949,int_stack+34536,int_stack+33948, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+200713,int_stack+35292,int_stack+34536, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+202981,int_stack+200713,int_stack+198949, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+206509,int_stack+36237,int_stack+35292, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+16800,int_stack+206509,int_stack+200713, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+206509,int_stack+16800,int_stack+202981, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|if) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+16800,int_stack+206509,int_stack+12600,280);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12600,int_stack+38176,int_stack+37392, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+58384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+29400,int_stack+39184,int_stack+38176, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+59952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+32424,int_stack+29400,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12600,int_stack+40444,int_stack+39184, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+198949,int_stack+12600,int_stack+29400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+158629,int_stack+198949,int_stack+32424, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|if) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+230477,int_stack+158629,int_stack+206509,280);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+158629,int_stack+42404,int_stack+41984, 0.0, zero_stack, 1.0, int_stack+87020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+159889,int_stack+42944,int_stack+42404, 0.0, zero_stack, 1.0, int_stack+87440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+161509,int_stack+159889,int_stack+158629, 0.0, zero_stack, 1.0, int_stack+103420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+164029,int_stack+43619,int_stack+42944, 0.0, zero_stack, 1.0, int_stack+87980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+198949,int_stack+164029,int_stack+159889, 0.0, zero_stack, 1.0, int_stack+104680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12600,int_stack+198949,int_stack+161509, 0.0, zero_stack, 1.0, int_stack+106300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+198949,int_stack+45032,int_stack+44444, 0.0, zero_stack, 1.0, int_stack+91940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+200713,int_stack+45788,int_stack+45032, 0.0, zero_stack, 1.0, int_stack+92528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+202981,int_stack+200713,int_stack+198949, 0.0, zero_stack, 1.0, int_stack+108820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+206509,int_stack+46733,int_stack+45788, 0.0, zero_stack, 1.0, int_stack+93284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+158629,int_stack+206509,int_stack+200713, 0.0, zero_stack, 1.0, int_stack+110584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+206509,int_stack+158629,int_stack+202981, 0.0, zero_stack, 1.0, int_stack+112852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|if) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+29400,int_stack+206509,int_stack+12600,280);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12600,int_stack+48672,int_stack+47888, 0.0, zero_stack, 1.0, int_stack+58384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+158629,int_stack+49680,int_stack+48672, 0.0, zero_stack, 1.0, int_stack+59952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+161653,int_stack+158629,int_stack+12600, 0.0, zero_stack, 1.0, int_stack+116380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12600,int_stack+50940,int_stack+49680, 0.0, zero_stack, 1.0, int_stack+61968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+198949,int_stack+12600,int_stack+158629, 0.0, zero_stack, 1.0, int_stack+118732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+42000,int_stack+198949,int_stack+161653, 0.0, zero_stack, 1.0, int_stack+136285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|if) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+248117,int_stack+42000,int_stack+206509,280);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+42000,int_stack+52900,int_stack+52480, 1.0, int_stack+87020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+43260,int_stack+53440,int_stack+52900, 1.0, int_stack+87440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+44880,int_stack+43260,int_stack+42000, 1.0, int_stack+103420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+47400,int_stack+54115,int_stack+53440, 1.0, int_stack+87980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+49425,int_stack+47400,int_stack+43260, 1.0, int_stack+104680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+12600,int_stack+49425,int_stack+44880, 1.0, int_stack+106300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+42000,int_stack+55528,int_stack+54940, 1.0, int_stack+91940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+43764,int_stack+56284,int_stack+55528, 1.0, int_stack+92528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+46032,int_stack+43764,int_stack+42000, 1.0, int_stack+108820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+49560,int_stack+57229,int_stack+56284, 1.0, int_stack+93284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+52395,int_stack+49560,int_stack+43764, 1.0, int_stack+110584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+198949,int_stack+52395,int_stack+46032, 1.0, int_stack+112852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|if) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+42000,int_stack+198949,int_stack+12600,280);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12600,int_stack+60960,int_stack+59168, 1.0, int_stack+58384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+54600,int_stack+63228,int_stack+60960, 1.0, int_stack+59952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+204829,int_stack+54600,int_stack+12600, 1.0, int_stack+116380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+12600,int_stack+64488,int_stack+63228, 1.0, int_stack+61968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+57624,int_stack+12600,int_stack+54600, 1.0, int_stack+118732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+158629,int_stack+57624,int_stack+204829, 1.0, int_stack+136285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|if) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+265757,int_stack+158629,int_stack+198949,280);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+198949,int_stack+88655,int_stack+87980,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+200974,int_stack+198949,int_stack+104680,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+12600,int_stack+200974,int_stack+106300,15);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+198949,int_stack+94229,int_stack+93284,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+201784,int_stack+198949,int_stack+110584,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+206320,int_stack+201784,int_stack+112852,21);
 /*--- compute (gp|if) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+103420,int_stack+206320,int_stack+12600,280);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+198949,int_stack+66448,int_stack+66028,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+200209,int_stack+66988,int_stack+66448,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+201829,int_stack+200209,int_stack+198949,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+158629,int_stack+67663,int_stack+66988,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+160654,int_stack+158629,int_stack+200209,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+163894,int_stack+160654,int_stack+201829,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+158629,int_stack+69076,int_stack+68488,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+160393,int_stack+69832,int_stack+69076,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+198949,int_stack+160393,int_stack+158629,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+202477,int_stack+70777,int_stack+69832,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+136285,int_stack+202477,int_stack+160393,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+54600,int_stack+136285,int_stack+198949,21);
 /*--- compute (gp|if) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+283397,int_stack+54600,int_stack+163894, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+198949,int_stack+72716,int_stack+71932,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+201301,int_stack+73724,int_stack+72716,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+136285,int_stack+201301,int_stack+198949,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+158629,int_stack+74984,int_stack+73724,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+162409,int_stack+158629,int_stack+201301,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+60480,int_stack+162409,int_stack+136285,28);
 /*--- compute (hp|if) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+295997,int_stack+60480,int_stack+54600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+206320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+54600,int_stack+76944,int_stack+76524,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+55860,int_stack+77484,int_stack+76944,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+57480,int_stack+55860,int_stack+54600,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+60000,int_stack+78159,int_stack+77484,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+62025,int_stack+60000,int_stack+55860,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+65265,int_stack+62025,int_stack+57480,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+54600,int_stack+79572,int_stack+78984,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+56364,int_stack+80328,int_stack+79572,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+58632,int_stack+56364,int_stack+54600,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+62160,int_stack+81273,int_stack+80328,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+69465,int_stack+62160,int_stack+56364,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+74001,int_stack+69465,int_stack+58632,21);
 /*--- compute (gp|if) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+313637,int_stack+74001,int_stack+65265, 0.0, zero_stack, 1.0, int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+54600,int_stack+83212,int_stack+82428,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+56952,int_stack+84220,int_stack+83212,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+136285,int_stack+56952,int_stack+54600,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+59976,int_stack+85480,int_stack+84220,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+63756,int_stack+59976,int_stack+56952,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+54600,int_stack+63756,int_stack+136285,28);
 /*--- compute (hp|if) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+326237,int_stack+54600,int_stack+74001, 0.0, zero_stack, 1.0, int_stack+206320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+54600,int_stack+89900,int_stack+89480,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+55860,int_stack+90440,int_stack+89900,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+57480,int_stack+55860,int_stack+54600,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+60000,int_stack+91115,int_stack+90440,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+62025,int_stack+60000,int_stack+55860,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+65265,int_stack+62025,int_stack+57480,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+54600,int_stack+95972,int_stack+95384,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+56364,int_stack+96728,int_stack+95972,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+58632,int_stack+56364,int_stack+54600,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+62160,int_stack+97673,int_stack+96728,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+69465,int_stack+62160,int_stack+56364,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+74001,int_stack+69465,int_stack+58632,21);
 /*--- compute (gp|if) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+79881,int_stack+74001,int_stack+65265, 1.0, int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+12600,int_stack+99612,int_stack+98828,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+54600,int_stack+100620,int_stack+99612,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+136285,int_stack+54600,int_stack+12600,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+12600,int_stack+101880,int_stack+100620,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+57624,int_stack+12600,int_stack+54600,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+63672,int_stack+57624,int_stack+136285,28);
 /*--- compute (hp|if) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+343877,int_stack+63672,int_stack+74001, 1.0, int_stack+206320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
 /*--- compute (gd|if) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+54600,int_stack+140989,int_stack+123685,280);
     Libderiv->ABCD[11] = int_stack + 54600;
 /*--- compute (gd|if) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+116020,int_stack+168709,int_stack+0,280);
     Libderiv->ABCD[10] = int_stack + 116020;
 /*--- compute (gd|if) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+141220,int_stack+212837,int_stack+186349,280);
     Libderiv->ABCD[9] = int_stack + 141220;
 /*--- compute (gd|if) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+166420,int_stack+230477,int_stack+16800,280);
     Libderiv->ABCD[8] = int_stack + 166420;
 /*--- compute (gd|if) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+0,int_stack+248117,int_stack+29400,280);
     Libderiv->ABCD[7] = int_stack + 0;
 /*--- compute (gd|if) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+191620,int_stack+265757,int_stack+42000,280);
     Libderiv->ABCD[6] = int_stack + 191620;
 /*--- compute (gd|if) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+25200,int_stack+295997,int_stack+283397, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
     Libderiv->ABCD[2] = int_stack + 25200;
 /*--- compute (gd|if) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+216820,int_stack+326237,int_stack+313637, 0.0, zero_stack, 1.0, int_stack+103420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
     Libderiv->ABCD[1] = int_stack + 216820;
 /*--- compute (gd|if) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+242020,int_stack+343877,int_stack+79881, 1.0, int_stack+103420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,280);
     Libderiv->ABCD[0] = int_stack + 242020;

}
