/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_hdhf(Libderiv_t *, prim_data *);

  /* Computes derivatives of (hd|hf) integrals */

void d1hrr_order_hdhf(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[5][5][11] = int_stack + 0;
 Libderiv->deriv_classes[5][6][11] = int_stack + 441;
 Libderiv->deriv_classes[5][7][11] = int_stack + 1029;
 Libderiv->deriv_classes[5][8][11] = int_stack + 1785;
 Libderiv->deriv_classes[6][5][11] = int_stack + 2730;
 Libderiv->deriv_classes[6][6][11] = int_stack + 3318;
 Libderiv->deriv_classes[6][7][11] = int_stack + 4102;
 Libderiv->deriv_classes[6][8][11] = int_stack + 5110;
 Libderiv->deriv_classes[7][5][11] = int_stack + 6370;
 Libderiv->deriv_classes[7][6][11] = int_stack + 7126;
 Libderiv->deriv_classes[7][7][11] = int_stack + 8134;
 Libderiv->deriv_classes[7][8][11] = int_stack + 9430;
 Libderiv->deriv_classes[5][5][10] = int_stack + 11050;
 Libderiv->deriv_classes[5][6][10] = int_stack + 11491;
 Libderiv->deriv_classes[5][7][10] = int_stack + 12079;
 Libderiv->deriv_classes[5][8][10] = int_stack + 12835;
 Libderiv->deriv_classes[6][5][10] = int_stack + 13780;
 Libderiv->deriv_classes[6][6][10] = int_stack + 14368;
 Libderiv->deriv_classes[6][7][10] = int_stack + 15152;
 Libderiv->deriv_classes[6][8][10] = int_stack + 16160;
 Libderiv->deriv_classes[7][5][10] = int_stack + 17420;
 Libderiv->deriv_classes[7][6][10] = int_stack + 18176;
 Libderiv->deriv_classes[7][7][10] = int_stack + 19184;
 Libderiv->deriv_classes[7][8][10] = int_stack + 20480;
 Libderiv->deriv_classes[5][5][9] = int_stack + 22100;
 Libderiv->deriv_classes[5][6][9] = int_stack + 22541;
 Libderiv->deriv_classes[5][7][9] = int_stack + 23129;
 Libderiv->deriv_classes[5][8][9] = int_stack + 23885;
 Libderiv->deriv_classes[6][5][9] = int_stack + 24830;
 Libderiv->deriv_classes[6][6][9] = int_stack + 25418;
 Libderiv->deriv_classes[6][7][9] = int_stack + 26202;
 Libderiv->deriv_classes[6][8][9] = int_stack + 27210;
 Libderiv->deriv_classes[7][5][9] = int_stack + 28470;
 Libderiv->deriv_classes[7][6][9] = int_stack + 29226;
 Libderiv->deriv_classes[7][7][9] = int_stack + 30234;
 Libderiv->deriv_classes[7][8][9] = int_stack + 31530;
 Libderiv->deriv_classes[5][5][8] = int_stack + 33150;
 Libderiv->deriv_classes[5][6][8] = int_stack + 33591;
 Libderiv->deriv_classes[5][7][8] = int_stack + 34179;
 Libderiv->deriv_classes[5][8][8] = int_stack + 34935;
 Libderiv->deriv_classes[6][5][8] = int_stack + 35880;
 Libderiv->deriv_classes[6][6][8] = int_stack + 36468;
 Libderiv->deriv_classes[6][7][8] = int_stack + 37252;
 Libderiv->deriv_classes[6][8][8] = int_stack + 38260;
 Libderiv->deriv_classes[7][5][8] = int_stack + 39520;
 Libderiv->deriv_classes[7][6][8] = int_stack + 40276;
 Libderiv->deriv_classes[7][7][8] = int_stack + 41284;
 Libderiv->deriv_classes[7][8][8] = int_stack + 42580;
 Libderiv->deriv_classes[5][5][7] = int_stack + 44200;
 Libderiv->deriv_classes[5][6][7] = int_stack + 44641;
 Libderiv->deriv_classes[5][7][7] = int_stack + 45229;
 Libderiv->deriv_classes[5][8][7] = int_stack + 45985;
 Libderiv->deriv_classes[6][5][7] = int_stack + 46930;
 Libderiv->deriv_classes[6][6][7] = int_stack + 47518;
 Libderiv->deriv_classes[6][7][7] = int_stack + 48302;
 Libderiv->deriv_classes[6][8][7] = int_stack + 49310;
 Libderiv->deriv_classes[7][5][7] = int_stack + 50570;
 Libderiv->deriv_classes[7][6][7] = int_stack + 51326;
 Libderiv->deriv_classes[7][7][7] = int_stack + 52334;
 Libderiv->deriv_classes[7][8][7] = int_stack + 53630;
 Libderiv->deriv_classes[5][5][6] = int_stack + 55250;
 Libderiv->deriv_classes[5][6][6] = int_stack + 55691;
 Libderiv->deriv_classes[5][7][6] = int_stack + 56279;
 Libderiv->deriv_classes[5][8][6] = int_stack + 57035;
 Libderiv->deriv_classes[6][5][6] = int_stack + 57980;
 Libderiv->deriv_classes[6][6][6] = int_stack + 58568;
 Libderiv->deriv_classes[6][7][6] = int_stack + 59352;
 Libderiv->deriv_classes[6][8][6] = int_stack + 60360;
 Libderiv->dvrr_classes[7][5] = int_stack + 61620;
 Libderiv->deriv_classes[7][5][6] = int_stack + 62376;
 Libderiv->dvrr_classes[7][6] = int_stack + 63132;
 Libderiv->deriv_classes[7][6][6] = int_stack + 64140;
 Libderiv->dvrr_classes[7][7] = int_stack + 65148;
 Libderiv->deriv_classes[7][7][6] = int_stack + 66444;
 Libderiv->deriv_classes[7][8][6] = int_stack + 67740;
 Libderiv->deriv_classes[5][5][2] = int_stack + 69360;
 Libderiv->deriv_classes[5][6][2] = int_stack + 69801;
 Libderiv->deriv_classes[5][7][2] = int_stack + 70389;
 Libderiv->deriv_classes[5][8][2] = int_stack + 71145;
 Libderiv->deriv_classes[6][5][2] = int_stack + 72090;
 Libderiv->deriv_classes[6][6][2] = int_stack + 72678;
 Libderiv->deriv_classes[6][7][2] = int_stack + 73462;
 Libderiv->deriv_classes[6][8][2] = int_stack + 74470;
 Libderiv->deriv_classes[7][5][2] = int_stack + 75730;
 Libderiv->deriv_classes[7][6][2] = int_stack + 76486;
 Libderiv->deriv_classes[7][7][2] = int_stack + 77494;
 Libderiv->deriv_classes[7][8][2] = int_stack + 78790;
 Libderiv->deriv_classes[5][5][1] = int_stack + 80410;
 Libderiv->deriv_classes[5][6][1] = int_stack + 80851;
 Libderiv->deriv_classes[5][7][1] = int_stack + 81439;
 Libderiv->deriv_classes[5][8][1] = int_stack + 82195;
 Libderiv->deriv_classes[6][5][1] = int_stack + 83140;
 Libderiv->deriv_classes[6][6][1] = int_stack + 83728;
 Libderiv->deriv_classes[6][7][1] = int_stack + 84512;
 Libderiv->deriv_classes[6][8][1] = int_stack + 85520;
 Libderiv->deriv_classes[7][5][1] = int_stack + 86780;
 Libderiv->deriv_classes[7][6][1] = int_stack + 87536;
 Libderiv->deriv_classes[7][7][1] = int_stack + 88544;
 Libderiv->deriv_classes[7][8][1] = int_stack + 89840;
 Libderiv->dvrr_classes[5][5] = int_stack + 91460;
 Libderiv->dvrr_classes[5][6] = int_stack + 91901;
 Libderiv->dvrr_classes[5][7] = int_stack + 92489;
 Libderiv->dvrr_classes[5][8] = int_stack + 93245;
 Libderiv->deriv_classes[5][5][0] = int_stack + 94190;
 Libderiv->deriv_classes[5][6][0] = int_stack + 94631;
 Libderiv->deriv_classes[5][7][0] = int_stack + 95219;
 Libderiv->deriv_classes[5][8][0] = int_stack + 95975;
 Libderiv->dvrr_classes[6][5] = int_stack + 96920;
 Libderiv->dvrr_classes[6][6] = int_stack + 97508;
 Libderiv->dvrr_classes[6][7] = int_stack + 98292;
 Libderiv->dvrr_classes[6][8] = int_stack + 99300;
 Libderiv->deriv_classes[6][5][0] = int_stack + 100560;
 Libderiv->deriv_classes[6][6][0] = int_stack + 101148;
 Libderiv->deriv_classes[6][7][0] = int_stack + 101932;
 Libderiv->deriv_classes[6][8][0] = int_stack + 102940;
 Libderiv->deriv_classes[7][5][0] = int_stack + 104200;
 Libderiv->deriv_classes[7][6][0] = int_stack + 104956;
 Libderiv->deriv_classes[7][7][0] = int_stack + 105964;
 Libderiv->deriv_classes[7][8][0] = int_stack + 107260;
 memset(int_stack,0,871040);

 Libderiv->dvrr_stack = int_stack + 369304;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_hdhf(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+108880,int_stack+91901,int_stack+91460,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+110203,int_stack+92489,int_stack+91901,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+111967,int_stack+110203,int_stack+108880,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+114613,int_stack+441,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91460,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+115936,int_stack+1029,int_stack+441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91901,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+117700,int_stack+115936,int_stack+114613, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108880,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+120346,int_stack+1785,int_stack+1029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92489,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+122614,int_stack+120346,int_stack+115936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110203,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+126142,int_stack+122614,int_stack+117700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111967,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+114613,int_stack+97508,int_stack+96920,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+116377,int_stack+98292,int_stack+97508,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+118729,int_stack+116377,int_stack+114613,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+122257,int_stack+3318,int_stack+2730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96920,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+4102,int_stack+3318, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97508,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+130552,int_stack+0,int_stack+122257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114613,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+122257,int_stack+5110,int_stack+4102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98292,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+134080,int_stack+122257,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116377,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+134080,int_stack+130552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118729,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+130552,int_stack+0,int_stack+126142,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+122257,int_stack+63132,int_stack+61620,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+124525,int_stack+65148,int_stack+63132,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+143782,int_stack+124525,int_stack+122257,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+127549,int_stack+7126,int_stack+6370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61620,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+148318,int_stack+8134,int_stack+7126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63132,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+151342,int_stack+148318,int_stack+127549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122257,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+155878,int_stack+9430,int_stack+8134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65148,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+159766,int_stack+155878,int_stack+148318, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124525,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+165814,int_stack+159766,int_stack+151342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143782,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+173374,int_stack+165814,int_stack+0,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+11491,int_stack+11050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91460, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1323,int_stack+12079,int_stack+11491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91901, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3087,int_stack+1323,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108880, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5733,int_stack+12835,int_stack+12079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92489, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001,int_stack+5733,int_stack+1323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110203, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+148318,int_stack+8001,int_stack+3087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111967, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+14368,int_stack+13780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96920, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1764,int_stack+15152,int_stack+14368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97508, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4116,int_stack+1764,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114613, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7644,int_stack+16160,int_stack+15152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98292, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10668,int_stack+7644,int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116377, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+152728,int_stack+10668,int_stack+4116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118729, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+0,int_stack+152728,int_stack+148318,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+148318,int_stack+18176,int_stack+17420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61620, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13230,int_stack+19184,int_stack+18176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63132, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+158608,int_stack+13230,int_stack+148318, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122257, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+148318,int_stack+20480,int_stack+19184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65148, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+163144,int_stack+148318,int_stack+13230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124525, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13230,int_stack+163144,int_stack+158608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143782, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+191014,int_stack+13230,int_stack+152728,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13230,int_stack+22541,int_stack+22100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91460, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+14553,int_stack+23129,int_stack+22541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91901, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+16317,int_stack+14553,int_stack+13230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108880, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+18963,int_stack+23885,int_stack+23129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92489, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+21231,int_stack+18963,int_stack+14553, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110203, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+148318,int_stack+21231,int_stack+16317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111967, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13230,int_stack+25418,int_stack+24830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96920, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+14994,int_stack+26202,int_stack+25418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97508, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+17346,int_stack+14994,int_stack+13230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114613, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+20874,int_stack+27210,int_stack+26202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98292, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+152728,int_stack+20874,int_stack+14994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116377, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+20874,int_stack+152728,int_stack+17346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118729, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+152728,int_stack+20874,int_stack+148318,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+148318,int_stack+29226,int_stack+28470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61620, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+165958,int_stack+30234,int_stack+29226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63132, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13230,int_stack+165958,int_stack+148318, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122257, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+148318,int_stack+31530,int_stack+30234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65148, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+26754,int_stack+148318,int_stack+165958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124525, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+208654,int_stack+26754,int_stack+13230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143782, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+216214,int_stack+208654,int_stack+20874,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+208654,int_stack+33591,int_stack+33150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+209977,int_stack+34179,int_stack+33591, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91901, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+211741,int_stack+209977,int_stack+208654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13230,int_stack+34935,int_stack+34179, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+15498,int_stack+13230,int_stack+209977, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+148318,int_stack+15498,int_stack+211741, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13230,int_stack+36468,int_stack+35880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+14994,int_stack+37252,int_stack+36468, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+17346,int_stack+14994,int_stack+13230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114613, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+20874,int_stack+38260,int_stack+37252, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+23898,int_stack+20874,int_stack+14994, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116377, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28602,int_stack+23898,int_stack+17346, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+13230,int_stack+28602,int_stack+148318,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+148318,int_stack+40276,int_stack+39520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+34482,int_stack+41284,int_stack+40276, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+208654,int_stack+34482,int_stack+148318, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+148318,int_stack+42580,int_stack+41284, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+37506,int_stack+148318,int_stack+34482, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+124525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+233854,int_stack+37506,int_stack+208654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+241414,int_stack+233854,int_stack+28602,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+233854,int_stack+44641,int_stack+44200, 0.0, zero_stack, 1.0, int_stack+91460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+235177,int_stack+45229,int_stack+44641, 0.0, zero_stack, 1.0, int_stack+91901, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+236941,int_stack+235177,int_stack+233854, 0.0, zero_stack, 1.0, int_stack+108880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+208654,int_stack+45985,int_stack+45229, 0.0, zero_stack, 1.0, int_stack+92489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+210922,int_stack+208654,int_stack+235177, 0.0, zero_stack, 1.0, int_stack+110203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+148318,int_stack+210922,int_stack+236941, 0.0, zero_stack, 1.0, int_stack+111967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+208654,int_stack+47518,int_stack+46930, 0.0, zero_stack, 1.0, int_stack+96920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+210418,int_stack+48302,int_stack+47518, 0.0, zero_stack, 1.0, int_stack+97508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+233854,int_stack+210418,int_stack+208654, 0.0, zero_stack, 1.0, int_stack+114613, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+212770,int_stack+49310,int_stack+48302, 0.0, zero_stack, 1.0, int_stack+98292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+26460,int_stack+212770,int_stack+210418, 0.0, zero_stack, 1.0, int_stack+116377, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+208654,int_stack+26460,int_stack+233854, 0.0, zero_stack, 1.0, int_stack+118729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+26460,int_stack+208654,int_stack+148318,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+148318,int_stack+51326,int_stack+50570, 0.0, zero_stack, 1.0, int_stack+61620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+233854,int_stack+52334,int_stack+51326, 0.0, zero_stack, 1.0, int_stack+63132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+236878,int_stack+233854,int_stack+148318, 0.0, zero_stack, 1.0, int_stack+122257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+148318,int_stack+53630,int_stack+52334, 0.0, zero_stack, 1.0, int_stack+65148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+39690,int_stack+148318,int_stack+233854, 0.0, zero_stack, 1.0, int_stack+124525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+45738,int_stack+39690,int_stack+236878, 0.0, zero_stack, 1.0, int_stack+143782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+259054,int_stack+45738,int_stack+208654,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+208654,int_stack+55691,int_stack+55250, 1.0, int_stack+91460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+209977,int_stack+56279,int_stack+55691, 1.0, int_stack+91901, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+211741,int_stack+209977,int_stack+208654, 1.0, int_stack+108880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+39690,int_stack+57035,int_stack+56279, 1.0, int_stack+92489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+41958,int_stack+39690,int_stack+209977, 1.0, int_stack+110203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+148318,int_stack+41958,int_stack+211741, 1.0, int_stack+111967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39690,int_stack+58568,int_stack+57980, 1.0, int_stack+96920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+41454,int_stack+59352,int_stack+58568, 1.0, int_stack+97508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+43806,int_stack+41454,int_stack+39690, 1.0, int_stack+114613, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+47334,int_stack+60360,int_stack+59352, 1.0, int_stack+98292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+50358,int_stack+47334,int_stack+41454, 1.0, int_stack+116377, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+55062,int_stack+50358,int_stack+43806, 1.0, int_stack+118729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+39690,int_stack+55062,int_stack+148318,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+148318,int_stack+64140,int_stack+62376, 1.0, int_stack+61620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+208654,int_stack+66444,int_stack+64140, 1.0, int_stack+63132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+211678,int_stack+208654,int_stack+148318, 1.0, int_stack+122257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+148318,int_stack+67740,int_stack+66444, 1.0, int_stack+65148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+60942,int_stack+148318,int_stack+208654, 1.0, int_stack+124525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+233854,int_stack+60942,int_stack+211678, 1.0, int_stack+143782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+276694,int_stack+233854,int_stack+55062,210);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+233854,int_stack+93245,int_stack+92489,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+236122,int_stack+233854,int_stack+110203,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+143782,int_stack+236122,int_stack+111967,21);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+233854,int_stack+99300,int_stack+98292,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+208654,int_stack+233854,int_stack+116377,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+233854,int_stack+208654,int_stack+118729,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+52920,int_stack+233854,int_stack+143782,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+208654,int_stack+69801,int_stack+69360,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+209977,int_stack+70389,int_stack+69801,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+211741,int_stack+209977,int_stack+208654,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+148192,int_stack+71145,int_stack+70389,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+66150,int_stack+148192,int_stack+209977,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+148192,int_stack+66150,int_stack+211741,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+66150,int_stack+72678,int_stack+72090,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+67914,int_stack+73462,int_stack+72678,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+208654,int_stack+67914,int_stack+66150,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+70266,int_stack+74470,int_stack+73462,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+108880,int_stack+70266,int_stack+67914,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+66150,int_stack+108880,int_stack+208654,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+108880,int_stack+66150,int_stack+148192, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+148192,int_stack+76486,int_stack+75730,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+208654,int_stack+77494,int_stack+76486,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+211678,int_stack+208654,int_stack+148192,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+148192,int_stack+78790,int_stack+77494,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+122110,int_stack+148192,int_stack+208654,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+72030,int_stack+122110,int_stack+211678,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+294334,int_stack+72030,int_stack+66150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+66150,int_stack+80851,int_stack+80410,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+67473,int_stack+81439,int_stack+80851,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+69237,int_stack+67473,int_stack+66150,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+71883,int_stack+82195,int_stack+81439,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+74151,int_stack+71883,int_stack+67473,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+77679,int_stack+74151,int_stack+69237,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+66150,int_stack+83728,int_stack+83140,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+67914,int_stack+84512,int_stack+83728,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+70266,int_stack+67914,int_stack+66150,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+73794,int_stack+85520,int_stack+84512,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+122110,int_stack+73794,int_stack+67914,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+208654,int_stack+122110,int_stack+70266,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+311974,int_stack+208654,int_stack+77679, 0.0, zero_stack, 1.0, int_stack+143782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+122110,int_stack+87536,int_stack+86780,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+124378,int_stack+88544,int_stack+87536,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+148192,int_stack+124378,int_stack+122110,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+66150,int_stack+89840,int_stack+88544,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+70038,int_stack+66150,int_stack+124378,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+122110,int_stack+70038,int_stack+148192,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+66150,int_stack+122110,int_stack+208654, 0.0, zero_stack, 1.0, int_stack+233854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+208654,int_stack+94631,int_stack+94190,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+209977,int_stack+95219,int_stack+94631,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+211741,int_stack+209977,int_stack+208654,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+122110,int_stack+95975,int_stack+95219,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+124378,int_stack+122110,int_stack+209977,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+148192,int_stack+124378,int_stack+211741,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+122110,int_stack+101148,int_stack+100560,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+123874,int_stack+101932,int_stack+101148,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+126226,int_stack+123874,int_stack+122110,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+208654,int_stack+102940,int_stack+101932,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+83790,int_stack+208654,int_stack+123874,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+208654,int_stack+83790,int_stack+126226,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+83790,int_stack+208654,int_stack+148192, 1.0, int_stack+143782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+143782,int_stack+104956,int_stack+104200,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+146050,int_stack+105964,int_stack+104956,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+97020,int_stack+146050,int_stack+143782,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+101556,int_stack+107260,int_stack+105964,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+122110,int_stack+101556,int_stack+146050,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+143782,int_stack+122110,int_stack+97020,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+325204,int_stack+143782,int_stack+208654, 1.0, int_stack+233854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+342844,int_stack+173374,int_stack+130552,210);
     Libderiv->ABCD[11] = int_stack + 342844;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+122110,int_stack+191014,int_stack+0,210);
     Libderiv->ABCD[10] = int_stack + 122110;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+165958,int_stack+216214,int_stack+152728,210);
     Libderiv->ABCD[9] = int_stack + 165958;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+192418,int_stack+241414,int_stack+13230,210);
     Libderiv->ABCD[8] = int_stack + 192418;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+0,int_stack+259054,int_stack+26460,210);
     Libderiv->ABCD[7] = int_stack + 0;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+218878,int_stack+276694,int_stack+39690,210);
     Libderiv->ABCD[6] = int_stack + 218878;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+26460,int_stack+294334,int_stack+108880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[2] = int_stack + 26460;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+245338,int_stack+66150,int_stack+311974, 0.0, zero_stack, 1.0, int_stack+52920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[1] = int_stack + 245338;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+271798,int_stack+325204,int_stack+83790, 1.0, int_stack+52920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[0] = int_stack + 271798;

}
