/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_hpih(Libderiv_t *, prim_data *);

  /* Computes derivatives of (hp|ih) integrals */

void d1hrr_order_hpih(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[5][6][11] = int_stack + 0;
 Libderiv->deriv_classes[5][7][11] = int_stack + 588;
 Libderiv->deriv_classes[5][8][11] = int_stack + 1344;
 Libderiv->deriv_classes[5][9][11] = int_stack + 2289;
 Libderiv->deriv_classes[5][10][11] = int_stack + 3444;
 Libderiv->deriv_classes[5][11][11] = int_stack + 4830;
 Libderiv->deriv_classes[6][6][11] = int_stack + 6468;
 Libderiv->deriv_classes[6][7][11] = int_stack + 7252;
 Libderiv->deriv_classes[6][8][11] = int_stack + 8260;
 Libderiv->deriv_classes[6][9][11] = int_stack + 9520;
 Libderiv->deriv_classes[6][10][11] = int_stack + 11060;
 Libderiv->deriv_classes[6][11][11] = int_stack + 12908;
 Libderiv->deriv_classes[5][6][10] = int_stack + 15092;
 Libderiv->deriv_classes[5][7][10] = int_stack + 15680;
 Libderiv->deriv_classes[5][8][10] = int_stack + 16436;
 Libderiv->deriv_classes[5][9][10] = int_stack + 17381;
 Libderiv->deriv_classes[5][10][10] = int_stack + 18536;
 Libderiv->deriv_classes[5][11][10] = int_stack + 19922;
 Libderiv->deriv_classes[6][6][10] = int_stack + 21560;
 Libderiv->deriv_classes[6][7][10] = int_stack + 22344;
 Libderiv->deriv_classes[6][8][10] = int_stack + 23352;
 Libderiv->deriv_classes[6][9][10] = int_stack + 24612;
 Libderiv->deriv_classes[6][10][10] = int_stack + 26152;
 Libderiv->deriv_classes[6][11][10] = int_stack + 28000;
 Libderiv->deriv_classes[5][6][9] = int_stack + 30184;
 Libderiv->deriv_classes[5][7][9] = int_stack + 30772;
 Libderiv->deriv_classes[5][8][9] = int_stack + 31528;
 Libderiv->deriv_classes[5][9][9] = int_stack + 32473;
 Libderiv->deriv_classes[5][10][9] = int_stack + 33628;
 Libderiv->deriv_classes[5][11][9] = int_stack + 35014;
 Libderiv->deriv_classes[6][6][9] = int_stack + 36652;
 Libderiv->deriv_classes[6][7][9] = int_stack + 37436;
 Libderiv->deriv_classes[6][8][9] = int_stack + 38444;
 Libderiv->deriv_classes[6][9][9] = int_stack + 39704;
 Libderiv->deriv_classes[6][10][9] = int_stack + 41244;
 Libderiv->deriv_classes[6][11][9] = int_stack + 43092;
 Libderiv->deriv_classes[5][6][8] = int_stack + 45276;
 Libderiv->deriv_classes[5][7][8] = int_stack + 45864;
 Libderiv->deriv_classes[5][8][8] = int_stack + 46620;
 Libderiv->deriv_classes[5][9][8] = int_stack + 47565;
 Libderiv->deriv_classes[5][10][8] = int_stack + 48720;
 Libderiv->deriv_classes[5][11][8] = int_stack + 50106;
 Libderiv->deriv_classes[6][6][8] = int_stack + 51744;
 Libderiv->deriv_classes[6][7][8] = int_stack + 52528;
 Libderiv->deriv_classes[6][8][8] = int_stack + 53536;
 Libderiv->deriv_classes[6][9][8] = int_stack + 54796;
 Libderiv->deriv_classes[6][10][8] = int_stack + 56336;
 Libderiv->deriv_classes[6][11][8] = int_stack + 58184;
 Libderiv->deriv_classes[5][6][7] = int_stack + 60368;
 Libderiv->deriv_classes[5][7][7] = int_stack + 60956;
 Libderiv->deriv_classes[5][8][7] = int_stack + 61712;
 Libderiv->deriv_classes[5][9][7] = int_stack + 62657;
 Libderiv->deriv_classes[5][10][7] = int_stack + 63812;
 Libderiv->deriv_classes[5][11][7] = int_stack + 65198;
 Libderiv->deriv_classes[6][6][7] = int_stack + 66836;
 Libderiv->deriv_classes[6][7][7] = int_stack + 67620;
 Libderiv->deriv_classes[6][8][7] = int_stack + 68628;
 Libderiv->deriv_classes[6][9][7] = int_stack + 69888;
 Libderiv->deriv_classes[6][10][7] = int_stack + 71428;
 Libderiv->deriv_classes[6][11][7] = int_stack + 73276;
 Libderiv->deriv_classes[5][6][6] = int_stack + 75460;
 Libderiv->deriv_classes[5][7][6] = int_stack + 76048;
 Libderiv->deriv_classes[5][8][6] = int_stack + 76804;
 Libderiv->deriv_classes[5][9][6] = int_stack + 77749;
 Libderiv->deriv_classes[5][10][6] = int_stack + 78904;
 Libderiv->deriv_classes[5][11][6] = int_stack + 80290;
 Libderiv->dvrr_classes[6][6] = int_stack + 81928;
 Libderiv->deriv_classes[6][6][6] = int_stack + 82712;
 Libderiv->dvrr_classes[6][7] = int_stack + 83496;
 Libderiv->deriv_classes[6][7][6] = int_stack + 84504;
 Libderiv->dvrr_classes[6][8] = int_stack + 85512;
 Libderiv->deriv_classes[6][8][6] = int_stack + 86772;
 Libderiv->dvrr_classes[6][9] = int_stack + 88032;
 Libderiv->deriv_classes[6][9][6] = int_stack + 89572;
 Libderiv->dvrr_classes[6][10] = int_stack + 91112;
 Libderiv->deriv_classes[6][10][6] = int_stack + 92960;
 Libderiv->deriv_classes[6][11][6] = int_stack + 94808;
 Libderiv->deriv_classes[5][6][2] = int_stack + 96992;
 Libderiv->deriv_classes[5][7][2] = int_stack + 97580;
 Libderiv->deriv_classes[5][8][2] = int_stack + 98336;
 Libderiv->deriv_classes[5][9][2] = int_stack + 99281;
 Libderiv->deriv_classes[5][10][2] = int_stack + 100436;
 Libderiv->deriv_classes[5][11][2] = int_stack + 101822;
 Libderiv->deriv_classes[6][6][2] = int_stack + 103460;
 Libderiv->deriv_classes[6][7][2] = int_stack + 104244;
 Libderiv->deriv_classes[6][8][2] = int_stack + 105252;
 Libderiv->deriv_classes[6][9][2] = int_stack + 106512;
 Libderiv->deriv_classes[6][10][2] = int_stack + 108052;
 Libderiv->deriv_classes[6][11][2] = int_stack + 109900;
 Libderiv->deriv_classes[5][6][1] = int_stack + 112084;
 Libderiv->deriv_classes[5][7][1] = int_stack + 112672;
 Libderiv->deriv_classes[5][8][1] = int_stack + 113428;
 Libderiv->deriv_classes[5][9][1] = int_stack + 114373;
 Libderiv->deriv_classes[5][10][1] = int_stack + 115528;
 Libderiv->deriv_classes[5][11][1] = int_stack + 116914;
 Libderiv->deriv_classes[6][6][1] = int_stack + 118552;
 Libderiv->deriv_classes[6][7][1] = int_stack + 119336;
 Libderiv->deriv_classes[6][8][1] = int_stack + 120344;
 Libderiv->deriv_classes[6][9][1] = int_stack + 121604;
 Libderiv->deriv_classes[6][10][1] = int_stack + 123144;
 Libderiv->deriv_classes[6][11][1] = int_stack + 124992;
 Libderiv->dvrr_classes[5][6] = int_stack + 127176;
 Libderiv->dvrr_classes[5][7] = int_stack + 127764;
 Libderiv->dvrr_classes[5][8] = int_stack + 128520;
 Libderiv->dvrr_classes[5][9] = int_stack + 129465;
 Libderiv->dvrr_classes[5][10] = int_stack + 130620;
 Libderiv->dvrr_classes[5][11] = int_stack + 132006;
 Libderiv->deriv_classes[5][6][0] = int_stack + 133644;
 Libderiv->deriv_classes[5][7][0] = int_stack + 134232;
 Libderiv->deriv_classes[5][8][0] = int_stack + 134988;
 Libderiv->deriv_classes[5][9][0] = int_stack + 135933;
 Libderiv->deriv_classes[5][10][0] = int_stack + 137088;
 Libderiv->deriv_classes[5][11][0] = int_stack + 138474;
 Libderiv->deriv_classes[6][6][0] = int_stack + 140112;
 Libderiv->deriv_classes[6][7][0] = int_stack + 140896;
 Libderiv->deriv_classes[6][8][0] = int_stack + 141904;
 Libderiv->deriv_classes[6][9][0] = int_stack + 143164;
 Libderiv->deriv_classes[6][10][0] = int_stack + 144704;
 Libderiv->deriv_classes[6][11][0] = int_stack + 146552;
 memset(int_stack,0,1189888);

 Libderiv->dvrr_stack = int_stack + 469119;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_hpih(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+148736,int_stack+127764,int_stack+127176,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+150500,int_stack+128520,int_stack+127764,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+152768,int_stack+150500,int_stack+148736,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+156296,int_stack+129465,int_stack+128520,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+159131,int_stack+156296,int_stack+150500,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+163667,int_stack+159131,int_stack+152768,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+169547,int_stack+130620,int_stack+129465,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+173012,int_stack+169547,int_stack+156296,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+178682,int_stack+173012,int_stack+159131,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+186242,int_stack+178682,int_stack+163667,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+195062,int_stack+588,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127176,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+196826,int_stack+1344,int_stack+588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127764,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+199094,int_stack+196826,int_stack+195062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148736,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+202622,int_stack+2289,int_stack+1344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128520,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+205457,int_stack+202622,int_stack+196826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+150500,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+209993,int_stack+205457,int_stack+199094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152768,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+195062,int_stack+3444,int_stack+2289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129465,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+215873,int_stack+195062,int_stack+202622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156296,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+221543,int_stack+215873,int_stack+205457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159131,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+198527,int_stack+221543,int_stack+209993, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163667,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+207347,int_stack+4830,int_stack+3444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130620,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+229103,int_stack+207347,int_stack+195062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169547,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+236033,int_stack+229103,int_stack+215873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173012,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+207347,int_stack+236033,int_stack+221543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178682,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+218687,int_stack+207347,int_stack+198527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+186242,21);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+195062,int_stack+83496,int_stack+81928,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+197414,int_stack+85512,int_stack+83496,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+200438,int_stack+197414,int_stack+195062,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+205142,int_stack+88032,int_stack+85512,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+208922,int_stack+205142,int_stack+197414,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+231035,int_stack+208922,int_stack+200438,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+238875,int_stack+91112,int_stack+88032,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+243495,int_stack+238875,int_stack+205142,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+251055,int_stack+243495,int_stack+208922,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+261135,int_stack+251055,int_stack+231035,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+214970,int_stack+7252,int_stack+6468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81928,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+8260,int_stack+7252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83496,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3024,int_stack+0,int_stack+214970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195062,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+272895,int_stack+9520,int_stack+8260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85512,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+276675,int_stack+272895,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197414,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+282723,int_stack+276675,int_stack+3024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200438,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+11060,int_stack+9520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88032,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+290563,int_stack+0,int_stack+272895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+205142,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+298123,int_stack+290563,int_stack+276675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208922,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+308203,int_stack+298123,int_stack+282723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+231035,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+272895,int_stack+12908,int_stack+11060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91112,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+278439,int_stack+272895,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238875,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+0,int_stack+278439,int_stack+290563, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243495,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+272895,int_stack+0,int_stack+298123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251055,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+288015,int_stack+272895,int_stack+308203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261135,28);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+272895,int_stack+15680,int_stack+15092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127176, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+274659,int_stack+16436,int_stack+15680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127764, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+276927,int_stack+274659,int_stack+272895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148736, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+280455,int_stack+17381,int_stack+16436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128520, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+283290,int_stack+280455,int_stack+274659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+150500, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+283290,int_stack+276927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152768, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+272895,int_stack+18536,int_stack+17381, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129465, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5880,int_stack+272895,int_stack+280455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156296, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+304479,int_stack+5880,int_stack+283290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159131, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+276360,int_stack+304479,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163667, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+0,int_stack+19922,int_stack+18536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130620, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+11550,int_stack+0,int_stack+272895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169547, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+312039,int_stack+11550,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173012, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+312039,int_stack+304479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178682, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+304479,int_stack+0,int_stack+276360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+186242, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+22344,int_stack+21560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81928, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2352,int_stack+23352,int_stack+22344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83496, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5376,int_stack+2352,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195062, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10080,int_stack+24612,int_stack+23352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85512, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13860,int_stack+10080,int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197414, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+272895,int_stack+13860,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200438, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+26152,int_stack+24612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88032, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+316827,int_stack+0,int_stack+10080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+205142, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+324387,int_stack+316827,int_stack+13860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208922, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4620,int_stack+324387,int_stack+272895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+231035, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+272895,int_stack+28000,int_stack+26152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91112, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+278439,int_stack+272895,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238875, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+16380,int_stack+278439,int_stack+316827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243495, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+272895,int_stack+16380,int_stack+324387, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251055, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+316827,int_stack+272895,int_stack+4620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261135, 0.0, zero_stack,28);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+272895,int_stack+30772,int_stack+30184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127176, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+274659,int_stack+31528,int_stack+30772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127764, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+276927,int_stack+274659,int_stack+272895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148736, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+280455,int_stack+32473,int_stack+31528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128520, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+283290,int_stack+280455,int_stack+274659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+150500, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+283290,int_stack+276927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152768, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+272895,int_stack+33628,int_stack+32473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129465, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5880,int_stack+272895,int_stack+280455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156296, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+11550,int_stack+5880,int_stack+283290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159131, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+276360,int_stack+11550,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163667, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+0,int_stack+35014,int_stack+33628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130620, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+19110,int_stack+0,int_stack+272895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169547, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+26040,int_stack+19110,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173012, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+26040,int_stack+11550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178682, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+11340,int_stack+0,int_stack+276360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+186242, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+37436,int_stack+36652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81928, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2352,int_stack+38444,int_stack+37436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83496, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5376,int_stack+2352,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195062, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+272895,int_stack+39704,int_stack+38444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85512, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+276675,int_stack+272895,int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197414, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+23688,int_stack+276675,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200438, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+41244,int_stack+39704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88032, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+31528,int_stack+0,int_stack+272895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+205142, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+333291,int_stack+31528,int_stack+276675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208922, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+272895,int_stack+333291,int_stack+23688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+231035, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+23688,int_stack+43092,int_stack+41244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91112, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+343371,int_stack+23688,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238875, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+352611,int_stack+343371,int_stack+31528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243495, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+23688,int_stack+352611,int_stack+333291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251055, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+333291,int_stack+23688,int_stack+272895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261135, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+272895,int_stack+45864,int_stack+45276, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+274659,int_stack+46620,int_stack+45864, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+276927,int_stack+274659,int_stack+272895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+280455,int_stack+47565,int_stack+46620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+283290,int_stack+280455,int_stack+274659, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+150500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+23688,int_stack+283290,int_stack+276927, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+272895,int_stack+48720,int_stack+47565, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+29568,int_stack+272895,int_stack+280455, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+35238,int_stack+29568,int_stack+283290, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+276360,int_stack+35238,int_stack+23688, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+23688,int_stack+50106,int_stack+48720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+42798,int_stack+23688,int_stack+272895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+169547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+349755,int_stack+42798,int_stack+29568, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+349755,int_stack+35238, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+349755,int_stack+0,int_stack+276360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+186242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+52528,int_stack+51744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2352,int_stack+53536,int_stack+52528, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5376,int_stack+2352,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+362103,int_stack+54796,int_stack+53536, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+272895,int_stack+362103,int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+278943,int_stack+272895,int_stack+5376, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+56336,int_stack+54796, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+23688,int_stack+0,int_stack+362103, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+205142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+31248,int_stack+23688,int_stack+272895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+41328,int_stack+31248,int_stack+278943, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+231035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+272895,int_stack+58184,int_stack+56336, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+278439,int_stack+272895,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+362103,int_stack+278439,int_stack+23688, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+272895,int_stack+362103,int_stack+31248, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+23688,int_stack+272895,int_stack+41328, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+272895,int_stack+60956,int_stack+60368, 0.0, zero_stack, 1.0, int_stack+127176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+274659,int_stack+61712,int_stack+60956, 0.0, zero_stack, 1.0, int_stack+127764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+276927,int_stack+274659,int_stack+272895, 0.0, zero_stack, 1.0, int_stack+148736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+280455,int_stack+62657,int_stack+61712, 0.0, zero_stack, 1.0, int_stack+128520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+283290,int_stack+280455,int_stack+274659, 0.0, zero_stack, 1.0, int_stack+150500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+362103,int_stack+283290,int_stack+276927, 0.0, zero_stack, 1.0, int_stack+152768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+272895,int_stack+63812,int_stack+62657, 0.0, zero_stack, 1.0, int_stack+129465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+367983,int_stack+272895,int_stack+280455, 0.0, zero_stack, 1.0, int_stack+156296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+40152,int_stack+367983,int_stack+283290, 0.0, zero_stack, 1.0, int_stack+159131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+276360,int_stack+40152,int_stack+362103, 0.0, zero_stack, 1.0, int_stack+163667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+362103,int_stack+65198,int_stack+63812, 0.0, zero_stack, 1.0, int_stack+130620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+47712,int_stack+362103,int_stack+272895, 0.0, zero_stack, 1.0, int_stack+169547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+54642,int_stack+47712,int_stack+367983, 0.0, zero_stack, 1.0, int_stack+173012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+54642,int_stack+40152, 0.0, zero_stack, 1.0, int_stack+178682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+40152,int_stack+0,int_stack+276360, 0.0, zero_stack, 1.0, int_stack+186242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+67620,int_stack+66836, 0.0, zero_stack, 1.0, int_stack+81928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2352,int_stack+68628,int_stack+67620, 0.0, zero_stack, 1.0, int_stack+83496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5376,int_stack+2352,int_stack+0, 0.0, zero_stack, 1.0, int_stack+195062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+52500,int_stack+69888,int_stack+68628, 0.0, zero_stack, 1.0, int_stack+85512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+56280,int_stack+52500,int_stack+2352, 0.0, zero_stack, 1.0, int_stack+197414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+272895,int_stack+56280,int_stack+5376, 0.0, zero_stack, 1.0, int_stack+200438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+71428,int_stack+69888, 0.0, zero_stack, 1.0, int_stack+88032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+62328,int_stack+0,int_stack+52500, 0.0, zero_stack, 1.0, int_stack+205142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+362103,int_stack+62328,int_stack+56280, 0.0, zero_stack, 1.0, int_stack+208922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+372183,int_stack+362103,int_stack+272895, 0.0, zero_stack, 1.0, int_stack+231035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+272895,int_stack+73276,int_stack+71428, 0.0, zero_stack, 1.0, int_stack+91112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+278439,int_stack+272895,int_stack+0, 0.0, zero_stack, 1.0, int_stack+238875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+383943,int_stack+278439,int_stack+62328, 0.0, zero_stack, 1.0, int_stack+243495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+272895,int_stack+383943,int_stack+362103, 0.0, zero_stack, 1.0, int_stack+251055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+52500,int_stack+272895,int_stack+372183, 0.0, zero_stack, 1.0, int_stack+261135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+272895,int_stack+76048,int_stack+75460, 1.0, int_stack+127176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+274659,int_stack+76804,int_stack+76048, 1.0, int_stack+127764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+276927,int_stack+274659,int_stack+272895, 1.0, int_stack+148736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+280455,int_stack+77749,int_stack+76804, 1.0, int_stack+128520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+283290,int_stack+280455,int_stack+274659, 1.0, int_stack+150500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+362103,int_stack+283290,int_stack+276927, 1.0, int_stack+152768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+148736,int_stack+78904,int_stack+77749, 1.0, int_stack+129465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+272895,int_stack+148736,int_stack+280455, 1.0, int_stack+156296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+367983,int_stack+272895,int_stack+283290, 1.0, int_stack+159131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+152201,int_stack+367983,int_stack+362103, 1.0, int_stack+163667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+362103,int_stack+80290,int_stack+78904, 1.0, int_stack+130620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+161021,int_stack+362103,int_stack+148736, 1.0, int_stack+169547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+278565,int_stack+161021,int_stack+272895, 1.0, int_stack+173012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+278565,int_stack+367983, 1.0, int_stack+178682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+272895,int_stack+0,int_stack+152201, 1.0, int_stack+186242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+84504,int_stack+82712, 1.0, int_stack+81928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2352,int_stack+86772,int_stack+84504, 1.0, int_stack+83496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5376,int_stack+2352,int_stack+0, 1.0, int_stack+195062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+148736,int_stack+89572,int_stack+86772, 1.0, int_stack+85512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+152516,int_stack+148736,int_stack+2352, 1.0, int_stack+197414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+158564,int_stack+152516,int_stack+5376, 1.0, int_stack+200438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+195062,int_stack+92960,int_stack+89572, 1.0, int_stack+88032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+195062,int_stack+148736, 1.0, int_stack+205142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+362103,int_stack+0,int_stack+152516, 1.0, int_stack+208922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+199682,int_stack+362103,int_stack+158564, 1.0, int_stack+231035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+231035,int_stack+94808,int_stack+92960, 1.0, int_stack+91112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+148736,int_stack+231035,int_stack+195062, 1.0, int_stack+238875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+372183,int_stack+148736,int_stack+0, 1.0, int_stack+243495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+148736,int_stack+372183,int_stack+362103, 1.0, int_stack+251055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+362103,int_stack+148736,int_stack+199682, 1.0, int_stack+261135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+148736,int_stack+132006,int_stack+130620,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+152894,int_stack+148736,int_stack+169547,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+159824,int_stack+152894,int_stack+173012,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+159824,int_stack+178682,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+148736,int_stack+0,int_stack+186242,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+97580,int_stack+96992,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1764,int_stack+98336,int_stack+97580,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4032,int_stack+1764,int_stack+0,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7560,int_stack+99281,int_stack+98336,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+161084,int_stack+7560,int_stack+1764,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+165620,int_stack+161084,int_stack+4032,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+100436,int_stack+99281,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+171500,int_stack+0,int_stack+7560,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3465,int_stack+171500,int_stack+161084,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+177170,int_stack+3465,int_stack+165620,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+161084,int_stack+101822,int_stack+100436,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+185990,int_stack+161084,int_stack+0,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+161084,int_stack+185990,int_stack+171500,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+185990,int_stack+161084,int_stack+3465,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+161084,int_stack+185990,int_stack+177170,21);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+173432,int_stack+104244,int_stack+103460,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+175784,int_stack+105252,int_stack+104244,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+178808,int_stack+175784,int_stack+173432,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+183512,int_stack+106512,int_stack+105252,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+187292,int_stack+183512,int_stack+175784,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+193340,int_stack+187292,int_stack+178808,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+173432,int_stack+108052,int_stack+106512,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+201180,int_stack+173432,int_stack+183512,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+201180,int_stack+187292,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+178052,int_stack+0,int_stack+193340,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+189812,int_stack+109900,int_stack+108052,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+208740,int_stack+189812,int_stack+173432,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+378567,int_stack+208740,int_stack+201180,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+189812,int_stack+378567,int_stack+0,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+378567,int_stack+189812,int_stack+178052,28);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+112672,int_stack+112084,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1764,int_stack+113428,int_stack+112672,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4032,int_stack+1764,int_stack+0,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7560,int_stack+114373,int_stack+113428,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+173432,int_stack+7560,int_stack+1764,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+177968,int_stack+173432,int_stack+4032,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+115528,int_stack+114373,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+183848,int_stack+0,int_stack+7560,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+3465,int_stack+183848,int_stack+173432,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+189518,int_stack+3465,int_stack+177968,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+173432,int_stack+116914,int_stack+115528,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+198338,int_stack+173432,int_stack+0,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+173432,int_stack+198338,int_stack+183848,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+198338,int_stack+173432,int_stack+3465,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+173432,int_stack+198338,int_stack+189518,21);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+185780,int_stack+119336,int_stack+118552,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+188132,int_stack+120344,int_stack+119336,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+191156,int_stack+188132,int_stack+185780,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+195860,int_stack+121604,int_stack+120344,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+199640,int_stack+195860,int_stack+188132,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+205688,int_stack+199640,int_stack+191156,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+185780,int_stack+123144,int_stack+121604,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+185780,int_stack+195860,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+231035,int_stack+0,int_stack+199640,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+190400,int_stack+231035,int_stack+205688,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+202160,int_stack+124992,int_stack+123144,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+207704,int_stack+202160,int_stack+185780,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+241115,int_stack+207704,int_stack+0,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+202160,int_stack+241115,int_stack+231035,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+231035,int_stack+202160,int_stack+190400,28);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+247499,int_stack+134232,int_stack+133644,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+249263,int_stack+134988,int_stack+134232,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+251531,int_stack+249263,int_stack+247499,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+255059,int_stack+135933,int_stack+134988,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+257894,int_stack+255059,int_stack+249263,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+262430,int_stack+257894,int_stack+251531,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+247499,int_stack+137088,int_stack+135933,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+247499,int_stack+255059,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+185780,int_stack+0,int_stack+257894,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+250964,int_stack+185780,int_stack+262430,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+259784,int_stack+138474,int_stack+137088,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+263942,int_stack+259784,int_stack+247499,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+193340,int_stack+263942,int_stack+0,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+193340,int_stack+185780,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+185780,int_stack+0,int_stack+250964,21);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+140896,int_stack+140112,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2352,int_stack+141904,int_stack+140896,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5376,int_stack+2352,int_stack+0,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+198128,int_stack+143164,int_stack+141904,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+201908,int_stack+198128,int_stack+2352,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+207956,int_stack+201908,int_stack+5376,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+144704,int_stack+143164,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+247499,int_stack+0,int_stack+198128,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+255059,int_stack+247499,int_stack+201908,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+68964,int_stack+255059,int_stack+207956,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+198128,int_stack+146552,int_stack+144704,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+203672,int_stack+198128,int_stack+0,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+80724,int_stack+203672,int_stack+247499,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+198128,int_stack+80724,int_stack+255059,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+80724,int_stack+198128,int_stack+68964,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+97188,int_stack+288015,int_stack+218687,588);
     Libderiv->ABCD[11] = int_stack + 97188;
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+395031,int_stack+316827,int_stack+304479,588);
     Libderiv->ABCD[10] = int_stack + 395031;
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+285243,int_stack+333291,int_stack+11340,588);
     Libderiv->ABCD[9] = int_stack + 285243;
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+432075,int_stack+23688,int_stack+349755,588);
     Libderiv->ABCD[8] = int_stack + 432075;
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+0,int_stack+52500,int_stack+40152,588);
     Libderiv->ABCD[7] = int_stack + 0;
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+37044,int_stack+362103,int_stack+272895,588);
     Libderiv->ABCD[6] = int_stack + 37044;
 /*--- compute (hp|ih) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+247499,int_stack+378567,int_stack+161084, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[2] = int_stack + 247499;
 /*--- compute (hp|ih) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+322287,int_stack+231035,int_stack+173432, 0.0, zero_stack, 1.0, int_stack+148736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[1] = int_stack + 322287;
 /*--- compute (hp|ih) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+198128,int_stack+80724,int_stack+185780, 1.0, int_stack+148736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[0] = int_stack + 198128;

}
