/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_pphg(Libderiv_t *, prim_data *);

  /* Computes derivatives of (pp|hg) integrals */

void d1hrr_order_pphg(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[1][5][11] = int_stack + 0;
 Libderiv->deriv_classes[1][6][11] = int_stack + 63;
 Libderiv->deriv_classes[1][7][11] = int_stack + 147;
 Libderiv->deriv_classes[1][8][11] = int_stack + 255;
 Libderiv->deriv_classes[1][9][11] = int_stack + 390;
 Libderiv->deriv_classes[2][5][11] = int_stack + 555;
 Libderiv->deriv_classes[2][6][11] = int_stack + 681;
 Libderiv->deriv_classes[2][7][11] = int_stack + 849;
 Libderiv->deriv_classes[2][8][11] = int_stack + 1065;
 Libderiv->deriv_classes[2][9][11] = int_stack + 1335;
 Libderiv->deriv_classes[1][5][10] = int_stack + 1665;
 Libderiv->deriv_classes[1][6][10] = int_stack + 1728;
 Libderiv->deriv_classes[1][7][10] = int_stack + 1812;
 Libderiv->deriv_classes[1][8][10] = int_stack + 1920;
 Libderiv->deriv_classes[1][9][10] = int_stack + 2055;
 Libderiv->deriv_classes[2][5][10] = int_stack + 2220;
 Libderiv->deriv_classes[2][6][10] = int_stack + 2346;
 Libderiv->deriv_classes[2][7][10] = int_stack + 2514;
 Libderiv->deriv_classes[2][8][10] = int_stack + 2730;
 Libderiv->deriv_classes[2][9][10] = int_stack + 3000;
 Libderiv->deriv_classes[1][5][9] = int_stack + 3330;
 Libderiv->deriv_classes[1][6][9] = int_stack + 3393;
 Libderiv->deriv_classes[1][7][9] = int_stack + 3477;
 Libderiv->deriv_classes[1][8][9] = int_stack + 3585;
 Libderiv->deriv_classes[1][9][9] = int_stack + 3720;
 Libderiv->deriv_classes[2][5][9] = int_stack + 3885;
 Libderiv->deriv_classes[2][6][9] = int_stack + 4011;
 Libderiv->deriv_classes[2][7][9] = int_stack + 4179;
 Libderiv->deriv_classes[2][8][9] = int_stack + 4395;
 Libderiv->deriv_classes[2][9][9] = int_stack + 4665;
 Libderiv->deriv_classes[1][5][8] = int_stack + 4995;
 Libderiv->deriv_classes[1][6][8] = int_stack + 5058;
 Libderiv->deriv_classes[1][7][8] = int_stack + 5142;
 Libderiv->deriv_classes[1][8][8] = int_stack + 5250;
 Libderiv->deriv_classes[1][9][8] = int_stack + 5385;
 Libderiv->deriv_classes[2][5][8] = int_stack + 5550;
 Libderiv->deriv_classes[2][6][8] = int_stack + 5676;
 Libderiv->deriv_classes[2][7][8] = int_stack + 5844;
 Libderiv->deriv_classes[2][8][8] = int_stack + 6060;
 Libderiv->deriv_classes[2][9][8] = int_stack + 6330;
 Libderiv->deriv_classes[1][5][7] = int_stack + 6660;
 Libderiv->deriv_classes[1][6][7] = int_stack + 6723;
 Libderiv->deriv_classes[1][7][7] = int_stack + 6807;
 Libderiv->deriv_classes[1][8][7] = int_stack + 6915;
 Libderiv->deriv_classes[1][9][7] = int_stack + 7050;
 Libderiv->deriv_classes[2][5][7] = int_stack + 7215;
 Libderiv->deriv_classes[2][6][7] = int_stack + 7341;
 Libderiv->deriv_classes[2][7][7] = int_stack + 7509;
 Libderiv->deriv_classes[2][8][7] = int_stack + 7725;
 Libderiv->deriv_classes[2][9][7] = int_stack + 7995;
 Libderiv->deriv_classes[1][5][6] = int_stack + 8325;
 Libderiv->deriv_classes[1][6][6] = int_stack + 8388;
 Libderiv->deriv_classes[1][7][6] = int_stack + 8472;
 Libderiv->deriv_classes[1][8][6] = int_stack + 8580;
 Libderiv->deriv_classes[1][9][6] = int_stack + 8715;
 Libderiv->dvrr_classes[2][5] = int_stack + 8880;
 Libderiv->deriv_classes[2][5][6] = int_stack + 9006;
 Libderiv->dvrr_classes[2][6] = int_stack + 9132;
 Libderiv->deriv_classes[2][6][6] = int_stack + 9300;
 Libderiv->dvrr_classes[2][7] = int_stack + 9468;
 Libderiv->deriv_classes[2][7][6] = int_stack + 9684;
 Libderiv->dvrr_classes[2][8] = int_stack + 9900;
 Libderiv->deriv_classes[2][8][6] = int_stack + 10170;
 Libderiv->deriv_classes[2][9][6] = int_stack + 10440;
 Libderiv->deriv_classes[1][5][2] = int_stack + 10770;
 Libderiv->deriv_classes[1][6][2] = int_stack + 10833;
 Libderiv->deriv_classes[1][7][2] = int_stack + 10917;
 Libderiv->deriv_classes[1][8][2] = int_stack + 11025;
 Libderiv->deriv_classes[1][9][2] = int_stack + 11160;
 Libderiv->deriv_classes[2][5][2] = int_stack + 11325;
 Libderiv->deriv_classes[2][6][2] = int_stack + 11451;
 Libderiv->deriv_classes[2][7][2] = int_stack + 11619;
 Libderiv->deriv_classes[2][8][2] = int_stack + 11835;
 Libderiv->deriv_classes[2][9][2] = int_stack + 12105;
 Libderiv->deriv_classes[1][5][1] = int_stack + 12435;
 Libderiv->deriv_classes[1][6][1] = int_stack + 12498;
 Libderiv->deriv_classes[1][7][1] = int_stack + 12582;
 Libderiv->deriv_classes[1][8][1] = int_stack + 12690;
 Libderiv->deriv_classes[1][9][1] = int_stack + 12825;
 Libderiv->deriv_classes[2][5][1] = int_stack + 12990;
 Libderiv->deriv_classes[2][6][1] = int_stack + 13116;
 Libderiv->deriv_classes[2][7][1] = int_stack + 13284;
 Libderiv->deriv_classes[2][8][1] = int_stack + 13500;
 Libderiv->deriv_classes[2][9][1] = int_stack + 13770;
 Libderiv->dvrr_classes[1][5] = int_stack + 14100;
 Libderiv->dvrr_classes[1][6] = int_stack + 14163;
 Libderiv->dvrr_classes[1][7] = int_stack + 14247;
 Libderiv->dvrr_classes[1][8] = int_stack + 14355;
 Libderiv->dvrr_classes[1][9] = int_stack + 14490;
 Libderiv->deriv_classes[1][5][0] = int_stack + 14655;
 Libderiv->deriv_classes[1][6][0] = int_stack + 14718;
 Libderiv->deriv_classes[1][7][0] = int_stack + 14802;
 Libderiv->deriv_classes[1][8][0] = int_stack + 14910;
 Libderiv->deriv_classes[1][9][0] = int_stack + 15045;
 Libderiv->deriv_classes[2][5][0] = int_stack + 15210;
 Libderiv->deriv_classes[2][6][0] = int_stack + 15336;
 Libderiv->deriv_classes[2][7][0] = int_stack + 15504;
 Libderiv->deriv_classes[2][8][0] = int_stack + 15720;
 Libderiv->deriv_classes[2][9][0] = int_stack + 15990;
 memset(int_stack,0,130560);

 Libderiv->dvrr_stack = int_stack + 38550;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_pphg(Libderiv, Data);
   Data++;
 }

 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+16320,int_stack+14163,int_stack+14100,3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+16509,int_stack+14247,int_stack+14163,3);
 /*--- compute (p0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+16761,int_stack+16509,int_stack+16320,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+17139,int_stack+14355,int_stack+14247,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+17463,int_stack+17139,int_stack+16509,3);
 /*--- compute (p0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+17967,int_stack+17463,int_stack+16761,3);
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+18597,int_stack+63,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14100,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+18786,int_stack+147,int_stack+63, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14163,3);
 /*--- compute (p0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+19038,int_stack+18786,int_stack+18597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16320,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+19416,int_stack+255,int_stack+147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14247,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+19740,int_stack+19416,int_stack+18786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16509,3);
 /*--- compute (p0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+20244,int_stack+19740,int_stack+19038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16761,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+18597,int_stack+390,int_stack+255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14355,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+20874,int_stack+18597,int_stack+19416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17139,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+18597,int_stack+20874,int_stack+19740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17463,3);
 /*--- compute (p0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+20874,int_stack+18597,int_stack+20244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17967,3);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+18597,int_stack+9132,int_stack+8880,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+18975,int_stack+9468,int_stack+9132,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+19479,int_stack+18975,int_stack+18597,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+21819,int_stack+9900,int_stack+9468,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+22467,int_stack+21819,int_stack+18975,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+23475,int_stack+22467,int_stack+19479,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+20235,int_stack+681,int_stack+555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8880,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+849,int_stack+681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9132,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+24735,int_stack+0,int_stack+20235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18597,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+25491,int_stack+1065,int_stack+849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9468,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+26139,int_stack+25491,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18975,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+27147,int_stack+26139,int_stack+24735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19479,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+1335,int_stack+1065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9900,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+28407,int_stack+0,int_stack+25491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21819,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+29703,int_stack+28407,int_stack+26139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22467,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+24735,int_stack+29703,int_stack+27147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23475,6);
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+1728,int_stack+1665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14100, 0.0, zero_stack,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+189,int_stack+1812,int_stack+1728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14163, 0.0, zero_stack,3);
 /*--- compute (p0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+441,int_stack+189,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16320, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+819,int_stack+1920,int_stack+1812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14247, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1143,int_stack+819,int_stack+189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16509, 0.0, zero_stack,3);
 /*--- compute (p0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+26625,int_stack+1143,int_stack+441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16761, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+2055,int_stack+1920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14355, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+27255,int_stack+0,int_stack+819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17139, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+27255,int_stack+1143, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17463, 0.0, zero_stack,3);
 /*--- compute (p0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+27255,int_stack+0,int_stack+26625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17967, 0.0, zero_stack,3);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26625,int_stack+2346,int_stack+2220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8880, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+2514,int_stack+2346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9132, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+504,int_stack+0,int_stack+26625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18597, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1260,int_stack+2730,int_stack+2514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9468, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+28200,int_stack+1260,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18975, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+29208,int_stack+28200,int_stack+504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19479, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+3000,int_stack+2730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9900, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1908,int_stack+0,int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21819, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+1908,int_stack+28200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22467, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+30468,int_stack+0,int_stack+29208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23475, 0.0, zero_stack,6);
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+3393,int_stack+3330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14100, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+189,int_stack+3477,int_stack+3393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14163, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+441,int_stack+189,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16320, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+819,int_stack+3585,int_stack+3477, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14247, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1143,int_stack+819,int_stack+189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16509, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+26625,int_stack+1143,int_stack+441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16761, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+3720,int_stack+3585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14355, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1647,int_stack+0,int_stack+819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17139, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+1647,int_stack+1143, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17463, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+840,int_stack+0,int_stack+26625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17967, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26625,int_stack+4011,int_stack+3885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8880, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+4179,int_stack+4011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9132, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1785,int_stack+0,int_stack+26625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18597, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2541,int_stack+4395,int_stack+4179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9468, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3189,int_stack+2541,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18975, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28200,int_stack+3189,int_stack+1785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19479, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+4665,int_stack+4395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9900, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+32358,int_stack+0,int_stack+2541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21819, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+33654,int_stack+32358,int_stack+3189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22467, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1785,int_stack+33654,int_stack+28200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23475, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28200,int_stack+5058,int_stack+4995, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+28389,int_stack+5142,int_stack+5058, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14163, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+28641,int_stack+28389,int_stack+28200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+29019,int_stack+5250,int_stack+5142, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+29343,int_stack+29019,int_stack+28389, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+26625,int_stack+29343,int_stack+28641, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+28200,int_stack+5385,int_stack+5250, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+32358,int_stack+28200,int_stack+29019, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+32358,int_stack+29343, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+32358,int_stack+0,int_stack+26625, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26625,int_stack+5676,int_stack+5550, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+5844,int_stack+5676, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+33303,int_stack+0,int_stack+26625, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+34059,int_stack+6060,int_stack+5844, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+34707,int_stack+34059,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28200,int_stack+34707,int_stack+33303, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+6330,int_stack+6060, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3675,int_stack+0,int_stack+34059, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4971,int_stack+3675,int_stack+34707, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+33303,int_stack+4971,int_stack+28200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28200,int_stack+6723,int_stack+6660, 0.0, zero_stack, 1.0, int_stack+14100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+28389,int_stack+6807,int_stack+6723, 0.0, zero_stack, 1.0, int_stack+14163, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+28641,int_stack+28389,int_stack+28200, 0.0, zero_stack, 1.0, int_stack+16320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+29019,int_stack+6915,int_stack+6807, 0.0, zero_stack, 1.0, int_stack+14247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+29343,int_stack+29019,int_stack+28389, 0.0, zero_stack, 1.0, int_stack+16509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+26625,int_stack+29343,int_stack+28641, 0.0, zero_stack, 1.0, int_stack+16761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+28200,int_stack+7050,int_stack+6915, 0.0, zero_stack, 1.0, int_stack+14355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3675,int_stack+28200,int_stack+29019, 0.0, zero_stack, 1.0, int_stack+17139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+3675,int_stack+29343, 0.0, zero_stack, 1.0, int_stack+17463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3675,int_stack+0,int_stack+26625, 0.0, zero_stack, 1.0, int_stack+17967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26625,int_stack+7341,int_stack+7215, 0.0, zero_stack, 1.0, int_stack+8880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+7509,int_stack+7341, 0.0, zero_stack, 1.0, int_stack+9132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4620,int_stack+0,int_stack+26625, 0.0, zero_stack, 1.0, int_stack+18597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5376,int_stack+7725,int_stack+7509, 0.0, zero_stack, 1.0, int_stack+9468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6024,int_stack+5376,int_stack+0, 0.0, zero_stack, 1.0, int_stack+18975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28200,int_stack+6024,int_stack+4620, 0.0, zero_stack, 1.0, int_stack+19479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+7995,int_stack+7725, 0.0, zero_stack, 1.0, int_stack+9900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+35193,int_stack+0,int_stack+5376, 0.0, zero_stack, 1.0, int_stack+21819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+36489,int_stack+35193,int_stack+6024, 0.0, zero_stack, 1.0, int_stack+22467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4620,int_stack+36489,int_stack+28200, 0.0, zero_stack, 1.0, int_stack+23475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28200,int_stack+8388,int_stack+8325, 1.0, int_stack+14100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+28389,int_stack+8472,int_stack+8388, 1.0, int_stack+14163, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+28641,int_stack+28389,int_stack+28200, 1.0, int_stack+16320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+29019,int_stack+8580,int_stack+8472, 1.0, int_stack+14247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+29343,int_stack+29019,int_stack+28389, 1.0, int_stack+16509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+26625,int_stack+29343,int_stack+28641, 1.0, int_stack+16761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+16320,int_stack+8715,int_stack+8580, 1.0, int_stack+14355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+28200,int_stack+16320,int_stack+29019, 1.0, int_stack+17139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+28200,int_stack+29343, 1.0, int_stack+17463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+28200,int_stack+0,int_stack+26625, 1.0, int_stack+17967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26625,int_stack+9300,int_stack+9006, 1.0, int_stack+8880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+9684,int_stack+9300, 1.0, int_stack+9132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29145,int_stack+0,int_stack+26625, 1.0, int_stack+18597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+16320,int_stack+10170,int_stack+9684, 1.0, int_stack+9468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+35193,int_stack+16320,int_stack+0, 1.0, int_stack+18975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+36201,int_stack+35193,int_stack+29145, 1.0, int_stack+19479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+29145,int_stack+10440,int_stack+10170, 1.0, int_stack+9900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+18597,int_stack+29145,int_stack+16320, 1.0, int_stack+21819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6510,int_stack+18597,int_stack+35193, 1.0, int_stack+22467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+18597,int_stack+6510,int_stack+36201, 1.0, int_stack+23475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6510,int_stack+14490,int_stack+14355,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6915,int_stack+6510,int_stack+17139,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+6915,int_stack+17463,3);
 /*--- compute (p0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6510,int_stack+0,int_stack+17967,3);
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+10833,int_stack+10770,3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+189,int_stack+10917,int_stack+10833,3);
 /*--- compute (p0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+441,int_stack+189,int_stack+0,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7455,int_stack+11025,int_stack+10917,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7779,int_stack+7455,int_stack+189,3);
 /*--- compute (p0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+26625,int_stack+7779,int_stack+441,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+11160,int_stack+11025,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+8283,int_stack+0,int_stack+7455,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+8283,int_stack+7779,3);
 /*--- compute (p0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7455,int_stack+0,int_stack+26625,3);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+26625,int_stack+11451,int_stack+11325,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+11619,int_stack+11451,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+8400,int_stack+0,int_stack+26625,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+9156,int_stack+11835,int_stack+11619,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+9804,int_stack+9156,int_stack+0,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+35193,int_stack+9804,int_stack+8400,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+12105,int_stack+11835,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+10812,int_stack+0,int_stack+9156,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+36453,int_stack+10812,int_stack+9804,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+8400,int_stack+36453,int_stack+35193,6);
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+35193,int_stack+12498,int_stack+12435,3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+35382,int_stack+12582,int_stack+12498,3);
 /*--- compute (p0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+35634,int_stack+35382,int_stack+35193,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+36012,int_stack+12690,int_stack+12582,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+36336,int_stack+36012,int_stack+35382,3);
 /*--- compute (p0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+26625,int_stack+36336,int_stack+35634,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+35193,int_stack+12825,int_stack+12690,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+36840,int_stack+35193,int_stack+36012,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+36840,int_stack+36336,3);
 /*--- compute (p0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+35193,int_stack+0,int_stack+26625,3);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+26625,int_stack+13116,int_stack+12990,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+13284,int_stack+13116,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+36138,int_stack+0,int_stack+26625,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+36894,int_stack+13500,int_stack+13284,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+37542,int_stack+36894,int_stack+0,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+10290,int_stack+37542,int_stack+36138,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+13770,int_stack+13500,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+11550,int_stack+0,int_stack+36894,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+12846,int_stack+11550,int_stack+37542,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+36138,int_stack+12846,int_stack+10290,6);
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+10290,int_stack+14718,int_stack+14655,3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+10479,int_stack+14802,int_stack+14718,3);
 /*--- compute (p0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+10731,int_stack+10479,int_stack+10290,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+11109,int_stack+14910,int_stack+14802,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+11433,int_stack+11109,int_stack+10479,3);
 /*--- compute (p0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+26625,int_stack+11433,int_stack+10731,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+10290,int_stack+15045,int_stack+14910,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+11937,int_stack+10290,int_stack+11109,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+11937,int_stack+11433,3);
 /*--- compute (p0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+10290,int_stack+0,int_stack+26625,3);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+26625,int_stack+15336,int_stack+15210,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+15504,int_stack+15336,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+11235,int_stack+0,int_stack+26625,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+11991,int_stack+15720,int_stack+15504,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+12639,int_stack+11991,int_stack+0,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+13647,int_stack+12639,int_stack+11235,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+15990,int_stack+15720,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+14907,int_stack+0,int_stack+11991,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+16203,int_stack+14907,int_stack+12639,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+11235,int_stack+16203,int_stack+13647,6);
 /*--- compute (pp|hg) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+13125,int_stack+24735,int_stack+20874,315);
     Libderiv->ABCD[11] = int_stack + 13125;
 /*--- compute (pp|hg) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+20487,int_stack+30468,int_stack+27255,315);
     Libderiv->ABCD[10] = int_stack + 20487;
 /*--- compute (pp|hg) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+23322,int_stack+1785,int_stack+840,315);
     Libderiv->ABCD[9] = int_stack + 23322;
 /*--- compute (pp|hg) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+0,int_stack+33303,int_stack+32358,315);
     Libderiv->ABCD[8] = int_stack + 0;
 /*--- compute (pp|hg) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+29145,int_stack+4620,int_stack+3675,315);
     Libderiv->ABCD[7] = int_stack + 29145;
 /*--- compute (pp|hg) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+2835,int_stack+18597,int_stack+28200,315);
     Libderiv->ABCD[6] = int_stack + 2835;
 /*--- compute (pp|hg) ---*/
   d1hrr1_build_pp(Libderiv->AB,int_stack+15960,int_stack+8400,int_stack+7455, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[2] = int_stack + 15960;
 /*--- compute (pp|hg) ---*/
   d1hrr1_build_pp(Libderiv->AB,int_stack+7455,int_stack+36138,int_stack+35193, 0.0, zero_stack, 1.0, int_stack+6510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[1] = int_stack + 7455;
 /*--- compute (pp|hg) ---*/
   d1hrr1_build_pp(Libderiv->AB,int_stack+26157,int_stack+11235,int_stack+10290, 1.0, int_stack+6510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[0] = int_stack + 26157;

}
