/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_ppig(Libderiv_t *, prim_data *);

  /* Computes derivatives of (pp|ig) integrals */

void d1hrr_order_ppig(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[1][6][11] = int_stack + 0;
 Libderiv->deriv_classes[1][7][11] = int_stack + 84;
 Libderiv->deriv_classes[1][8][11] = int_stack + 192;
 Libderiv->deriv_classes[1][9][11] = int_stack + 327;
 Libderiv->deriv_classes[1][10][11] = int_stack + 492;
 Libderiv->deriv_classes[2][6][11] = int_stack + 690;
 Libderiv->deriv_classes[2][7][11] = int_stack + 858;
 Libderiv->deriv_classes[2][8][11] = int_stack + 1074;
 Libderiv->deriv_classes[2][9][11] = int_stack + 1344;
 Libderiv->deriv_classes[2][10][11] = int_stack + 1674;
 Libderiv->deriv_classes[1][6][10] = int_stack + 2070;
 Libderiv->deriv_classes[1][7][10] = int_stack + 2154;
 Libderiv->deriv_classes[1][8][10] = int_stack + 2262;
 Libderiv->deriv_classes[1][9][10] = int_stack + 2397;
 Libderiv->deriv_classes[1][10][10] = int_stack + 2562;
 Libderiv->deriv_classes[2][6][10] = int_stack + 2760;
 Libderiv->deriv_classes[2][7][10] = int_stack + 2928;
 Libderiv->deriv_classes[2][8][10] = int_stack + 3144;
 Libderiv->deriv_classes[2][9][10] = int_stack + 3414;
 Libderiv->deriv_classes[2][10][10] = int_stack + 3744;
 Libderiv->deriv_classes[1][6][9] = int_stack + 4140;
 Libderiv->deriv_classes[1][7][9] = int_stack + 4224;
 Libderiv->deriv_classes[1][8][9] = int_stack + 4332;
 Libderiv->deriv_classes[1][9][9] = int_stack + 4467;
 Libderiv->deriv_classes[1][10][9] = int_stack + 4632;
 Libderiv->deriv_classes[2][6][9] = int_stack + 4830;
 Libderiv->deriv_classes[2][7][9] = int_stack + 4998;
 Libderiv->deriv_classes[2][8][9] = int_stack + 5214;
 Libderiv->deriv_classes[2][9][9] = int_stack + 5484;
 Libderiv->deriv_classes[2][10][9] = int_stack + 5814;
 Libderiv->deriv_classes[1][6][8] = int_stack + 6210;
 Libderiv->deriv_classes[1][7][8] = int_stack + 6294;
 Libderiv->deriv_classes[1][8][8] = int_stack + 6402;
 Libderiv->deriv_classes[1][9][8] = int_stack + 6537;
 Libderiv->deriv_classes[1][10][8] = int_stack + 6702;
 Libderiv->deriv_classes[2][6][8] = int_stack + 6900;
 Libderiv->deriv_classes[2][7][8] = int_stack + 7068;
 Libderiv->deriv_classes[2][8][8] = int_stack + 7284;
 Libderiv->deriv_classes[2][9][8] = int_stack + 7554;
 Libderiv->deriv_classes[2][10][8] = int_stack + 7884;
 Libderiv->deriv_classes[1][6][7] = int_stack + 8280;
 Libderiv->deriv_classes[1][7][7] = int_stack + 8364;
 Libderiv->deriv_classes[1][8][7] = int_stack + 8472;
 Libderiv->deriv_classes[1][9][7] = int_stack + 8607;
 Libderiv->deriv_classes[1][10][7] = int_stack + 8772;
 Libderiv->deriv_classes[2][6][7] = int_stack + 8970;
 Libderiv->deriv_classes[2][7][7] = int_stack + 9138;
 Libderiv->deriv_classes[2][8][7] = int_stack + 9354;
 Libderiv->deriv_classes[2][9][7] = int_stack + 9624;
 Libderiv->deriv_classes[2][10][7] = int_stack + 9954;
 Libderiv->deriv_classes[1][6][6] = int_stack + 10350;
 Libderiv->deriv_classes[1][7][6] = int_stack + 10434;
 Libderiv->deriv_classes[1][8][6] = int_stack + 10542;
 Libderiv->deriv_classes[1][9][6] = int_stack + 10677;
 Libderiv->deriv_classes[1][10][6] = int_stack + 10842;
 Libderiv->dvrr_classes[2][6] = int_stack + 11040;
 Libderiv->deriv_classes[2][6][6] = int_stack + 11208;
 Libderiv->dvrr_classes[2][7] = int_stack + 11376;
 Libderiv->deriv_classes[2][7][6] = int_stack + 11592;
 Libderiv->dvrr_classes[2][8] = int_stack + 11808;
 Libderiv->deriv_classes[2][8][6] = int_stack + 12078;
 Libderiv->dvrr_classes[2][9] = int_stack + 12348;
 Libderiv->deriv_classes[2][9][6] = int_stack + 12678;
 Libderiv->deriv_classes[2][10][6] = int_stack + 13008;
 Libderiv->deriv_classes[1][6][2] = int_stack + 13404;
 Libderiv->deriv_classes[1][7][2] = int_stack + 13488;
 Libderiv->deriv_classes[1][8][2] = int_stack + 13596;
 Libderiv->deriv_classes[1][9][2] = int_stack + 13731;
 Libderiv->deriv_classes[1][10][2] = int_stack + 13896;
 Libderiv->deriv_classes[2][6][2] = int_stack + 14094;
 Libderiv->deriv_classes[2][7][2] = int_stack + 14262;
 Libderiv->deriv_classes[2][8][2] = int_stack + 14478;
 Libderiv->deriv_classes[2][9][2] = int_stack + 14748;
 Libderiv->deriv_classes[2][10][2] = int_stack + 15078;
 Libderiv->deriv_classes[1][6][1] = int_stack + 15474;
 Libderiv->deriv_classes[1][7][1] = int_stack + 15558;
 Libderiv->deriv_classes[1][8][1] = int_stack + 15666;
 Libderiv->deriv_classes[1][9][1] = int_stack + 15801;
 Libderiv->deriv_classes[1][10][1] = int_stack + 15966;
 Libderiv->deriv_classes[2][6][1] = int_stack + 16164;
 Libderiv->deriv_classes[2][7][1] = int_stack + 16332;
 Libderiv->deriv_classes[2][8][1] = int_stack + 16548;
 Libderiv->deriv_classes[2][9][1] = int_stack + 16818;
 Libderiv->deriv_classes[2][10][1] = int_stack + 17148;
 Libderiv->dvrr_classes[1][6] = int_stack + 17544;
 Libderiv->dvrr_classes[1][7] = int_stack + 17628;
 Libderiv->dvrr_classes[1][8] = int_stack + 17736;
 Libderiv->dvrr_classes[1][9] = int_stack + 17871;
 Libderiv->dvrr_classes[1][10] = int_stack + 18036;
 Libderiv->deriv_classes[1][6][0] = int_stack + 18234;
 Libderiv->deriv_classes[1][7][0] = int_stack + 18318;
 Libderiv->deriv_classes[1][8][0] = int_stack + 18426;
 Libderiv->deriv_classes[1][9][0] = int_stack + 18561;
 Libderiv->deriv_classes[1][10][0] = int_stack + 18726;
 Libderiv->deriv_classes[2][6][0] = int_stack + 18924;
 Libderiv->deriv_classes[2][7][0] = int_stack + 19092;
 Libderiv->deriv_classes[2][8][0] = int_stack + 19308;
 Libderiv->deriv_classes[2][9][0] = int_stack + 19578;
 Libderiv->deriv_classes[2][10][0] = int_stack + 19908;
 memset(int_stack,0,162432);

 Libderiv->dvrr_stack = int_stack + 55104;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_ppig(Libderiv, Data);
   Data++;
 }

 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+20304,int_stack+17628,int_stack+17544,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+20556,int_stack+17736,int_stack+17628,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+20880,int_stack+20556,int_stack+20304,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+21384,int_stack+17871,int_stack+17736,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+21789,int_stack+21384,int_stack+20556,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+22437,int_stack+21789,int_stack+20880,3);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+23277,int_stack+84,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17544,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+23529,int_stack+192,int_stack+84, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17628,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+23853,int_stack+23529,int_stack+23277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20304,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+24357,int_stack+327,int_stack+192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17736,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+24762,int_stack+24357,int_stack+23529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20556,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+25410,int_stack+24762,int_stack+23853, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20880,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+23277,int_stack+492,int_stack+327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17871,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+26250,int_stack+23277,int_stack+24357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21384,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+23277,int_stack+26250,int_stack+24762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21789,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+26250,int_stack+23277,int_stack+25410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22437,3);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+23277,int_stack+11376,int_stack+11040,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+23781,int_stack+11808,int_stack+11376,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+24429,int_stack+23781,int_stack+23277,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+25437,int_stack+12348,int_stack+11808,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+27510,int_stack+25437,int_stack+23781,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+28806,int_stack+27510,int_stack+24429,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30486,int_stack+858,int_stack+690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11040,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+1074,int_stack+858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11376,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+30990,int_stack+0,int_stack+30486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23277,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+31998,int_stack+1344,int_stack+1074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11808,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+32808,int_stack+31998,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23781,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+34104,int_stack+32808,int_stack+30990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24429,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+1674,int_stack+1344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12348,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+35784,int_stack+0,int_stack+31998, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25437,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+30486,int_stack+35784,int_stack+32808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27510,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+35784,int_stack+30486,int_stack+34104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28806,6);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30486,int_stack+2154,int_stack+2070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17544, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+30738,int_stack+2262,int_stack+2154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17628, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+31062,int_stack+30738,int_stack+30486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20304, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+31566,int_stack+2397,int_stack+2262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17736, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+31971,int_stack+31566,int_stack+30738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20556, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+32619,int_stack+31971,int_stack+31062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20880, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+30486,int_stack+2562,int_stack+2397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17871, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+33459,int_stack+30486,int_stack+31566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21384, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+30486,int_stack+33459,int_stack+31971, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21789, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+33459,int_stack+30486,int_stack+32619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22437, 0.0, zero_stack,3);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30486,int_stack+2928,int_stack+2760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11040, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+30990,int_stack+3144,int_stack+2928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11376, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+31638,int_stack+30990,int_stack+30486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23277, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+32646,int_stack+3414,int_stack+3144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11808, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+32646,int_stack+30990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23781, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1296,int_stack+0,int_stack+31638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24429, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+30486,int_stack+3744,int_stack+3414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12348, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+38304,int_stack+30486,int_stack+32646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25437, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+30486,int_stack+38304,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27510, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+38304,int_stack+30486,int_stack+1296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28806, 0.0, zero_stack,6);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30486,int_stack+4224,int_stack+4140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17544, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+30738,int_stack+4332,int_stack+4224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17628, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+31062,int_stack+30738,int_stack+30486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20304, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+31566,int_stack+4467,int_stack+4332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17736, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+31971,int_stack+31566,int_stack+30738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20556, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+32619,int_stack+31971,int_stack+31062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20880, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+30486,int_stack+4632,int_stack+4467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17871, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+0,int_stack+30486,int_stack+31566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21384, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+30486,int_stack+0,int_stack+31971, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21789, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+30486,int_stack+32619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22437, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30486,int_stack+4998,int_stack+4830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11040, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+30990,int_stack+5214,int_stack+4998, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11376, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+31638,int_stack+30990,int_stack+30486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23277, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+32646,int_stack+5484,int_stack+5214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11808, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1260,int_stack+32646,int_stack+30990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23781, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2556,int_stack+1260,int_stack+31638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24429, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+30486,int_stack+5814,int_stack+5484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12348, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4236,int_stack+30486,int_stack+32646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25437, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+30486,int_stack+4236,int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27510, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+40824,int_stack+30486,int_stack+2556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28806, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30486,int_stack+6294,int_stack+6210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+30738,int_stack+6402,int_stack+6294, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+31062,int_stack+30738,int_stack+30486, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+31566,int_stack+6537,int_stack+6402, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+31971,int_stack+31566,int_stack+30738, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+32619,int_stack+31971,int_stack+31062, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+30486,int_stack+6702,int_stack+6537, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1260,int_stack+30486,int_stack+31566, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+30486,int_stack+1260,int_stack+31971, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1260,int_stack+30486,int_stack+32619, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30486,int_stack+7068,int_stack+6900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+30990,int_stack+7284,int_stack+7068, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+31638,int_stack+30990,int_stack+30486, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+32646,int_stack+7554,int_stack+7284, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+11808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2520,int_stack+32646,int_stack+30990, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23781, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3816,int_stack+2520,int_stack+31638, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+30486,int_stack+7884,int_stack+7554, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5496,int_stack+30486,int_stack+32646, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+30486,int_stack+5496,int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5496,int_stack+30486,int_stack+3816, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30486,int_stack+8364,int_stack+8280, 0.0, zero_stack, 1.0, int_stack+17544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+30738,int_stack+8472,int_stack+8364, 0.0, zero_stack, 1.0, int_stack+17628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+31062,int_stack+30738,int_stack+30486, 0.0, zero_stack, 1.0, int_stack+20304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+31566,int_stack+8607,int_stack+8472, 0.0, zero_stack, 1.0, int_stack+17736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+31971,int_stack+31566,int_stack+30738, 0.0, zero_stack, 1.0, int_stack+20556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+32619,int_stack+31971,int_stack+31062, 0.0, zero_stack, 1.0, int_stack+20880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+30486,int_stack+8772,int_stack+8607, 0.0, zero_stack, 1.0, int_stack+17871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2520,int_stack+30486,int_stack+31566, 0.0, zero_stack, 1.0, int_stack+21384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+30486,int_stack+2520,int_stack+31971, 0.0, zero_stack, 1.0, int_stack+21789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2520,int_stack+30486,int_stack+32619, 0.0, zero_stack, 1.0, int_stack+22437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30486,int_stack+9138,int_stack+8970, 0.0, zero_stack, 1.0, int_stack+11040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+30990,int_stack+9354,int_stack+9138, 0.0, zero_stack, 1.0, int_stack+11376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+31638,int_stack+30990,int_stack+30486, 0.0, zero_stack, 1.0, int_stack+23277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+32646,int_stack+9624,int_stack+9354, 0.0, zero_stack, 1.0, int_stack+11808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3780,int_stack+32646,int_stack+30990, 0.0, zero_stack, 1.0, int_stack+23781, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+43344,int_stack+3780,int_stack+31638, 0.0, zero_stack, 1.0, int_stack+24429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+30486,int_stack+9954,int_stack+9624, 0.0, zero_stack, 1.0, int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8016,int_stack+30486,int_stack+32646, 0.0, zero_stack, 1.0, int_stack+25437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+30486,int_stack+8016,int_stack+3780, 0.0, zero_stack, 1.0, int_stack+27510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+45024,int_stack+30486,int_stack+43344, 0.0, zero_stack, 1.0, int_stack+28806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+43344,int_stack+10434,int_stack+10350, 1.0, int_stack+17544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+43596,int_stack+10542,int_stack+10434, 1.0, int_stack+17628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+43920,int_stack+43596,int_stack+43344, 1.0, int_stack+20304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+44424,int_stack+10677,int_stack+10542, 1.0, int_stack+17736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+30486,int_stack+44424,int_stack+43596, 1.0, int_stack+20556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+31134,int_stack+30486,int_stack+43920, 1.0, int_stack+20880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+20304,int_stack+10842,int_stack+10677, 1.0, int_stack+17871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+43344,int_stack+20304,int_stack+44424, 1.0, int_stack+21384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+20304,int_stack+43344,int_stack+30486, 1.0, int_stack+21789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (p0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+43344,int_stack+20304,int_stack+31134, 1.0, int_stack+22437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,3);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+20304,int_stack+11592,int_stack+11208, 1.0, int_stack+11040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+30486,int_stack+12078,int_stack+11592, 1.0, int_stack+11376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+31134,int_stack+30486,int_stack+20304, 1.0, int_stack+23277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+20304,int_stack+12678,int_stack+12078, 1.0, int_stack+11808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+32142,int_stack+20304,int_stack+30486, 1.0, int_stack+23781, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3780,int_stack+32142,int_stack+31134, 1.0, int_stack+24429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+30486,int_stack+13008,int_stack+12678, 1.0, int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+23277,int_stack+30486,int_stack+20304, 1.0, int_stack+25437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016,int_stack+23277,int_stack+32142, 1.0, int_stack+27510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+23277,int_stack+8016,int_stack+3780, 1.0, int_stack+28806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (p0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+3780,int_stack+18036,int_stack+17871,3);
 /*--- compute (p0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+4275,int_stack+3780,int_stack+21384,3);
 /*--- compute (p0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+8016,int_stack+4275,int_stack+21789,3);
 /*--- compute (p0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+3780,int_stack+8016,int_stack+22437,3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+8016,int_stack+13488,int_stack+13404,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+8268,int_stack+13596,int_stack+13488,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+8592,int_stack+8268,int_stack+8016,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9096,int_stack+13731,int_stack+13596,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+9501,int_stack+9096,int_stack+8268,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+10149,int_stack+9501,int_stack+8592,3);
 /*--- compute (p0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+8016,int_stack+13896,int_stack+13731,3);
 /*--- compute (p0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+10989,int_stack+8016,int_stack+9096,3);
 /*--- compute (p0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+8016,int_stack+10989,int_stack+9501,3);
 /*--- compute (p0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+10989,int_stack+8016,int_stack+10149,3);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+8016,int_stack+14262,int_stack+14094,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+8520,int_stack+14478,int_stack+14262,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+9168,int_stack+8520,int_stack+8016,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+10176,int_stack+14748,int_stack+14478,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+12249,int_stack+10176,int_stack+8520,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+27510,int_stack+12249,int_stack+9168,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+8016,int_stack+15078,int_stack+14748,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+13545,int_stack+8016,int_stack+10176,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+8016,int_stack+13545,int_stack+12249,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+12249,int_stack+8016,int_stack+27510,6);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+27510,int_stack+15558,int_stack+15474,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+27762,int_stack+15666,int_stack+15558,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+28086,int_stack+27762,int_stack+27510,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+28590,int_stack+15801,int_stack+15666,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+28995,int_stack+28590,int_stack+27762,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+29643,int_stack+28995,int_stack+28086,3);
 /*--- compute (p0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+27510,int_stack+15966,int_stack+15801,3);
 /*--- compute (p0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+30483,int_stack+27510,int_stack+28590,3);
 /*--- compute (p0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+27510,int_stack+30483,int_stack+28995,3);
 /*--- compute (p0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+30483,int_stack+27510,int_stack+29643,3);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+27510,int_stack+16332,int_stack+16164,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+28014,int_stack+16548,int_stack+16332,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+28662,int_stack+28014,int_stack+27510,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+29670,int_stack+16818,int_stack+16548,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+31743,int_stack+29670,int_stack+28014,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+8016,int_stack+31743,int_stack+28662,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+27510,int_stack+17148,int_stack+16818,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+14769,int_stack+27510,int_stack+29670,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+27510,int_stack+14769,int_stack+31743,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+14769,int_stack+27510,int_stack+8016,6);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+8016,int_stack+18318,int_stack+18234,3);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+8268,int_stack+18426,int_stack+18318,3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+8592,int_stack+8268,int_stack+8016,3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9096,int_stack+18561,int_stack+18426,3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+9501,int_stack+9096,int_stack+8268,3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+10149,int_stack+9501,int_stack+8592,3);
 /*--- compute (p0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+8016,int_stack+18726,int_stack+18561,3);
 /*--- compute (p0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+27510,int_stack+8016,int_stack+9096,3);
 /*--- compute (p0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+8016,int_stack+27510,int_stack+9501,3);
 /*--- compute (p0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+27510,int_stack+8016,int_stack+10149,3);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+8016,int_stack+19092,int_stack+18924,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+8520,int_stack+19308,int_stack+19092,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+9168,int_stack+8520,int_stack+8016,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+10176,int_stack+19578,int_stack+19308,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+28770,int_stack+10176,int_stack+8520,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+31743,int_stack+28770,int_stack+9168,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+8016,int_stack+19908,int_stack+19578,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+17289,int_stack+8016,int_stack+10176,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+8016,int_stack+17289,int_stack+28770,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+17289,int_stack+8016,int_stack+31743,6);
 /*--- compute (pp|ig) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+47544,int_stack+35784,int_stack+26250,420);
     Libderiv->ABCD[11] = int_stack + 47544;
 /*--- compute (pp|ig) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+51324,int_stack+38304,int_stack+33459,420);
     Libderiv->ABCD[10] = int_stack + 51324;
 /*--- compute (pp|ig) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+31743,int_stack+40824,int_stack+0,420);
     Libderiv->ABCD[9] = int_stack + 31743;
 /*--- compute (pp|ig) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+35523,int_stack+5496,int_stack+1260,420);
     Libderiv->ABCD[8] = int_stack + 35523;
 /*--- compute (pp|ig) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+39303,int_stack+45024,int_stack+2520,420);
     Libderiv->ABCD[7] = int_stack + 39303;
 /*--- compute (pp|ig) ---*/
   hrr1_build_pp(Libderiv->AB,int_stack+0,int_stack+23277,int_stack+43344,420);
     Libderiv->ABCD[6] = int_stack + 0;
 /*--- compute (pp|ig) ---*/
   d1hrr1_build_pp(Libderiv->AB,int_stack+43083,int_stack+12249,int_stack+10989, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[2] = int_stack + 43083;
 /*--- compute (pp|ig) ---*/
   d1hrr1_build_pp(Libderiv->AB,int_stack+19809,int_stack+14769,int_stack+30483, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[1] = int_stack + 19809;
 /*--- compute (pp|ig) ---*/
   d1hrr1_build_pp(Libderiv->AB,int_stack+23589,int_stack+17289,int_stack+27510, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,420);
     Libderiv->ABCD[0] = int_stack + 23589;

}
