/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include "libint.h"
#include "hrr_header.h"

extern void vrr_order_kknl(Libint_t*, prim_data*);

  /* Computes quartets of (kk|nl) integrals */

REALTYPE *hrr_order_kknl(Libint_t *Libint, int num_prim_comb)
{
 prim_data *Data = Libint->PrimQuartet;
 REALTYPE *int_stack = Libint->int_stack;
 int i;

 Libint->vrr_classes[7][10] = int_stack + 0;
 Libint->vrr_classes[7][11] = int_stack + 2376;
 Libint->vrr_classes[7][12] = int_stack + 5184;
 Libint->vrr_classes[7][13] = int_stack + 8460;
 Libint->vrr_classes[7][14] = int_stack + 12240;
 Libint->vrr_classes[7][15] = int_stack + 16560;
 Libint->vrr_classes[7][16] = int_stack + 21456;
 Libint->vrr_classes[7][17] = int_stack + 26964;
 Libint->vrr_classes[7][18] = int_stack + 33120;
 Libint->vrr_classes[8][10] = int_stack + 39960;
 Libint->vrr_classes[8][11] = int_stack + 42930;
 Libint->vrr_classes[8][12] = int_stack + 46440;
 Libint->vrr_classes[8][13] = int_stack + 50535;
 Libint->vrr_classes[8][14] = int_stack + 55260;
 Libint->vrr_classes[8][15] = int_stack + 60660;
 Libint->vrr_classes[8][16] = int_stack + 66780;
 Libint->vrr_classes[8][17] = int_stack + 73665;
 Libint->vrr_classes[8][18] = int_stack + 81360;
 Libint->vrr_classes[9][10] = int_stack + 89910;
 Libint->vrr_classes[9][11] = int_stack + 93540;
 Libint->vrr_classes[9][12] = int_stack + 97830;
 Libint->vrr_classes[9][13] = int_stack + 102835;
 Libint->vrr_classes[9][14] = int_stack + 108610;
 Libint->vrr_classes[9][15] = int_stack + 115210;
 Libint->vrr_classes[9][16] = int_stack + 122690;
 Libint->vrr_classes[9][17] = int_stack + 131105;
 Libint->vrr_classes[9][18] = int_stack + 140510;
 Libint->vrr_classes[10][10] = int_stack + 150960;
 Libint->vrr_classes[10][11] = int_stack + 155316;
 Libint->vrr_classes[10][12] = int_stack + 160464;
 Libint->vrr_classes[10][13] = int_stack + 166470;
 Libint->vrr_classes[10][14] = int_stack + 173400;
 Libint->vrr_classes[10][15] = int_stack + 181320;
 Libint->vrr_classes[10][16] = int_stack + 190296;
 Libint->vrr_classes[10][17] = int_stack + 200394;
 Libint->vrr_classes[10][18] = int_stack + 211680;
 Libint->vrr_classes[11][10] = int_stack + 224220;
 Libint->vrr_classes[11][11] = int_stack + 229368;
 Libint->vrr_classes[11][12] = int_stack + 235452;
 Libint->vrr_classes[11][13] = int_stack + 242550;
 Libint->vrr_classes[11][14] = int_stack + 250740;
 Libint->vrr_classes[11][15] = int_stack + 260100;
 Libint->vrr_classes[11][16] = int_stack + 270708;
 Libint->vrr_classes[11][17] = int_stack + 282642;
 Libint->vrr_classes[11][18] = int_stack + 295980;
 Libint->vrr_classes[12][10] = int_stack + 310800;
 Libint->vrr_classes[12][11] = int_stack + 316806;
 Libint->vrr_classes[12][12] = int_stack + 323904;
 Libint->vrr_classes[12][13] = int_stack + 332185;
 Libint->vrr_classes[12][14] = int_stack + 341740;
 Libint->vrr_classes[12][15] = int_stack + 352660;
 Libint->vrr_classes[12][16] = int_stack + 365036;
 Libint->vrr_classes[12][17] = int_stack + 378959;
 Libint->vrr_classes[12][18] = int_stack + 394520;
 Libint->vrr_classes[13][10] = int_stack + 411810;
 Libint->vrr_classes[13][11] = int_stack + 418740;
 Libint->vrr_classes[13][12] = int_stack + 426930;
 Libint->vrr_classes[13][13] = int_stack + 436485;
 Libint->vrr_classes[13][14] = int_stack + 447510;
 Libint->vrr_classes[13][15] = int_stack + 460110;
 Libint->vrr_classes[13][16] = int_stack + 474390;
 Libint->vrr_classes[13][17] = int_stack + 490455;
 Libint->vrr_classes[13][18] = int_stack + 508410;
 Libint->vrr_classes[14][10] = int_stack + 528360;
 Libint->vrr_classes[14][11] = int_stack + 536280;
 Libint->vrr_classes[14][12] = int_stack + 545640;
 Libint->vrr_classes[14][13] = int_stack + 556560;
 Libint->vrr_classes[14][14] = int_stack + 569160;
 Libint->vrr_classes[14][15] = int_stack + 583560;
 Libint->vrr_classes[14][16] = int_stack + 599880;
 Libint->vrr_classes[14][17] = int_stack + 618240;
 Libint->vrr_classes[14][18] = int_stack + 638760;
 memset(int_stack,0,661560*sizeof(REALTYPE));

 Libint->vrr_stack = int_stack + 661560;
 for(i=0;i<num_prim_comb;i++) {
   vrr_order_kknl(Libint, Data);
   Data++;
 }
 /*--- compute (k0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+661560,int_stack+2376,int_stack+0,36);
 /*--- compute (k0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+668688,int_stack+5184,int_stack+2376,36);
 /*--- compute (k0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+677112,int_stack+668688,int_stack+661560,36);
 /*--- compute (k0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+691368,int_stack+8460,int_stack+5184,36);
 /*--- compute (k0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+701196,int_stack+691368,int_stack+668688,36);
 /*--- compute (k0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+718044,int_stack+701196,int_stack+677112,36);
 /*--- compute (k0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+661560,int_stack+12240,int_stack+8460,36);
 /*--- compute (k0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+741804,int_stack+661560,int_stack+691368,36);
 /*--- compute (k0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+672900,int_stack+741804,int_stack+701196,36);
 /*--- compute (k0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+761460,int_stack+672900,int_stack+718044,36);
 /*--- compute (k0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+700980,int_stack+16560,int_stack+12240,36);
 /*--- compute (k0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+713940,int_stack+700980,int_stack+661560,36);
 /*--- compute (k0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+797100,int_stack+713940,int_stack+741804,36);
 /*--- compute (k0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+829860,int_stack+797100,int_stack+672900,36);
 /*--- compute (k0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+871980,int_stack+829860,int_stack+761460,36);
 /*--- compute (k0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+661560,int_stack+21456,int_stack+16560,36);
 /*--- compute (k0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+736620,int_stack+661560,int_stack+700980,36);
 /*--- compute (k0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+921876,int_stack+736620,int_stack+713940,36);
 /*--- compute (k0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+676248,int_stack+921876,int_stack+797100,36);
 /*--- compute (k0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+762540,int_stack+676248,int_stack+829860,36);
 /*--- compute (k0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+959676,int_stack+762540,int_stack+871980,36);
 /*--- compute (k0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+821508,int_stack+26964,int_stack+21456,36);
 /*--- compute (k0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+838032,int_stack+821508,int_stack+661560,36);
 /*--- compute (k0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+867408,int_stack+838032,int_stack+736620,36);
 /*--- compute (k0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+1026204,int_stack+867408,int_stack+921876,36);
 /*--- compute (k0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+1082904,int_stack+1026204,int_stack+676248,36);
 /*--- compute (k0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+661560,int_stack+1082904,int_stack+762540,36);
 /*--- compute (k0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+1151700,int_stack+661560,int_stack+959676,36);
 /*--- compute (k0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+740184,int_stack+33120,int_stack+26964,36);
 /*--- compute (k0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+758652,int_stack+740184,int_stack+821508,36);
 /*--- compute (k0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+910608,int_stack+758652,int_stack+838032,36);
 /*--- compute (k0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+740184,int_stack+910608,int_stack+867408,36);
 /*--- compute (k0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+804984,int_stack+740184,int_stack+1026204,36);
 /*--- compute (k0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+884364,int_stack+804984,int_stack+1082904,36);
 /*--- compute (k0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+740184,int_stack+884364,int_stack+661560,36);
 /*--- compute (k0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+841272,int_stack+740184,int_stack+1151700,36);
 /*--- compute (l0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+661560,int_stack+42930,int_stack+39960,45);
 /*--- compute (l0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+670470,int_stack+46440,int_stack+42930,45);
 /*--- compute (l0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+681000,int_stack+670470,int_stack+661560,45);
 /*--- compute (l0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+698820,int_stack+50535,int_stack+46440,45);
 /*--- compute (l0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+711105,int_stack+698820,int_stack+670470,45);
 /*--- compute (l0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+732165,int_stack+711105,int_stack+681000,45);
 /*--- compute (l0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+661560,int_stack+55260,int_stack+50535,45);
 /*--- compute (l0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+761865,int_stack+661560,int_stack+698820,45);
 /*--- compute (l0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+675735,int_stack+761865,int_stack+711105,45);
 /*--- compute (l0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+786435,int_stack+675735,int_stack+732165,45);
 /*--- compute (l0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+710835,int_stack+60660,int_stack+55260,45);
 /*--- compute (l0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+727035,int_stack+710835,int_stack+661560,45);
 /*--- compute (l0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+948192,int_stack+727035,int_stack+761865,45);
 /*--- compute (l0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+989142,int_stack+948192,int_stack+675735,45);
 /*--- compute (l0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+1041792,int_stack+989142,int_stack+786435,45);
 /*--- compute (l0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+661560,int_stack+66780,int_stack+60660,45);
 /*--- compute (l0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+755385,int_stack+661560,int_stack+710835,45);
 /*--- compute (l0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+787785,int_stack+755385,int_stack+727035,45);
 /*--- compute (l0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+679920,int_stack+787785,int_stack+948192,45);
 /*--- compute (l0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+1104162,int_stack+679920,int_stack+989142,45);
 /*--- compute (l0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+948192,int_stack+1104162,int_stack+1041792,45);
 /*--- compute (l0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+1031352,int_stack+73665,int_stack+66780,45);
 /*--- compute (l0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+1052007,int_stack+1031352,int_stack+661560,45);
 /*--- compute (l0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1177872,int_stack+1052007,int_stack+755385,45);
 /*--- compute (l0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+0,int_stack+1177872,int_stack+787785,45);
 /*--- compute (l0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+741345,int_stack+0,int_stack+679920,45);
 /*--- compute (l0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+1231872,int_stack+741345,int_stack+1104162,45);
 /*--- compute (l0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+1330152,int_stack+1231872,int_stack+948192,45);
 /*--- compute (l0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+948192,int_stack+81360,int_stack+73665,45);
 /*--- compute (l0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+971277,int_stack+948192,int_stack+1031352,45);
 /*--- compute (l0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+661560,int_stack+971277,int_stack+1052007,45);
 /*--- compute (l0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+948192,int_stack+661560,int_stack+1177872,45);
 /*--- compute (l0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+1029192,int_stack+948192,int_stack+0,45);
 /*--- compute (l0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+1437072,int_stack+1029192,int_stack+741345,45);
 /*--- compute (l0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+948192,int_stack+1437072,int_stack+1231872,45);
 /*--- compute (l0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+1074552,int_stack+948192,int_stack+1330152,45);
 /*--- compute (kp|nl) ---*/
 hrr1_build_kp(Libint->AB,int_stack+1208202,int_stack+1074552,int_stack+841272,2970);
 /*--- compute (m0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+0,int_stack+93540,int_stack+89910,55);
 /*--- compute (m0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+10890,int_stack+97830,int_stack+93540,55);
 /*--- compute (m0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+23760,int_stack+10890,int_stack+0,55);
 /*--- compute (m0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+45540,int_stack+102835,int_stack+97830,55);
 /*--- compute (m0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+60555,int_stack+45540,int_stack+10890,55);
 /*--- compute (m0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+661560,int_stack+60555,int_stack+23760,55);
 /*--- compute (m0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+0,int_stack+108610,int_stack+102835,55);
 /*--- compute (m0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+697860,int_stack+0,int_stack+45540,55);
 /*--- compute (m0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+17325,int_stack+697860,int_stack+60555,55);
 /*--- compute (m0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+727890,int_stack+17325,int_stack+661560,55);
 /*--- compute (m0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+661560,int_stack+115210,int_stack+108610,55);
 /*--- compute (m0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+60225,int_stack+661560,int_stack+0,55);
 /*--- compute (m0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+782340,int_stack+60225,int_stack+697860,55);
 /*--- compute (m0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+832390,int_stack+782340,int_stack+17325,55);
 /*--- compute (m0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+896740,int_stack+832390,int_stack+727890,55);
 /*--- compute (m0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+0,int_stack+122690,int_stack+115210,55);
 /*--- compute (m0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+681360,int_stack+0,int_stack+661560,55);
 /*--- compute (m0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+720960,int_stack+681360,int_stack+60225,55);
 /*--- compute (m0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+22440,int_stack+720960,int_stack+782340,55);
 /*--- compute (m0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+972970,int_stack+22440,int_stack+832390,55);
 /*--- compute (m0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+778710,int_stack+972970,int_stack+896740,55);
 /*--- compute (m0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+880350,int_stack+131105,int_stack+122690,55);
 /*--- compute (m0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+905595,int_stack+880350,int_stack+0,55);
 /*--- compute (m0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1528962,int_stack+905595,int_stack+681360,55);
 /*--- compute (m0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+1594962,int_stack+1528962,int_stack+720960,55);
 /*--- compute (m0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+661560,int_stack+1594962,int_stack+22440,55);
 /*--- compute (m0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+0,int_stack+661560,int_stack+972970,55);
 /*--- compute (m0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+1681587,int_stack+0,int_stack+778710,55);
 /*--- compute (m0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+766665,int_stack+140510,int_stack+131105,55);
 /*--- compute (m0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+794880,int_stack+766665,int_stack+880350,55);
 /*--- compute (m0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+950475,int_stack+794880,int_stack+905595,55);
 /*--- compute (m0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+766665,int_stack+950475,int_stack+1528962,55);
 /*--- compute (m0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+865665,int_stack+766665,int_stack+1594962,55);
 /*--- compute (m0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+1528962,int_stack+865665,int_stack+661560,55);
 /*--- compute (m0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+661560,int_stack+1528962,int_stack+0,55);
 /*--- compute (m0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+816000,int_stack+661560,int_stack+1681587,55);
 /*--- compute (lp|nl) ---*/
 hrr1_build_lp(Libint->AB,int_stack+1528962,int_stack+816000,int_stack+1074552,2970);
 /*--- compute (kd|nl) ---*/
 hrr1_build_kd(Libint->AB,int_stack+1929912,int_stack+1528962,int_stack+1208202,2970);
 /*--- compute (n0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+661560,int_stack+155316,int_stack+150960,66);
 /*--- compute (n0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+674628,int_stack+160464,int_stack+155316,66);
 /*--- compute (n0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+690072,int_stack+674628,int_stack+661560,66);
 /*--- compute (n0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+716208,int_stack+166470,int_stack+160464,66);
 /*--- compute (n0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+734226,int_stack+716208,int_stack+674628,66);
 /*--- compute (n0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+765114,int_stack+734226,int_stack+690072,66);
 /*--- compute (n0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+661560,int_stack+173400,int_stack+166470,66);
 /*--- compute (n0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+0,int_stack+661560,int_stack+716208,66);
 /*--- compute (n0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+682350,int_stack+0,int_stack+734226,66);
 /*--- compute (n0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+36036,int_stack+682350,int_stack+765114,66);
 /*--- compute (n0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+733830,int_stack+181320,int_stack+173400,66);
 /*--- compute (n0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+757590,int_stack+733830,int_stack+661560,66);
 /*--- compute (n0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+101376,int_stack+757590,int_stack+0,66);
 /*--- compute (n0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+979350,int_stack+101376,int_stack+682350,66);
 /*--- compute (n0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+1056570,int_stack+979350,int_stack+36036,66);
 /*--- compute (n0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+0,int_stack+190296,int_stack+181320,66);
 /*--- compute (n0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+26928,int_stack+0,int_stack+733830,66);
 /*--- compute (n0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+661560,int_stack+26928,int_stack+757590,66);
 /*--- compute (n0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+1148046,int_stack+661560,int_stack+101376,66);
 /*--- compute (n0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+74448,int_stack+1148046,int_stack+979350,66);
 /*--- compute (n0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+1238136,int_stack+74448,int_stack+1056570,66);
 /*--- compute (n0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+979350,int_stack+200394,int_stack+190296,66);
 /*--- compute (n0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+1009644,int_stack+979350,int_stack+0,66);
 /*--- compute (n0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1063500,int_stack+1009644,int_stack+26928,66);
 /*--- compute (n0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+1360104,int_stack+1063500,int_stack+661560,66);
 /*--- compute (n0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+661560,int_stack+1360104,int_stack+1148046,66);
 /*--- compute (n0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+2571432,int_stack+661560,int_stack+74448,66);
 /*--- compute (n0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+0,int_stack+2571432,int_stack+1238136,66);
 /*--- compute (n0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+156816,int_stack+211680,int_stack+200394,66);
 /*--- compute (n0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+1142700,int_stack+156816,int_stack+979350,66);
 /*--- compute (n0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+1203288,int_stack+1142700,int_stack+1009644,66);
 /*--- compute (n0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+2715576,int_stack+1203288,int_stack+1063500,66);
 /*--- compute (n0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+979350,int_stack+2715576,int_stack+1360104,66);
 /*--- compute (n0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+1124880,int_stack+979350,int_stack+661560,66);
 /*--- compute (n0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+1293048,int_stack+1124880,int_stack+2571432,66);
 /*--- compute (n0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+2571432,int_stack+1293048,int_stack+0,66);
 /*--- compute (mp|nl) ---*/
 hrr1_build_mp(Libint->AB,int_stack+979350,int_stack+2571432,int_stack+816000,2970);
 /*--- compute (ld|nl) ---*/
 hrr1_build_ld(Libint->AB,int_stack+2767452,int_stack+979350,int_stack+1528962,2970);
 /*--- compute (kf|nl) ---*/
 hrr1_build_kf(Libint->AB,int_stack+3569352,int_stack+2767452,int_stack+1929912,2970);
 /*--- compute (o0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+0,int_stack+229368,int_stack+224220,78);
 /*--- compute (o0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+15444,int_stack+235452,int_stack+229368,78);
 /*--- compute (o0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+33696,int_stack+15444,int_stack+0,78);
 /*--- compute (o0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+64584,int_stack+242550,int_stack+235452,78);
 /*--- compute (o0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+85878,int_stack+64584,int_stack+15444,78);
 /*--- compute (o0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+122382,int_stack+85878,int_stack+33696,78);
 /*--- compute (o0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+0,int_stack+250740,int_stack+242550,78);
 /*--- compute (o0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+173862,int_stack+0,int_stack+64584,78);
 /*--- compute (o0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+24570,int_stack+173862,int_stack+85878,78);
 /*--- compute (o0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+661560,int_stack+24570,int_stack+122382,78);
 /*--- compute (o0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+85410,int_stack+260100,int_stack+250740,78);
 /*--- compute (o0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+113490,int_stack+85410,int_stack+0,78);
 /*--- compute (o0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+738780,int_stack+113490,int_stack+173862,78);
 /*--- compute (o0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+162630,int_stack+738780,int_stack+24570,78);
 /*--- compute (o0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+809760,int_stack+162630,int_stack+661560,78);
 /*--- compute (o0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+661560,int_stack+270708,int_stack+260100,78);
 /*--- compute (o0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+0,int_stack+661560,int_stack+85410,78);
 /*--- compute (o0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+1469400,int_stack+0,int_stack+113490,78);
 /*--- compute (o0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+56160,int_stack+1469400,int_stack+738780,78);
 /*--- compute (o0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+1551300,int_stack+56160,int_stack+162630,78);
 /*--- compute (o0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+1679064,int_stack+1551300,int_stack+809760,78);
 /*--- compute (o0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+162630,int_stack+282642,int_stack+270708,78);
 /*--- compute (o0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+198432,int_stack+162630,int_stack+661560,78);
 /*--- compute (o0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+661560,int_stack+198432,int_stack+0,78);
 /*--- compute (o0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+755160,int_stack+661560,int_stack+1469400,78);
 /*--- compute (o0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+1823208,int_stack+755160,int_stack+56160,78);
 /*--- compute (o0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+1972266,int_stack+1823208,int_stack+1551300,78);
 /*--- compute (o0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+1469400,int_stack+1972266,int_stack+1679064,78);
 /*--- compute (o0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+1654728,int_stack+295980,int_stack+282642,78);
 /*--- compute (o0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+1694742,int_stack+1654728,int_stack+162630,78);
 /*--- compute (o0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+0,int_stack+1694742,int_stack+198432,78);
 /*--- compute (o0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+1654728,int_stack+0,int_stack+661560,78);
 /*--- compute (o0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+0,int_stack+1654728,int_stack+755160,78);
 /*--- compute (o0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+661560,int_stack+0,int_stack+1823208,78);
 /*--- compute (o0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+0,int_stack+661560,int_stack+1972266,78);
 /*--- compute (o0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+661560,int_stack+0,int_stack+1469400,78);
 /*--- compute (np|nl) ---*/
 hrr1_build_np(Libint->AB,int_stack+1469400,int_stack+661560,int_stack+2571432,2970);
 /*--- compute (md|nl) ---*/
 hrr1_build_md(Libint->AB,int_stack+4638552,int_stack+1469400,int_stack+979350,2970);
 /*--- compute (lf|nl) ---*/
 hrr1_build_lf(Libint->AB,int_stack+5618652,int_stack+4638552,int_stack+2767452,2970);
 /*--- compute (kg|nl) ---*/
 hrr1_build_kg(Libint->AB,int_stack+6955152,int_stack+5618652,int_stack+3569352,2970);
 /*--- compute (q0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+2057460,int_stack+316806,int_stack+310800,91);
 /*--- compute (q0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+2075478,int_stack+323904,int_stack+316806,91);
 /*--- compute (q0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+2096772,int_stack+2075478,int_stack+2057460,91);
 /*--- compute (q0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+2132808,int_stack+332185,int_stack+323904,91);
 /*--- compute (q0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+2157651,int_stack+2132808,int_stack+2075478,91);
 /*--- compute (q0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+2200239,int_stack+2157651,int_stack+2096772,91);
 /*--- compute (q0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+2057460,int_stack+341740,int_stack+332185,91);
 /*--- compute (q0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+2260299,int_stack+2057460,int_stack+2132808,91);
 /*--- compute (q0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+2086125,int_stack+2260299,int_stack+2157651,91);
 /*--- compute (q0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+2309985,int_stack+2086125,int_stack+2200239,91);
 /*--- compute (q0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+2157105,int_stack+352660,int_stack+341740,91);
 /*--- compute (q0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+2189865,int_stack+2157105,int_stack+2057460,91);
 /*--- compute (q0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+2400075,int_stack+2189865,int_stack+2260299,91);
 /*--- compute (q0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+2482885,int_stack+2400075,int_stack+2086125,91);
 /*--- compute (q0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+2589355,int_stack+2482885,int_stack+2309985,91);
 /*--- compute (q0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+2057460,int_stack+365036,int_stack+352660,91);
 /*--- compute (q0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+2247195,int_stack+2057460,int_stack+2157105,91);
 /*--- compute (q0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+2715481,int_stack+2247195,int_stack+2189865,91);
 /*--- compute (q0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+2094588,int_stack+2715481,int_stack+2400075,91);
 /*--- compute (q0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+2312715,int_stack+2094588,int_stack+2482885,91);
 /*--- compute (q0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+2811031,int_stack+2312715,int_stack+2589355,91);
 /*--- compute (q0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+2461773,int_stack+378959,int_stack+365036,91);
 /*--- compute (q0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+2503542,int_stack+2461773,int_stack+2057460,91);
 /*--- compute (q0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+2577798,int_stack+2503542,int_stack+2247195,91);
 /*--- compute (q0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+2979199,int_stack+2577798,int_stack+2715481,91);
 /*--- compute (q0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+3122524,int_stack+2979199,int_stack+2094588,91);
 /*--- compute (q0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+2057460,int_stack+3122524,int_stack+2312715,91);
 /*--- compute (q0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+3296425,int_stack+2057460,int_stack+2811031,91);
 /*--- compute (q0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+2256204,int_stack+394520,int_stack+378959,91);
 /*--- compute (q0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+2302887,int_stack+2256204,int_stack+2461773,91);
 /*--- compute (q0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+2686998,int_stack+2302887,int_stack+2503542,91);
 /*--- compute (q0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+2256204,int_stack+2686998,int_stack+2577798,91);
 /*--- compute (q0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+2420004,int_stack+2256204,int_stack+2979199,91);
 /*--- compute (q0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+2620659,int_stack+2420004,int_stack+3122524,91);
 /*--- compute (q0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+2256204,int_stack+2620659,int_stack+2057460,91);
 /*--- compute (q0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+2511732,int_stack+2256204,int_stack+3296425,91);
 /*--- compute (op|nl) ---*/
 hrr1_build_op(Libint->AB,int_stack+2782002,int_stack+2511732,int_stack+661560,2970);
 /*--- compute (nd|nl) ---*/
 hrr1_build_nd(Libint->AB,int_stack+8558952,int_stack+2782002,int_stack+1469400,2970);
 /*--- compute (mf|nl) ---*/
 hrr1_build_mf(Libint->AB,int_stack+661560,int_stack+8558952,int_stack+4638552,2970);
 /*--- compute (lg|nl) ---*/
 hrr1_build_lg(Libint->AB,int_stack+3476982,int_stack+661560,int_stack+5618652,2970);
 /*--- compute (kh|nl) ---*/
 hrr1_build_kh(Libint->AB,int_stack+9735072,int_stack+3476982,int_stack+6955152,2970);
 /*--- compute (r0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+2295060,int_stack+418740,int_stack+411810,105);
 /*--- compute (r0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+2315850,int_stack+426930,int_stack+418740,105);
 /*--- compute (r0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+2340420,int_stack+2315850,int_stack+2295060,105);
 /*--- compute (r0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+2382000,int_stack+436485,int_stack+426930,105);
 /*--- compute (r0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+2410665,int_stack+2382000,int_stack+2315850,105);
 /*--- compute (r0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+5481732,int_stack+2410665,int_stack+2340420,105);
 /*--- compute (r0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+2295060,int_stack+447510,int_stack+436485,105);
 /*--- compute (r0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+5551032,int_stack+2295060,int_stack+2382000,105);
 /*--- compute (r0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+2328135,int_stack+5551032,int_stack+2410665,105);
 /*--- compute (r0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+5608362,int_stack+2328135,int_stack+5481732,105);
 /*--- compute (r0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+5481732,int_stack+460110,int_stack+447510,105);
 /*--- compute (r0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+2410035,int_stack+5481732,int_stack+2295060,105);
 /*--- compute (r0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+5712312,int_stack+2410035,int_stack+5551032,105);
 /*--- compute (r0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+5807862,int_stack+5712312,int_stack+2328135,105);
 /*--- compute (r0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+5930712,int_stack+5807862,int_stack+5608362,105);
 /*--- compute (r0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+2295060,int_stack+474390,int_stack+460110,105);
 /*--- compute (r0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+5519532,int_stack+2295060,int_stack+5481732,105);
 /*--- compute (r0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+5595132,int_stack+5519532,int_stack+2410035,105);
 /*--- compute (r0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+2337900,int_stack+5595132,int_stack+5712312,105);
 /*--- compute (r0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+6076242,int_stack+2337900,int_stack+5807862,105);
 /*--- compute (r0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+5705382,int_stack+6076242,int_stack+5930712,105);
 /*--- compute (r0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+5899422,int_stack+490455,int_stack+474390,105);
 /*--- compute (r0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+5947617,int_stack+5899422,int_stack+2295060,105);
 /*--- compute (r0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+6248232,int_stack+5947617,int_stack+5519532,105);
 /*--- compute (r0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+6374232,int_stack+6248232,int_stack+5595132,105);
 /*--- compute (r0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+5481732,int_stack+6374232,int_stack+2337900,105);
 /*--- compute (r0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+6539607,int_stack+5481732,int_stack+6076242,105);
 /*--- compute (r0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+6768927,int_stack+6539607,int_stack+5705382,105);
 /*--- compute (r0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+2295060,int_stack+508410,int_stack+490455,105);
 /*--- compute (r0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+2348925,int_stack+2295060,int_stack+5899422,105);
 /*--- compute (r0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+5682387,int_stack+2348925,int_stack+5947617,105);
 /*--- compute (r0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+2295060,int_stack+5682387,int_stack+6248232,105);
 /*--- compute (r0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+5682387,int_stack+2295060,int_stack+6374232,105);
 /*--- compute (r0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+5913912,int_stack+5682387,int_stack+5481732,105);
 /*--- compute (r0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+5481732,int_stack+5913912,int_stack+6539607,105);
 /*--- compute (r0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+5776572,int_stack+5481732,int_stack+6768927,105);
 /*--- compute (qp|nl) ---*/
 hrr1_build_qp(Libint->AB,int_stack+6088422,int_stack+5776572,int_stack+2511732,2970);
 /*--- compute (od|nl) ---*/
 hrr1_build_od(Libint->AB,int_stack+6899232,int_stack+6088422,int_stack+2782002,2970);
 /*--- compute (nf|nl) ---*/
 hrr1_build_nf(Libint->AB,int_stack+11980392,int_stack+6899232,int_stack+8558952,2970);
 /*--- compute (mg|nl) ---*/
 hrr1_build_mg(Libint->AB,int_stack+13940592,int_stack+11980392,int_stack+661560,2970);
 /*--- compute (lh|nl) ---*/
 hrr1_build_lh(Libint->AB,int_stack+661560,int_stack+13940592,int_stack+3476982,2970);
 /*--- compute (ki|nl) ---*/
 hrr1_build_ki(Libint->AB,int_stack+16390842,int_stack+661560,int_stack+9735072,2970);
 /*--- compute (t0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+3468210,int_stack+536280,int_stack+528360,120);
 /*--- compute (t0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+3491970,int_stack+545640,int_stack+536280,120);
 /*--- compute (t0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+3520050,int_stack+3491970,int_stack+3468210,120);
 /*--- compute (t0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+3567570,int_stack+556560,int_stack+545640,120);
 /*--- compute (t0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+3600330,int_stack+3567570,int_stack+3491970,120);
 /*--- compute (t0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+3656490,int_stack+3600330,int_stack+3520050,120);
 /*--- compute (t0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+3468210,int_stack+569160,int_stack+556560,120);
 /*--- compute (t0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+3735690,int_stack+3468210,int_stack+3567570,120);
 /*--- compute (t0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+3506010,int_stack+3735690,int_stack+3600330,120);
 /*--- compute (t0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+3801210,int_stack+3506010,int_stack+3656490,120);
 /*--- compute (t0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+3599610,int_stack+583560,int_stack+569160,120);
 /*--- compute (t0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+3642810,int_stack+3599610,int_stack+3468210,120);
 /*--- compute (t0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+3920010,int_stack+3642810,int_stack+3735690,120);
 /*--- compute (t0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+4029210,int_stack+3920010,int_stack+3506010,120);
 /*--- compute (t0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+4169610,int_stack+4029210,int_stack+3801210,120);
 /*--- compute (t0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+3468210,int_stack+599880,int_stack+583560,120);
 /*--- compute (t0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+3718410,int_stack+3468210,int_stack+3599610,120);
 /*--- compute (t0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+4335930,int_stack+3718410,int_stack+3642810,120);
 /*--- compute (t0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+3517170,int_stack+4335930,int_stack+3920010,120);
 /*--- compute (t0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+3804810,int_stack+3517170,int_stack+4029210,120);
 /*--- compute (t0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+4461930,int_stack+3804810,int_stack+4169610,120);
 /*--- compute (t0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+4001370,int_stack+618240,int_stack+599880,120);
 /*--- compute (t0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+4056450,int_stack+4001370,int_stack+3468210,120);
 /*--- compute (t0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+4154370,int_stack+4056450,int_stack+3718410,120);
 /*--- compute (t0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+4683690,int_stack+4154370,int_stack+4335930,120);
 /*--- compute (t0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+4872690,int_stack+4683690,int_stack+3517170,120);
 /*--- compute (t0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+3468210,int_stack+4872690,int_stack+3804810,120);
 /*--- compute (t0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+5102010,int_stack+3468210,int_stack+4461930,120);
 /*--- compute (t0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+3730290,int_stack+638760,int_stack+618240,120);
 /*--- compute (t0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+3791850,int_stack+3730290,int_stack+4001370,120);
 /*--- compute (t0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+4298370,int_stack+3791850,int_stack+4056450,120);
 /*--- compute (t0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+3730290,int_stack+4298370,int_stack+4154370,120);
 /*--- compute (t0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+3946290,int_stack+3730290,int_stack+4683690,120);
 /*--- compute (t0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+4210890,int_stack+3946290,int_stack+4872690,120);
 /*--- compute (t0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+3730290,int_stack+4210890,int_stack+3468210,120);
 /*--- compute (t0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+4067250,int_stack+3730290,int_stack+5102010,120);
 /*--- compute (rp|nl) ---*/
 hrr1_build_rp(Libint->AB,int_stack+4423650,int_stack+4067250,int_stack+5776572,2970);
 /*--- compute (qd|nl) ---*/
 hrr1_build_qd(Libint->AB,int_stack+8289192,int_stack+4423650,int_stack+6088422,2970);
 /*--- compute (of|nl) ---*/
 hrr1_build_of(Libint->AB,int_stack+3468210,int_stack+8289192,int_stack+6899232,2970);
 /*--- compute (ng|nl) ---*/
 hrr1_build_ng(Libint->AB,int_stack+5784810,int_stack+3468210,int_stack+11980392,2970);
 /*--- compute (mh|nl) ---*/
 hrr1_build_mh(Libint->AB,int_stack+8725110,int_stack+5784810,int_stack+13940592,2970);
 /*--- compute (li|nl) ---*/
 hrr1_build_li(Libint->AB,int_stack+3468210,int_stack+8725110,int_stack+661560,2970);
 /*--- compute (kk|nl) ---*/
 hrr1_build_kk(Libint->AB,int_stack+7210410,int_stack+3468210,int_stack+16390842,2970);
 return int_stack+7210410;}
