/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include "libint.h"
#include "hrr_header.h"

extern void vrr_order_llnm(Libint_t*, prim_data*);

  /* Computes quartets of (ll|nm) integrals */

REALTYPE *hrr_order_llnm(Libint_t *Libint, int num_prim_comb)
{
 prim_data *Data = Libint->PrimQuartet;
 REALTYPE *int_stack = Libint->int_stack;
 int i;

 Libint->vrr_classes[8][10] = int_stack + 0;
 Libint->vrr_classes[8][11] = int_stack + 2970;
 Libint->vrr_classes[8][12] = int_stack + 6480;
 Libint->vrr_classes[8][13] = int_stack + 10575;
 Libint->vrr_classes[8][14] = int_stack + 15300;
 Libint->vrr_classes[8][15] = int_stack + 20700;
 Libint->vrr_classes[8][16] = int_stack + 26820;
 Libint->vrr_classes[8][17] = int_stack + 33705;
 Libint->vrr_classes[8][18] = int_stack + 41400;
 Libint->vrr_classes[8][19] = int_stack + 49950;
 Libint->vrr_classes[9][10] = int_stack + 59400;
 Libint->vrr_classes[9][11] = int_stack + 63030;
 Libint->vrr_classes[9][12] = int_stack + 67320;
 Libint->vrr_classes[9][13] = int_stack + 72325;
 Libint->vrr_classes[9][14] = int_stack + 78100;
 Libint->vrr_classes[9][15] = int_stack + 84700;
 Libint->vrr_classes[9][16] = int_stack + 92180;
 Libint->vrr_classes[9][17] = int_stack + 100595;
 Libint->vrr_classes[9][18] = int_stack + 110000;
 Libint->vrr_classes[9][19] = int_stack + 120450;
 Libint->vrr_classes[10][10] = int_stack + 132000;
 Libint->vrr_classes[10][11] = int_stack + 136356;
 Libint->vrr_classes[10][12] = int_stack + 141504;
 Libint->vrr_classes[10][13] = int_stack + 147510;
 Libint->vrr_classes[10][14] = int_stack + 154440;
 Libint->vrr_classes[10][15] = int_stack + 162360;
 Libint->vrr_classes[10][16] = int_stack + 171336;
 Libint->vrr_classes[10][17] = int_stack + 181434;
 Libint->vrr_classes[10][18] = int_stack + 192720;
 Libint->vrr_classes[10][19] = int_stack + 205260;
 Libint->vrr_classes[11][10] = int_stack + 219120;
 Libint->vrr_classes[11][11] = int_stack + 224268;
 Libint->vrr_classes[11][12] = int_stack + 230352;
 Libint->vrr_classes[11][13] = int_stack + 237450;
 Libint->vrr_classes[11][14] = int_stack + 245640;
 Libint->vrr_classes[11][15] = int_stack + 255000;
 Libint->vrr_classes[11][16] = int_stack + 265608;
 Libint->vrr_classes[11][17] = int_stack + 277542;
 Libint->vrr_classes[11][18] = int_stack + 290880;
 Libint->vrr_classes[11][19] = int_stack + 305700;
 Libint->vrr_classes[12][10] = int_stack + 322080;
 Libint->vrr_classes[12][11] = int_stack + 328086;
 Libint->vrr_classes[12][12] = int_stack + 335184;
 Libint->vrr_classes[12][13] = int_stack + 343465;
 Libint->vrr_classes[12][14] = int_stack + 353020;
 Libint->vrr_classes[12][15] = int_stack + 363940;
 Libint->vrr_classes[12][16] = int_stack + 376316;
 Libint->vrr_classes[12][17] = int_stack + 390239;
 Libint->vrr_classes[12][18] = int_stack + 405800;
 Libint->vrr_classes[12][19] = int_stack + 423090;
 Libint->vrr_classes[13][10] = int_stack + 442200;
 Libint->vrr_classes[13][11] = int_stack + 449130;
 Libint->vrr_classes[13][12] = int_stack + 457320;
 Libint->vrr_classes[13][13] = int_stack + 466875;
 Libint->vrr_classes[13][14] = int_stack + 477900;
 Libint->vrr_classes[13][15] = int_stack + 490500;
 Libint->vrr_classes[13][16] = int_stack + 504780;
 Libint->vrr_classes[13][17] = int_stack + 520845;
 Libint->vrr_classes[13][18] = int_stack + 538800;
 Libint->vrr_classes[13][19] = int_stack + 558750;
 Libint->vrr_classes[14][10] = int_stack + 580800;
 Libint->vrr_classes[14][11] = int_stack + 588720;
 Libint->vrr_classes[14][12] = int_stack + 598080;
 Libint->vrr_classes[14][13] = int_stack + 609000;
 Libint->vrr_classes[14][14] = int_stack + 621600;
 Libint->vrr_classes[14][15] = int_stack + 636000;
 Libint->vrr_classes[14][16] = int_stack + 652320;
 Libint->vrr_classes[14][17] = int_stack + 670680;
 Libint->vrr_classes[14][18] = int_stack + 691200;
 Libint->vrr_classes[14][19] = int_stack + 714000;
 Libint->vrr_classes[15][10] = int_stack + 739200;
 Libint->vrr_classes[15][11] = int_stack + 748176;
 Libint->vrr_classes[15][12] = int_stack + 758784;
 Libint->vrr_classes[15][13] = int_stack + 771160;
 Libint->vrr_classes[15][14] = int_stack + 785440;
 Libint->vrr_classes[15][15] = int_stack + 801760;
 Libint->vrr_classes[15][16] = int_stack + 820256;
 Libint->vrr_classes[15][17] = int_stack + 841064;
 Libint->vrr_classes[15][18] = int_stack + 864320;
 Libint->vrr_classes[15][19] = int_stack + 890160;
 Libint->vrr_classes[16][10] = int_stack + 918720;
 Libint->vrr_classes[16][11] = int_stack + 928818;
 Libint->vrr_classes[16][12] = int_stack + 940752;
 Libint->vrr_classes[16][13] = int_stack + 954675;
 Libint->vrr_classes[16][14] = int_stack + 970740;
 Libint->vrr_classes[16][15] = int_stack + 989100;
 Libint->vrr_classes[16][16] = int_stack + 1009908;
 Libint->vrr_classes[16][17] = int_stack + 1033317;
 Libint->vrr_classes[16][18] = int_stack + 1059480;
 Libint->vrr_classes[16][19] = int_stack + 1088550;
 memset(int_stack,0,1120680*sizeof(REALTYPE));

 Libint->vrr_stack = int_stack + 1120680;
 for(i=0;i<num_prim_comb;i++) {
   vrr_order_llnm(Libint, Data);
   Data++;
 }
 /*--- compute (l0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+1120680,int_stack+2970,int_stack+0,45);
 /*--- compute (l0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+1129590,int_stack+6480,int_stack+2970,45);
 /*--- compute (l0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+1140120,int_stack+1129590,int_stack+1120680,45);
 /*--- compute (l0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+1157940,int_stack+10575,int_stack+6480,45);
 /*--- compute (l0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+1170225,int_stack+1157940,int_stack+1129590,45);
 /*--- compute (l0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+1191285,int_stack+1170225,int_stack+1140120,45);
 /*--- compute (l0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+1120680,int_stack+15300,int_stack+10575,45);
 /*--- compute (l0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+1220985,int_stack+1120680,int_stack+1157940,45);
 /*--- compute (l0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+1134855,int_stack+1220985,int_stack+1170225,45);
 /*--- compute (l0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+1245555,int_stack+1134855,int_stack+1191285,45);
 /*--- compute (l0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+1169955,int_stack+20700,int_stack+15300,45);
 /*--- compute (l0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+1186155,int_stack+1169955,int_stack+1120680,45);
 /*--- compute (l0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+1290105,int_stack+1186155,int_stack+1220985,45);
 /*--- compute (l0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+1331055,int_stack+1290105,int_stack+1134855,45);
 /*--- compute (l0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+1383705,int_stack+1331055,int_stack+1245555,45);
 /*--- compute (l0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+1120680,int_stack+26820,int_stack+20700,45);
 /*--- compute (l0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+1214505,int_stack+1120680,int_stack+1169955,45);
 /*--- compute (l0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+1446075,int_stack+1214505,int_stack+1186155,45);
 /*--- compute (l0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+1139040,int_stack+1446075,int_stack+1290105,45);
 /*--- compute (l0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+1246905,int_stack+1139040,int_stack+1331055,45);
 /*--- compute (l0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+1493325,int_stack+1246905,int_stack+1383705,45);
 /*--- compute (l0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+1320615,int_stack+33705,int_stack+26820,45);
 /*--- compute (l0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+1341270,int_stack+1320615,int_stack+1120680,45);
 /*--- compute (l0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1377990,int_stack+1341270,int_stack+1214505,45);
 /*--- compute (l0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+1576485,int_stack+1377990,int_stack+1446075,45);
 /*--- compute (l0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+1647360,int_stack+1576485,int_stack+1139040,45);
 /*--- compute (l0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+1120680,int_stack+1647360,int_stack+1246905,45);
 /*--- compute (l0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+1733355,int_stack+1120680,int_stack+1493325,45);
 /*--- compute (l0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+1218960,int_stack+41400,int_stack+33705,45);
 /*--- compute (l0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+1242045,int_stack+1218960,int_stack+1320615,45);
 /*--- compute (l0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+1431990,int_stack+1242045,int_stack+1341270,45);
 /*--- compute (l0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+1283355,int_stack+1431990,int_stack+1377990,45);
 /*--- compute (l0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+1840275,int_stack+1283355,int_stack+1576485,45);
 /*--- compute (l0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+1493190,int_stack+1840275,int_stack+1647360,45);
 /*--- compute (l0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+1939500,int_stack+1493190,int_stack+1120680,45);
 /*--- compute (l0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+2065860,int_stack+1939500,int_stack+1733355,45);
 /*--- compute (l0|xp) ---*/
 hrr3_build_xp(Libint->CD,int_stack+1120680,int_stack+49950,int_stack+41400,45);
 /*--- compute (l0|wd) ---*/
 hrr3_build_wd(Libint->CD,int_stack+1146330,int_stack+1120680,int_stack+1218960,45);
 /*--- compute (l0|vf) ---*/
 hrr3_build_vf(Libint->CD,int_stack+1607850,int_stack+1146330,int_stack+1242045,45);
 /*--- compute (l0|ug) ---*/
 hrr3_build_ug(Libint->CD,int_stack+1120680,int_stack+1607850,int_stack+1431990,45);
 /*--- compute (l0|th) ---*/
 hrr3_build_th(Libint->CD,int_stack+1607850,int_stack+1120680,int_stack+1283355,45);
 /*--- compute (l0|ri) ---*/
 hrr3_build_ri(Libint->CD,int_stack+1120680,int_stack+1607850,int_stack+1840275,45);
 /*--- compute (l0|qk) ---*/
 hrr3_build_qk(Libint->CD,int_stack+1607850,int_stack+1120680,int_stack+1493190,45);
 /*--- compute (l0|ol) ---*/
 hrr3_build_ol(Libint->CD,int_stack+1120680,int_stack+1607850,int_stack+1939500,45);
 /*--- compute (l0|nm) ---*/
 hrr3_build_nm(Libint->CD,int_stack+1278630,int_stack+1120680,int_stack+2065860,45);
 /*--- compute (m0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+1120680,int_stack+63030,int_stack+59400,55);
 /*--- compute (m0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+1131570,int_stack+67320,int_stack+63030,55);
 /*--- compute (m0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+1144440,int_stack+1131570,int_stack+1120680,55);
 /*--- compute (m0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+1166220,int_stack+72325,int_stack+67320,55);
 /*--- compute (m0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+1181235,int_stack+1166220,int_stack+1131570,55);
 /*--- compute (m0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+1206975,int_stack+1181235,int_stack+1144440,55);
 /*--- compute (m0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+1120680,int_stack+78100,int_stack+72325,55);
 /*--- compute (m0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+1243275,int_stack+1120680,int_stack+1166220,55);
 /*--- compute (m0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+1138005,int_stack+1243275,int_stack+1181235,55);
 /*--- compute (m0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+1441980,int_stack+1138005,int_stack+1206975,55);
 /*--- compute (m0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+1180905,int_stack+84700,int_stack+78100,55);
 /*--- compute (m0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+1200705,int_stack+1180905,int_stack+1120680,55);
 /*--- compute (m0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+1496430,int_stack+1200705,int_stack+1243275,55);
 /*--- compute (m0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+1546480,int_stack+1496430,int_stack+1138005,55);
 /*--- compute (m0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+1610830,int_stack+1546480,int_stack+1441980,55);
 /*--- compute (m0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+1441980,int_stack+92180,int_stack+84700,55);
 /*--- compute (m0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+1120680,int_stack+1441980,int_stack+1180905,55);
 /*--- compute (m0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+1687060,int_stack+1120680,int_stack+1200705,55);
 /*--- compute (m0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+1160280,int_stack+1687060,int_stack+1496430,55);
 /*--- compute (m0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+1744810,int_stack+1160280,int_stack+1546480,55);
 /*--- compute (m0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+1464420,int_stack+1744810,int_stack+1610830,55);
 /*--- compute (m0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+1566060,int_stack+100595,int_stack+92180,55);
 /*--- compute (m0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+1591305,int_stack+1566060,int_stack+1441980,55);
 /*--- compute (m0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1834900,int_stack+1591305,int_stack+1120680,55);
 /*--- compute (m0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+1900900,int_stack+1834900,int_stack+1687060,55);
 /*--- compute (m0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+1636185,int_stack+1900900,int_stack+1160280,55);
 /*--- compute (m0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+1120680,int_stack+1636185,int_stack+1744810,55);
 /*--- compute (m0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+1987525,int_stack+1120680,int_stack+1464420,55);
 /*--- compute (m0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+1240800,int_stack+110000,int_stack+100595,55);
 /*--- compute (m0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+1441980,int_stack+1240800,int_stack+1566060,55);
 /*--- compute (m0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+1492470,int_stack+1441980,int_stack+1591305,55);
 /*--- compute (m0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+0,int_stack+1492470,int_stack+1834900,55);
 /*--- compute (m0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+1741290,int_stack+0,int_stack+1900900,55);
 /*--- compute (m0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+2118205,int_stack+1741290,int_stack+1636185,55);
 /*--- compute (m0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+1567270,int_stack+2118205,int_stack+1120680,55);
 /*--- compute (m0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+2258345,int_stack+1567270,int_stack+1987525,55);
 /*--- compute (m0|xp) ---*/
 hrr3_build_xp(Libint->CD,int_stack+1120680,int_stack+120450,int_stack+110000,55);
 /*--- compute (m0|wd) ---*/
 hrr3_build_wd(Libint->CD,int_stack+1152030,int_stack+1120680,int_stack+1240800,55);
 /*--- compute (m0|vf) ---*/
 hrr3_build_vf(Libint->CD,int_stack+1862565,int_stack+1152030,int_stack+1441980,55);
 /*--- compute (m0|ug) ---*/
 hrr3_build_ug(Libint->CD,int_stack+1120680,int_stack+1862565,int_stack+1492470,55);
 /*--- compute (m0|th) ---*/
 hrr3_build_th(Libint->CD,int_stack+1862565,int_stack+1120680,int_stack+0,55);
 /*--- compute (m0|ri) ---*/
 hrr3_build_ri(Libint->CD,int_stack+2421695,int_stack+1862565,int_stack+1741290,55);
 /*--- compute (m0|qk) ---*/
 hrr3_build_qk(Libint->CD,int_stack+1721710,int_stack+2421695,int_stack+2118205,55);
 /*--- compute (m0|ol) ---*/
 hrr3_build_ol(Libint->CD,int_stack+1901890,int_stack+1721710,int_stack+1567270,55);
 /*--- compute (m0|nm) ---*/
 hrr3_build_nm(Libint->CD,int_stack+1441980,int_stack+1901890,int_stack+2258345,55);
 /*--- compute (lp|nm) ---*/
 hrr1_build_lp(Libint->AB,int_stack+1641630,int_stack+1441980,int_stack+1278630,3630);
 /*--- compute (n0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+0,int_stack+136356,int_stack+132000,66);
 /*--- compute (n0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+13068,int_stack+141504,int_stack+136356,66);
 /*--- compute (n0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+28512,int_stack+13068,int_stack+0,66);
 /*--- compute (n0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+54648,int_stack+147510,int_stack+141504,66);
 /*--- compute (n0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+72666,int_stack+54648,int_stack+13068,66);
 /*--- compute (n0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+103554,int_stack+72666,int_stack+28512,66);
 /*--- compute (n0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+0,int_stack+154440,int_stack+147510,66);
 /*--- compute (n0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+1120680,int_stack+0,int_stack+54648,66);
 /*--- compute (n0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+20790,int_stack+1120680,int_stack+72666,66);
 /*--- compute (n0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+1156716,int_stack+20790,int_stack+103554,66);
 /*--- compute (n0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+72270,int_stack+162360,int_stack+154440,66);
 /*--- compute (n0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+96030,int_stack+72270,int_stack+0,66);
 /*--- compute (n0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+1222056,int_stack+96030,int_stack+1120680,66);
 /*--- compute (n0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+1282116,int_stack+1222056,int_stack+20790,66);
 /*--- compute (n0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+2131680,int_stack+1282116,int_stack+1156716,66);
 /*--- compute (n0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+1120680,int_stack+171336,int_stack+162360,66);
 /*--- compute (n0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+1147608,int_stack+1120680,int_stack+72270,66);
 /*--- compute (n0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+0,int_stack+1147608,int_stack+96030,66);
 /*--- compute (n0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+69300,int_stack+0,int_stack+1222056,66);
 /*--- compute (n0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+2223156,int_stack+69300,int_stack+1282116,66);
 /*--- compute (n0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+1195128,int_stack+2223156,int_stack+2131680,66);
 /*--- compute (n0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+2131680,int_stack+181434,int_stack+171336,66);
 /*--- compute (n0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+2161974,int_stack+2131680,int_stack+1120680,66);
 /*--- compute (n0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1317096,int_stack+2161974,int_stack+1147608,66);
 /*--- compute (n0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+2331264,int_stack+1317096,int_stack+0,66);
 /*--- compute (n0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+2435214,int_stack+2331264,int_stack+69300,66);
 /*--- compute (n0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+0,int_stack+2435214,int_stack+2223156,66);
 /*--- compute (n0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+2561340,int_stack+0,int_stack+1195128,66);
 /*--- compute (n0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+144144,int_stack+192720,int_stack+181434,66);
 /*--- compute (n0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+1120680,int_stack+144144,int_stack+2131680,66);
 /*--- compute (n0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+1181268,int_stack+1120680,int_stack+2161974,66);
 /*--- compute (n0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+2131680,int_stack+1181268,int_stack+1317096,66);
 /*--- compute (n0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+1271028,int_stack+2131680,int_stack+2331264,66);
 /*--- compute (n0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+2250480,int_stack+1271028,int_stack+2435214,66);
 /*--- compute (n0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+2718156,int_stack+2250480,int_stack+0,66);
 /*--- compute (n0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+2903484,int_stack+2718156,int_stack+2561340,66);
 /*--- compute (n0|xp) ---*/
 hrr3_build_xp(Libint->CD,int_stack+0,int_stack+205260,int_stack+192720,66);
 /*--- compute (n0|wd) ---*/
 hrr3_build_wd(Libint->CD,int_stack+37620,int_stack+0,int_stack+144144,66);
 /*--- compute (n0|vf) ---*/
 hrr3_build_vf(Libint->CD,int_stack+105336,int_stack+37620,int_stack+1120680,66);
 /*--- compute (n0|ug) ---*/
 hrr3_build_ug(Libint->CD,int_stack+2418648,int_stack+105336,int_stack+1181268,66);
 /*--- compute (n0|th) ---*/
 hrr3_build_th(Libint->CD,int_stack+0,int_stack+2418648,int_stack+2131680,66);
 /*--- compute (n0|ri) ---*/
 hrr3_build_ri(Libint->CD,int_stack+2418648,int_stack+0,int_stack+1271028,66);
 /*--- compute (n0|qk) ---*/
 hrr3_build_qk(Libint->CD,int_stack+0,int_stack+2418648,int_stack+2250480,66);
 /*--- compute (n0|ol) ---*/
 hrr3_build_ol(Libint->CD,int_stack+2131680,int_stack+0,int_stack+2718156,66);
 /*--- compute (n0|nm) ---*/
 hrr3_build_nm(Libint->CD,int_stack+2363340,int_stack+2131680,int_stack+2903484,66);
 /*--- compute (mp|nm) ---*/
 hrr1_build_mp(Libint->AB,int_stack+2602920,int_stack+2363340,int_stack+1441980,3630);
 /*--- compute (ld|nm) ---*/
 hrr1_build_ld(Libint->AB,int_stack+3201870,int_stack+2602920,int_stack+1641630,3630);
 /*--- compute (o0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+0,int_stack+224268,int_stack+219120,78);
 /*--- compute (o0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+15444,int_stack+230352,int_stack+224268,78);
 /*--- compute (o0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+33696,int_stack+15444,int_stack+0,78);
 /*--- compute (o0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+64584,int_stack+237450,int_stack+230352,78);
 /*--- compute (o0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+85878,int_stack+64584,int_stack+15444,78);
 /*--- compute (o0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+122382,int_stack+85878,int_stack+33696,78);
 /*--- compute (o0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+0,int_stack+245640,int_stack+237450,78);
 /*--- compute (o0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+173862,int_stack+0,int_stack+64584,78);
 /*--- compute (o0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+24570,int_stack+173862,int_stack+85878,78);
 /*--- compute (o0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+1120680,int_stack+24570,int_stack+122382,78);
 /*--- compute (o0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+85410,int_stack+255000,int_stack+245640,78);
 /*--- compute (o0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+113490,int_stack+85410,int_stack+0,78);
 /*--- compute (o0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+1197900,int_stack+113490,int_stack+173862,78);
 /*--- compute (o0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+162630,int_stack+1197900,int_stack+24570,78);
 /*--- compute (o0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+1268880,int_stack+162630,int_stack+1120680,78);
 /*--- compute (o0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+1120680,int_stack+265608,int_stack+255000,78);
 /*--- compute (o0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+0,int_stack+1120680,int_stack+85410,78);
 /*--- compute (o0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+1376988,int_stack+0,int_stack+113490,78);
 /*--- compute (o0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+56160,int_stack+1376988,int_stack+1197900,78);
 /*--- compute (o0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+1458888,int_stack+56160,int_stack+162630,78);
 /*--- compute (o0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+1586652,int_stack+1458888,int_stack+1268880,78);
 /*--- compute (o0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+162630,int_stack+277542,int_stack+265608,78);
 /*--- compute (o0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+198432,int_stack+162630,int_stack+1120680,78);
 /*--- compute (o0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1120680,int_stack+198432,int_stack+0,78);
 /*--- compute (o0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+1214280,int_stack+1120680,int_stack+1376988,78);
 /*--- compute (o0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+1730796,int_stack+1214280,int_stack+56160,78);
 /*--- compute (o0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+1879854,int_stack+1730796,int_stack+1458888,78);
 /*--- compute (o0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+1337130,int_stack+1879854,int_stack+1586652,78);
 /*--- compute (o0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+0,int_stack+290880,int_stack+277542,78);
 /*--- compute (o0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+40014,int_stack+0,int_stack+162630,78);
 /*--- compute (o0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+1522458,int_stack+40014,int_stack+198432,78);
 /*--- compute (o0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+111618,int_stack+1522458,int_stack+1120680,78);
 /*--- compute (o0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+2050206,int_stack+111618,int_stack+1214280,78);
 /*--- compute (o0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+1120680,int_stack+2050206,int_stack+1730796,78);
 /*--- compute (o0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+1628538,int_stack+1120680,int_stack+1879854,78);
 /*--- compute (o0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+4181970,int_stack+1628538,int_stack+1337130,78);
 /*--- compute (o0|xp) ---*/
 hrr3_build_xp(Libint->CD,int_stack+1319424,int_stack+305700,int_stack+290880,78);
 /*--- compute (o0|wd) ---*/
 hrr3_build_wd(Libint->CD,int_stack+1363884,int_stack+1319424,int_stack+0,78);
 /*--- compute (o0|vf) ---*/
 hrr3_build_vf(Libint->CD,int_stack+1847562,int_stack+1363884,int_stack+40014,78);
 /*--- compute (o0|ug) ---*/
 hrr3_build_ug(Libint->CD,int_stack+1319424,int_stack+1847562,int_stack+1522458,78);
 /*--- compute (o0|th) ---*/
 hrr3_build_th(Libint->CD,int_stack+1847562,int_stack+1319424,int_stack+111618,78);
 /*--- compute (o0|ri) ---*/
 hrr3_build_ri(Libint->CD,int_stack+1319424,int_stack+1847562,int_stack+2050206,78);
 /*--- compute (o0|qk) ---*/
 hrr3_build_qk(Libint->CD,int_stack+1847562,int_stack+1319424,int_stack+1120680,78);
 /*--- compute (o0|ol) ---*/
 hrr3_build_ol(Libint->CD,int_stack+1120680,int_stack+1847562,int_stack+1628538,78);
 /*--- compute (o0|nm) ---*/
 hrr3_build_nm(Libint->CD,int_stack+1394460,int_stack+1120680,int_stack+4181970,78);
 /*--- compute (np|nm) ---*/
 hrr1_build_np(Libint->AB,int_stack+4181970,int_stack+1394460,int_stack+2363340,3630);
 /*--- compute (md|nm) ---*/
 hrr1_build_md(Libint->AB,int_stack+4900710,int_stack+4181970,int_stack+2602920,3630);
 /*--- compute (lf|nm) ---*/
 hrr1_build_lf(Libint->AB,int_stack+6098610,int_stack+4900710,int_stack+3201870,3630);
 /*--- compute (q0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+1120680,int_stack+328086,int_stack+322080,91);
 /*--- compute (q0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+1138698,int_stack+335184,int_stack+328086,91);
 /*--- compute (q0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+1159992,int_stack+1138698,int_stack+1120680,91);
 /*--- compute (q0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+1196028,int_stack+343465,int_stack+335184,91);
 /*--- compute (q0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+1220871,int_stack+1196028,int_stack+1138698,91);
 /*--- compute (q0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+1263459,int_stack+1220871,int_stack+1159992,91);
 /*--- compute (q0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+1120680,int_stack+353020,int_stack+343465,91);
 /*--- compute (q0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+1323519,int_stack+1120680,int_stack+1196028,91);
 /*--- compute (q0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+1149345,int_stack+1323519,int_stack+1220871,91);
 /*--- compute (q0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+1677600,int_stack+1149345,int_stack+1263459,91);
 /*--- compute (q0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+1220325,int_stack+363940,int_stack+353020,91);
 /*--- compute (q0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+1253085,int_stack+1220325,int_stack+1120680,91);
 /*--- compute (q0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+1767690,int_stack+1253085,int_stack+1323519,91);
 /*--- compute (q0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+1850500,int_stack+1767690,int_stack+1149345,91);
 /*--- compute (q0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+1956970,int_stack+1850500,int_stack+1677600,91);
 /*--- compute (q0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+1677600,int_stack+376316,int_stack+363940,91);
 /*--- compute (q0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+1120680,int_stack+1677600,int_stack+1220325,91);
 /*--- compute (q0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+2083096,int_stack+1120680,int_stack+1253085,91);
 /*--- compute (q0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+1186200,int_stack+2083096,int_stack+1767690,91);
 /*--- compute (q0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+2178646,int_stack+1186200,int_stack+1850500,91);
 /*--- compute (q0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+1714728,int_stack+2178646,int_stack+1956970,91);
 /*--- compute (q0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+1882896,int_stack+390239,int_stack+376316,91);
 /*--- compute (q0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+1924665,int_stack+1882896,int_stack+1677600,91);
 /*--- compute (q0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+2327704,int_stack+1924665,int_stack+1120680,91);
 /*--- compute (q0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+2436904,int_stack+2327704,int_stack+2083096,91);
 /*--- compute (q0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+1998921,int_stack+2436904,int_stack+1186200,91);
 /*--- compute (q0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+1120680,int_stack+1998921,int_stack+2178646,91);
 /*--- compute (q0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+2580229,int_stack+1120680,int_stack+1714728,91);
 /*--- compute (q0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+1319424,int_stack+405800,int_stack+390239,91);
 /*--- compute (q0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+1677600,int_stack+1319424,int_stack+1882896,91);
 /*--- compute (q0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+1761138,int_stack+1677600,int_stack+1924665,91);
 /*--- compute (q0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+2796445,int_stack+1761138,int_stack+2327704,91);
 /*--- compute (q0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+2172822,int_stack+2796445,int_stack+2436904,91);
 /*--- compute (q0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+2960245,int_stack+2172822,int_stack+1998921,91);
 /*--- compute (q0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+1884898,int_stack+2960245,int_stack+1120680,91);
 /*--- compute (q0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+3192113,int_stack+1884898,int_stack+2580229,91);
 /*--- compute (q0|xp) ---*/
 hrr3_build_xp(Libint->CD,int_stack+1120680,int_stack+423090,int_stack+405800,91);
 /*--- compute (q0|wd) ---*/
 hrr3_build_wd(Libint->CD,int_stack+1172550,int_stack+1120680,int_stack+1319424,91);
 /*--- compute (q0|vf) ---*/
 hrr3_build_vf(Libint->CD,int_stack+2373477,int_stack+1172550,int_stack+1677600,91);
 /*--- compute (q0|ug) ---*/
 hrr3_build_ug(Libint->CD,int_stack+1120680,int_stack+2373477,int_stack+1761138,91);
 /*--- compute (q0|th) ---*/
 hrr3_build_th(Libint->CD,int_stack+2373477,int_stack+1120680,int_stack+2796445,91);
 /*--- compute (q0|ri) ---*/
 hrr3_build_ri(Libint->CD,int_stack+1120680,int_stack+2373477,int_stack+2172822,91);
 /*--- compute (q0|qk) ---*/
 hrr3_build_qk(Libint->CD,int_stack+2140426,int_stack+1120680,int_stack+2960245,91);
 /*--- compute (q0|ol) ---*/
 hrr3_build_ol(Libint->CD,int_stack+2438542,int_stack+2140426,int_stack+1884898,91);
 /*--- compute (q0|nm) ---*/
 hrr3_build_nm(Libint->CD,int_stack+1677600,int_stack+2438542,int_stack+3192113,91);
 /*--- compute (op|nm) ---*/
 hrr1_build_op(Libint->AB,int_stack+2007930,int_stack+1677600,int_stack+1394460,3630);
 /*--- compute (nd|nm) ---*/
 hrr1_build_nd(Libint->AB,int_stack+7732110,int_stack+2007930,int_stack+4181970,3630);
 /*--- compute (mf|nm) ---*/
 hrr1_build_mf(Libint->AB,int_stack+2857350,int_stack+7732110,int_stack+4900710,3630);
 /*--- compute (lg|nm) ---*/
 hrr1_build_lg(Libint->AB,int_stack+9169590,int_stack+2857350,int_stack+6098610,3630);
 /*--- compute (r0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+1120680,int_stack+449130,int_stack+442200,105);
 /*--- compute (r0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+1141470,int_stack+457320,int_stack+449130,105);
 /*--- compute (r0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+1166040,int_stack+1141470,int_stack+1120680,105);
 /*--- compute (r0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+1207620,int_stack+466875,int_stack+457320,105);
 /*--- compute (r0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+1236285,int_stack+1207620,int_stack+1141470,105);
 /*--- compute (r0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+1285425,int_stack+1236285,int_stack+1166040,105);
 /*--- compute (r0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+1120680,int_stack+477900,int_stack+466875,105);
 /*--- compute (r0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+1354725,int_stack+1120680,int_stack+1207620,105);
 /*--- compute (r0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+1153755,int_stack+1354725,int_stack+1236285,105);
 /*--- compute (r0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+1412055,int_stack+1153755,int_stack+1285425,105);
 /*--- compute (r0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+1235655,int_stack+490500,int_stack+477900,105);
 /*--- compute (r0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+1273455,int_stack+1235655,int_stack+1120680,105);
 /*--- compute (r0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+1516005,int_stack+1273455,int_stack+1354725,105);
 /*--- compute (r0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+4853850,int_stack+1516005,int_stack+1153755,105);
 /*--- compute (r0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+4976700,int_stack+4853850,int_stack+1412055,105);
 /*--- compute (r0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+1120680,int_stack+504780,int_stack+490500,105);
 /*--- compute (r0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+1339605,int_stack+1120680,int_stack+1235655,105);
 /*--- compute (r0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+5122230,int_stack+1339605,int_stack+1273455,105);
 /*--- compute (r0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+1163520,int_stack+5122230,int_stack+1516005,105);
 /*--- compute (r0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+1415205,int_stack+1163520,int_stack+4853850,105);
 /*--- compute (r0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+5232480,int_stack+1415205,int_stack+4976700,105);
 /*--- compute (r0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+4853850,int_stack+520845,int_stack+504780,105);
 /*--- compute (r0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+4902045,int_stack+4853850,int_stack+1120680,105);
 /*--- compute (r0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+4987725,int_stack+4902045,int_stack+1339605,105);
 /*--- compute (r0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+5426520,int_stack+4987725,int_stack+5122230,105);
 /*--- compute (r0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+5591895,int_stack+5426520,int_stack+1163520,105);
 /*--- compute (r0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+1120680,int_stack+5591895,int_stack+1415205,105);
 /*--- compute (r0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+1350000,int_stack+1120680,int_stack+5232480,105);
 /*--- compute (r0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+1599480,int_stack+538800,int_stack+520845,105);
 /*--- compute (r0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+5113725,int_stack+1599480,int_stack+4853850,105);
 /*--- compute (r0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+5210115,int_stack+5113725,int_stack+4902045,105);
 /*--- compute (r0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+5792550,int_stack+5210115,int_stack+4987725,105);
 /*--- compute (r0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+4853850,int_stack+5792550,int_stack+5426520,105);
 /*--- compute (r0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+5981550,int_stack+4853850,int_stack+5591895,105);
 /*--- compute (r0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+5352915,int_stack+5981550,int_stack+1120680,105);
 /*--- compute (r0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+6249090,int_stack+5352915,int_stack+1350000,105);
 /*--- compute (r0|xp) ---*/
 hrr3_build_xp(Libint->CD,int_stack+1120680,int_stack+558750,int_stack+538800,105);
 /*--- compute (r0|wd) ---*/
 hrr3_build_wd(Libint->CD,int_stack+1180530,int_stack+1120680,int_stack+1599480,105);
 /*--- compute (r0|vf) ---*/
 hrr3_build_vf(Libint->CD,int_stack+1288260,int_stack+1180530,int_stack+5113725,105);
 /*--- compute (r0|ug) ---*/
 hrr3_build_ug(Libint->CD,int_stack+1448910,int_stack+1288260,int_stack+5210115,105);
 /*--- compute (r0|th) ---*/
 hrr3_build_th(Libint->CD,int_stack+1120680,int_stack+1448910,int_stack+5792550,105);
 /*--- compute (r0|ri) ---*/
 hrr3_build_ri(Libint->CD,int_stack+5647755,int_stack+1120680,int_stack+4853850,105);
 /*--- compute (r0|qk) ---*/
 hrr3_build_qk(Libint->CD,int_stack+4853850,int_stack+5647755,int_stack+5981550,105);
 /*--- compute (r0|ol) ---*/
 hrr3_build_ol(Libint->CD,int_stack+5647755,int_stack+4853850,int_stack+5352915,105);
 /*--- compute (r0|nm) ---*/
 hrr3_build_nm(Libint->CD,int_stack+4853850,int_stack+5647755,int_stack+6249090,105);
 /*--- compute (qp|nm) ---*/
 hrr1_build_qp(Libint->AB,int_stack+5235000,int_stack+4853850,int_stack+1677600,3630);
 /*--- compute (od|nm) ---*/
 hrr1_build_od(Libint->AB,int_stack+11619840,int_stack+5235000,int_stack+2007930,3630);
 /*--- compute (nf|nm) ---*/
 hrr1_build_nf(Libint->AB,int_stack+13318680,int_stack+11619840,int_stack+7732110,3630);
 /*--- compute (mg|nm) ---*/
 hrr1_build_mg(Libint->AB,int_stack+15714480,int_stack+13318680,int_stack+2857350,3630);
 /*--- compute (lh|nm) ---*/
 hrr1_build_lh(Libint->AB,int_stack+1120680,int_stack+15714480,int_stack+9169590,3630);
 /*--- compute (t0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+6225990,int_stack+588720,int_stack+580800,120);
 /*--- compute (t0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+6249750,int_stack+598080,int_stack+588720,120);
 /*--- compute (t0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+6277830,int_stack+6249750,int_stack+6225990,120);
 /*--- compute (t0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+6325350,int_stack+609000,int_stack+598080,120);
 /*--- compute (t0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+6358110,int_stack+6325350,int_stack+6249750,120);
 /*--- compute (t0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+6414270,int_stack+6358110,int_stack+6277830,120);
 /*--- compute (t0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+6225990,int_stack+621600,int_stack+609000,120);
 /*--- compute (t0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+6493470,int_stack+6225990,int_stack+6325350,120);
 /*--- compute (t0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+6263790,int_stack+6493470,int_stack+6358110,120);
 /*--- compute (t0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+6558990,int_stack+6263790,int_stack+6414270,120);
 /*--- compute (t0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+6357390,int_stack+636000,int_stack+621600,120);
 /*--- compute (t0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+6400590,int_stack+6357390,int_stack+6225990,120);
 /*--- compute (t0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+6677790,int_stack+6400590,int_stack+6493470,120);
 /*--- compute (t0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+6786990,int_stack+6677790,int_stack+6263790,120);
 /*--- compute (t0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+6927390,int_stack+6786990,int_stack+6558990,120);
 /*--- compute (t0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+6225990,int_stack+652320,int_stack+636000,120);
 /*--- compute (t0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+6476190,int_stack+6225990,int_stack+6357390,120);
 /*--- compute (t0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+7093710,int_stack+6476190,int_stack+6400590,120);
 /*--- compute (t0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+6274950,int_stack+7093710,int_stack+6677790,120);
 /*--- compute (t0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+6562590,int_stack+6274950,int_stack+6786990,120);
 /*--- compute (t0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+7219710,int_stack+6562590,int_stack+6927390,120);
 /*--- compute (t0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+6759150,int_stack+670680,int_stack+652320,120);
 /*--- compute (t0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+6814230,int_stack+6759150,int_stack+6225990,120);
 /*--- compute (t0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+6912150,int_stack+6814230,int_stack+6476190,120);
 /*--- compute (t0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+7441470,int_stack+6912150,int_stack+7093710,120);
 /*--- compute (t0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+7630470,int_stack+7441470,int_stack+6274950,120);
 /*--- compute (t0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+6225990,int_stack+7630470,int_stack+6562590,120);
 /*--- compute (t0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+7859790,int_stack+6225990,int_stack+7219710,120);
 /*--- compute (t0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+6488070,int_stack+691200,int_stack+670680,120);
 /*--- compute (t0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+6549630,int_stack+6488070,int_stack+6759150,120);
 /*--- compute (t0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+7056150,int_stack+6549630,int_stack+6814230,120);
 /*--- compute (t0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+6659790,int_stack+7056150,int_stack+6912150,120);
 /*--- compute (t0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+8144910,int_stack+6659790,int_stack+7441470,120);
 /*--- compute (t0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+7219350,int_stack+8144910,int_stack+7630470,120);
 /*--- compute (t0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+8409510,int_stack+7219350,int_stack+6225990,120);
 /*--- compute (t0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+8746470,int_stack+8409510,int_stack+7859790,120);
 /*--- compute (t0|xp) ---*/
 hrr3_build_xp(Libint->CD,int_stack+6225990,int_stack+714000,int_stack+691200,120);
 /*--- compute (t0|wd) ---*/
 hrr3_build_wd(Libint->CD,int_stack+6294390,int_stack+6225990,int_stack+6488070,120);
 /*--- compute (t0|vf) ---*/
 hrr3_build_vf(Libint->CD,int_stack+7525110,int_stack+6294390,int_stack+6549630,120);
 /*--- compute (t0|ug) ---*/
 hrr3_build_ug(Libint->CD,int_stack+6225990,int_stack+7525110,int_stack+7056150,120);
 /*--- compute (t0|th) ---*/
 hrr3_build_th(Libint->CD,int_stack+7525110,int_stack+6225990,int_stack+6659790,120);
 /*--- compute (t0|ri) ---*/
 hrr3_build_ri(Libint->CD,int_stack+6225990,int_stack+7525110,int_stack+8144910,120);
 /*--- compute (t0|qk) ---*/
 hrr3_build_qk(Libint->CD,int_stack+7525110,int_stack+6225990,int_stack+7219350,120);
 /*--- compute (t0|ol) ---*/
 hrr3_build_ol(Libint->CD,int_stack+6225990,int_stack+7525110,int_stack+8409510,120);
 /*--- compute (t0|nm) ---*/
 hrr3_build_nm(Libint->CD,int_stack+6647190,int_stack+6225990,int_stack+8746470,120);
 /*--- compute (rp|nm) ---*/
 hrr1_build_rp(Libint->AB,int_stack+7082790,int_stack+6647190,int_stack+4853850,3630);
 /*--- compute (qd|nm) ---*/
 hrr1_build_qd(Libint->AB,int_stack+8226240,int_stack+7082790,int_stack+5235000,3630);
 /*--- compute (of|nm) ---*/
 hrr1_build_of(Libint->AB,int_stack+18709230,int_stack+8226240,int_stack+11619840,3630);
 /*--- compute (ng|nm) ---*/
 hrr1_build_ng(Libint->AB,int_stack+21540630,int_stack+18709230,int_stack+13318680,3630);
 /*--- compute (mh|nm) ---*/
 hrr1_build_mh(Libint->AB,int_stack+10208220,int_stack+21540630,int_stack+15714480,3630);
 /*--- compute (li|nm) ---*/
 hrr1_build_li(Libint->AB,int_stack+25134330,int_stack+10208220,int_stack+1120680,3630);
 /*--- compute (u0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+1120680,int_stack+748176,int_stack+739200,136);
 /*--- compute (u0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+1147608,int_stack+758784,int_stack+748176,136);
 /*--- compute (u0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+1179432,int_stack+1147608,int_stack+1120680,136);
 /*--- compute (u0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+1233288,int_stack+771160,int_stack+758784,136);
 /*--- compute (u0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+1270416,int_stack+1233288,int_stack+1147608,136);
 /*--- compute (u0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+1334064,int_stack+1270416,int_stack+1179432,136);
 /*--- compute (u0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+1120680,int_stack+785440,int_stack+771160,136);
 /*--- compute (u0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+1423824,int_stack+1120680,int_stack+1233288,136);
 /*--- compute (u0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+1163520,int_stack+1423824,int_stack+1270416,136);
 /*--- compute (u0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+1498080,int_stack+1163520,int_stack+1334064,136);
 /*--- compute (u0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+1269600,int_stack+801760,int_stack+785440,136);
 /*--- compute (u0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+1318560,int_stack+1269600,int_stack+1120680,136);
 /*--- compute (u0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+1632720,int_stack+1318560,int_stack+1423824,136);
 /*--- compute (u0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+1756480,int_stack+1632720,int_stack+1163520,136);
 /*--- compute (u0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+1915600,int_stack+1756480,int_stack+1498080,136);
 /*--- compute (u0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+1120680,int_stack+820256,int_stack+801760,136);
 /*--- compute (u0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+1404240,int_stack+1120680,int_stack+1269600,136);
 /*--- compute (u0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+2104096,int_stack+1404240,int_stack+1318560,136);
 /*--- compute (u0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+1176168,int_stack+2104096,int_stack+1632720,136);
 /*--- compute (u0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+1502160,int_stack+1176168,int_stack+1756480,136);
 /*--- compute (u0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+2246896,int_stack+1502160,int_stack+1915600,136);
 /*--- compute (u0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+1724928,int_stack+841064,int_stack+820256,136);
 /*--- compute (u0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+1787352,int_stack+1724928,int_stack+1120680,136);
 /*--- compute (u0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1898328,int_stack+1787352,int_stack+1404240,136);
 /*--- compute (u0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+2498224,int_stack+1898328,int_stack+2104096,136);
 /*--- compute (u0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+2712424,int_stack+2498224,int_stack+1176168,136);
 /*--- compute (u0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+1120680,int_stack+2712424,int_stack+1502160,136);
 /*--- compute (u0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+2972320,int_stack+1120680,int_stack+2246896,136);
 /*--- compute (u0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+1417704,int_stack+864320,int_stack+841064,136);
 /*--- compute (u0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+1487472,int_stack+1417704,int_stack+1724928,136);
 /*--- compute (u0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+2061528,int_stack+1487472,int_stack+1787352,136);
 /*--- compute (u0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+1612320,int_stack+2061528,int_stack+1898328,136);
 /*--- compute (u0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+3295456,int_stack+1612320,int_stack+2498224,136);
 /*--- compute (u0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+2246488,int_stack+3295456,int_stack+2712424,136);
 /*--- compute (u0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+3595336,int_stack+2246488,int_stack+1120680,136);
 /*--- compute (u0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+3977224,int_stack+3595336,int_stack+2972320,136);
 /*--- compute (u0|xp) ---*/
 hrr3_build_xp(Libint->CD,int_stack+1120680,int_stack+890160,int_stack+864320,136);
 /*--- compute (u0|wd) ---*/
 hrr3_build_wd(Libint->CD,int_stack+1198200,int_stack+1120680,int_stack+1417704,136);
 /*--- compute (u0|vf) ---*/
 hrr3_build_vf(Libint->CD,int_stack+2593016,int_stack+1198200,int_stack+1487472,136);
 /*--- compute (u0|ug) ---*/
 hrr3_build_ug(Libint->CD,int_stack+1120680,int_stack+2593016,int_stack+2061528,136);
 /*--- compute (u0|th) ---*/
 hrr3_build_th(Libint->CD,int_stack+2593016,int_stack+1120680,int_stack+1612320,136);
 /*--- compute (u0|ri) ---*/
 hrr3_build_ri(Libint->CD,int_stack+1120680,int_stack+2593016,int_stack+3295456,136);
 /*--- compute (u0|qk) ---*/
 hrr3_build_qk(Libint->CD,int_stack+2593016,int_stack+1120680,int_stack+2246488,136);
 /*--- compute (u0|ol) ---*/
 hrr3_build_ol(Libint->CD,int_stack+1120680,int_stack+2593016,int_stack+3595336,136);
 /*--- compute (u0|nm) ---*/
 hrr3_build_nm(Libint->CD,int_stack+1598040,int_stack+1120680,int_stack+3977224,136);
 /*--- compute (tp|nm) ---*/
 hrr1_build_tp(Libint->AB,int_stack+2091720,int_stack+1598040,int_stack+6647190,3630);
 /*--- compute (rd|nm) ---*/
 hrr1_build_rd(Libint->AB,int_stack+3398520,int_stack+2091720,int_stack+7082790,3630);
 /*--- compute (qf|nm) ---*/
 hrr1_build_qf(Libint->AB,int_stack+14400870,int_stack+3398520,int_stack+8226240,3630);
 /*--- compute (og|nm) ---*/
 hrr1_build_og(Libint->AB,int_stack+5685420,int_stack+14400870,int_stack+18709230,3630);
 /*--- compute (nh|nm) ---*/
 hrr1_build_nh(Libint->AB,int_stack+29708130,int_stack+5685420,int_stack+21540630,3630);
 /*--- compute (mi|nm) ---*/
 hrr1_build_mi(Libint->AB,int_stack+17704170,int_stack+29708130,int_stack+10208220,3630);
 /*--- compute (lk|nm) ---*/
 hrr1_build_lk(Libint->AB,int_stack+34739310,int_stack+17704170,int_stack+25134330,3630);
 /*--- compute (v0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+1120680,int_stack+928818,int_stack+918720,153);
 /*--- compute (v0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+1150974,int_stack+940752,int_stack+928818,153);
 /*--- compute (v0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+1186776,int_stack+1150974,int_stack+1120680,153);
 /*--- compute (v0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+1247364,int_stack+954675,int_stack+940752,153);
 /*--- compute (v0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+1289133,int_stack+1247364,int_stack+1150974,153);
 /*--- compute (v0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+1360737,int_stack+1289133,int_stack+1186776,153);
 /*--- compute (v0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+1120680,int_stack+970740,int_stack+954675,153);
 /*--- compute (v0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+1461717,int_stack+1120680,int_stack+1247364,153);
 /*--- compute (v0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+1168875,int_stack+1461717,int_stack+1289133,153);
 /*--- compute (v0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+9932520,int_stack+1168875,int_stack+1360737,153);
 /*--- compute (v0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+1288215,int_stack+989100,int_stack+970740,153);
 /*--- compute (v0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+1343295,int_stack+1288215,int_stack+1120680,153);
 /*--- compute (v0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+10083990,int_stack+1343295,int_stack+1461717,153);
 /*--- compute (v0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+10223220,int_stack+10083990,int_stack+1168875,153);
 /*--- compute (v0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+10402230,int_stack+10223220,int_stack+9932520,153);
 /*--- compute (v0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+9932520,int_stack+1009908,int_stack+989100,153);
 /*--- compute (v0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+1120680,int_stack+9932520,int_stack+1288215,153);
 /*--- compute (v0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+10614288,int_stack+1120680,int_stack+1343295,153);
 /*--- compute (v0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+1230840,int_stack+10614288,int_stack+10083990,153);
 /*--- compute (v0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+10774938,int_stack+1230840,int_stack+10223220,153);
 /*--- compute (v0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+9994944,int_stack+10774938,int_stack+10402230,153);
 /*--- compute (v0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+10277688,int_stack+1033317,int_stack+1009908,153);
 /*--- compute (v0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+10347915,int_stack+10277688,int_stack+9932520,153);
 /*--- compute (v0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+11025552,int_stack+10347915,int_stack+1120680,153);
 /*--- compute (v0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+11209152,int_stack+11025552,int_stack+10614288,153);
 /*--- compute (v0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+10472763,int_stack+11209152,int_stack+1230840,153);
 /*--- compute (v0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+1120680,int_stack+10472763,int_stack+10774938,153);
 /*--- compute (v0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+11450127,int_stack+1120680,int_stack+9994944,153);
 /*--- compute (v0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+1454832,int_stack+1059480,int_stack+1033317,153);
 /*--- compute (v0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+9932520,int_stack+1454832,int_stack+10277688,153);
 /*--- compute (v0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+10072974,int_stack+9932520,int_stack+10347915,153);
 /*--- compute (v0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+11813655,int_stack+10072974,int_stack+11025552,153);
 /*--- compute (v0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+10765146,int_stack+11813655,int_stack+11209152,153);
 /*--- compute (v0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+12089055,int_stack+10765146,int_stack+10472763,153);
 /*--- compute (v0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+10281054,int_stack+12089055,int_stack+1120680,153);
 /*--- compute (v0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+12478899,int_stack+10281054,int_stack+11450127,153);
 /*--- compute (v0|xp) ---*/
 hrr3_build_xp(Libint->CD,int_stack+1120680,int_stack+1088550,int_stack+1059480,153);
 /*--- compute (v0|wd) ---*/
 hrr3_build_wd(Libint->CD,int_stack+1207890,int_stack+1120680,int_stack+1454832,153);
 /*--- compute (v0|vf) ---*/
 hrr3_build_vf(Libint->CD,int_stack+11102511,int_stack+1207890,int_stack+9932520,153);
 /*--- compute (v0|ug) ---*/
 hrr3_build_ug(Libint->CD,int_stack+11336601,int_stack+11102511,int_stack+10072974,153);
 /*--- compute (v0|th) ---*/
 hrr3_build_th(Libint->CD,int_stack+12933309,int_stack+11336601,int_stack+11813655,153);
 /*--- compute (v0|ri) ---*/
 hrr3_build_ri(Libint->CD,int_stack+11102511,int_stack+12933309,int_stack+10765146,153);
 /*--- compute (v0|qk) ---*/
 hrr3_build_qk(Libint->CD,int_stack+12933309,int_stack+11102511,int_stack+12089055,153);
 /*--- compute (v0|ol) ---*/
 hrr3_build_ol(Libint->CD,int_stack+13434537,int_stack+12933309,int_stack+10281054,153);
 /*--- compute (v0|nm) ---*/
 hrr3_build_nm(Libint->CD,int_stack+9932520,int_stack+13434537,int_stack+12478899,153);
 /*--- compute (up|nm) ---*/
 hrr1_build_up(Libint->AB,int_stack+10487910,int_stack+9932520,int_stack+1598040,3630);
 /*--- compute (td|nm) ---*/
 hrr1_build_td(Libint->AB,int_stack+23294370,int_stack+10487910,int_stack+2091720,3630);
 /*--- compute (rf|nm) ---*/
 hrr1_build_rf(Libint->AB,int_stack+9932520,int_stack+23294370,int_stack+3398520,3630);
 /*--- compute (qg|nm) ---*/
 hrr1_build_qg(Libint->AB,int_stack+23294370,int_stack+9932520,int_stack+14400870,3630);
 /*--- compute (oh|nm) ---*/
 hrr1_build_oh(Libint->AB,int_stack+9932520,int_stack+23294370,int_stack+5685420,3630);
 /*--- compute (ni|nm) ---*/
 hrr1_build_ni(Libint->AB,int_stack+0,int_stack+9932520,int_stack+29708130,3630);
 /*--- compute (mk|nm) ---*/
 hrr1_build_mk(Libint->AB,int_stack+23294370,int_stack+0,int_stack+17704170,3630);
 /*--- compute (ll|nm) ---*/
 hrr1_build_ll(Libint->AB,int_stack+0,int_stack+23294370,int_stack+34739310,3630);
 return int_stack+0;}
