/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include "libint.h"
#include "hrr_header.h"

extern void vrr_order_nlmm(Libint_t*, prim_data*);

  /* Computes quartets of (nl|mm) integrals */

REALTYPE *hrr_order_nlmm(Libint_t *Libint, int num_prim_comb)
{
 prim_data *Data = Libint->PrimQuartet;
 REALTYPE *int_stack = Libint->int_stack;
 int i;

 Libint->vrr_classes[10][9] = int_stack + 0;
 Libint->vrr_classes[10][10] = int_stack + 3630;
 Libint->vrr_classes[10][11] = int_stack + 7986;
 Libint->vrr_classes[10][12] = int_stack + 13134;
 Libint->vrr_classes[10][13] = int_stack + 19140;
 Libint->vrr_classes[10][14] = int_stack + 26070;
 Libint->vrr_classes[10][15] = int_stack + 33990;
 Libint->vrr_classes[10][16] = int_stack + 42966;
 Libint->vrr_classes[10][17] = int_stack + 53064;
 Libint->vrr_classes[10][18] = int_stack + 64350;
 Libint->vrr_classes[11][9] = int_stack + 76890;
 Libint->vrr_classes[11][10] = int_stack + 81180;
 Libint->vrr_classes[11][11] = int_stack + 86328;
 Libint->vrr_classes[11][12] = int_stack + 92412;
 Libint->vrr_classes[11][13] = int_stack + 99510;
 Libint->vrr_classes[11][14] = int_stack + 107700;
 Libint->vrr_classes[11][15] = int_stack + 117060;
 Libint->vrr_classes[11][16] = int_stack + 127668;
 Libint->vrr_classes[11][17] = int_stack + 139602;
 Libint->vrr_classes[11][18] = int_stack + 152940;
 Libint->vrr_classes[12][9] = int_stack + 167760;
 Libint->vrr_classes[12][10] = int_stack + 172765;
 Libint->vrr_classes[12][11] = int_stack + 178771;
 Libint->vrr_classes[12][12] = int_stack + 185869;
 Libint->vrr_classes[12][13] = int_stack + 194150;
 Libint->vrr_classes[12][14] = int_stack + 203705;
 Libint->vrr_classes[12][15] = int_stack + 214625;
 Libint->vrr_classes[12][16] = int_stack + 227001;
 Libint->vrr_classes[12][17] = int_stack + 240924;
 Libint->vrr_classes[12][18] = int_stack + 256485;
 Libint->vrr_classes[13][9] = int_stack + 273775;
 Libint->vrr_classes[13][10] = int_stack + 279550;
 Libint->vrr_classes[13][11] = int_stack + 286480;
 Libint->vrr_classes[13][12] = int_stack + 294670;
 Libint->vrr_classes[13][13] = int_stack + 304225;
 Libint->vrr_classes[13][14] = int_stack + 315250;
 Libint->vrr_classes[13][15] = int_stack + 327850;
 Libint->vrr_classes[13][16] = int_stack + 342130;
 Libint->vrr_classes[13][17] = int_stack + 358195;
 Libint->vrr_classes[13][18] = int_stack + 376150;
 Libint->vrr_classes[14][9] = int_stack + 396100;
 Libint->vrr_classes[14][10] = int_stack + 402700;
 Libint->vrr_classes[14][11] = int_stack + 410620;
 Libint->vrr_classes[14][12] = int_stack + 419980;
 Libint->vrr_classes[14][13] = int_stack + 430900;
 Libint->vrr_classes[14][14] = int_stack + 443500;
 Libint->vrr_classes[14][15] = int_stack + 457900;
 Libint->vrr_classes[14][16] = int_stack + 474220;
 Libint->vrr_classes[14][17] = int_stack + 492580;
 Libint->vrr_classes[14][18] = int_stack + 513100;
 Libint->vrr_classes[15][9] = int_stack + 535900;
 Libint->vrr_classes[15][10] = int_stack + 543380;
 Libint->vrr_classes[15][11] = int_stack + 552356;
 Libint->vrr_classes[15][12] = int_stack + 562964;
 Libint->vrr_classes[15][13] = int_stack + 575340;
 Libint->vrr_classes[15][14] = int_stack + 589620;
 Libint->vrr_classes[15][15] = int_stack + 605940;
 Libint->vrr_classes[15][16] = int_stack + 624436;
 Libint->vrr_classes[15][17] = int_stack + 645244;
 Libint->vrr_classes[15][18] = int_stack + 668500;
 Libint->vrr_classes[16][9] = int_stack + 694340;
 Libint->vrr_classes[16][10] = int_stack + 702755;
 Libint->vrr_classes[16][11] = int_stack + 712853;
 Libint->vrr_classes[16][12] = int_stack + 724787;
 Libint->vrr_classes[16][13] = int_stack + 738710;
 Libint->vrr_classes[16][14] = int_stack + 754775;
 Libint->vrr_classes[16][15] = int_stack + 773135;
 Libint->vrr_classes[16][16] = int_stack + 793943;
 Libint->vrr_classes[16][17] = int_stack + 817352;
 Libint->vrr_classes[16][18] = int_stack + 843515;
 Libint->vrr_classes[17][9] = int_stack + 872585;
 Libint->vrr_classes[17][10] = int_stack + 881990;
 Libint->vrr_classes[17][11] = int_stack + 893276;
 Libint->vrr_classes[17][12] = int_stack + 906614;
 Libint->vrr_classes[17][13] = int_stack + 922175;
 Libint->vrr_classes[17][14] = int_stack + 940130;
 Libint->vrr_classes[17][15] = int_stack + 960650;
 Libint->vrr_classes[17][16] = int_stack + 983906;
 Libint->vrr_classes[17][17] = int_stack + 1010069;
 Libint->vrr_classes[17][18] = int_stack + 1039310;
 Libint->vrr_classes[18][9] = int_stack + 1071800;
 Libint->vrr_classes[18][10] = int_stack + 1082250;
 Libint->vrr_classes[18][11] = int_stack + 1094790;
 Libint->vrr_classes[18][12] = int_stack + 1109610;
 Libint->vrr_classes[18][13] = int_stack + 1126900;
 Libint->vrr_classes[18][14] = int_stack + 1146850;
 Libint->vrr_classes[18][15] = int_stack + 1169650;
 Libint->vrr_classes[18][16] = int_stack + 1195490;
 Libint->vrr_classes[18][17] = int_stack + 1224560;
 Libint->vrr_classes[18][18] = int_stack + 1257050;
 memset(int_stack,0,1293150*sizeof(REALTYPE));

 Libint->vrr_stack = int_stack + 1293150;
 for(i=0;i<num_prim_comb;i++) {
   vrr_order_nlmm(Libint, Data);
   Data++;
 }
 /*--- compute (n0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+1293150,int_stack+3630,int_stack+0,66);
 /*--- compute (n0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+1304040,int_stack+7986,int_stack+3630,66);
 /*--- compute (n0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+1317108,int_stack+1304040,int_stack+1293150,66);
 /*--- compute (n0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+1338888,int_stack+13134,int_stack+7986,66);
 /*--- compute (n0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+1354332,int_stack+1338888,int_stack+1304040,66);
 /*--- compute (n0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+1380468,int_stack+1354332,int_stack+1317108,66);
 /*--- compute (n0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+1293150,int_stack+19140,int_stack+13134,66);
 /*--- compute (n0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+1416768,int_stack+1293150,int_stack+1338888,66);
 /*--- compute (n0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+1447656,int_stack+1416768,int_stack+1354332,66);
 /*--- compute (n0|mg) ---*/
 hrr3_build_mg(Libint->CD,int_stack+1311168,int_stack+1447656,int_stack+1380468,66);
 /*--- compute (n0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+1365618,int_stack+26070,int_stack+19140,66);
 /*--- compute (n0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+1491216,int_stack+1365618,int_stack+1293150,66);
 /*--- compute (n0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+1527252,int_stack+1491216,int_stack+1416768,66);
 /*--- compute (n0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+1578732,int_stack+1527252,int_stack+1447656,66);
 /*--- compute (n0|mh) ---*/
 hrr3_build_mh(Libint->CD,int_stack+1386408,int_stack+1578732,int_stack+1311168,66);
 /*--- compute (n0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+1293150,int_stack+33990,int_stack+26070,66);
 /*--- compute (n0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+1316910,int_stack+1293150,int_stack+1365618,66);
 /*--- compute (n0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+1644072,int_stack+1316910,int_stack+1491216,66);
 /*--- compute (n0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+1704132,int_stack+1644072,int_stack+1527252,66);
 /*--- compute (n0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+1462638,int_stack+1704132,int_stack+1578732,66);
 /*--- compute (n0|mi) ---*/
 hrr3_build_mi(Libint->CD,int_stack+1781352,int_stack+1462638,int_stack+1386408,66);
 /*--- compute (n0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+1358490,int_stack+42966,int_stack+33990,66);
 /*--- compute (n0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+1385418,int_stack+1358490,int_stack+1293150,66);
 /*--- compute (n0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+1554114,int_stack+1385418,int_stack+1316910,66);
 /*--- compute (n0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+1882992,int_stack+1554114,int_stack+1644072,66);
 /*--- compute (n0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+1973082,int_stack+1882992,int_stack+1704132,66);
 /*--- compute (n0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+1623414,int_stack+1973082,int_stack+1462638,66);
 /*--- compute (n0|mk) ---*/
 hrr3_build_mk(Libint->CD,int_stack+2081190,int_stack+1623414,int_stack+1781352,66);
 /*--- compute (n0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+1293150,int_stack+53064,int_stack+42966,66);
 /*--- compute (n0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+1432938,int_stack+1293150,int_stack+1358490,66);
 /*--- compute (n0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1745382,int_stack+1432938,int_stack+1385418,66);
 /*--- compute (n0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+1323444,int_stack+1745382,int_stack+1554114,66);
 /*--- compute (n0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+1486794,int_stack+1323444,int_stack+1882992,66);
 /*--- compute (n0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+1824582,int_stack+1486794,int_stack+1973082,66);
 /*--- compute (n0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+2211870,int_stack+1824582,int_stack+1623414,66);
 /*--- compute (n0|ml) ---*/
 hrr3_build_ml(Libint->CD,int_stack+2368686,int_stack+2211870,int_stack+2081190,66);
 /*--- compute (n0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+1612920,int_stack+64350,int_stack+53064,66);
 /*--- compute (n0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+1646778,int_stack+1612920,int_stack+1293150,66);
 /*--- compute (n0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+1968726,int_stack+1646778,int_stack+1432938,66);
 /*--- compute (n0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+1612920,int_stack+1968726,int_stack+1745382,66);
 /*--- compute (n0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+1968726,int_stack+1612920,int_stack+1323444,66);
 /*--- compute (n0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+1612920,int_stack+1968726,int_stack+1486794,66);
 /*--- compute (n0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+1968726,int_stack+1612920,int_stack+1824582,66);
 /*--- compute (n0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+1293150,int_stack+1968726,int_stack+2211870,66);
 /*--- compute (n0|mm) ---*/
 hrr3_build_mm(Libint->CD,int_stack+1489170,int_stack+1293150,int_stack+2368686,66);
 /*--- compute (o0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+1293150,int_stack+81180,int_stack+76890,78);
 /*--- compute (o0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+1306020,int_stack+86328,int_stack+81180,78);
 /*--- compute (o0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+1321464,int_stack+1306020,int_stack+1293150,78);
 /*--- compute (o0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+1347204,int_stack+92412,int_stack+86328,78);
 /*--- compute (o0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+1365456,int_stack+1347204,int_stack+1306020,78);
 /*--- compute (o0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+1396344,int_stack+1365456,int_stack+1321464,78);
 /*--- compute (o0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+1293150,int_stack+99510,int_stack+92412,78);
 /*--- compute (o0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+1439244,int_stack+1293150,int_stack+1347204,78);
 /*--- compute (o0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+1688820,int_stack+1439244,int_stack+1365456,78);
 /*--- compute (o0|mg) ---*/
 hrr3_build_mg(Libint->CD,int_stack+1314444,int_stack+1688820,int_stack+1396344,78);
 /*--- compute (o0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+1378794,int_stack+107700,int_stack+99510,78);
 /*--- compute (o0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+1740300,int_stack+1378794,int_stack+1293150,78);
 /*--- compute (o0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+1782888,int_stack+1740300,int_stack+1439244,78);
 /*--- compute (o0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+1403364,int_stack+1782888,int_stack+1688820,78);
 /*--- compute (o0|mh) ---*/
 hrr3_build_mh(Libint->CD,int_stack+1843728,int_stack+1403364,int_stack+1314444,78);
 /*--- compute (o0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+1688820,int_stack+117060,int_stack+107700,78);
 /*--- compute (o0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+1293150,int_stack+1688820,int_stack+1378794,78);
 /*--- compute (o0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+1933818,int_stack+1293150,int_stack+1740300,78);
 /*--- compute (o0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+2004798,int_stack+1933818,int_stack+1782888,78);
 /*--- compute (o0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+1716900,int_stack+2004798,int_stack+1403364,78);
 /*--- compute (o0|mi) ---*/
 hrr3_build_mi(Libint->CD,int_stack+1342290,int_stack+1716900,int_stack+1843728,78);
 /*--- compute (o0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+1825008,int_stack+127668,int_stack+117060,78);
 /*--- compute (o0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+1856832,int_stack+1825008,int_stack+1688820,78);
 /*--- compute (o0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+2096058,int_stack+1856832,int_stack+1293150,78);
 /*--- compute (o0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+2177958,int_stack+2096058,int_stack+1933818,78);
 /*--- compute (o0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+2284428,int_stack+2177958,int_stack+2004798,78);
 /*--- compute (o0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+1912992,int_stack+2284428,int_stack+1716900,78);
 /*--- compute (o0|mk) ---*/
 hrr3_build_mk(Libint->CD,int_stack+2412192,int_stack+1912992,int_stack+1342290,78);
 /*--- compute (o0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+1293150,int_stack+139602,int_stack+127668,78);
 /*--- compute (o0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+1328952,int_stack+1293150,int_stack+1825008,78);
 /*--- compute (o0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1392600,int_stack+1328952,int_stack+1856832,78);
 /*--- compute (o0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+1688820,int_stack+1392600,int_stack+2096058,78);
 /*--- compute (o0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+2566632,int_stack+1688820,int_stack+2177958,78);
 /*--- compute (o0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+2057136,int_stack+2566632,int_stack+2284428,78);
 /*--- compute (o0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+2715690,int_stack+2057136,int_stack+1912992,78);
 /*--- compute (o0|ml) ---*/
 hrr3_build_ml(Libint->CD,int_stack+1811670,int_stack+2715690,int_stack+2412192,78);
 /*--- compute (o0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+2004720,int_stack+152940,int_stack+139602,78);
 /*--- compute (o0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+2227488,int_stack+2004720,int_stack+1293150,78);
 /*--- compute (o0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+2299092,int_stack+2227488,int_stack+1328952,78);
 /*--- compute (o0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+2405172,int_stack+2299092,int_stack+1392600,78);
 /*--- compute (o0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+2227488,int_stack+2405172,int_stack+1688820,78);
 /*--- compute (o0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+2901018,int_stack+2227488,int_stack+2566632,78);
 /*--- compute (o0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+2227488,int_stack+2901018,int_stack+2057136,78);
 /*--- compute (o0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+2446512,int_stack+2227488,int_stack+2715690,78);
 /*--- compute (o0|mm) ---*/
 hrr3_build_mm(Libint->CD,int_stack+2678172,int_stack+2446512,int_stack+1811670,78);
 /*--- compute (np|mm) ---*/
 hrr1_build_np(Libint->AB,int_stack+1688820,int_stack+2678172,int_stack+1489170,3025);
 /*--- compute (q0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+2914122,int_stack+172765,int_stack+167760,91);
 /*--- compute (q0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+2929137,int_stack+178771,int_stack+172765,91);
 /*--- compute (q0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+2947155,int_stack+2929137,int_stack+2914122,91);
 /*--- compute (q0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+2977185,int_stack+185869,int_stack+178771,91);
 /*--- compute (q0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+2998479,int_stack+2977185,int_stack+2929137,91);
 /*--- compute (q0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+3034515,int_stack+2998479,int_stack+2947155,91);
 /*--- compute (q0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+2914122,int_stack+194150,int_stack+185869,91);
 /*--- compute (q0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+2287770,int_stack+2914122,int_stack+2977185,91);
 /*--- compute (q0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+2330358,int_stack+2287770,int_stack+2998479,91);
 /*--- compute (q0|mg) ---*/
 hrr3_build_mg(Libint->CD,int_stack+2938965,int_stack+2330358,int_stack+3034515,91);
 /*--- compute (q0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+3014040,int_stack+203705,int_stack+194150,91);
 /*--- compute (q0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+3042705,int_stack+3014040,int_stack+2914122,91);
 /*--- compute (q0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+2390418,int_stack+3042705,int_stack+2287770,91);
 /*--- compute (q0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+2461398,int_stack+2390418,int_stack+2330358,91);
 /*--- compute (q0|mh) ---*/
 hrr3_build_mh(Libint->CD,int_stack+2551488,int_stack+2461398,int_stack+2938965,91);
 /*--- compute (q0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+2287770,int_stack+214625,int_stack+203705,91);
 /*--- compute (q0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+2320530,int_stack+2287770,int_stack+3014040,91);
 /*--- compute (q0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+2914122,int_stack+2320530,int_stack+3042705,91);
 /*--- compute (q0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+1293150,int_stack+2914122,int_stack+2390418,91);
 /*--- compute (q0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+1399620,int_stack+1293150,int_stack+2461398,91);
 /*--- compute (q0|mi) ---*/
 hrr3_build_mi(Libint->CD,int_stack+2377860,int_stack+1399620,int_stack+2551488,91);
 /*--- compute (q0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+2518000,int_stack+227001,int_stack+214625,91);
 /*--- compute (q0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+2555128,int_stack+2518000,int_stack+2287770,91);
 /*--- compute (q0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+2996932,int_stack+2555128,int_stack+2320530,91);
 /*--- compute (q0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+1525746,int_stack+2996932,int_stack+2914122,91);
 /*--- compute (q0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+0,int_stack+1525746,int_stack+1293150,91);
 /*--- compute (q0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+3092482,int_stack+0,int_stack+1399620,91);
 /*--- compute (q0|mk) ---*/
 hrr3_build_mk(Libint->CD,int_stack+1293150,int_stack+3092482,int_stack+2377860,91);
 /*--- compute (q0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+1473330,int_stack+240924,int_stack+227001,91);
 /*--- compute (q0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+2914122,int_stack+1473330,int_stack+2518000,91);
 /*--- compute (q0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+2287770,int_stack+2914122,int_stack+2555128,91);
 /*--- compute (q0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+2396970,int_stack+2287770,int_stack+2996932,91);
 /*--- compute (q0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+3260650,int_stack+2396970,int_stack+1525746,91);
 /*--- compute (q0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+3434551,int_stack+3260650,int_stack+0,91);
 /*--- compute (q0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+0,int_stack+3434551,int_stack+3092482,91);
 /*--- compute (q0|ml) ---*/
 hrr3_build_ml(Libint->CD,int_stack+2988378,int_stack+0,int_stack+1293150,91);
 /*--- compute (q0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+1293150,int_stack+256485,int_stack+240924,91);
 /*--- compute (q0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+1339833,int_stack+1293150,int_stack+1473330,91);
 /*--- compute (q0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+1423371,int_stack+1339833,int_stack+2914122,91);
 /*--- compute (q0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+3633295,int_stack+1423371,int_stack+2287770,91);
 /*--- compute (q0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+1293150,int_stack+3633295,int_stack+2396970,91);
 /*--- compute (q0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+2287770,int_stack+1293150,int_stack+3260650,91);
 /*--- compute (q0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+1293150,int_stack+2287770,int_stack+3434551,91);
 /*--- compute (q0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+2287770,int_stack+1293150,int_stack+0,91);
 /*--- compute (q0|mm) ---*/
 hrr3_build_mm(Libint->CD,int_stack+1293150,int_stack+2287770,int_stack+2988378,91);
 /*--- compute (op|mm) ---*/
 hrr1_build_op(Libint->AB,int_stack+2914122,int_stack+1293150,int_stack+2678172,3025);
 /*--- compute (nd|mm) ---*/
 hrr1_build_nd(Libint->AB,int_stack+3621972,int_stack+2914122,int_stack+1688820,3025);
 /*--- compute (r0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+0,int_stack+279550,int_stack+273775,105);
 /*--- compute (r0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+17325,int_stack+286480,int_stack+279550,105);
 /*--- compute (r0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+38115,int_stack+17325,int_stack+0,105);
 /*--- compute (r0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+72765,int_stack+294670,int_stack+286480,105);
 /*--- compute (r0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+97335,int_stack+72765,int_stack+17325,105);
 /*--- compute (r0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+138915,int_stack+97335,int_stack+38115,105);
 /*--- compute (r0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+0,int_stack+304225,int_stack+294670,105);
 /*--- compute (r0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+196665,int_stack+0,int_stack+72765,105);
 /*--- compute (r0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+1568425,int_stack+196665,int_stack+97335,105);
 /*--- compute (r0|mg) ---*/
 hrr3_build_mg(Libint->CD,int_stack+28665,int_stack+1568425,int_stack+138915,105);
 /*--- compute (r0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+115290,int_stack+315250,int_stack+304225,105);
 /*--- compute (r0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+245805,int_stack+115290,int_stack+0,105);
 /*--- compute (r0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+1637725,int_stack+245805,int_stack+196665,105);
 /*--- compute (r0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+1719625,int_stack+1637725,int_stack+1568425,105);
 /*--- compute (r0|mh) ---*/
 hrr3_build_mh(Libint->CD,int_stack+1823575,int_stack+1719625,int_stack+28665,105);
 /*--- compute (r0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+1568425,int_stack+327850,int_stack+315250,105);
 /*--- compute (r0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+0,int_stack+1568425,int_stack+115290,105);
 /*--- compute (r0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+66150,int_stack+0,int_stack+245805,105);
 /*--- compute (r0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+161700,int_stack+66150,int_stack+1637725,105);
 /*--- compute (r0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+1944850,int_stack+161700,int_stack+1719625,105);
 /*--- compute (r0|mi) ---*/
 hrr3_build_mi(Libint->CD,int_stack+1606225,int_stack+1944850,int_stack+1823575,105);
 /*--- compute (r0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+1767925,int_stack+342130,int_stack+327850,105);
 /*--- compute (r0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+1810765,int_stack+1767925,int_stack+1568425,105);
 /*--- compute (r0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+2090380,int_stack+1810765,int_stack+0,105);
 /*--- compute (r0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+2200630,int_stack+2090380,int_stack+66150,105);
 /*--- compute (r0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+2343955,int_stack+2200630,int_stack+161700,105);
 /*--- compute (r0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+0,int_stack+2343955,int_stack+1944850,105);
 /*--- compute (r0|mk) ---*/
 hrr3_build_mk(Libint->CD,int_stack+2515945,int_stack+0,int_stack+1606225,105);
 /*--- compute (r0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+194040,int_stack+358195,int_stack+342130,105);
 /*--- compute (r0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+242235,int_stack+194040,int_stack+1767925,105);
 /*--- compute (r0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+1568425,int_stack+242235,int_stack+1810765,105);
 /*--- compute (r0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+1694425,int_stack+1568425,int_stack+2090380,105);
 /*--- compute (r0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+1859800,int_stack+1694425,int_stack+2200630,105);
 /*--- compute (r0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+2060455,int_stack+1859800,int_stack+2343955,105);
 /*--- compute (r0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+4819872,int_stack+2060455,int_stack+0,105);
 /*--- compute (r0|ml) ---*/
 hrr3_build_ml(Libint->CD,int_stack+5069352,int_stack+4819872,int_stack+2515945,105);
 /*--- compute (r0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+0,int_stack+376150,int_stack+358195,105);
 /*--- compute (r0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+53865,int_stack+0,int_stack+194040,105);
 /*--- compute (r0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+2289775,int_stack+53865,int_stack+242235,105);
 /*--- compute (r0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+0,int_stack+2289775,int_stack+1568425,105);
 /*--- compute (r0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+2289775,int_stack+0,int_stack+1694425,105);
 /*--- compute (r0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+0,int_stack+2289775,int_stack+1859800,105);
 /*--- compute (r0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+2289775,int_stack+0,int_stack+2060455,105);
 /*--- compute (r0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+0,int_stack+2289775,int_stack+4819872,105);
 /*--- compute (r0|mm) ---*/
 hrr3_build_mm(Libint->CD,int_stack+1568425,int_stack+0,int_stack+5069352,105);
 /*--- compute (qp|mm) ---*/
 hrr1_build_qp(Libint->AB,int_stack+1886050,int_stack+1568425,int_stack+1293150,3025);
 /*--- compute (od|mm) ---*/
 hrr1_build_od(Libint->AB,int_stack+4819872,int_stack+1886050,int_stack+2914122,3025);
 /*--- compute (nf|mm) ---*/
 hrr1_build_nf(Libint->AB,int_stack+6235572,int_stack+4819872,int_stack+3621972,3025);
 /*--- compute (t0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+1293150,int_stack+402700,int_stack+396100,120);
 /*--- compute (t0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+1312950,int_stack+410620,int_stack+402700,120);
 /*--- compute (t0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+1336710,int_stack+1312950,int_stack+1293150,120);
 /*--- compute (t0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+1376310,int_stack+419980,int_stack+410620,120);
 /*--- compute (t0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+1404390,int_stack+1376310,int_stack+1312950,120);
 /*--- compute (t0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+1451910,int_stack+1404390,int_stack+1336710,120);
 /*--- compute (t0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+1293150,int_stack+430900,int_stack+419980,120);
 /*--- compute (t0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+0,int_stack+1293150,int_stack+1376310,120);
 /*--- compute (t0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+56160,int_stack+0,int_stack+1404390,120);
 /*--- compute (t0|mg) ---*/
 hrr3_build_mg(Libint->CD,int_stack+1325910,int_stack+56160,int_stack+1451910,120);
 /*--- compute (t0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+1424910,int_stack+443500,int_stack+430900,120);
 /*--- compute (t0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+1462710,int_stack+1424910,int_stack+1293150,120);
 /*--- compute (t0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+135360,int_stack+1462710,int_stack+0,120);
 /*--- compute (t0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+228960,int_stack+135360,int_stack+56160,120);
 /*--- compute (t0|mh) ---*/
 hrr3_build_mh(Libint->CD,int_stack+2711875,int_stack+228960,int_stack+1325910,120);
 /*--- compute (t0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+0,int_stack+457900,int_stack+443500,120);
 /*--- compute (t0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+43200,int_stack+0,int_stack+1424910,120);
 /*--- compute (t0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+1293150,int_stack+43200,int_stack+1462710,120);
 /*--- compute (t0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+1402350,int_stack+1293150,int_stack+135360,120);
 /*--- compute (t0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+2850475,int_stack+1402350,int_stack+228960,120);
 /*--- compute (t0|mi) ---*/
 hrr3_build_mi(Libint->CD,int_stack+118800,int_stack+2850475,int_stack+2711875,120);
 /*--- compute (t0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+2711875,int_stack+474220,int_stack+457900,120);
 /*--- compute (t0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+2760835,int_stack+2711875,int_stack+0,120);
 /*--- compute (t0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+303600,int_stack+2760835,int_stack+43200,120);
 /*--- compute (t0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+3016795,int_stack+303600,int_stack+1293150,120);
 /*--- compute (t0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+3180595,int_stack+3016795,int_stack+1402350,120);
 /*--- compute (t0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+1293150,int_stack+3180595,int_stack+2850475,120);
 /*--- compute (t0|mk) ---*/
 hrr3_build_mk(Libint->CD,int_stack+3377155,int_stack+1293150,int_stack+118800,120);
 /*--- compute (t0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+0,int_stack+492580,int_stack+474220,120);
 /*--- compute (t0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+55080,int_stack+0,int_stack+2711875,120);
 /*--- compute (t0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+153000,int_stack+55080,int_stack+2760835,120);
 /*--- compute (t0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+2711875,int_stack+153000,int_stack+303600,120);
 /*--- compute (t0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+3614755,int_stack+2711875,int_stack+3016795,120);
 /*--- compute (t0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+2900875,int_stack+3614755,int_stack+3180595,120);
 /*--- compute (t0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+3844075,int_stack+2900875,int_stack+1293150,120);
 /*--- compute (t0|ml) ---*/
 hrr3_build_ml(Libint->CD,int_stack+4129195,int_stack+3844075,int_stack+3377155,120);
 /*--- compute (t0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+1293150,int_stack+513100,int_stack+492580,120);
 /*--- compute (t0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+1354710,int_stack+1293150,int_stack+0,120);
 /*--- compute (t0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+3162955,int_stack+1354710,int_stack+55080,120);
 /*--- compute (t0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+1293150,int_stack+3162955,int_stack+153000,120);
 /*--- compute (t0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+3162955,int_stack+1293150,int_stack+2711875,120);
 /*--- compute (t0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+0,int_stack+3162955,int_stack+3614755,120);
 /*--- compute (t0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+3162955,int_stack+0,int_stack+2900875,120);
 /*--- compute (t0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+0,int_stack+3162955,int_stack+3844075,120);
 /*--- compute (t0|mm) ---*/
 hrr3_build_mm(Libint->CD,int_stack+2711875,int_stack+0,int_stack+4129195,120);
 /*--- compute (rp|mm) ---*/
 hrr1_build_rp(Libint->AB,int_stack+3074875,int_stack+2711875,int_stack+1568425,3025);
 /*--- compute (qd|mm) ---*/
 hrr1_build_qd(Libint->AB,int_stack+8232072,int_stack+3074875,int_stack+1886050,3025);
 /*--- compute (of|mm) ---*/
 hrr1_build_of(Libint->AB,int_stack+9883722,int_stack+8232072,int_stack+4819872,3025);
 /*--- compute (ng|mm) ---*/
 hrr1_build_ng(Libint->AB,int_stack+12243222,int_stack+9883722,int_stack+6235572,3025);
 /*--- compute (u0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+0,int_stack+543380,int_stack+535900,136);
 /*--- compute (u0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+22440,int_stack+552356,int_stack+543380,136);
 /*--- compute (u0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+49368,int_stack+22440,int_stack+0,136);
 /*--- compute (u0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+94248,int_stack+562964,int_stack+552356,136);
 /*--- compute (u0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+126072,int_stack+94248,int_stack+22440,136);
 /*--- compute (u0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+179928,int_stack+126072,int_stack+49368,136);
 /*--- compute (u0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+0,int_stack+575340,int_stack+562964,136);
 /*--- compute (u0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+254728,int_stack+0,int_stack+94248,136);
 /*--- compute (u0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+318376,int_stack+254728,int_stack+126072,136);
 /*--- compute (u0|mg) ---*/
 hrr3_build_mg(Libint->CD,int_stack+37128,int_stack+318376,int_stack+179928,136);
 /*--- compute (u0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+149328,int_stack+589620,int_stack+575340,136);
 /*--- compute (u0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+408136,int_stack+149328,int_stack+0,136);
 /*--- compute (u0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+482392,int_stack+408136,int_stack+254728,136);
 /*--- compute (u0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+4027750,int_stack+482392,int_stack+318376,136);
 /*--- compute (u0|mh) ---*/
 hrr3_build_mh(Libint->CD,int_stack+192168,int_stack+4027750,int_stack+37128,136);
 /*--- compute (u0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+0,int_stack+605940,int_stack+589620,136);
 /*--- compute (u0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+48960,int_stack+0,int_stack+149328,136);
 /*--- compute (u0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+4162390,int_stack+48960,int_stack+408136,136);
 /*--- compute (u0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+4286150,int_stack+4162390,int_stack+482392,136);
 /*--- compute (u0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+349248,int_stack+4286150,int_stack+4027750,136);
 /*--- compute (u0|mi) ---*/
 hrr3_build_mi(Libint->CD,int_stack+4445270,int_stack+349248,int_stack+192168,136);
 /*--- compute (u0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+4027750,int_stack+624436,int_stack+605940,136);
 /*--- compute (u0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+134640,int_stack+4027750,int_stack+0,136);
 /*--- compute (u0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+4654710,int_stack+134640,int_stack+48960,136);
 /*--- compute (u0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+4797510,int_stack+4654710,int_stack+4162390,136);
 /*--- compute (u0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+4983150,int_stack+4797510,int_stack+4286150,136);
 /*--- compute (u0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+4083238,int_stack+4983150,int_stack+349248,136);
 /*--- compute (u0|mk) ---*/
 hrr3_build_mk(Libint->CD,int_stack+232560,int_stack+4083238,int_stack+4445270,136);
 /*--- compute (u0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+0,int_stack+645244,int_stack+624436,136);
 /*--- compute (u0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+4334566,int_stack+0,int_stack+4027750,136);
 /*--- compute (u0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+4445542,int_stack+4334566,int_stack+134640,136);
 /*--- compute (u0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+5205918,int_stack+4445542,int_stack+4654710,136);
 /*--- compute (u0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+5420118,int_stack+5205918,int_stack+4797510,136);
 /*--- compute (u0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+4608742,int_stack+5420118,int_stack+4983150,136);
 /*--- compute (u0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+5680014,int_stack+4608742,int_stack+4083238,136);
 /*--- compute (u0|ml) ---*/
 hrr3_build_ml(Libint->CD,int_stack+6003150,int_stack+5680014,int_stack+232560,136);
 /*--- compute (u0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+4027750,int_stack+668500,int_stack+645244,136);
 /*--- compute (u0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+4097518,int_stack+4027750,int_stack+0,136);
 /*--- compute (u0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+0,int_stack+4097518,int_stack+4334566,136);
 /*--- compute (u0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+184960,int_stack+0,int_stack+4445542,136);
 /*--- compute (u0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+4027750,int_stack+184960,int_stack+5205918,136);
 /*--- compute (u0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+0,int_stack+4027750,int_stack+5420118,136);
 /*--- compute (u0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+4027750,int_stack+0,int_stack+4608742,136);
 /*--- compute (u0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+0,int_stack+4027750,int_stack+5680014,136);
 /*--- compute (u0|mm) ---*/
 hrr3_build_mm(Libint->CD,int_stack+4027750,int_stack+0,int_stack+6003150,136);
 /*--- compute (tp|mm) ---*/
 hrr1_build_tp(Libint->AB,int_stack+4439150,int_stack+4027750,int_stack+2711875,3025);
 /*--- compute (rd|mm) ---*/
 hrr1_build_rd(Libint->AB,int_stack+5528150,int_stack+4439150,int_stack+3074875,3025);
 /*--- compute (qf|mm) ---*/
 hrr1_build_qf(Libint->AB,int_stack+15237972,int_stack+5528150,int_stack+8232072,3025);
 /*--- compute (og|mm) ---*/
 hrr1_build_og(Libint->AB,int_stack+17990722,int_stack+15237972,int_stack+9883722,3025);
 /*--- compute (nh|mm) ---*/
 hrr1_build_nh(Libint->AB,int_stack+7433900,int_stack+17990722,int_stack+12243222,3025);
 /*--- compute (v0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+0,int_stack+702755,int_stack+694340,153);
 /*--- compute (v0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+25245,int_stack+712853,int_stack+702755,153);
 /*--- compute (v0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+55539,int_stack+25245,int_stack+0,153);
 /*--- compute (v0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+106029,int_stack+724787,int_stack+712853,153);
 /*--- compute (v0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+141831,int_stack+106029,int_stack+25245,153);
 /*--- compute (v0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+202419,int_stack+141831,int_stack+55539,153);
 /*--- compute (v0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+0,int_stack+738710,int_stack+724787,153);
 /*--- compute (v0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+286569,int_stack+0,int_stack+106029,153);
 /*--- compute (v0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+358173,int_stack+286569,int_stack+141831,153);
 /*--- compute (v0|mg) ---*/
 hrr3_build_mg(Libint->CD,int_stack+41769,int_stack+358173,int_stack+202419,153);
 /*--- compute (v0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+167994,int_stack+754775,int_stack+738710,153);
 /*--- compute (v0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+459153,int_stack+167994,int_stack+0,153);
 /*--- compute (v0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+542691,int_stack+459153,int_stack+286569,153);
 /*--- compute (v0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+11626550,int_stack+542691,int_stack+358173,153);
 /*--- compute (v0|mh) ---*/
 hrr3_build_mh(Libint->CD,int_stack+216189,int_stack+11626550,int_stack+41769,153);
 /*--- compute (v0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+0,int_stack+773135,int_stack+754775,153);
 /*--- compute (v0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+55080,int_stack+0,int_stack+167994,153);
 /*--- compute (v0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+11778020,int_stack+55080,int_stack+459153,153);
 /*--- compute (v0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+11917250,int_stack+11778020,int_stack+542691,153);
 /*--- compute (v0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+392904,int_stack+11917250,int_stack+11626550,153);
 /*--- compute (v0|mi) ---*/
 hrr3_build_mi(Libint->CD,int_stack+12096260,int_stack+392904,int_stack+216189,153);
 /*--- compute (v0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+11626550,int_stack+793943,int_stack+773135,153);
 /*--- compute (v0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+151470,int_stack+11626550,int_stack+0,153);
 /*--- compute (v0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+604962,int_stack+151470,int_stack+55080,153);
 /*--- compute (v0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+12331880,int_stack+604962,int_stack+11778020,153);
 /*--- compute (v0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+12540725,int_stack+12331880,int_stack+11917250,153);
 /*--- compute (v0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+11688974,int_stack+12540725,int_stack+392904,153);
 /*--- compute (v0|mk) ---*/
 hrr3_build_mk(Libint->CD,int_stack+261630,int_stack+11688974,int_stack+12096260,153);
 /*--- compute (v0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+0,int_stack+817352,int_stack+793943,153);
 /*--- compute (v0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+11971718,int_stack+0,int_stack+11626550,153);
 /*--- compute (v0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+12096566,int_stack+11971718,int_stack+151470,153);
 /*--- compute (v0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+12791339,int_stack+12096566,int_stack+604962,153);
 /*--- compute (v0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+13032314,int_stack+12791339,int_stack+12331880,153);
 /*--- compute (v0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+13324697,int_stack+13032314,int_stack+12540725,153);
 /*--- compute (v0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+12280166,int_stack+13324697,int_stack+11688974,153);
 /*--- compute (v0|ml) ---*/
 hrr3_build_ml(Libint->CD,int_stack+13658849,int_stack+12280166,int_stack+261630,153);
 /*--- compute (v0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+11626550,int_stack+843515,int_stack+817352,153);
 /*--- compute (v0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+11705039,int_stack+11626550,int_stack+0,153);
 /*--- compute (v0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+0,int_stack+11705039,int_stack+11971718,153);
 /*--- compute (v0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+208080,int_stack+0,int_stack+12096566,153);
 /*--- compute (v0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+483480,int_stack+208080,int_stack+12791339,153);
 /*--- compute (v0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+0,int_stack+483480,int_stack+13032314,153);
 /*--- compute (v0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+389844,int_stack+0,int_stack+13324697,153);
 /*--- compute (v0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+11626550,int_stack+389844,int_stack+12280166,153);
 /*--- compute (v0|mm) ---*/
 hrr3_build_mm(Libint->CD,int_stack+0,int_stack+11626550,int_stack+13658849,153);
 /*--- compute (up|mm) ---*/
 hrr1_build_up(Libint->AB,int_stack+11626550,int_stack+0,int_stack+4027750,3025);
 /*--- compute (td|mm) ---*/
 hrr1_build_td(Libint->AB,int_stack+12860750,int_stack+11626550,int_stack+4439150,3025);
 /*--- compute (rf|mm) ---*/
 hrr1_build_rf(Libint->AB,int_stack+1293150,int_stack+12860750,int_stack+5528150,3025);
 /*--- compute (qg|mm) ---*/
 hrr1_build_qg(Libint->AB,int_stack+21529972,int_stack+1293150,int_stack+15237972,3025);
 /*--- compute (oh|mm) ---*/
 hrr1_build_oh(Libint->AB,int_stack+25659097,int_stack+21529972,int_stack+17990722,3025);
 /*--- compute (ni|mm) ---*/
 hrr1_build_ni(Libint->AB,int_stack+15038750,int_stack+25659097,int_stack+7433900,3025);
 /*--- compute (w0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+20628950,int_stack+881990,int_stack+872585,171);
 /*--- compute (w0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+20657165,int_stack+893276,int_stack+881990,171);
 /*--- compute (w0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+20691023,int_stack+20657165,int_stack+20628950,171);
 /*--- compute (w0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+20747453,int_stack+906614,int_stack+893276,171);
 /*--- compute (w0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+20787467,int_stack+20747453,int_stack+20657165,171);
 /*--- compute (w0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+20855183,int_stack+20787467,int_stack+20691023,171);
 /*--- compute (w0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+20628950,int_stack+922175,int_stack+906614,171);
 /*--- compute (w0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+20949233,int_stack+20628950,int_stack+20747453,171);
 /*--- compute (w0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+21029261,int_stack+20949233,int_stack+20787467,171);
 /*--- compute (w0|mg) ---*/
 hrr3_build_mg(Libint->CD,int_stack+20675633,int_stack+21029261,int_stack+20855183,171);
 /*--- compute (w0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+20816708,int_stack+940130,int_stack+922175,171);
 /*--- compute (w0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+21142121,int_stack+20816708,int_stack+20628950,171);
 /*--- compute (w0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+21235487,int_stack+21142121,int_stack+20949233,171);
 /*--- compute (w0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+462825,int_stack+21235487,int_stack+21029261,171);
 /*--- compute (w0|mh) ---*/
 hrr3_build_mh(Libint->CD,int_stack+20870573,int_stack+462825,int_stack+20675633,171);
 /*--- compute (w0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+20628950,int_stack+960650,int_stack+940130,171);
 /*--- compute (w0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+20690510,int_stack+20628950,int_stack+20816708,171);
 /*--- compute (w0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+21368867,int_stack+20690510,int_stack+21142121,171);
 /*--- compute (w0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+632115,int_stack+21368867,int_stack+21235487,171);
 /*--- compute (w0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+21068078,int_stack+632115,int_stack+462825,171);
 /*--- compute (w0|mi) ---*/
 hrr3_build_mi(Libint->CD,int_stack+4469400,int_stack+21068078,int_stack+20870573,171);
 /*--- compute (w0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+462825,int_stack+983906,int_stack+960650,171);
 /*--- compute (w0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+20798240,int_stack+462825,int_stack+20628950,171);
 /*--- compute (w0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+4732740,int_stack+20798240,int_stack+20690510,171);
 /*--- compute (w0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+4912290,int_stack+4732740,int_stack+21368867,171);
 /*--- compute (w0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+5145705,int_stack+4912290,int_stack+632115,171);
 /*--- compute (w0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+532593,int_stack+5145705,int_stack+21068078,171);
 /*--- compute (w0|mk) ---*/
 hrr3_build_mk(Libint->CD,int_stack+20921360,int_stack+532593,int_stack+4469400,171);
 /*--- compute (w0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+4469400,int_stack+1010069,int_stack+983906,171);
 /*--- compute (w0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+4547889,int_stack+4469400,int_stack+462825,171);
 /*--- compute (w0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+21259940,int_stack+4547889,int_stack+20798240,171);
 /*--- compute (w0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+20628950,int_stack+21259940,int_stack+4732740,171);
 /*--- compute (w0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+5425803,int_stack+20628950,int_stack+4912290,171);
 /*--- compute (w0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+4687425,int_stack+5425803,int_stack+5145705,171);
 /*--- compute (w0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+5752584,int_stack+4687425,int_stack+532593,171);
 /*--- compute (w0|ml) ---*/
 hrr3_build_ml(Libint->CD,int_stack+462825,int_stack+5752584,int_stack+20921360,171);
 /*--- compute (w0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+886050,int_stack+1039310,int_stack+1010069,171);
 /*--- compute (w0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+5060889,int_stack+886050,int_stack+4469400,171);
 /*--- compute (w0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+20898275,int_stack+5060889,int_stack+4547889,171);
 /*--- compute (w0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+5060889,int_stack+20898275,int_stack+21259940,171);
 /*--- compute (w0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+20898275,int_stack+5060889,int_stack+20628950,171);
 /*--- compute (w0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+6158880,int_stack+20898275,int_stack+5425803,171);
 /*--- compute (w0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+20628950,int_stack+6158880,int_stack+4687425,171);
 /*--- compute (w0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+6158880,int_stack+20628950,int_stack+5752584,171);
 /*--- compute (w0|mm) ---*/
 hrr3_build_mm(Libint->CD,int_stack+20628950,int_stack+6158880,int_stack+462825,171);
 /*--- compute (vp|mm) ---*/
 hrr1_build_vp(Libint->AB,int_stack+4469400,int_stack+20628950,int_stack+0,3025);
 /*--- compute (ud|mm) ---*/
 hrr1_build_ud(Libint->AB,int_stack+5857875,int_stack+4469400,int_stack+11626550,3025);
 /*--- compute (tf|mm) ---*/
 hrr1_build_tf(Libint->AB,int_stack+8326275,int_stack+5857875,int_stack+12860750,3025);
 /*--- compute (rg|mm) ---*/
 hrr1_build_rg(Libint->AB,int_stack+30614047,int_stack+8326275,int_stack+1293150,3025);
 /*--- compute (qh|mm) ---*/
 hrr1_build_qh(Libint->AB,int_stack+35378422,int_stack+30614047,int_stack+21529972,3025);
 /*--- compute (oi|mm) ---*/
 hrr1_build_oi(Libint->AB,int_stack+41159197,int_stack+35378422,int_stack+25659097,3025);
 /*--- compute (nk|mm) ---*/
 hrr1_build_nk(Libint->AB,int_stack+21146225,int_stack+41159197,int_stack+15038750,3025);
 /*--- compute (x0|mp) ---*/
 hrr3_build_mp(Libint->CD,int_stack+1293150,int_stack+1082250,int_stack+1071800,190);
 /*--- compute (x0|np) ---*/
 hrr3_build_np(Libint->CD,int_stack+1324500,int_stack+1094790,int_stack+1082250,190);
 /*--- compute (x0|md) ---*/
 hrr3_build_md(Libint->CD,int_stack+1362120,int_stack+1324500,int_stack+1293150,190);
 /*--- compute (x0|op) ---*/
 hrr3_build_op(Libint->CD,int_stack+1424820,int_stack+1109610,int_stack+1094790,190);
 /*--- compute (x0|nd) ---*/
 hrr3_build_nd(Libint->CD,int_stack+1469280,int_stack+1424820,int_stack+1324500,190);
 /*--- compute (x0|mf) ---*/
 hrr3_build_mf(Libint->CD,int_stack+1544520,int_stack+1469280,int_stack+1362120,190);
 /*--- compute (x0|qp) ---*/
 hrr3_build_qp(Libint->CD,int_stack+1293150,int_stack+1126900,int_stack+1109610,190);
 /*--- compute (x0|od) ---*/
 hrr3_build_od(Libint->CD,int_stack+1649020,int_stack+1293150,int_stack+1424820,190);
 /*--- compute (x0|nf) ---*/
 hrr3_build_nf(Libint->CD,int_stack+1737940,int_stack+1649020,int_stack+1469280,190);
 /*--- compute (x0|mg) ---*/
 hrr3_build_mg(Libint->CD,int_stack+1345020,int_stack+1737940,int_stack+1544520,190);
 /*--- compute (x0|rp) ---*/
 hrr3_build_rp(Libint->CD,int_stack+1501770,int_stack+1146850,int_stack+1126900,190);
 /*--- compute (x0|qd) ---*/
 hrr3_build_qd(Libint->CD,int_stack+1863340,int_stack+1501770,int_stack+1293150,190);
 /*--- compute (x0|of) ---*/
 hrr3_build_of(Libint->CD,int_stack+1967080,int_stack+1863340,int_stack+1649020,190);
 /*--- compute (x0|ng) ---*/
 hrr3_build_ng(Libint->CD,int_stack+2115280,int_stack+1967080,int_stack+1737940,190);
 /*--- compute (x0|mh) ---*/
 hrr3_build_mh(Libint->CD,int_stack+1561620,int_stack+2115280,int_stack+1345020,190);
 /*--- compute (x0|tp) ---*/
 hrr3_build_tp(Libint->CD,int_stack+1293150,int_stack+1169650,int_stack+1146850,190);
 /*--- compute (x0|rd) ---*/
 hrr3_build_rd(Libint->CD,int_stack+1361550,int_stack+1293150,int_stack+1501770,190);
 /*--- compute (x0|qf) ---*/
 hrr3_build_qf(Libint->CD,int_stack+2303380,int_stack+1361550,int_stack+1863340,190);
 /*--- compute (x0|og) ---*/
 hrr3_build_og(Libint->CD,int_stack+2476280,int_stack+2303380,int_stack+1967080,190);
 /*--- compute (x0|nh) ---*/
 hrr3_build_nh(Libint->CD,int_stack+1781070,int_stack+2476280,int_stack+2115280,190);
 /*--- compute (x0|mi) ---*/
 hrr3_build_mi(Libint->CD,int_stack+2698580,int_stack+1781070,int_stack+1561620,190);
 /*--- compute (x0|up) ---*/
 hrr3_build_up(Libint->CD,int_stack+1481250,int_stack+1195490,int_stack+1169650,190);
 /*--- compute (x0|td) ---*/
 hrr3_build_td(Libint->CD,int_stack+1558770,int_stack+1481250,int_stack+1293150,190);
 /*--- compute (x0|rf) ---*/
 hrr3_build_rf(Libint->CD,int_stack+2044410,int_stack+1558770,int_stack+1361550,190);
 /*--- compute (x0|qg) ---*/
 hrr3_build_qg(Libint->CD,int_stack+2991180,int_stack+2044410,int_stack+2303380,190);
 /*--- compute (x0|oh) ---*/
 hrr3_build_oh(Libint->CD,int_stack+3250530,int_stack+2991180,int_stack+2476280,190);
 /*--- compute (x0|ni) ---*/
 hrr3_build_ni(Libint->CD,int_stack+2243910,int_stack+3250530,int_stack+1781070,190);
 /*--- compute (x0|mk) ---*/
 hrr3_build_mk(Libint->CD,int_stack+3561750,int_stack+2243910,int_stack+2698580,190);
 /*--- compute (x0|vp) ---*/
 hrr3_build_vp(Libint->CD,int_stack+1293150,int_stack+1224560,int_stack+1195490,190);
 /*--- compute (x0|ud) ---*/
 hrr3_build_ud(Libint->CD,int_stack+1695570,int_stack+1293150,int_stack+1481250,190);
 /*--- compute (x0|tf) ---*/
 hrr3_build_tf(Libint->CD,int_stack+2595030,int_stack+1695570,int_stack+1558770,190);
 /*--- compute (x0|rg) ---*/
 hrr3_build_rg(Libint->CD,int_stack+1380360,int_stack+2595030,int_stack+2044410,190);
 /*--- compute (x0|qh) ---*/
 hrr3_build_qh(Libint->CD,int_stack+1850610,int_stack+1380360,int_stack+2991180,190);
 /*--- compute (x0|oi) ---*/
 hrr3_build_oi(Libint->CD,int_stack+2823030,int_stack+1850610,int_stack+3250530,190);
 /*--- compute (x0|nk) ---*/
 hrr3_build_nk(Libint->CD,int_stack+3937950,int_stack+2823030,int_stack+2243910,190);
 /*--- compute (x0|ml) ---*/
 hrr3_build_ml(Libint->CD,int_stack+0,int_stack+3937950,int_stack+3561750,190);
 /*--- compute (x0|wp) ---*/
 hrr3_build_wp(Libint->CD,int_stack+2213700,int_stack+1257050,int_stack+1224560,190);
 /*--- compute (x0|vd) ---*/
 hrr3_build_vd(Libint->CD,int_stack+2311170,int_stack+2213700,int_stack+1293150,190);
 /*--- compute (x0|uf) ---*/
 hrr3_build_uf(Libint->CD,int_stack+3237990,int_stack+2311170,int_stack+1695570,190);
 /*--- compute (x0|tg) ---*/
 hrr3_build_tg(Libint->CD,int_stack+2213700,int_stack+3237990,int_stack+2595030,190);
 /*--- compute (x0|rh) ---*/
 hrr3_build_rh(Libint->CD,int_stack+3237990,int_stack+2213700,int_stack+1380360,190);
 /*--- compute (x0|qi) ---*/
 hrr3_build_qi(Libint->CD,int_stack+2213700,int_stack+3237990,int_stack+1850610,190);
 /*--- compute (x0|ok) ---*/
 hrr3_build_ok(Libint->CD,int_stack+3237990,int_stack+2213700,int_stack+2823030,190);
 /*--- compute (x0|nl) ---*/
 hrr3_build_nl(Libint->CD,int_stack+470250,int_stack+3237990,int_stack+3937950,190);
 /*--- compute (x0|mm) ---*/
 hrr3_build_mm(Libint->CD,int_stack+1034550,int_stack+470250,int_stack+0,190);
 /*--- compute (wp|mm) ---*/
 hrr1_build_wp(Libint->AB,int_stack+1609300,int_stack+1034550,int_stack+20628950,3025);
 /*--- compute (vd|mm) ---*/
 hrr1_build_vd(Libint->AB,int_stack+11956275,int_stack+1609300,int_stack+4469400,3025);
 /*--- compute (uf|mm) ---*/
 hrr1_build_uf(Libint->AB,int_stack+0,int_stack+11956275,int_stack+5857875,3025);
 /*--- compute (tg|mm) ---*/
 hrr1_build_tg(Libint->AB,int_stack+11956275,int_stack+0,int_stack+8326275,3025);
 /*--- compute (rh|mm) ---*/
 hrr1_build_rh(Libint->AB,int_stack+0,int_stack+11956275,int_stack+30614047,3025);
 /*--- compute (qi|mm) ---*/
 hrr1_build_qi(Libint->AB,int_stack+6670125,int_stack+0,int_stack+35378422,3025);
 /*--- compute (ok|mm) ---*/
 hrr1_build_ok(Libint->AB,int_stack+28333625,int_stack+6670125,int_stack+41159197,3025);
 /*--- compute (nl|mm) ---*/
 hrr1_build_nl(Libint->AB,int_stack+0,int_stack+28333625,int_stack+21146225,3025);
 return int_stack+0;}
