/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_d0gg(Libr12_t *, prim_data *);

  /* Computes (d0|gg) integrals for linear R12-methods */

void hrr_grt_order_d0gg(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[3][4] = int_stack + 0;
 Libr12->t2vrr_classes[2][4] = int_stack + 150;
 Libr12->gvrr_classes[3][5] = int_stack + 240;
 Libr12->t2vrr_classes[2][5] = int_stack + 450;
 Libr12->gvrr_classes[3][6] = int_stack + 576;
 Libr12->t2vrr_classes[2][6] = int_stack + 856;
 Libr12->gvrr_classes[3][7] = int_stack + 1024;
 Libr12->t2vrr_classes[2][7] = int_stack + 1384;
 Libr12->t2vrr_classes[2][8] = int_stack + 1600;
 Libr12->t1vrr_classes[2][4] = int_stack + 1870;
 Libr12->t1vrr_classes[2][5] = int_stack + 1960;
 Libr12->t1vrr_classes[2][6] = int_stack + 2086;
 Libr12->t1vrr_classes[2][7] = int_stack + 2254;
 Libr12->t1vrr_classes[2][8] = int_stack + 2470;
 Libr12->rvrr_classes[2][4] = int_stack + 2740;
 Libr12->rvrr_classes[2][5] = int_stack + 2830;
 Libr12->rvrr_classes[2][6] = int_stack + 2956;
 Libr12->rvrr_classes[2][7] = int_stack + 3124;
 Libr12->rvrr_classes[2][8] = int_stack + 3340;
 Libr12->gvrr_classes[2][4] = int_stack + 3610;
 Libr12->gvrr_classes[2][5] = int_stack + 3700;
 Libr12->gvrr_classes[2][6] = int_stack + 3826;
 Libr12->gvrr_classes[2][7] = int_stack + 3994;
 Libr12->gvrr_classes[2][8] = int_stack + 4210;
 memset(int_stack,0,4480*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 4480;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_d0gg(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+4480, int_stack+3700, int_stack+3610, 6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+4750, int_stack+3826, int_stack+3700, 6);
 /*--- compute (d0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+5128, int_stack+4750, int_stack+4480, 6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+5668, int_stack+3994, int_stack+3826, 6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+6172, int_stack+5668, int_stack+4750, 6);
 /*--- compute (d0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+6928, int_stack+6172, int_stack+5128, 6);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+7828, int_stack+240, int_stack+0, 10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+8278, int_stack+576, int_stack+240, 10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+8908, int_stack+8278, int_stack+7828, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+9808, int_stack+1024, int_stack+576, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+10648, int_stack+9808, int_stack+8278, 10);
 /*--- compute (f0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+11908, int_stack+10648, int_stack+8908, 10);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+13408, int_stack+4210, int_stack+3994, 6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+14056, int_stack+13408, int_stack+5668, 6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+15064, int_stack+14056, int_stack+6172, 6);
 /*--- compute (d0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+16324, int_stack+450, int_stack+150, int_stack+3700, int_stack+0, int_stack+3610, 2, 0);
 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+16594, int_stack+856, int_stack+450, int_stack+3826, int_stack+240, int_stack+3700, 2, 0);
 /*--- compute (d0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+16594, int_stack+16324, int_stack+4750, int_stack+7828, int_stack+4480, 2, 0);
 /*--- compute (d0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+16972, int_stack+1384, int_stack+856, int_stack+3994, int_stack+576, int_stack+3826, 2, 0);
 /*--- compute (d0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+17476, int_stack+16972, int_stack+16594, int_stack+5668, int_stack+8278, int_stack+4750, 2, 0);
 /*--- compute (d0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+7828, int_stack+17476, int_stack+0, int_stack+6172, int_stack+8908, int_stack+5128, 2, 0);
 /*--- compute (d0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+16324, int_stack+1600, int_stack+1384, int_stack+4210, int_stack+1024, int_stack+3994, 2, 0);
 /*--- compute (d0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+16324, int_stack+16972, int_stack+13408, int_stack+9808, int_stack+5668, 2, 0);
 /*--- compute (d0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+8728, int_stack+0, int_stack+17476, int_stack+14056, int_stack+10648, int_stack+6172, 2, 0);
 /*--- compute (d0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+1960, int_stack+1870, 6);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+270, int_stack+2086, int_stack+1960, 6);
 /*--- compute (d0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+648, int_stack+270, int_stack+0, 6);
 /*--- compute (d0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+1188, int_stack+2254, int_stack+2086, 6);
 /*--- compute (d0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+13408, int_stack+1188, int_stack+270, 6);
 /*--- compute (d0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+14164, int_stack+13408, int_stack+648, 6);
 /*--- compute (d0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+2470, int_stack+2254, 6);
 /*--- compute (d0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+1692, int_stack+0, int_stack+1188, 6);
 /*--- compute (d0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+1692, int_stack+13408, 6);
 /*--- compute (d0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+13408, int_stack+2830, int_stack+2740, 6);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+13678, int_stack+2956, int_stack+2830, 6);
 /*--- compute (d0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+1260, int_stack+13678, int_stack+13408, 6);
 /*--- compute (d0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+1800, int_stack+3124, int_stack+2956, 6);
 /*--- compute (d0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+2304, int_stack+1800, int_stack+13678, 6);
 /*--- compute (d0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+16324, int_stack+2304, int_stack+1260, 6);
 /*--- compute (d0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+13408, int_stack+3340, int_stack+3124, 6);
 /*--- compute (d0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+3060, int_stack+13408, int_stack+1800, 6);
 /*--- compute (d0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+4068, int_stack+3060, int_stack+2304, 6);
 /*--- compute (d0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1260, int_stack+8728, int_stack+7828, int_stack+15064, int_stack+11908, int_stack+6928, 2, 0);
     Libr12->te_ptr[3] = int_stack + 1260;
 /*--- compute (d0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+7828, int_stack+0, int_stack+14164, 6);
     Libr12->te_ptr[2] = int_stack + 7828;
 /*--- compute (d0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+9178, int_stack+4068, int_stack+16324, 6);
     Libr12->te_ptr[1] = int_stack + 9178;
 /*--- compute (d0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+16324, int_stack+15064, int_stack+6928, 6);
     Libr12->te_ptr[0] = int_stack + 16324;

}
