/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_d0hh(Libr12_t *, prim_data *);

  /* Computes (d0|hh) integrals for linear R12-methods */

void hrr_grt_order_d0hh(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[3][5] = int_stack + 0;
 Libr12->t2vrr_classes[2][5] = int_stack + 210;
 Libr12->gvrr_classes[3][6] = int_stack + 336;
 Libr12->t2vrr_classes[2][6] = int_stack + 616;
 Libr12->gvrr_classes[3][7] = int_stack + 784;
 Libr12->t2vrr_classes[2][7] = int_stack + 1144;
 Libr12->gvrr_classes[3][8] = int_stack + 1360;
 Libr12->t2vrr_classes[2][8] = int_stack + 1810;
 Libr12->gvrr_classes[3][9] = int_stack + 2080;
 Libr12->t2vrr_classes[2][9] = int_stack + 2630;
 Libr12->t2vrr_classes[2][10] = int_stack + 2960;
 Libr12->t1vrr_classes[2][5] = int_stack + 3356;
 Libr12->t1vrr_classes[2][6] = int_stack + 3482;
 Libr12->t1vrr_classes[2][7] = int_stack + 3650;
 Libr12->t1vrr_classes[2][8] = int_stack + 3866;
 Libr12->t1vrr_classes[2][9] = int_stack + 4136;
 Libr12->t1vrr_classes[2][10] = int_stack + 4466;
 Libr12->rvrr_classes[2][5] = int_stack + 4862;
 Libr12->rvrr_classes[2][6] = int_stack + 4988;
 Libr12->rvrr_classes[2][7] = int_stack + 5156;
 Libr12->rvrr_classes[2][8] = int_stack + 5372;
 Libr12->rvrr_classes[2][9] = int_stack + 5642;
 Libr12->rvrr_classes[2][10] = int_stack + 5972;
 Libr12->gvrr_classes[2][5] = int_stack + 6368;
 Libr12->gvrr_classes[2][6] = int_stack + 6494;
 Libr12->gvrr_classes[2][7] = int_stack + 6662;
 Libr12->gvrr_classes[2][8] = int_stack + 6878;
 Libr12->gvrr_classes[2][9] = int_stack + 7148;
 Libr12->gvrr_classes[2][10] = int_stack + 7478;
 memset(int_stack,0,7874*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 7874;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_d0hh(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+7874, int_stack+6494, int_stack+6368, 6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+8252, int_stack+6662, int_stack+6494, 6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+8756, int_stack+8252, int_stack+7874, 6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+9512, int_stack+6878, int_stack+6662, 6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+10160, int_stack+9512, int_stack+8252, 6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+11168, int_stack+10160, int_stack+8756, 6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+12428, int_stack+7148, int_stack+6878, 6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+13238, int_stack+12428, int_stack+9512, 6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+14534, int_stack+13238, int_stack+10160, 6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+16214, int_stack+14534, int_stack+11168, 6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+18104, int_stack+336, int_stack+0, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+18734, int_stack+784, int_stack+336, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+19574, int_stack+18734, int_stack+18104, 10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+20834, int_stack+1360, int_stack+784, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+21914, int_stack+20834, int_stack+18734, 10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+23594, int_stack+21914, int_stack+19574, 10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+25694, int_stack+2080, int_stack+1360, 10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+27044, int_stack+25694, int_stack+20834, 10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+29204, int_stack+27044, int_stack+21914, 10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+32004, int_stack+29204, int_stack+23594, 10);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+35154, int_stack+7478, int_stack+7148, 6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+36144, int_stack+35154, int_stack+12428, 6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+37764, int_stack+36144, int_stack+13238, 6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+39924, int_stack+37764, int_stack+14534, 6);
 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+42444, int_stack+616, int_stack+210, int_stack+6494, int_stack+0, int_stack+6368, 2, 0);
 /*--- compute (d0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+42822, int_stack+1144, int_stack+616, int_stack+6662, int_stack+336, int_stack+6494, 2, 0);
 /*--- compute (d0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+42822, int_stack+42444, int_stack+8252, int_stack+18104, int_stack+7874, 2, 0);
 /*--- compute (d0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+43326, int_stack+1810, int_stack+1144, int_stack+6878, int_stack+784, int_stack+6662, 2, 0);
 /*--- compute (d0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+43974, int_stack+43326, int_stack+42822, int_stack+9512, int_stack+18734, int_stack+8252, 2, 0);
 /*--- compute (d0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+18104, int_stack+43974, int_stack+0, int_stack+10160, int_stack+19574, int_stack+8756, 2, 0);
 /*--- compute (d0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+2630, int_stack+1810, int_stack+7148, int_stack+1360, int_stack+6878, 2, 0);
 /*--- compute (d0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+7874, int_stack+0, int_stack+43326, int_stack+12428, int_stack+20834, int_stack+9512, 2, 0);
 /*--- compute (d0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+19364, int_stack+7874, int_stack+43974, int_stack+13238, int_stack+21914, int_stack+10160, 2, 0);
 /*--- compute (d0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+9170, int_stack+19364, int_stack+18104, int_stack+14534, int_stack+23594, int_stack+11168, 2, 0);
 /*--- compute (d0|[r12,T2]|mp) ---*/
   t2hrr3_build_mp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+18104, int_stack+2960, int_stack+2630, int_stack+7478, int_stack+2080, int_stack+7148, 2, 0);
 /*--- compute (d0|[r12,T2]|ld) ---*/
   t2hrr3_build_ld(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+810, int_stack+18104, int_stack+0, int_stack+35154, int_stack+25694, int_stack+12428, 2, 0);
 /*--- compute (d0|[r12,T2]|kf) ---*/
   t2hrr3_build_kf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+11060, int_stack+810, int_stack+7874, int_stack+36144, int_stack+27044, int_stack+13238, 2, 0);
 /*--- compute (d0|[r12,T2]|ig) ---*/
   t2hrr3_build_ig(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+35154, int_stack+11060, int_stack+19364, int_stack+37764, int_stack+29204, int_stack+14534, 2, 0);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+11060, int_stack+3482, int_stack+3356, 6);
 /*--- compute (d0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+11438, int_stack+3650, int_stack+3482, 6);
 /*--- compute (d0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+11942, int_stack+11438, int_stack+11060, 6);
 /*--- compute (d0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+12698, int_stack+3866, int_stack+3650, 6);
 /*--- compute (d0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+13346, int_stack+12698, int_stack+11438, 6);
 /*--- compute (d0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+14354, int_stack+13346, int_stack+11942, 6);
 /*--- compute (d0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+11060, int_stack+4136, int_stack+3866, 6);
 /*--- compute (d0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+37674, int_stack+11060, int_stack+12698, 6);
 /*--- compute (d0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+0, int_stack+37674, int_stack+13346, 6);
 /*--- compute (d0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+11870, int_stack+0, int_stack+14354, 6);
 /*--- compute (d0|[r12,T1]|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+13760, int_stack+4466, int_stack+4136, 6);
 /*--- compute (d0|[r12,T1]|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+1680, int_stack+13760, int_stack+11060, 6);
 /*--- compute (d0|[r12,T1]|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+13760, int_stack+1680, int_stack+37674, 6);
 /*--- compute (d0|[r12,T1]|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+1680, int_stack+13760, int_stack+0, 6);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+4988, int_stack+4862, 6);
 /*--- compute (d0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+378, int_stack+5156, int_stack+4988, 6);
 /*--- compute (d0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+882, int_stack+378, int_stack+0, 6);
 /*--- compute (d0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+13760, int_stack+5372, int_stack+5156, 6);
 /*--- compute (d0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+14408, int_stack+13760, int_stack+378, 6);
 /*--- compute (d0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+37674, int_stack+14408, int_stack+882, 6);
 /*--- compute (d0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+11060, int_stack+5642, int_stack+5372, 6);
 /*--- compute (d0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+11060, int_stack+13760, 6);
 /*--- compute (d0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+18104, int_stack+0, int_stack+14408, 6);
 /*--- compute (d0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+13760, int_stack+18104, int_stack+37674, 6);
 /*--- compute (d0||mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+37674, int_stack+5972, int_stack+5642, 6);
 /*--- compute (d0||ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+4200, int_stack+37674, int_stack+11060, 6);
 /*--- compute (d0||kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+37674, int_stack+4200, int_stack+0, 6);
 /*--- compute (d0||ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+4200, int_stack+37674, int_stack+18104, 6);
 /*--- compute (d0|[r12,T2]|hh) ---*/
   t2hrr3_build_hh(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+18104, int_stack+35154, int_stack+9170, int_stack+39924, int_stack+32004, int_stack+16214, 2, 0);
     Libr12->te_ptr[3] = int_stack + 18104;
 /*--- compute (d0|[r12,T1]|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+20750, int_stack+1680, int_stack+11870, 6);
     Libr12->te_ptr[2] = int_stack + 20750;
 /*--- compute (d0||hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+23396, int_stack+4200, int_stack+13760, 6);
     Libr12->te_ptr[1] = int_stack + 23396;
 /*--- compute (d0|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+26042, int_stack+39924, int_stack+16214, 6);
     Libr12->te_ptr[0] = int_stack + 26042;

}
