/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_ddfp(Libr12_t *, prim_data *);

  /* Computes (dd|fp) integrals for linear R12-methods */

void hrr_grt_order_ddfp(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[2][3] = int_stack + 0;
 Libr12->t2vrr_classes[2][4] = int_stack + 60;
 Libr12->t2vrr_classes[3][3] = int_stack + 150;
 Libr12->t2vrr_classes[3][4] = int_stack + 250;
 Libr12->gvrr_classes[5][3] = int_stack + 400;
 Libr12->t2vrr_classes[4][3] = int_stack + 610;
 Libr12->t2vrr_classes[4][4] = int_stack + 760;
 Libr12->gvrr_classes[2][5] = int_stack + 985;
 Libr12->t1vrr_classes[2][3] = int_stack + 1111;
 Libr12->t1vrr_classes[2][4] = int_stack + 1171;
 Libr12->gvrr_classes[3][5] = int_stack + 1261;
 Libr12->t1vrr_classes[3][3] = int_stack + 1471;
 Libr12->t1vrr_classes[3][4] = int_stack + 1571;
 Libr12->t1vrr_classes[4][3] = int_stack + 1721;
 Libr12->t1vrr_classes[4][4] = int_stack + 1871;
 Libr12->rvrr_classes[2][3] = int_stack + 2096;
 Libr12->rvrr_classes[2][4] = int_stack + 2156;
 Libr12->rvrr_classes[3][3] = int_stack + 2246;
 Libr12->rvrr_classes[3][4] = int_stack + 2346;
 Libr12->rvrr_classes[4][3] = int_stack + 2496;
 Libr12->rvrr_classes[4][4] = int_stack + 2646;
 Libr12->gvrr_classes[2][3] = int_stack + 2871;
 Libr12->gvrr_classes[2][4] = int_stack + 2931;
 Libr12->gvrr_classes[3][3] = int_stack + 3021;
 Libr12->gvrr_classes[3][4] = int_stack + 3121;
 Libr12->gvrr_classes[4][3] = int_stack + 3271;
 Libr12->gvrr_classes[4][4] = int_stack + 3421;
 memset(int_stack,0,3646*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 3646;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_ddfp(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3646, int_stack+60, int_stack+0, int_stack+2931, int_stack+3021, int_stack+2871, 2, 0);
 /*--- compute (f0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3826, int_stack+250, int_stack+150, int_stack+3121, int_stack+3271, int_stack+3021, 3, 0);
 /*--- compute (dp|[r12,T2]|fp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+4126, int_stack+3826, int_stack+3646, 30);
 /*--- compute (g0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4666, int_stack+760, int_stack+610, int_stack+3421, int_stack+400, int_stack+3271, 4, 0);
 /*--- compute (fp|[r12,T2]|fp) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+4666, int_stack+3826, 30);
 /*--- compute (d0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+4666, int_stack+2931, int_stack+2871, 6);
 /*--- compute (f0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+4846, int_stack+3121, int_stack+3021, 10);
 /*--- compute (dp|fp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+5146, int_stack+4846, int_stack+4666, 30);
 /*--- compute (d0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+5686, int_stack+985, int_stack+2931, 6);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+3646, int_stack+1261, int_stack+3121, 10);
 /*--- compute (dp|gp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+5956, int_stack+3646, int_stack+5686, 45);
 /*--- compute (g0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+6766, int_stack+3421, int_stack+3271, 15);
 /*--- compute (fp|fp) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+7216, int_stack+6766, int_stack+4846, 30);
 /*--- compute (d0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+1261, int_stack+1171, int_stack+1111, 6);
 /*--- compute (f0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+2871, int_stack+1571, int_stack+1471, 10);
 /*--- compute (dp|[r12,T1]|fp) ---*/
   t1hrr1_build_dp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+8116, int_stack+2871, int_stack+1261, int_stack+4846, int_stack+5686, int_stack+4666, 3, 1);
 /*--- compute (g0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+3171, int_stack+1871, int_stack+1721, 15);
 /*--- compute (fp|[r12,T1]|fp) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+900, int_stack+3171, int_stack+2871, int_stack+6766, int_stack+3646, int_stack+4846, 3, 1);
 /*--- compute (d0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+6766, int_stack+2156, int_stack+2096, 6);
 /*--- compute (f0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+2871, int_stack+2346, int_stack+2246, 10);
 /*--- compute (dp||fp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+3171, int_stack+2871, int_stack+6766, 30);
 /*--- compute (g0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+6766, int_stack+2646, int_stack+2496, 15);
 /*--- compute (fp||fp) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+1800, int_stack+6766, int_stack+2871, 30);
 /*--- compute (dd|[r12,T2]|fp) ---*/
   hrr1_build_dd(Libr12->ShellQuartet.AB,int_stack+8656, int_stack+0, int_stack+4126, 30);
     Libr12->te_ptr[3] = int_stack + 8656;
 /*--- compute (dd|[r12,T1]|fp) ---*/
   t1hrr1_build_dd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+3711, int_stack+900, int_stack+8116, int_stack+7216, int_stack+5956, int_stack+5146, 3, 1);
     Libr12->te_ptr[2] = int_stack + 3711;
 /*--- compute (dd||fp) ---*/
   hrr1_build_dd(Libr12->ShellQuartet.AB,int_stack+0, int_stack+1800, int_stack+3171, 30);
     Libr12->te_ptr[1] = int_stack + 0;
 /*--- compute (dd|fp) ---*/
   hrr1_build_dd(Libr12->ShellQuartet.AB,int_stack+1080, int_stack+7216, int_stack+5146, 30);
     Libr12->te_ptr[0] = int_stack + 1080;

}
