/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_ddh0(Libr12_t *, prim_data *);

  /* Computes (dd|h0) integrals for linear R12-methods */

void hrr_grt_order_ddh0(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[2][5] = int_stack + 0;
 Libr12->t2vrr_classes[3][5] = int_stack + 126;
 Libr12->t2vrr_classes[4][5] = int_stack + 336;
 Libr12->gvrr_classes[2][6] = int_stack + 651;
 Libr12->t1vrr_classes[2][5] = int_stack + 819;
 Libr12->gvrr_classes[3][6] = int_stack + 945;
 Libr12->t1vrr_classes[3][5] = int_stack + 1225;
 Libr12->t1vrr_classes[4][5] = int_stack + 1435;
 Libr12->rvrr_classes[2][5] = int_stack + 1750;
 Libr12->rvrr_classes[3][5] = int_stack + 1876;
 Libr12->rvrr_classes[4][5] = int_stack + 2086;
 Libr12->gvrr_classes[2][5] = int_stack + 2401;
 Libr12->gvrr_classes[3][5] = int_stack + 2527;
 Libr12->gvrr_classes[4][5] = int_stack + 2737;
 memset(int_stack,0,3052*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 3052;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_ddh0(Libr12, Data);
   Data++;
 }

 /*--- compute (dp|[r12,T2]|h0) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+3052, int_stack+126, int_stack+0, 21);
 /*--- compute (fp|[r12,T2]|h0) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+3430, int_stack+336, int_stack+126, 21);
 /*--- compute (dp|h0) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+2527, int_stack+2401, 21);
 /*--- compute (dp|i0) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+4060, int_stack+945, int_stack+651, 28);
 /*--- compute (fp|h0) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+4564, int_stack+2737, int_stack+2527, 21);
 /*--- compute (dp|[r12,T1]|h0) ---*/
   t1hrr1_build_dp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+5194, int_stack+1225, int_stack+819, int_stack+2527, int_stack+651, int_stack+2401, 5, 0);
 /*--- compute (fp|[r12,T1]|h0) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+5572, int_stack+1435, int_stack+1225, int_stack+2737, int_stack+945, int_stack+2527, 5, 0);
 /*--- compute (dp||h0) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+2401, int_stack+1876, int_stack+1750, 21);
 /*--- compute (fp||h0) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+378, int_stack+2086, int_stack+1876, 21);
 /*--- compute (dd|[r12,T2]|h0) ---*/
   hrr1_build_dd(Libr12->ShellQuartet.AB,int_stack+1008, int_stack+3430, int_stack+3052, 21);
     Libr12->te_ptr[3] = int_stack + 1008;
 /*--- compute (dd|[r12,T1]|h0) ---*/
   t1hrr1_build_dd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+2779, int_stack+5572, int_stack+5194, int_stack+4564, int_stack+4060, int_stack+0, 5, 0);
     Libr12->te_ptr[2] = int_stack + 2779;
 /*--- compute (dd||h0) ---*/
   hrr1_build_dd(Libr12->ShellQuartet.AB,int_stack+5194, int_stack+378, int_stack+2401, 21);
     Libr12->te_ptr[1] = int_stack + 5194;
 /*--- compute (dd|h0) ---*/
   hrr1_build_dd(Libr12->ShellQuartet.AB,int_stack+5950, int_stack+4564, int_stack+0, 21);
     Libr12->te_ptr[0] = int_stack + 5950;

}
