/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_ddhf(Libr12_t *, prim_data *);

  /* Computes (dd|hf) integrals for linear R12-methods */

void hrr_grt_order_ddhf(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[2][5] = int_stack + 0;
 Libr12->t2vrr_classes[2][6] = int_stack + 126;
 Libr12->t2vrr_classes[2][7] = int_stack + 294;
 Libr12->t2vrr_classes[2][8] = int_stack + 510;
 Libr12->t2vrr_classes[3][5] = int_stack + 780;
 Libr12->t2vrr_classes[3][6] = int_stack + 990;
 Libr12->t2vrr_classes[3][7] = int_stack + 1270;
 Libr12->t2vrr_classes[3][8] = int_stack + 1630;
 Libr12->gvrr_classes[5][5] = int_stack + 2080;
 Libr12->t2vrr_classes[4][5] = int_stack + 2521;
 Libr12->gvrr_classes[5][6] = int_stack + 2836;
 Libr12->t2vrr_classes[4][6] = int_stack + 3424;
 Libr12->gvrr_classes[5][7] = int_stack + 3844;
 Libr12->t2vrr_classes[4][7] = int_stack + 4600;
 Libr12->t2vrr_classes[4][8] = int_stack + 5140;
 Libr12->gvrr_classes[2][9] = int_stack + 5815;
 Libr12->t1vrr_classes[2][5] = int_stack + 6145;
 Libr12->t1vrr_classes[2][6] = int_stack + 6271;
 Libr12->t1vrr_classes[2][7] = int_stack + 6439;
 Libr12->t1vrr_classes[2][8] = int_stack + 6655;
 Libr12->gvrr_classes[3][9] = int_stack + 6925;
 Libr12->t1vrr_classes[3][5] = int_stack + 7475;
 Libr12->t1vrr_classes[3][6] = int_stack + 7685;
 Libr12->t1vrr_classes[3][7] = int_stack + 7965;
 Libr12->t1vrr_classes[3][8] = int_stack + 8325;
 Libr12->t1vrr_classes[4][5] = int_stack + 8775;
 Libr12->t1vrr_classes[4][6] = int_stack + 9090;
 Libr12->t1vrr_classes[4][7] = int_stack + 9510;
 Libr12->t1vrr_classes[4][8] = int_stack + 10050;
 Libr12->rvrr_classes[2][5] = int_stack + 10725;
 Libr12->rvrr_classes[2][6] = int_stack + 10851;
 Libr12->rvrr_classes[2][7] = int_stack + 11019;
 Libr12->rvrr_classes[2][8] = int_stack + 11235;
 Libr12->rvrr_classes[3][5] = int_stack + 11505;
 Libr12->rvrr_classes[3][6] = int_stack + 11715;
 Libr12->rvrr_classes[3][7] = int_stack + 11995;
 Libr12->rvrr_classes[3][8] = int_stack + 12355;
 Libr12->rvrr_classes[4][5] = int_stack + 12805;
 Libr12->rvrr_classes[4][6] = int_stack + 13120;
 Libr12->rvrr_classes[4][7] = int_stack + 13540;
 Libr12->rvrr_classes[4][8] = int_stack + 14080;
 Libr12->gvrr_classes[2][5] = int_stack + 14755;
 Libr12->gvrr_classes[2][6] = int_stack + 14881;
 Libr12->gvrr_classes[2][7] = int_stack + 15049;
 Libr12->gvrr_classes[2][8] = int_stack + 15265;
 Libr12->gvrr_classes[3][5] = int_stack + 15535;
 Libr12->gvrr_classes[3][6] = int_stack + 15745;
 Libr12->gvrr_classes[3][7] = int_stack + 16025;
 Libr12->gvrr_classes[3][8] = int_stack + 16385;
 Libr12->gvrr_classes[4][5] = int_stack + 16835;
 Libr12->gvrr_classes[4][6] = int_stack + 17150;
 Libr12->gvrr_classes[4][7] = int_stack + 17570;
 Libr12->gvrr_classes[4][8] = int_stack + 18110;
 memset(int_stack,0,18785*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 18785;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_ddhf(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+18785, int_stack+14881, int_stack+14755, 6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+19163, int_stack+15049, int_stack+14881, 6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+19667, int_stack+19163, int_stack+18785, 6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+20423, int_stack+15745, int_stack+15535, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+21053, int_stack+16025, int_stack+15745, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+21893, int_stack+21053, int_stack+20423, 10);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+23153, int_stack+15265, int_stack+15049, 6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+23801, int_stack+23153, int_stack+19163, 6);
 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+24809, int_stack+126, int_stack+0, int_stack+14881, int_stack+15535, int_stack+14755, 2, 0);
 /*--- compute (d0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+25187, int_stack+294, int_stack+126, int_stack+15049, int_stack+15745, int_stack+14881, 2, 0);
 /*--- compute (d0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+25691, int_stack+25187, int_stack+24809, int_stack+19163, int_stack+20423, int_stack+18785, 2, 0);
 /*--- compute (d0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+26447, int_stack+510, int_stack+294, int_stack+15265, int_stack+16025, int_stack+15049, 2, 0);
 /*--- compute (d0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+27095, int_stack+26447, int_stack+25187, int_stack+23153, int_stack+21053, int_stack+19163, 2, 0);
 /*--- compute (d0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+28103, int_stack+27095, int_stack+25691, int_stack+23801, int_stack+21893, int_stack+19667, 2, 0);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+24809, int_stack+17150, int_stack+16835, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+25754, int_stack+17570, int_stack+17150, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+29363, int_stack+25754, int_stack+24809, 15);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+27014, int_stack+16385, int_stack+16025, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+31253, int_stack+27014, int_stack+21053, 10);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+18785, int_stack+990, int_stack+780, int_stack+15745, int_stack+16835, int_stack+15535, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+1270, int_stack+990, int_stack+16025, int_stack+17150, int_stack+15745, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+32933, int_stack+0, int_stack+18785, int_stack+21053, int_stack+24809, int_stack+20423, 3, 0);
 /*--- compute (f0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+34193, int_stack+1630, int_stack+1270, int_stack+16385, int_stack+17570, int_stack+16025, 3, 0);
 /*--- compute (f0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+35273, int_stack+34193, int_stack+0, int_stack+27014, int_stack+25754, int_stack+21053, 3, 0);
 /*--- compute (f0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+36953, int_stack+35273, int_stack+32933, int_stack+31253, int_stack+29363, int_stack+21893, 3, 0);
 /*--- compute (dp|[r12,T2]|hf) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+32933, int_stack+36953, int_stack+28103, 210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+2836, int_stack+2080, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+39053, int_stack+3844, int_stack+2836, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+40817, int_stack+39053, int_stack+0, 21);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+43463, int_stack+18110, int_stack+17570, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+45083, int_stack+43463, int_stack+25754, 15);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+20423, int_stack+3424, int_stack+2521, int_stack+17150, int_stack+2080, int_stack+16835, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1323, int_stack+4600, int_stack+3424, int_stack+17570, int_stack+2836, int_stack+17150, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+47603, int_stack+1323, int_stack+20423, int_stack+25754, int_stack+0, int_stack+24809, 4, 0);
 /*--- compute (g0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+49493, int_stack+5140, int_stack+4600, int_stack+18110, int_stack+3844, int_stack+17570, 4, 0);
 /*--- compute (g0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+16835, int_stack+49493, int_stack+1323, int_stack+43463, int_stack+39053, int_stack+25754, 4, 0);
 /*--- compute (g0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+16835, int_stack+47603, int_stack+45083, int_stack+40817, int_stack+29363, 4, 0);
 /*--- compute (fp|[r12,T2]|hf) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+47603, int_stack+0, int_stack+36953, 210);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+23801, int_stack+19667, 6);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+1260, int_stack+31253, int_stack+21893, 10);
 /*--- compute (dp|hf) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+16835, int_stack+1260, int_stack+0, 210);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+3360, int_stack+5815, int_stack+15265, 6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+4170, int_stack+3360, int_stack+23153, 6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+20615, int_stack+4170, int_stack+23801, 6);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+3360, int_stack+6925, int_stack+16385, 10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+22295, int_stack+3360, int_stack+27014, 10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+24455, int_stack+22295, int_stack+31253, 10);
 /*--- compute (dp|if) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+36713, int_stack+24455, int_stack+20615, 280);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+41753, int_stack+45083, int_stack+29363, 15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+53903, int_stack+41753, int_stack+1260, 210);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+22295, int_stack+6271, int_stack+6145, 6);
 /*--- compute (d0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+22673, int_stack+6439, int_stack+6271, 6);
 /*--- compute (d0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+23177, int_stack+22673, int_stack+22295, 6);
 /*--- compute (d0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+3360, int_stack+6655, int_stack+6439, 6);
 /*--- compute (d0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+4008, int_stack+3360, int_stack+22673, 6);
 /*--- compute (d0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+5016, int_stack+4008, int_stack+23177, 6);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+3360, int_stack+7685, int_stack+7475, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+3990, int_stack+7965, int_stack+7685, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+22295, int_stack+3990, int_stack+3360, 10);
 /*--- compute (f0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+6276, int_stack+8325, int_stack+7965, 10);
 /*--- compute (f0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+27255, int_stack+6276, int_stack+3990, 10);
 /*--- compute (f0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+6276, int_stack+27255, int_stack+22295, 10);
 /*--- compute (dp|[r12,T1]|hf) ---*/
   t1hrr1_build_dp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+27255, int_stack+6276, int_stack+5016, int_stack+1260, int_stack+20615, int_stack+0, 5, 3);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+9090, int_stack+8775, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+20615, int_stack+9510, int_stack+9090, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+21875, int_stack+20615, int_stack+0, 15);
 /*--- compute (g0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+31035, int_stack+10050, int_stack+9510, 15);
 /*--- compute (g0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+3360, int_stack+31035, int_stack+20615, 15);
 /*--- compute (g0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+60203, int_stack+3360, int_stack+21875, 15);
 /*--- compute (fp|[r12,T1]|hf) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+63353, int_stack+60203, int_stack+6276, int_stack+41753, int_stack+24455, int_stack+1260, 5, 3);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+41753, int_stack+10851, int_stack+10725, 6);
 /*--- compute (d0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+42131, int_stack+11019, int_stack+10851, 6);
 /*--- compute (d0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+42635, int_stack+42131, int_stack+41753, 6);
 /*--- compute (d0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+43391, int_stack+11235, int_stack+11019, 6);
 /*--- compute (d0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+44039, int_stack+43391, int_stack+42131, 6);
 /*--- compute (d0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+45047, int_stack+44039, int_stack+42635, 6);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+41753, int_stack+11715, int_stack+11505, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+42383, int_stack+11995, int_stack+11715, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+43223, int_stack+42383, int_stack+41753, 10);
 /*--- compute (f0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+46307, int_stack+12355, int_stack+11995, 10);
 /*--- compute (f0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+60203, int_stack+46307, int_stack+42383, 10);
 /*--- compute (f0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+20615, int_stack+60203, int_stack+43223, 10);
 /*--- compute (dp||hf) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+22715, int_stack+20615, int_stack+45047, 210);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+60203, int_stack+13120, int_stack+12805, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+61148, int_stack+13540, int_stack+13120, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+41753, int_stack+61148, int_stack+60203, 15);
 /*--- compute (g0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+43643, int_stack+14080, int_stack+13540, 15);
 /*--- compute (g0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+0, int_stack+43643, int_stack+61148, 15);
 /*--- compute (g0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+60203, int_stack+0, int_stack+41753, 15);
 /*--- compute (fp||hf) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+60203, int_stack+20615, 210);
 /*--- compute (dd|[r12,T2]|hf) ---*/
   hrr1_build_dd(Libr12->ShellQuartet.AB,int_stack+6300, int_stack+47603, int_stack+32933, 210);
     Libr12->te_ptr[3] = int_stack + 6300;
 /*--- compute (dd|[r12,T1]|hf) ---*/
   t1hrr1_build_dd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+41753, int_stack+63353, int_stack+27255, int_stack+53903, int_stack+36713, int_stack+16835, 5, 3);
     Libr12->te_ptr[2] = int_stack + 41753;
 /*--- compute (dd||hf) ---*/
   hrr1_build_dd(Libr12->ShellQuartet.AB,int_stack+60203, int_stack+0, int_stack+22715, 210);
     Libr12->te_ptr[1] = int_stack + 60203;
 /*--- compute (dd|hf) ---*/
   hrr1_build_dd(Libr12->ShellQuartet.AB,int_stack+20615, int_stack+53903, int_stack+16835, 210);
     Libr12->te_ptr[0] = int_stack + 20615;

}
