/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_dphd(Libr12_t *, prim_data *);

  /* Computes (dp|hd) integrals for linear R12-methods */

void hrr_grt_order_dphd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[2][5] = int_stack + 0;
 Libr12->t2vrr_classes[2][6] = int_stack + 126;
 Libr12->t2vrr_classes[2][7] = int_stack + 294;
 Libr12->gvrr_classes[4][5] = int_stack + 510;
 Libr12->t2vrr_classes[3][5] = int_stack + 825;
 Libr12->gvrr_classes[4][6] = int_stack + 1035;
 Libr12->t2vrr_classes[3][6] = int_stack + 1455;
 Libr12->t2vrr_classes[3][7] = int_stack + 1735;
 Libr12->gvrr_classes[2][8] = int_stack + 2095;
 Libr12->t1vrr_classes[2][5] = int_stack + 2365;
 Libr12->t1vrr_classes[2][6] = int_stack + 2491;
 Libr12->t1vrr_classes[2][7] = int_stack + 2659;
 Libr12->t1vrr_classes[3][5] = int_stack + 2875;
 Libr12->t1vrr_classes[3][6] = int_stack + 3085;
 Libr12->t1vrr_classes[3][7] = int_stack + 3365;
 Libr12->rvrr_classes[2][5] = int_stack + 3725;
 Libr12->rvrr_classes[2][6] = int_stack + 3851;
 Libr12->rvrr_classes[2][7] = int_stack + 4019;
 Libr12->rvrr_classes[3][5] = int_stack + 4235;
 Libr12->rvrr_classes[3][6] = int_stack + 4445;
 Libr12->rvrr_classes[3][7] = int_stack + 4725;
 Libr12->gvrr_classes[2][5] = int_stack + 5085;
 Libr12->gvrr_classes[2][6] = int_stack + 5211;
 Libr12->gvrr_classes[2][7] = int_stack + 5379;
 Libr12->gvrr_classes[3][5] = int_stack + 5595;
 Libr12->gvrr_classes[3][6] = int_stack + 5805;
 Libr12->gvrr_classes[3][7] = int_stack + 6085;
 memset(int_stack,0,6445*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 6445;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_dphd(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+6445, int_stack+5211, int_stack+5085, 6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+6823, int_stack+5805, int_stack+5595, 10);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+7453, int_stack+5379, int_stack+5211, 6);
 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+7957, int_stack+126, int_stack+0, int_stack+5211, int_stack+5595, int_stack+5085, 2, 0);
 /*--- compute (d0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+8335, int_stack+294, int_stack+126, int_stack+5379, int_stack+5805, int_stack+5211, 2, 0);
 /*--- compute (d0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+8839, int_stack+8335, int_stack+7957, int_stack+7453, int_stack+6823, int_stack+6445, 2, 0);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+9595, int_stack+1035, int_stack+510, 15);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+7957, int_stack+6085, int_stack+5805, 10);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+10540, int_stack+1455, int_stack+825, int_stack+5805, int_stack+510, int_stack+5595, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+1735, int_stack+1455, int_stack+6085, int_stack+1035, int_stack+5805, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+11170, int_stack+0, int_stack+10540, int_stack+7957, int_stack+9595, int_stack+6823, 3, 0);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+9595, int_stack+7453, int_stack+6445, 6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+10351, int_stack+2095, int_stack+5379, 6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+0, int_stack+10351, int_stack+7453, 6);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+1008, int_stack+7957, int_stack+6823, 10);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+10351, int_stack+2491, int_stack+2365, 6);
 /*--- compute (d0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+5085, int_stack+2659, int_stack+2491, 6);
 /*--- compute (d0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+5589, int_stack+5085, int_stack+10351, 6);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+10351, int_stack+3085, int_stack+2875, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+6345, int_stack+3365, int_stack+3085, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+2268, int_stack+6345, int_stack+10351, 10);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+10351, int_stack+3851, int_stack+3725, 6);
 /*--- compute (d0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+5085, int_stack+4019, int_stack+3851, 6);
 /*--- compute (d0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+6345, int_stack+5085, int_stack+10351, 6);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+10351, int_stack+4445, int_stack+4235, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+7101, int_stack+4725, int_stack+4445, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+3528, int_stack+7101, int_stack+10351, 10);
 /*--- compute (dp|[r12,T2]|hd) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+12430, int_stack+11170, int_stack+8839, 126);
     Libr12->te_ptr[3] = int_stack + 12430;
 /*--- compute (dp|[r12,T1]|hd) ---*/
   t1hrr1_build_dp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+7101, int_stack+2268, int_stack+5589, int_stack+1008, int_stack+0, int_stack+9595, 5, 2);
     Libr12->te_ptr[2] = int_stack + 7101;
 /*--- compute (dp||hd) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+14698, int_stack+3528, int_stack+6345, 126);
     Libr12->te_ptr[1] = int_stack + 14698;
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+2268, int_stack+1008, int_stack+9595, 126);
     Libr12->te_ptr[0] = int_stack + 2268;

}
