/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_dphf(Libr12_t *, prim_data *);

  /* Computes (dp|hf) integrals for linear R12-methods */

void hrr_grt_order_dphf(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[2][5] = int_stack + 0;
 Libr12->t2vrr_classes[2][6] = int_stack + 126;
 Libr12->t2vrr_classes[2][7] = int_stack + 294;
 Libr12->t2vrr_classes[2][8] = int_stack + 510;
 Libr12->gvrr_classes[4][5] = int_stack + 780;
 Libr12->t2vrr_classes[3][5] = int_stack + 1095;
 Libr12->gvrr_classes[4][6] = int_stack + 1305;
 Libr12->t2vrr_classes[3][6] = int_stack + 1725;
 Libr12->gvrr_classes[4][7] = int_stack + 2005;
 Libr12->t2vrr_classes[3][7] = int_stack + 2545;
 Libr12->t2vrr_classes[3][8] = int_stack + 2905;
 Libr12->gvrr_classes[2][9] = int_stack + 3355;
 Libr12->t1vrr_classes[2][5] = int_stack + 3685;
 Libr12->t1vrr_classes[2][6] = int_stack + 3811;
 Libr12->t1vrr_classes[2][7] = int_stack + 3979;
 Libr12->t1vrr_classes[2][8] = int_stack + 4195;
 Libr12->t1vrr_classes[3][5] = int_stack + 4465;
 Libr12->t1vrr_classes[3][6] = int_stack + 4675;
 Libr12->t1vrr_classes[3][7] = int_stack + 4955;
 Libr12->t1vrr_classes[3][8] = int_stack + 5315;
 Libr12->rvrr_classes[2][5] = int_stack + 5765;
 Libr12->rvrr_classes[2][6] = int_stack + 5891;
 Libr12->rvrr_classes[2][7] = int_stack + 6059;
 Libr12->rvrr_classes[2][8] = int_stack + 6275;
 Libr12->rvrr_classes[3][5] = int_stack + 6545;
 Libr12->rvrr_classes[3][6] = int_stack + 6755;
 Libr12->rvrr_classes[3][7] = int_stack + 7035;
 Libr12->rvrr_classes[3][8] = int_stack + 7395;
 Libr12->gvrr_classes[2][5] = int_stack + 7845;
 Libr12->gvrr_classes[2][6] = int_stack + 7971;
 Libr12->gvrr_classes[2][7] = int_stack + 8139;
 Libr12->gvrr_classes[2][8] = int_stack + 8355;
 Libr12->gvrr_classes[3][5] = int_stack + 8625;
 Libr12->gvrr_classes[3][6] = int_stack + 8835;
 Libr12->gvrr_classes[3][7] = int_stack + 9115;
 Libr12->gvrr_classes[3][8] = int_stack + 9475;
 memset(int_stack,0,9925*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 9925;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_dphf(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+9925, int_stack+7971, int_stack+7845, 6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+10303, int_stack+8139, int_stack+7971, 6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+10807, int_stack+10303, int_stack+9925, 6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+11563, int_stack+8835, int_stack+8625, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+12193, int_stack+9115, int_stack+8835, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+13033, int_stack+12193, int_stack+11563, 10);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+14293, int_stack+8355, int_stack+8139, 6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+14941, int_stack+14293, int_stack+10303, 6);
 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+15949, int_stack+126, int_stack+0, int_stack+7971, int_stack+8625, int_stack+7845, 2, 0);
 /*--- compute (d0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+16327, int_stack+294, int_stack+126, int_stack+8139, int_stack+8835, int_stack+7971, 2, 0);
 /*--- compute (d0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+16831, int_stack+16327, int_stack+15949, int_stack+10303, int_stack+11563, int_stack+9925, 2, 0);
 /*--- compute (d0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+17587, int_stack+510, int_stack+294, int_stack+8355, int_stack+9115, int_stack+8139, 2, 0);
 /*--- compute (d0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+18235, int_stack+17587, int_stack+16327, int_stack+14293, int_stack+12193, int_stack+10303, 2, 0);
 /*--- compute (d0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+19243, int_stack+18235, int_stack+16831, int_stack+14941, int_stack+13033, int_stack+10807, 2, 0);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+15949, int_stack+1305, int_stack+780, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+16894, int_stack+2005, int_stack+1305, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+20503, int_stack+16894, int_stack+15949, 15);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+18154, int_stack+9475, int_stack+9115, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+22393, int_stack+18154, int_stack+12193, 10);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+9925, int_stack+1725, int_stack+1095, int_stack+8835, int_stack+780, int_stack+8625, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+2545, int_stack+1725, int_stack+9115, int_stack+1305, int_stack+8835, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+24073, int_stack+0, int_stack+9925, int_stack+12193, int_stack+15949, int_stack+11563, 3, 0);
 /*--- compute (f0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+840, int_stack+2905, int_stack+2545, int_stack+9475, int_stack+2005, int_stack+9115, 3, 0);
 /*--- compute (f0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+8625, int_stack+840, int_stack+0, int_stack+18154, int_stack+16894, int_stack+12193, 3, 0);
 /*--- compute (f0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+8625, int_stack+24073, int_stack+22393, int_stack+20503, int_stack+13033, 3, 0);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+20503, int_stack+14941, int_stack+10807, 6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+24073, int_stack+3355, int_stack+8355, 6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+2100, int_stack+24073, int_stack+14293, 6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+24073, int_stack+2100, int_stack+14941, 6);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+14293, int_stack+22393, int_stack+13033, 10);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+2100, int_stack+3811, int_stack+3685, 6);
 /*--- compute (d0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+2478, int_stack+3979, int_stack+3811, 6);
 /*--- compute (d0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+2982, int_stack+2478, int_stack+2100, 6);
 /*--- compute (d0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+16393, int_stack+4195, int_stack+3979, 6);
 /*--- compute (d0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+17041, int_stack+16393, int_stack+2478, 6);
 /*--- compute (d0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+21763, int_stack+17041, int_stack+2982, 6);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+16393, int_stack+4675, int_stack+4465, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+17023, int_stack+4955, int_stack+4675, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+17863, int_stack+17023, int_stack+16393, 10);
 /*--- compute (f0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+2100, int_stack+5315, int_stack+4955, 10);
 /*--- compute (f0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+3180, int_stack+2100, int_stack+17023, 10);
 /*--- compute (f0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+7845, int_stack+3180, int_stack+17863, 10);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+2100, int_stack+5891, int_stack+5765, 6);
 /*--- compute (d0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+2478, int_stack+6059, int_stack+5891, 6);
 /*--- compute (d0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+2982, int_stack+2478, int_stack+2100, 6);
 /*--- compute (d0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+3738, int_stack+6275, int_stack+6059, 6);
 /*--- compute (d0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+4386, int_stack+3738, int_stack+2478, 6);
 /*--- compute (d0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+16393, int_stack+4386, int_stack+2982, 6);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+2100, int_stack+6755, int_stack+6545, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+2730, int_stack+7035, int_stack+6755, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+3570, int_stack+2730, int_stack+2100, 10);
 /*--- compute (f0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+4830, int_stack+7395, int_stack+7035, 10);
 /*--- compute (f0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+5910, int_stack+4830, int_stack+2730, 10);
 /*--- compute (f0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+9945, int_stack+5910, int_stack+3570, 10);
 /*--- compute (dp|[r12,T2]|hf) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+2100, int_stack+0, int_stack+19243, 210);
     Libr12->te_ptr[3] = int_stack + 2100;
 /*--- compute (dp|[r12,T1]|hf) ---*/
   t1hrr1_build_dp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+25753, int_stack+7845, int_stack+21763, int_stack+14293, int_stack+24073, int_stack+20503, 5, 3);
     Libr12->te_ptr[2] = int_stack + 25753;
 /*--- compute (dp||hf) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+21763, int_stack+9945, int_stack+16393, 210);
     Libr12->te_ptr[1] = int_stack + 21763;
 /*--- compute (dp|hf) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+16393, int_stack+14293, int_stack+20503, 210);
     Libr12->te_ptr[0] = int_stack + 16393;

}
