/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_f0hh(Libr12_t *, prim_data *);

  /* Computes (f0|hh) integrals for linear R12-methods */

void hrr_grt_order_f0hh(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[4][5] = int_stack + 0;
 Libr12->t2vrr_classes[3][5] = int_stack + 315;
 Libr12->gvrr_classes[4][6] = int_stack + 525;
 Libr12->t2vrr_classes[3][6] = int_stack + 945;
 Libr12->gvrr_classes[4][7] = int_stack + 1225;
 Libr12->t2vrr_classes[3][7] = int_stack + 1765;
 Libr12->gvrr_classes[4][8] = int_stack + 2125;
 Libr12->t2vrr_classes[3][8] = int_stack + 2800;
 Libr12->gvrr_classes[4][9] = int_stack + 3250;
 Libr12->t2vrr_classes[3][9] = int_stack + 4075;
 Libr12->t2vrr_classes[3][10] = int_stack + 4625;
 Libr12->t1vrr_classes[3][5] = int_stack + 5285;
 Libr12->t1vrr_classes[3][6] = int_stack + 5495;
 Libr12->t1vrr_classes[3][7] = int_stack + 5775;
 Libr12->t1vrr_classes[3][8] = int_stack + 6135;
 Libr12->t1vrr_classes[3][9] = int_stack + 6585;
 Libr12->t1vrr_classes[3][10] = int_stack + 7135;
 Libr12->rvrr_classes[3][5] = int_stack + 7795;
 Libr12->rvrr_classes[3][6] = int_stack + 8005;
 Libr12->rvrr_classes[3][7] = int_stack + 8285;
 Libr12->rvrr_classes[3][8] = int_stack + 8645;
 Libr12->rvrr_classes[3][9] = int_stack + 9095;
 Libr12->rvrr_classes[3][10] = int_stack + 9645;
 Libr12->gvrr_classes[3][5] = int_stack + 10305;
 Libr12->gvrr_classes[3][6] = int_stack + 10515;
 Libr12->gvrr_classes[3][7] = int_stack + 10795;
 Libr12->gvrr_classes[3][8] = int_stack + 11155;
 Libr12->gvrr_classes[3][9] = int_stack + 11605;
 Libr12->gvrr_classes[3][10] = int_stack + 12155;
 memset(int_stack,0,12815*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 12815;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_f0hh(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+12815, int_stack+10515, int_stack+10305, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+13445, int_stack+10795, int_stack+10515, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+14285, int_stack+13445, int_stack+12815, 10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+15545, int_stack+11155, int_stack+10795, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+16625, int_stack+15545, int_stack+13445, 10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+18305, int_stack+16625, int_stack+14285, 10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+20405, int_stack+11605, int_stack+11155, 10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+21755, int_stack+20405, int_stack+15545, 10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+23915, int_stack+21755, int_stack+16625, 10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+26715, int_stack+23915, int_stack+18305, 10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+29865, int_stack+525, int_stack+0, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+30810, int_stack+1225, int_stack+525, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+32070, int_stack+30810, int_stack+29865, 15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+33960, int_stack+2125, int_stack+1225, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+35580, int_stack+33960, int_stack+30810, 15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+38100, int_stack+35580, int_stack+32070, 15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+41250, int_stack+3250, int_stack+2125, 15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+43275, int_stack+41250, int_stack+33960, 15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+46515, int_stack+43275, int_stack+35580, 15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+50715, int_stack+46515, int_stack+38100, 15);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+55440, int_stack+12155, int_stack+11605, 10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+57090, int_stack+55440, int_stack+20405, 10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+59790, int_stack+57090, int_stack+21755, 10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+63390, int_stack+59790, int_stack+23915, 10);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+67590, int_stack+945, int_stack+315, int_stack+10515, int_stack+0, int_stack+10305, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+68220, int_stack+1765, int_stack+945, int_stack+10795, int_stack+525, int_stack+10515, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+69060, int_stack+68220, int_stack+67590, int_stack+13445, int_stack+29865, int_stack+12815, 3, 0);
 /*--- compute (f0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+2800, int_stack+1765, int_stack+11155, int_stack+1225, int_stack+10795, 3, 0);
 /*--- compute (f0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+70320, int_stack+0, int_stack+68220, int_stack+15545, int_stack+30810, int_stack+13445, 3, 0);
 /*--- compute (f0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+29865, int_stack+70320, int_stack+69060, int_stack+16625, int_stack+32070, int_stack+14285, 3, 0);
 /*--- compute (f0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+12815, int_stack+4075, int_stack+2800, int_stack+11605, int_stack+2125, int_stack+11155, 3, 0);
 /*--- compute (f0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+67590, int_stack+12815, int_stack+0, int_stack+20405, int_stack+33960, int_stack+15545, 3, 0);
 /*--- compute (f0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+67590, int_stack+70320, int_stack+21755, int_stack+35580, int_stack+16625, 3, 0);
 /*--- compute (f0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+14165, int_stack+0, int_stack+29865, int_stack+23915, int_stack+38100, int_stack+18305, 3, 0);
 /*--- compute (f0|[r12,T2]|mp) ---*/
   t2hrr3_build_mp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+29865, int_stack+4625, int_stack+4075, int_stack+12155, int_stack+3250, int_stack+11605, 3, 0);
 /*--- compute (f0|[r12,T2]|ld) ---*/
   t2hrr3_build_ld(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+31515, int_stack+29865, int_stack+12815, int_stack+55440, int_stack+41250, int_stack+20405, 3, 0);
 /*--- compute (f0|[r12,T2]|kf) ---*/
   t2hrr3_build_kf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+34215, int_stack+31515, int_stack+67590, int_stack+57090, int_stack+43275, int_stack+21755, 3, 0);
 /*--- compute (f0|[r12,T2]|ig) ---*/
   t2hrr3_build_ig(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+67590, int_stack+34215, int_stack+0, int_stack+59790, int_stack+46515, int_stack+23915, 3, 0);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+5495, int_stack+5285, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+630, int_stack+5775, int_stack+5495, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+1470, int_stack+630, int_stack+0, 10);
 /*--- compute (f0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+2730, int_stack+6135, int_stack+5775, 10);
 /*--- compute (f0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+3810, int_stack+2730, int_stack+630, 10);
 /*--- compute (f0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+55440, int_stack+3810, int_stack+1470, 10);
 /*--- compute (f0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+6585, int_stack+6135, 10);
 /*--- compute (f0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+57540, int_stack+0, int_stack+2730, 10);
 /*--- compute (f0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+59700, int_stack+57540, int_stack+3810, 10);
 /*--- compute (f0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+1350, int_stack+59700, int_stack+55440, 10);
 /*--- compute (f0|[r12,T1]|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+55440, int_stack+7135, int_stack+6585, 10);
 /*--- compute (f0|[r12,T1]|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+4500, int_stack+55440, int_stack+0, 10);
 /*--- compute (f0|[r12,T1]|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+29865, int_stack+4500, int_stack+57540, 10);
 /*--- compute (f0|[r12,T1]|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+55440, int_stack+29865, int_stack+59700, 10);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+29865, int_stack+8005, int_stack+7795, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+30495, int_stack+8285, int_stack+8005, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+31335, int_stack+30495, int_stack+29865, 10);
 /*--- compute (f0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+32595, int_stack+8645, int_stack+8285, 10);
 /*--- compute (f0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+33675, int_stack+32595, int_stack+30495, 10);
 /*--- compute (f0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+35355, int_stack+33675, int_stack+31335, 10);
 /*--- compute (f0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+9095, int_stack+8645, 10);
 /*--- compute (f0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+29865, int_stack+0, int_stack+32595, 10);
 /*--- compute (f0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+37455, int_stack+29865, int_stack+33675, 10);
 /*--- compute (f0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+32025, int_stack+37455, int_stack+35355, 10);
 /*--- compute (f0||mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+35175, int_stack+9645, int_stack+9095, 10);
 /*--- compute (f0||ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+40255, int_stack+35175, int_stack+0, 10);
 /*--- compute (f0||kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+42955, int_stack+40255, int_stack+29865, 10);
 /*--- compute (f0||ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+4500, int_stack+42955, int_stack+37455, 10);
 /*--- compute (f0|[r12,T2]|hh) ---*/
   t2hrr3_build_hh(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+35175, int_stack+67590, int_stack+14165, int_stack+63390, int_stack+50715, int_stack+26715, 3, 0);
     Libr12->te_ptr[3] = int_stack + 35175;
 /*--- compute (f0|[r12,T1]|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+67590, int_stack+55440, int_stack+1350, 10);
     Libr12->te_ptr[2] = int_stack + 67590;
 /*--- compute (f0||hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+0, int_stack+4500, int_stack+32025, 10);
     Libr12->te_ptr[1] = int_stack + 0;
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+29865, int_stack+63390, int_stack+26715, 10);
     Libr12->te_ptr[0] = int_stack + 29865;

}
