/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_ffgg(Libr12_t *, prim_data *);

  /* Computes (ff|gg) integrals for linear R12-methods */

void hrr_grt_order_ffgg(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][4] = int_stack + 0;
 Libr12->t2vrr_classes[3][5] = int_stack + 150;
 Libr12->t2vrr_classes[3][6] = int_stack + 360;
 Libr12->t2vrr_classes[3][7] = int_stack + 640;
 Libr12->t2vrr_classes[3][8] = int_stack + 1000;
 Libr12->t2vrr_classes[4][4] = int_stack + 1450;
 Libr12->t2vrr_classes[4][5] = int_stack + 1675;
 Libr12->t2vrr_classes[4][6] = int_stack + 1990;
 Libr12->t2vrr_classes[4][7] = int_stack + 2410;
 Libr12->t2vrr_classes[4][8] = int_stack + 2950;
 Libr12->t2vrr_classes[5][4] = int_stack + 3625;
 Libr12->t2vrr_classes[5][5] = int_stack + 3940;
 Libr12->t2vrr_classes[5][6] = int_stack + 4381;
 Libr12->t2vrr_classes[5][7] = int_stack + 4969;
 Libr12->t2vrr_classes[5][8] = int_stack + 5725;
 Libr12->gvrr_classes[7][4] = int_stack + 6670;
 Libr12->t2vrr_classes[6][4] = int_stack + 7210;
 Libr12->gvrr_classes[7][5] = int_stack + 7630;
 Libr12->t2vrr_classes[6][5] = int_stack + 8386;
 Libr12->gvrr_classes[7][6] = int_stack + 8974;
 Libr12->t2vrr_classes[6][6] = int_stack + 9982;
 Libr12->gvrr_classes[7][7] = int_stack + 10766;
 Libr12->t2vrr_classes[6][7] = int_stack + 12062;
 Libr12->t2vrr_classes[6][8] = int_stack + 13070;
 Libr12->gvrr_classes[3][9] = int_stack + 14330;
 Libr12->t1vrr_classes[3][4] = int_stack + 14880;
 Libr12->t1vrr_classes[3][5] = int_stack + 15030;
 Libr12->t1vrr_classes[3][6] = int_stack + 15240;
 Libr12->t1vrr_classes[3][7] = int_stack + 15520;
 Libr12->t1vrr_classes[3][8] = int_stack + 15880;
 Libr12->gvrr_classes[4][9] = int_stack + 16330;
 Libr12->t1vrr_classes[4][4] = int_stack + 17155;
 Libr12->t1vrr_classes[4][5] = int_stack + 17380;
 Libr12->t1vrr_classes[4][6] = int_stack + 17695;
 Libr12->t1vrr_classes[4][7] = int_stack + 18115;
 Libr12->t1vrr_classes[4][8] = int_stack + 18655;
 Libr12->gvrr_classes[5][9] = int_stack + 19330;
 Libr12->t1vrr_classes[5][4] = int_stack + 20485;
 Libr12->t1vrr_classes[5][5] = int_stack + 20800;
 Libr12->t1vrr_classes[5][6] = int_stack + 21241;
 Libr12->t1vrr_classes[5][7] = int_stack + 21829;
 Libr12->t1vrr_classes[5][8] = int_stack + 22585;
 Libr12->t1vrr_classes[6][4] = int_stack + 23530;
 Libr12->t1vrr_classes[6][5] = int_stack + 23950;
 Libr12->t1vrr_classes[6][6] = int_stack + 24538;
 Libr12->t1vrr_classes[6][7] = int_stack + 25322;
 Libr12->t1vrr_classes[6][8] = int_stack + 26330;
 Libr12->rvrr_classes[3][4] = int_stack + 27590;
 Libr12->rvrr_classes[3][5] = int_stack + 27740;
 Libr12->rvrr_classes[3][6] = int_stack + 27950;
 Libr12->rvrr_classes[3][7] = int_stack + 28230;
 Libr12->rvrr_classes[3][8] = int_stack + 28590;
 Libr12->rvrr_classes[4][4] = int_stack + 29040;
 Libr12->rvrr_classes[4][5] = int_stack + 29265;
 Libr12->rvrr_classes[4][6] = int_stack + 29580;
 Libr12->rvrr_classes[4][7] = int_stack + 30000;
 Libr12->rvrr_classes[4][8] = int_stack + 30540;
 Libr12->rvrr_classes[5][4] = int_stack + 31215;
 Libr12->rvrr_classes[5][5] = int_stack + 31530;
 Libr12->rvrr_classes[5][6] = int_stack + 31971;
 Libr12->rvrr_classes[5][7] = int_stack + 32559;
 Libr12->rvrr_classes[5][8] = int_stack + 33315;
 Libr12->rvrr_classes[6][4] = int_stack + 34260;
 Libr12->rvrr_classes[6][5] = int_stack + 34680;
 Libr12->rvrr_classes[6][6] = int_stack + 35268;
 Libr12->rvrr_classes[6][7] = int_stack + 36052;
 Libr12->rvrr_classes[6][8] = int_stack + 37060;
 Libr12->gvrr_classes[3][4] = int_stack + 38320;
 Libr12->gvrr_classes[3][5] = int_stack + 38470;
 Libr12->gvrr_classes[3][6] = int_stack + 38680;
 Libr12->gvrr_classes[3][7] = int_stack + 38960;
 Libr12->gvrr_classes[3][8] = int_stack + 39320;
 Libr12->gvrr_classes[4][4] = int_stack + 39770;
 Libr12->gvrr_classes[4][5] = int_stack + 39995;
 Libr12->gvrr_classes[4][6] = int_stack + 40310;
 Libr12->gvrr_classes[4][7] = int_stack + 40730;
 Libr12->gvrr_classes[4][8] = int_stack + 41270;
 Libr12->gvrr_classes[5][4] = int_stack + 41945;
 Libr12->gvrr_classes[5][5] = int_stack + 42260;
 Libr12->gvrr_classes[5][6] = int_stack + 42701;
 Libr12->gvrr_classes[5][7] = int_stack + 43289;
 Libr12->gvrr_classes[5][8] = int_stack + 44045;
 Libr12->gvrr_classes[6][4] = int_stack + 44990;
 Libr12->gvrr_classes[6][5] = int_stack + 45410;
 Libr12->gvrr_classes[6][6] = int_stack + 45998;
 Libr12->gvrr_classes[6][7] = int_stack + 46782;
 Libr12->gvrr_classes[6][8] = int_stack + 47790;
 memset(int_stack,0,49050*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 49050;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_ffgg(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+49050, int_stack+38470, int_stack+38320, 10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+49500, int_stack+38680, int_stack+38470, 10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+50130, int_stack+49500, int_stack+49050, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+51030, int_stack+38960, int_stack+38680, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+51870, int_stack+51030, int_stack+49500, 10);
 /*--- compute (f0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+53130, int_stack+51870, int_stack+50130, 10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+54630, int_stack+39995, int_stack+39770, 15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+55305, int_stack+40310, int_stack+39995, 15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+56250, int_stack+55305, int_stack+54630, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+57600, int_stack+40730, int_stack+40310, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+58860, int_stack+57600, int_stack+55305, 15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+60750, int_stack+58860, int_stack+56250, 15);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+63000, int_stack+39320, int_stack+38960, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+64080, int_stack+63000, int_stack+51030, 10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+65760, int_stack+64080, int_stack+51870, 10);
 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+67860, int_stack+150, int_stack+0, int_stack+38470, int_stack+39770, int_stack+38320, 3, 0);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+68310, int_stack+360, int_stack+150, int_stack+38680, int_stack+39995, int_stack+38470, 3, 0);
 /*--- compute (f0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+68940, int_stack+68310, int_stack+67860, int_stack+49500, int_stack+54630, int_stack+49050, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+69840, int_stack+640, int_stack+360, int_stack+38960, int_stack+40310, int_stack+38680, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+70680, int_stack+69840, int_stack+68310, int_stack+51030, int_stack+55305, int_stack+49500, 3, 0);
 /*--- compute (f0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+71940, int_stack+70680, int_stack+68940, int_stack+51870, int_stack+56250, int_stack+50130, 3, 0);
 /*--- compute (f0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+49050, int_stack+1000, int_stack+640, int_stack+39320, int_stack+40730, int_stack+38960, 3, 0);
 /*--- compute (f0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+67860, int_stack+49050, int_stack+69840, int_stack+63000, int_stack+57600, int_stack+51030, 3, 0);
 /*--- compute (f0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+49050, int_stack+67860, int_stack+70680, int_stack+64080, int_stack+58860, int_stack+51870, 3, 0);
 /*--- compute (f0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+67860, int_stack+49050, int_stack+71940, int_stack+65760, int_stack+60750, int_stack+53130, 3, 0);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+49050, int_stack+42260, int_stack+41945, 21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+49995, int_stack+42701, int_stack+42260, 21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+70110, int_stack+49995, int_stack+49050, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+51318, int_stack+43289, int_stack+42701, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+72000, int_stack+51318, int_stack+49995, 21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+74646, int_stack+72000, int_stack+70110, 21);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+77796, int_stack+41270, int_stack+40730, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+79416, int_stack+77796, int_stack+57600, 15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+81936, int_stack+79416, int_stack+58860, 15);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+85086, int_stack+1675, int_stack+1450, int_stack+39995, int_stack+41945, int_stack+39770, 4, 0);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+38320, int_stack+1990, int_stack+1675, int_stack+40310, int_stack+42260, int_stack+39995, 4, 0);
 /*--- compute (g0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+38320, int_stack+85086, int_stack+55305, int_stack+49050, int_stack+54630, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+85086, int_stack+2410, int_stack+1990, int_stack+40730, int_stack+42701, int_stack+40310, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+86346, int_stack+85086, int_stack+38320, int_stack+57600, int_stack+49995, int_stack+55305, 4, 0);
 /*--- compute (g0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+88236, int_stack+86346, int_stack+0, int_stack+58860, int_stack+70110, int_stack+56250, 4, 0);
 /*--- compute (g0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+2950, int_stack+2410, int_stack+41270, int_stack+43289, int_stack+40730, 4, 0);
 /*--- compute (g0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+54630, int_stack+0, int_stack+85086, int_stack+77796, int_stack+51318, int_stack+57600, 4, 0);
 /*--- compute (g0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+54630, int_stack+86346, int_stack+79416, int_stack+72000, int_stack+58860, 4, 0);
 /*--- compute (g0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+54630, int_stack+0, int_stack+88236, int_stack+81936, int_stack+74646, int_stack+60750, 4, 0);
 /*--- compute (fp|[r12,T2]|gg) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+85086, int_stack+54630, int_stack+67860, 225);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+67860, int_stack+45410, int_stack+44990, 28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+45998, int_stack+45410, 28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+58005, int_stack+0, int_stack+67860, 28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+91836, int_stack+46782, int_stack+45998, 28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+94188, int_stack+91836, int_stack+0, 28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+97716, int_stack+94188, int_stack+58005, 28);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+101916, int_stack+44045, int_stack+43289, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+104184, int_stack+101916, int_stack+51318, 21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+107712, int_stack+104184, int_stack+72000, 21);
 /*--- compute (h0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+69120, int_stack+3940, int_stack+3625, int_stack+42260, int_stack+44990, int_stack+41945, 5, 0);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1764, int_stack+4381, int_stack+3940, int_stack+42701, int_stack+45410, int_stack+42260, 5, 0);
 /*--- compute (h0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+112122, int_stack+1764, int_stack+69120, int_stack+49995, int_stack+67860, int_stack+49050, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+114012, int_stack+4969, int_stack+4381, int_stack+43289, int_stack+45998, int_stack+42701, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+115776, int_stack+114012, int_stack+1764, int_stack+51318, int_stack+0, int_stack+49995, 5, 0);
 /*--- compute (h0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1764, int_stack+115776, int_stack+112122, int_stack+72000, int_stack+58005, int_stack+70110, 5, 0);
 /*--- compute (h0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+49050, int_stack+5725, int_stack+4969, int_stack+44045, int_stack+46782, int_stack+43289, 5, 0);
 /*--- compute (h0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+118422, int_stack+49050, int_stack+114012, int_stack+101916, int_stack+91836, int_stack+51318, 5, 0);
 /*--- compute (h0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+121950, int_stack+118422, int_stack+115776, int_stack+104184, int_stack+94188, int_stack+72000, 5, 0);
 /*--- compute (h0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+112122, int_stack+121950, int_stack+1764, int_stack+107712, int_stack+97716, int_stack+74646, 5, 0);
 /*--- compute (gp|[r12,T2]|gg) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+116847, int_stack+112122, int_stack+54630, 225);
 /*--- compute (fd|[r12,T2]|gg) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+126972, int_stack+116847, int_stack+85086, 225);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+85086, int_stack+7630, int_stack+6670, 36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+86706, int_stack+8974, int_stack+7630, 36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+54630, int_stack+86706, int_stack+85086, 36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+1764, int_stack+10766, int_stack+8974, 36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+69120, int_stack+1764, int_stack+86706, 36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+69120, int_stack+54630, 36);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+49050, int_stack+47790, int_stack+46782, 28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+145872, int_stack+49050, int_stack+91836, 28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+150576, int_stack+145872, int_stack+94188, 28);
 /*--- compute (i0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+88974, int_stack+8386, int_stack+7210, int_stack+45410, int_stack+6670, int_stack+44990, 6, 0);
 /*--- compute (i0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4788, int_stack+9982, int_stack+8386, int_stack+45998, int_stack+7630, int_stack+45410, 6, 0);
 /*--- compute (i0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+156456, int_stack+4788, int_stack+88974, int_stack+0, int_stack+85086, int_stack+67860, 6, 0);
 /*--- compute (i0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+88974, int_stack+12062, int_stack+9982, int_stack+46782, int_stack+8974, int_stack+45998, 6, 0);
 /*--- compute (i0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+6552, int_stack+88974, int_stack+4788, int_stack+91836, int_stack+86706, int_stack+0, 6, 0);
 /*--- compute (i0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+158976, int_stack+6552, int_stack+156456, int_stack+94188, int_stack+54630, int_stack+58005, 6, 0);
 /*--- compute (i0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+54630, int_stack+13070, int_stack+12062, int_stack+47790, int_stack+10766, int_stack+46782, 6, 0);
 /*--- compute (i0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+163176, int_stack+54630, int_stack+88974, int_stack+49050, int_stack+1764, int_stack+91836, 6, 0);
 /*--- compute (i0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+54630, int_stack+163176, int_stack+6552, int_stack+145872, int_stack+69120, int_stack+94188, 6, 0);
 /*--- compute (i0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+54630, int_stack+158976, int_stack+150576, int_stack+140472, int_stack+97716, 6, 0);
 /*--- compute (hp|[r12,T2]|gg) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+156456, int_stack+0, int_stack+112122, 225);
 /*--- compute (gd|[r12,T2]|gg) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+170631, int_stack+156456, int_stack+116847, 225);
 /*--- compute (f0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+156456, int_stack+65760, int_stack+53130, 10);
 /*--- compute (g0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+158706, int_stack+81936, int_stack+60750, 15);
 /*--- compute (fp|gg) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+162081, int_stack+158706, int_stack+156456, 225);
 /*--- compute (h0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+112122, int_stack+107712, int_stack+74646, 21);
 /*--- compute (gp|gg) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+116847, int_stack+112122, int_stack+158706, 225);
 /*--- compute (fd|gg) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+0, int_stack+116847, int_stack+162081, 225);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+168831, int_stack+14330, int_stack+39320, 10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+168831, int_stack+63000, 10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+142632, int_stack+140472, int_stack+64080, 10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+145432, int_stack+142632, int_stack+65760, 10);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+16330, int_stack+41270, 15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+85086, int_stack+140472, int_stack+77796, 15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+85086, int_stack+79416, 15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+85086, int_stack+140472, int_stack+81936, 15);
 /*--- compute (fp|hg) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+44990, int_stack+85086, int_stack+145432, 315);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+19330, int_stack+44045, 21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+89811, int_stack+140472, int_stack+101916, 21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+54440, int_stack+89811, int_stack+104184, 21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+89811, int_stack+54440, int_stack+107712, 21);
 /*--- compute (gp|hg) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+54440, int_stack+89811, int_stack+85086, 315);
 /*--- compute (fd|hg) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+190881, int_stack+54440, int_stack+44990, 315);
 /*--- compute (i0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+68615, int_stack+150576, int_stack+97716, 28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+96426, int_stack+68615, int_stack+112122, 225);
 /*--- compute (gd|gg) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+209781, int_stack+96426, int_stack+116847, 225);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+74915, int_stack+15030, int_stack+14880, 10);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+75365, int_stack+15240, int_stack+15030, 10);
 /*--- compute (f0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+75995, int_stack+75365, int_stack+74915, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+76895, int_stack+15520, int_stack+15240, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+77735, int_stack+76895, int_stack+75365, 10);
 /*--- compute (f0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+78995, int_stack+77735, int_stack+75995, 10);
 /*--- compute (f0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+74915, int_stack+15880, int_stack+15520, 10);
 /*--- compute (f0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+80495, int_stack+74915, int_stack+76895, 10);
 /*--- compute (f0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+74915, int_stack+80495, int_stack+77735, 10);
 /*--- compute (f0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+80495, int_stack+74915, int_stack+78995, 10);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+74915, int_stack+17380, int_stack+17155, 15);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+75590, int_stack+17695, int_stack+17380, 15);
 /*--- compute (g0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+76535, int_stack+75590, int_stack+74915, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+77885, int_stack+18115, int_stack+17695, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+82745, int_stack+77885, int_stack+75590, 15);
 /*--- compute (g0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+82745, int_stack+76535, 15);
 /*--- compute (g0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+74915, int_stack+18655, int_stack+18115, 15);
 /*--- compute (g0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+142722, int_stack+74915, int_stack+77885, 15);
 /*--- compute (g0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+74915, int_stack+142722, int_stack+82745, 15);
 /*--- compute (g0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+13500, int_stack+74915, int_stack+140472, 15);
 /*--- compute (fp|[r12,T1]|gg) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+148582, int_stack+13500, int_stack+80495, int_stack+158706, int_stack+145432, int_stack+156456, 4, 4);
 /*--- compute (h0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+20800, int_stack+20485, 21);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+141417, int_stack+21241, int_stack+20800, 21);
 /*--- compute (h0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+142740, int_stack+141417, int_stack+140472, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+144630, int_stack+21829, int_stack+21241, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+74915, int_stack+144630, int_stack+141417, 21);
 /*--- compute (h0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+77561, int_stack+74915, int_stack+142740, 21);
 /*--- compute (h0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+22585, int_stack+21829, 21);
 /*--- compute (h0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+80711, int_stack+140472, int_stack+144630, 21);
 /*--- compute (h0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+80711, int_stack+74915, 21);
 /*--- compute (h0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+16875, int_stack+140472, int_stack+77561, 21);
 /*--- compute (gp|[r12,T1]|gg) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+74915, int_stack+16875, int_stack+13500, int_stack+112122, int_stack+85086, int_stack+158706, 4, 4);
 /*--- compute (fd|[r12,T1]|gg) ---*/
   t1hrr1_build_fd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+230031, int_stack+74915, int_stack+148582, int_stack+116847, int_stack+44990, int_stack+162081, 4, 4);
 /*--- compute (i0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+13500, int_stack+23950, int_stack+23530, 28);
 /*--- compute (i0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+14760, int_stack+24538, int_stack+23950, 28);
 /*--- compute (i0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+14760, int_stack+13500, 28);
 /*--- compute (i0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+142992, int_stack+25322, int_stack+24538, 28);
 /*--- compute (i0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+145344, int_stack+142992, int_stack+14760, 28);
 /*--- compute (i0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+148872, int_stack+145344, int_stack+140472, 28);
 /*--- compute (i0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+13500, int_stack+26330, int_stack+25322, 28);
 /*--- compute (i0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+153072, int_stack+13500, int_stack+142992, 28);
 /*--- compute (i0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+157776, int_stack+153072, int_stack+145344, 28);
 /*--- compute (i0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+157776, int_stack+148872, 28);
 /*--- compute (hp|[r12,T1]|gg) ---*/
   t1hrr1_build_hp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+146772, int_stack+140472, int_stack+16875, int_stack+68615, int_stack+89811, int_stack+112122, 4, 4);
 /*--- compute (gd|[r12,T1]|gg) ---*/
   t1hrr1_build_gd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+243531, int_stack+146772, int_stack+74915, int_stack+96426, int_stack+54440, int_stack+116847, 4, 4);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+27740, int_stack+27590, 10);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+140922, int_stack+27950, int_stack+27740, 10);
 /*--- compute (f0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+141552, int_stack+140922, int_stack+140472, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+142452, int_stack+28230, int_stack+27950, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+143292, int_stack+142452, int_stack+140922, 10);
 /*--- compute (f0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+144552, int_stack+143292, int_stack+141552, 10);
 /*--- compute (f0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+28590, int_stack+28230, 10);
 /*--- compute (f0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+146052, int_stack+140472, int_stack+142452, 10);
 /*--- compute (f0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+146052, int_stack+143292, 10);
 /*--- compute (f0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+146052, int_stack+140472, int_stack+144552, 10);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+29265, int_stack+29040, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+141147, int_stack+29580, int_stack+29265, 15);
 /*--- compute (g0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+142092, int_stack+141147, int_stack+140472, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+143442, int_stack+30000, int_stack+29580, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+148302, int_stack+143442, int_stack+141147, 15);
 /*--- compute (g0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+150192, int_stack+148302, int_stack+142092, 15);
 /*--- compute (g0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+30540, int_stack+30000, 15);
 /*--- compute (g0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+152442, int_stack+140472, int_stack+143442, 15);
 /*--- compute (g0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+152442, int_stack+148302, 15);
 /*--- compute (g0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+152442, int_stack+140472, int_stack+150192, 15);
 /*--- compute (fp||gg) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+155817, int_stack+152442, int_stack+146052, 225);
 /*--- compute (h0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+31530, int_stack+31215, 21);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+141417, int_stack+31971, int_stack+31530, 21);
 /*--- compute (h0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+142740, int_stack+141417, int_stack+140472, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+144630, int_stack+32559, int_stack+31971, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+146394, int_stack+144630, int_stack+141417, 21);
 /*--- compute (h0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+149040, int_stack+146394, int_stack+142740, 21);
 /*--- compute (h0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+33315, int_stack+32559, 21);
 /*--- compute (h0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+162567, int_stack+140472, int_stack+144630, 21);
 /*--- compute (h0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+140472, int_stack+162567, int_stack+146394, 21);
 /*--- compute (h0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+162567, int_stack+140472, int_stack+149040, 21);
 /*--- compute (gp||gg) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+140472, int_stack+162567, int_stack+152442, 225);
 /*--- compute (fd||gg) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+13500, int_stack+140472, int_stack+155817, 225);
 /*--- compute (i0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+150597, int_stack+34680, int_stack+34260, 28);
 /*--- compute (i0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+151857, int_stack+35268, int_stack+34680, 28);
 /*--- compute (i0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+153621, int_stack+151857, int_stack+150597, 28);
 /*--- compute (i0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+156141, int_stack+36052, int_stack+35268, 28);
 /*--- compute (i0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+158493, int_stack+156141, int_stack+151857, 28);
 /*--- compute (i0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+27000, int_stack+158493, int_stack+153621, 28);
 /*--- compute (i0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+150597, int_stack+37060, int_stack+36052, 28);
 /*--- compute (i0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+31200, int_stack+150597, int_stack+156141, 28);
 /*--- compute (i0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+150597, int_stack+31200, int_stack+158493, 28);
 /*--- compute (i0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+31200, int_stack+150597, int_stack+27000, 28);
 /*--- compute (hp||gg) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+37500, int_stack+31200, int_stack+162567, 225);
 /*--- compute (gd||gg) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+51675, int_stack+37500, int_stack+140472, 225);
 /*--- compute (ff|[r12,T2]|gg) ---*/
   hrr1_build_ff(Libr12->ShellQuartet.AB,int_stack+140472, int_stack+170631, int_stack+126972, 225);
     Libr12->te_ptr[3] = int_stack + 140472;
 /*--- compute (ff|[r12,T1]|gg) ---*/
   t1hrr1_build_ff(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+162972, int_stack+243531, int_stack+230031, int_stack+209781, int_stack+190881, int_stack+0, 4, 4);
     Libr12->te_ptr[2] = int_stack + 162972;
 /*--- compute (ff||gg) ---*/
   hrr1_build_ff(Libr12->ShellQuartet.AB,int_stack+230031, int_stack+51675, int_stack+13500, 225);
     Libr12->te_ptr[1] = int_stack + 230031;
 /*--- compute (ff|gg) ---*/
   hrr1_build_ff(Libr12->ShellQuartet.AB,int_stack+13500, int_stack+209781, int_stack+0, 225);
     Libr12->te_ptr[0] = int_stack + 13500;

}
