/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_ffhd(Libr12_t *, prim_data *);

  /* Computes (ff|hd) integrals for linear R12-methods */

void hrr_grt_order_ffhd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][5] = int_stack + 0;
 Libr12->t2vrr_classes[3][6] = int_stack + 210;
 Libr12->t2vrr_classes[3][7] = int_stack + 490;
 Libr12->t2vrr_classes[4][5] = int_stack + 850;
 Libr12->t2vrr_classes[4][6] = int_stack + 1165;
 Libr12->t2vrr_classes[4][7] = int_stack + 1585;
 Libr12->t2vrr_classes[5][5] = int_stack + 2125;
 Libr12->t2vrr_classes[5][6] = int_stack + 2566;
 Libr12->t2vrr_classes[5][7] = int_stack + 3154;
 Libr12->gvrr_classes[7][5] = int_stack + 3910;
 Libr12->t2vrr_classes[6][5] = int_stack + 4666;
 Libr12->gvrr_classes[7][6] = int_stack + 5254;
 Libr12->t2vrr_classes[6][6] = int_stack + 6262;
 Libr12->t2vrr_classes[6][7] = int_stack + 7046;
 Libr12->gvrr_classes[3][8] = int_stack + 8054;
 Libr12->t1vrr_classes[3][5] = int_stack + 8504;
 Libr12->t1vrr_classes[3][6] = int_stack + 8714;
 Libr12->t1vrr_classes[3][7] = int_stack + 8994;
 Libr12->gvrr_classes[4][8] = int_stack + 9354;
 Libr12->t1vrr_classes[4][5] = int_stack + 10029;
 Libr12->t1vrr_classes[4][6] = int_stack + 10344;
 Libr12->t1vrr_classes[4][7] = int_stack + 10764;
 Libr12->gvrr_classes[5][8] = int_stack + 11304;
 Libr12->t1vrr_classes[5][5] = int_stack + 12249;
 Libr12->t1vrr_classes[5][6] = int_stack + 12690;
 Libr12->t1vrr_classes[5][7] = int_stack + 13278;
 Libr12->t1vrr_classes[6][5] = int_stack + 14034;
 Libr12->t1vrr_classes[6][6] = int_stack + 14622;
 Libr12->t1vrr_classes[6][7] = int_stack + 15406;
 Libr12->rvrr_classes[3][5] = int_stack + 16414;
 Libr12->rvrr_classes[3][6] = int_stack + 16624;
 Libr12->rvrr_classes[3][7] = int_stack + 16904;
 Libr12->rvrr_classes[4][5] = int_stack + 17264;
 Libr12->rvrr_classes[4][6] = int_stack + 17579;
 Libr12->rvrr_classes[4][7] = int_stack + 17999;
 Libr12->rvrr_classes[5][5] = int_stack + 18539;
 Libr12->rvrr_classes[5][6] = int_stack + 18980;
 Libr12->rvrr_classes[5][7] = int_stack + 19568;
 Libr12->rvrr_classes[6][5] = int_stack + 20324;
 Libr12->rvrr_classes[6][6] = int_stack + 20912;
 Libr12->rvrr_classes[6][7] = int_stack + 21696;
 Libr12->gvrr_classes[3][5] = int_stack + 22704;
 Libr12->gvrr_classes[3][6] = int_stack + 22914;
 Libr12->gvrr_classes[3][7] = int_stack + 23194;
 Libr12->gvrr_classes[4][5] = int_stack + 23554;
 Libr12->gvrr_classes[4][6] = int_stack + 23869;
 Libr12->gvrr_classes[4][7] = int_stack + 24289;
 Libr12->gvrr_classes[5][5] = int_stack + 24829;
 Libr12->gvrr_classes[5][6] = int_stack + 25270;
 Libr12->gvrr_classes[5][7] = int_stack + 25858;
 Libr12->gvrr_classes[6][5] = int_stack + 26614;
 Libr12->gvrr_classes[6][6] = int_stack + 27202;
 Libr12->gvrr_classes[6][7] = int_stack + 27986;
 memset(int_stack,0,28994*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 28994;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_ffhd(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+28994, int_stack+22914, int_stack+22704, 10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+29624, int_stack+23869, int_stack+23554, 15);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+30569, int_stack+23194, int_stack+22914, 10);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+31409, int_stack+210, int_stack+0, int_stack+22914, int_stack+23554, int_stack+22704, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+32039, int_stack+490, int_stack+210, int_stack+23194, int_stack+23869, int_stack+22914, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+32879, int_stack+32039, int_stack+31409, int_stack+30569, int_stack+29624, int_stack+28994, 3, 0);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+31409, int_stack+25270, int_stack+24829, 21);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+34139, int_stack+24289, int_stack+23869, 15);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+35399, int_stack+1165, int_stack+850, int_stack+23869, int_stack+24829, int_stack+23554, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+36344, int_stack+1585, int_stack+1165, int_stack+24289, int_stack+25270, int_stack+23869, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+36344, int_stack+35399, int_stack+34139, int_stack+31409, int_stack+29624, 4, 0);
 /*--- compute (fp|[r12,T2]|hd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+35399, int_stack+0, int_stack+32879, 126);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+39179, int_stack+27202, int_stack+26614, 28);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+40943, int_stack+25858, int_stack+25270, 21);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+32732, int_stack+2566, int_stack+2125, int_stack+25270, int_stack+26614, int_stack+24829, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+42707, int_stack+3154, int_stack+2566, int_stack+25858, int_stack+27202, int_stack+25270, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+44471, int_stack+42707, int_stack+32732, int_stack+40943, int_stack+39179, int_stack+31409, 5, 0);
 /*--- compute (gp|[r12,T2]|hd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+47117, int_stack+44471, int_stack+0, 126);
 /*--- compute (fd|[r12,T2]|hd) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+52787, int_stack+47117, int_stack+35399, 126);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+35399, int_stack+5254, int_stack+3910, 36);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+0, int_stack+27986, int_stack+27202, 28);
 /*--- compute (i0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+42707, int_stack+6262, int_stack+4666, int_stack+27202, int_stack+3910, int_stack+26614, 6, 0);
 /*--- compute (i0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2352, int_stack+7046, int_stack+6262, int_stack+27986, int_stack+5254, int_stack+27202, 6, 0);
 /*--- compute (i0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+60347, int_stack+2352, int_stack+42707, int_stack+0, int_stack+35399, int_stack+39179, 6, 0);
 /*--- compute (hp|[r12,T2]|hd) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+63875, int_stack+60347, int_stack+44471, 126);
 /*--- compute (gd|[r12,T2]|hd) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+71813, int_stack+63875, int_stack+47117, 126);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+60347, int_stack+30569, int_stack+28994, 10);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+61607, int_stack+34139, int_stack+29624, 15);
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+35399, int_stack+61607, int_stack+60347, 126);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+63497, int_stack+40943, int_stack+31409, 21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+66143, int_stack+63497, int_stack+61607, 126);
 /*--- compute (fd|hd) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+42707, int_stack+66143, int_stack+35399, 126);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+31409, int_stack+8054, int_stack+23194, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+50267, int_stack+31409, int_stack+30569, 10);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+2352, int_stack+9354, int_stack+24289, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+3972, int_stack+2352, int_stack+34139, 15);
 /*--- compute (fp|id) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+26614, int_stack+3972, int_stack+50267, 168);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+31654, int_stack+11304, int_stack+25858, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+22704, int_stack+31654, int_stack+40943, 21);
 /*--- compute (gp|id) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+83153, int_stack+22704, int_stack+3972, 168);
 /*--- compute (fd|id) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+90713, int_stack+83153, int_stack+26614, 168);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+31654, int_stack+0, int_stack+39179, 28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+100793, int_stack+31654, int_stack+63497, 126);
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+108731, int_stack+100793, int_stack+66143, 126);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+39179, int_stack+8714, int_stack+8504, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+51947, int_stack+8994, int_stack+8714, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+39809, int_stack+51947, int_stack+39179, 10);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+11304, int_stack+10344, int_stack+10029, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+41069, int_stack+10764, int_stack+10344, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+41069, int_stack+11304, 15);
 /*--- compute (fp|[r12,T1]|hd) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+6492, int_stack+0, int_stack+39809, int_stack+61607, int_stack+50267, int_stack+60347, 5, 2);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+50267, int_stack+12690, int_stack+12249, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+39179, int_stack+13278, int_stack+12690, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+10272, int_stack+39179, int_stack+50267, 21);
 /*--- compute (gp|[r12,T1]|hd) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+120071, int_stack+10272, int_stack+0, int_stack+63497, int_stack+3972, int_stack+61607, 5, 2);
 /*--- compute (fd|[r12,T1]|hd) ---*/
   t1hrr1_build_fd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+125741, int_stack+120071, int_stack+6492, int_stack+66143, int_stack+26614, int_stack+35399, 5, 2);
 /*--- compute (i0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+14622, int_stack+14034, 28);
 /*--- compute (i0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+1764, int_stack+15406, int_stack+14622, 28);
 /*--- compute (i0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+4116, int_stack+1764, int_stack+0, 28);
 /*--- compute (hp|[r12,T1]|hd) ---*/
   t1hrr1_build_hp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+133301, int_stack+4116, int_stack+10272, int_stack+31654, int_stack+22704, int_stack+63497, 5, 2);
 /*--- compute (gd|[r12,T1]|hd) ---*/
   t1hrr1_build_gd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+22704, int_stack+133301, int_stack+120071, int_stack+100793, int_stack+83153, int_stack+66143, 5, 2);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+83153, int_stack+16624, int_stack+16414, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+83783, int_stack+16904, int_stack+16624, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+84623, int_stack+83783, int_stack+83153, 10);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+83153, int_stack+17579, int_stack+17264, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+85883, int_stack+17999, int_stack+17579, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+87143, int_stack+85883, int_stack+83153, 15);
 /*--- compute (fp||hd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+100793, int_stack+87143, int_stack+84623, 126);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+83153, int_stack+18980, int_stack+18539, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+84476, int_stack+19568, int_stack+18980, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+104573, int_stack+84476, int_stack+83153, 21);
 /*--- compute (gp||hd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+120071, int_stack+104573, int_stack+87143, 126);
 /*--- compute (fd||hd) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+83153, int_stack+120071, int_stack+100793, 126);
 /*--- compute (i0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+100793, int_stack+20912, int_stack+20324, 28);
 /*--- compute (i0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+133301, int_stack+21696, int_stack+20912, 28);
 /*--- compute (i0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+135653, int_stack+133301, int_stack+100793, 28);
 /*--- compute (hp||hd) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+34044, int_stack+135653, int_stack+104573, 126);
 /*--- compute (gd||hd) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+0, int_stack+34044, int_stack+120071, 126);
 /*--- compute (ff|[r12,T2]|hd) ---*/
   hrr1_build_ff(Libr12->ShellQuartet.AB,int_stack+133301, int_stack+71813, int_stack+52787, 126);
     Libr12->te_ptr[3] = int_stack + 133301;
 /*--- compute (ff|[r12,T1]|hd) ---*/
   t1hrr1_build_ff(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+50267, int_stack+22704, int_stack+125741, int_stack+108731, int_stack+90713, int_stack+42707, 5, 2);
     Libr12->te_ptr[2] = int_stack + 50267;
 /*--- compute (ff||hd) ---*/
   hrr1_build_ff(Libr12->ShellQuartet.AB,int_stack+90713, int_stack+0, int_stack+83153, 126);
     Libr12->te_ptr[1] = int_stack + 90713;
 /*--- compute (ff|hd) ---*/
   hrr1_build_ff(Libr12->ShellQuartet.AB,int_stack+0, int_stack+108731, int_stack+42707, 126);
     Libr12->te_ptr[0] = int_stack + 0;

}
