/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_fpgg(Libr12_t *, prim_data *);

  /* Computes (fp|gg) integrals for linear R12-methods */

void hrr_grt_order_fpgg(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][4] = int_stack + 0;
 Libr12->t2vrr_classes[3][5] = int_stack + 150;
 Libr12->t2vrr_classes[3][6] = int_stack + 360;
 Libr12->t2vrr_classes[3][7] = int_stack + 640;
 Libr12->t2vrr_classes[3][8] = int_stack + 1000;
 Libr12->gvrr_classes[5][4] = int_stack + 1450;
 Libr12->t2vrr_classes[4][4] = int_stack + 1765;
 Libr12->gvrr_classes[5][5] = int_stack + 1990;
 Libr12->t2vrr_classes[4][5] = int_stack + 2431;
 Libr12->gvrr_classes[5][6] = int_stack + 2746;
 Libr12->t2vrr_classes[4][6] = int_stack + 3334;
 Libr12->gvrr_classes[5][7] = int_stack + 3754;
 Libr12->t2vrr_classes[4][7] = int_stack + 4510;
 Libr12->t2vrr_classes[4][8] = int_stack + 5050;
 Libr12->gvrr_classes[3][9] = int_stack + 5725;
 Libr12->t1vrr_classes[3][4] = int_stack + 6275;
 Libr12->t1vrr_classes[3][5] = int_stack + 6425;
 Libr12->t1vrr_classes[3][6] = int_stack + 6635;
 Libr12->t1vrr_classes[3][7] = int_stack + 6915;
 Libr12->t1vrr_classes[3][8] = int_stack + 7275;
 Libr12->t1vrr_classes[4][4] = int_stack + 7725;
 Libr12->t1vrr_classes[4][5] = int_stack + 7950;
 Libr12->t1vrr_classes[4][6] = int_stack + 8265;
 Libr12->t1vrr_classes[4][7] = int_stack + 8685;
 Libr12->t1vrr_classes[4][8] = int_stack + 9225;
 Libr12->rvrr_classes[3][4] = int_stack + 9900;
 Libr12->rvrr_classes[3][5] = int_stack + 10050;
 Libr12->rvrr_classes[3][6] = int_stack + 10260;
 Libr12->rvrr_classes[3][7] = int_stack + 10540;
 Libr12->rvrr_classes[3][8] = int_stack + 10900;
 Libr12->rvrr_classes[4][4] = int_stack + 11350;
 Libr12->rvrr_classes[4][5] = int_stack + 11575;
 Libr12->rvrr_classes[4][6] = int_stack + 11890;
 Libr12->rvrr_classes[4][7] = int_stack + 12310;
 Libr12->rvrr_classes[4][8] = int_stack + 12850;
 Libr12->gvrr_classes[3][4] = int_stack + 13525;
 Libr12->gvrr_classes[3][5] = int_stack + 13675;
 Libr12->gvrr_classes[3][6] = int_stack + 13885;
 Libr12->gvrr_classes[3][7] = int_stack + 14165;
 Libr12->gvrr_classes[3][8] = int_stack + 14525;
 Libr12->gvrr_classes[4][4] = int_stack + 14975;
 Libr12->gvrr_classes[4][5] = int_stack + 15200;
 Libr12->gvrr_classes[4][6] = int_stack + 15515;
 Libr12->gvrr_classes[4][7] = int_stack + 15935;
 Libr12->gvrr_classes[4][8] = int_stack + 16475;
 memset(int_stack,0,17150*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 17150;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_fpgg(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+17150, int_stack+13675, int_stack+13525, 10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+17600, int_stack+13885, int_stack+13675, 10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+18230, int_stack+17600, int_stack+17150, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+19130, int_stack+14165, int_stack+13885, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+19970, int_stack+19130, int_stack+17600, 10);
 /*--- compute (f0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+21230, int_stack+19970, int_stack+18230, 10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+22730, int_stack+15200, int_stack+14975, 15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+23405, int_stack+15515, int_stack+15200, 15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+24350, int_stack+23405, int_stack+22730, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+25700, int_stack+15935, int_stack+15515, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+26960, int_stack+25700, int_stack+23405, 15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+28850, int_stack+26960, int_stack+24350, 15);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+31100, int_stack+14525, int_stack+14165, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+32180, int_stack+31100, int_stack+19130, 10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+33860, int_stack+32180, int_stack+19970, 10);
 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+35960, int_stack+150, int_stack+0, int_stack+13675, int_stack+14975, int_stack+13525, 3, 0);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+36410, int_stack+360, int_stack+150, int_stack+13885, int_stack+15200, int_stack+13675, 3, 0);
 /*--- compute (f0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+37040, int_stack+36410, int_stack+35960, int_stack+17600, int_stack+22730, int_stack+17150, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+37940, int_stack+640, int_stack+360, int_stack+14165, int_stack+15515, int_stack+13885, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+38780, int_stack+37940, int_stack+36410, int_stack+19130, int_stack+23405, int_stack+17600, 3, 0);
 /*--- compute (f0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+40040, int_stack+38780, int_stack+37040, int_stack+19970, int_stack+24350, int_stack+18230, 3, 0);
 /*--- compute (f0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+17150, int_stack+1000, int_stack+640, int_stack+14525, int_stack+15935, int_stack+14165, 3, 0);
 /*--- compute (f0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+35960, int_stack+17150, int_stack+37940, int_stack+31100, int_stack+25700, int_stack+19130, 3, 0);
 /*--- compute (f0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+17150, int_stack+35960, int_stack+38780, int_stack+32180, int_stack+26960, int_stack+19970, 3, 0);
 /*--- compute (f0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+35960, int_stack+17150, int_stack+40040, int_stack+33860, int_stack+28850, int_stack+21230, 3, 0);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+17150, int_stack+1990, int_stack+1450, 21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+18095, int_stack+2746, int_stack+1990, 21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+38210, int_stack+18095, int_stack+17150, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+19418, int_stack+3754, int_stack+2746, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+40100, int_stack+19418, int_stack+18095, 21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+42746, int_stack+40100, int_stack+38210, 21);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+45896, int_stack+16475, int_stack+15935, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+47516, int_stack+45896, int_stack+25700, 15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+50036, int_stack+47516, int_stack+26960, 15);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+53186, int_stack+2431, int_stack+1765, int_stack+15200, int_stack+1450, int_stack+14975, 4, 0);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+13525, int_stack+3334, int_stack+2431, int_stack+15515, int_stack+1990, int_stack+15200, 4, 0);
 /*--- compute (g0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+13525, int_stack+53186, int_stack+23405, int_stack+17150, int_stack+22730, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1350, int_stack+4510, int_stack+3334, int_stack+15935, int_stack+2746, int_stack+15515, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+53186, int_stack+1350, int_stack+13525, int_stack+25700, int_stack+18095, int_stack+23405, 4, 0);
 /*--- compute (g0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+17150, int_stack+53186, int_stack+0, int_stack+26960, int_stack+38210, int_stack+24350, 4, 0);
 /*--- compute (g0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+38210, int_stack+5050, int_stack+4510, int_stack+16475, int_stack+3754, int_stack+15935, 4, 0);
 /*--- compute (g0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+22730, int_stack+38210, int_stack+1350, int_stack+45896, int_stack+19418, int_stack+25700, 4, 0);
 /*--- compute (g0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+22730, int_stack+53186, int_stack+47516, int_stack+40100, int_stack+26960, 4, 0);
 /*--- compute (g0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+22730, int_stack+0, int_stack+17150, int_stack+50036, int_stack+42746, int_stack+28850, 4, 0);
 /*--- compute (f0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+0, int_stack+33860, int_stack+21230, 10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+2250, int_stack+5725, int_stack+14525, 10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+3600, int_stack+2250, int_stack+31100, 10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+53186, int_stack+3600, int_stack+32180, 10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+2250, int_stack+53186, int_stack+33860, 10);
 /*--- compute (g0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+31100, int_stack+50036, int_stack+28850, 15);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+34475, int_stack+6425, int_stack+6275, 10);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+34925, int_stack+6635, int_stack+6425, 10);
 /*--- compute (f0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+5400, int_stack+34925, int_stack+34475, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+26105, int_stack+6915, int_stack+6635, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+26945, int_stack+26105, int_stack+34925, 10);
 /*--- compute (f0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+28205, int_stack+26945, int_stack+5400, 10);
 /*--- compute (f0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+5400, int_stack+7275, int_stack+6915, 10);
 /*--- compute (f0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+38210, int_stack+5400, int_stack+26105, 10);
 /*--- compute (f0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+5400, int_stack+38210, int_stack+26945, 10);
 /*--- compute (f0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+38210, int_stack+5400, int_stack+28205, 10);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+5400, int_stack+7950, int_stack+7725, 15);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+6075, int_stack+8265, int_stack+7950, 15);
 /*--- compute (g0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+40460, int_stack+6075, int_stack+5400, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+41810, int_stack+8685, int_stack+8265, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+43070, int_stack+41810, int_stack+6075, 15);
 /*--- compute (g0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+5400, int_stack+43070, int_stack+40460, 15);
 /*--- compute (g0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+44960, int_stack+9225, int_stack+8685, 15);
 /*--- compute (g0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+46580, int_stack+44960, int_stack+41810, 15);
 /*--- compute (g0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+49100, int_stack+46580, int_stack+43070, 15);
 /*--- compute (g0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+40460, int_stack+49100, int_stack+5400, 15);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+5400, int_stack+10050, int_stack+9900, 10);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+5850, int_stack+10260, int_stack+10050, 10);
 /*--- compute (f0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+6480, int_stack+5850, int_stack+5400, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+7380, int_stack+10540, int_stack+10260, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+8220, int_stack+7380, int_stack+5850, 10);
 /*--- compute (f0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+43835, int_stack+8220, int_stack+6480, 10);
 /*--- compute (f0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+5400, int_stack+10900, int_stack+10540, 10);
 /*--- compute (f0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+9480, int_stack+5400, int_stack+7380, 10);
 /*--- compute (f0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+5400, int_stack+9480, int_stack+8220, 10);
 /*--- compute (f0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+7500, int_stack+5400, int_stack+43835, 10);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+43835, int_stack+11575, int_stack+11350, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+44510, int_stack+11890, int_stack+11575, 15);
 /*--- compute (g0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+45455, int_stack+44510, int_stack+43835, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+46805, int_stack+12310, int_stack+11890, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+48065, int_stack+46805, int_stack+44510, 15);
 /*--- compute (g0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+49955, int_stack+48065, int_stack+45455, 15);
 /*--- compute (g0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+43835, int_stack+12850, int_stack+12310, 15);
 /*--- compute (g0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+52205, int_stack+43835, int_stack+46805, 15);
 /*--- compute (g0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+43835, int_stack+52205, int_stack+48065, 15);
 /*--- compute (g0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+52205, int_stack+43835, int_stack+49955, 15);
 /*--- compute (fp|[r12,T2]|gg) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+43835, int_stack+22730, int_stack+35960, 225);
     Libr12->te_ptr[3] = int_stack + 43835;
 /*--- compute (fp|[r12,T1]|gg) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+9750, int_stack+40460, int_stack+38210, int_stack+31100, int_stack+2250, int_stack+0, 4, 4);
     Libr12->te_ptr[2] = int_stack + 9750;
 /*--- compute (fp||gg) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+16500, int_stack+52205, int_stack+7500, 225);
     Libr12->te_ptr[1] = int_stack + 16500;
 /*--- compute (fp|gg) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+2250, int_stack+31100, int_stack+0, 225);
     Libr12->te_ptr[0] = int_stack + 2250;

}
