/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_fphd(Libr12_t *, prim_data *);

  /* Computes (fp|hd) integrals for linear R12-methods */

void hrr_grt_order_fphd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][5] = int_stack + 0;
 Libr12->t2vrr_classes[3][6] = int_stack + 210;
 Libr12->t2vrr_classes[3][7] = int_stack + 490;
 Libr12->gvrr_classes[5][5] = int_stack + 850;
 Libr12->t2vrr_classes[4][5] = int_stack + 1291;
 Libr12->gvrr_classes[5][6] = int_stack + 1606;
 Libr12->t2vrr_classes[4][6] = int_stack + 2194;
 Libr12->t2vrr_classes[4][7] = int_stack + 2614;
 Libr12->gvrr_classes[3][8] = int_stack + 3154;
 Libr12->t1vrr_classes[3][5] = int_stack + 3604;
 Libr12->t1vrr_classes[3][6] = int_stack + 3814;
 Libr12->t1vrr_classes[3][7] = int_stack + 4094;
 Libr12->t1vrr_classes[4][5] = int_stack + 4454;
 Libr12->t1vrr_classes[4][6] = int_stack + 4769;
 Libr12->t1vrr_classes[4][7] = int_stack + 5189;
 Libr12->rvrr_classes[3][5] = int_stack + 5729;
 Libr12->rvrr_classes[3][6] = int_stack + 5939;
 Libr12->rvrr_classes[3][7] = int_stack + 6219;
 Libr12->rvrr_classes[4][5] = int_stack + 6579;
 Libr12->rvrr_classes[4][6] = int_stack + 6894;
 Libr12->rvrr_classes[4][7] = int_stack + 7314;
 Libr12->gvrr_classes[3][5] = int_stack + 7854;
 Libr12->gvrr_classes[3][6] = int_stack + 8064;
 Libr12->gvrr_classes[3][7] = int_stack + 8344;
 Libr12->gvrr_classes[4][5] = int_stack + 8704;
 Libr12->gvrr_classes[4][6] = int_stack + 9019;
 Libr12->gvrr_classes[4][7] = int_stack + 9439;
 memset(int_stack,0,9979*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 9979;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_fphd(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+9979, int_stack+8064, int_stack+7854, 10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+10609, int_stack+9019, int_stack+8704, 15);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+11554, int_stack+8344, int_stack+8064, 10);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+12394, int_stack+210, int_stack+0, int_stack+8064, int_stack+8704, int_stack+7854, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+13024, int_stack+490, int_stack+210, int_stack+8344, int_stack+9019, int_stack+8064, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+13864, int_stack+13024, int_stack+12394, int_stack+11554, int_stack+10609, int_stack+9979, 3, 0);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+12394, int_stack+1606, int_stack+850, 21);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+15124, int_stack+9439, int_stack+9019, 15);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+16384, int_stack+2194, int_stack+1291, int_stack+9019, int_stack+850, int_stack+8704, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+2614, int_stack+2194, int_stack+9439, int_stack+1606, int_stack+9019, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1260, int_stack+0, int_stack+16384, int_stack+15124, int_stack+12394, int_stack+10609, 4, 0);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+11554, int_stack+9979, 10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+12394, int_stack+3154, int_stack+8344, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+7854, int_stack+12394, int_stack+11554, 10);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+11554, int_stack+15124, int_stack+10609, 15);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+15124, int_stack+3814, int_stack+3604, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+15754, int_stack+4094, int_stack+3814, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+16594, int_stack+15754, int_stack+15124, 10);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+15124, int_stack+4769, int_stack+4454, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+9534, int_stack+5189, int_stack+4769, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+3150, int_stack+9534, int_stack+15124, 15);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+15124, int_stack+5939, int_stack+5729, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+15754, int_stack+6219, int_stack+5939, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+9534, int_stack+15754, int_stack+15124, 10);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+15124, int_stack+6894, int_stack+6579, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+5040, int_stack+7314, int_stack+6894, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+17854, int_stack+5040, int_stack+15124, 15);
 /*--- compute (fp|[r12,T2]|hd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+19744, int_stack+1260, int_stack+13864, 126);
     Libr12->te_ptr[3] = int_stack + 19744;
 /*--- compute (fp|[r12,T1]|hd) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+23524, int_stack+3150, int_stack+16594, int_stack+11554, int_stack+7854, int_stack+0, 5, 2);
     Libr12->te_ptr[2] = int_stack + 23524;
 /*--- compute (fp||hd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+1260, int_stack+17854, int_stack+9534, 126);
     Libr12->te_ptr[1] = int_stack + 1260;
 /*--- compute (fp|hd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+5040, int_stack+11554, int_stack+0, 126);
     Libr12->te_ptr[0] = int_stack + 5040;

}
