/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_gghf(Libr12_t *, prim_data *);

  /* Computes (gg|hf) integrals for linear R12-methods */

void hrr_grt_order_gghf(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[4][5] = int_stack + 0;
 Libr12->t2vrr_classes[4][6] = int_stack + 315;
 Libr12->t2vrr_classes[4][7] = int_stack + 735;
 Libr12->t2vrr_classes[4][8] = int_stack + 1275;
 Libr12->t2vrr_classes[5][5] = int_stack + 1950;
 Libr12->t2vrr_classes[5][6] = int_stack + 2391;
 Libr12->t2vrr_classes[5][7] = int_stack + 2979;
 Libr12->t2vrr_classes[5][8] = int_stack + 3735;
 Libr12->t2vrr_classes[6][5] = int_stack + 4680;
 Libr12->t2vrr_classes[6][6] = int_stack + 5268;
 Libr12->t2vrr_classes[6][7] = int_stack + 6052;
 Libr12->t2vrr_classes[6][8] = int_stack + 7060;
 Libr12->t2vrr_classes[7][5] = int_stack + 8320;
 Libr12->t2vrr_classes[7][6] = int_stack + 9076;
 Libr12->t2vrr_classes[7][7] = int_stack + 10084;
 Libr12->t2vrr_classes[7][8] = int_stack + 11380;
 Libr12->gvrr_classes[9][5] = int_stack + 13000;
 Libr12->t2vrr_classes[8][5] = int_stack + 14155;
 Libr12->gvrr_classes[9][6] = int_stack + 15100;
 Libr12->t2vrr_classes[8][6] = int_stack + 16640;
 Libr12->gvrr_classes[9][7] = int_stack + 17900;
 Libr12->t2vrr_classes[8][7] = int_stack + 19880;
 Libr12->t2vrr_classes[8][8] = int_stack + 21500;
 Libr12->gvrr_classes[4][9] = int_stack + 23525;
 Libr12->t1vrr_classes[4][5] = int_stack + 24350;
 Libr12->t1vrr_classes[4][6] = int_stack + 24665;
 Libr12->t1vrr_classes[4][7] = int_stack + 25085;
 Libr12->t1vrr_classes[4][8] = int_stack + 25625;
 Libr12->gvrr_classes[5][9] = int_stack + 26300;
 Libr12->t1vrr_classes[5][5] = int_stack + 27455;
 Libr12->t1vrr_classes[5][6] = int_stack + 27896;
 Libr12->t1vrr_classes[5][7] = int_stack + 28484;
 Libr12->t1vrr_classes[5][8] = int_stack + 29240;
 Libr12->gvrr_classes[6][9] = int_stack + 30185;
 Libr12->t1vrr_classes[6][5] = int_stack + 31725;
 Libr12->t1vrr_classes[6][6] = int_stack + 32313;
 Libr12->t1vrr_classes[6][7] = int_stack + 33097;
 Libr12->t1vrr_classes[6][8] = int_stack + 34105;
 Libr12->gvrr_classes[7][9] = int_stack + 35365;
 Libr12->t1vrr_classes[7][5] = int_stack + 37345;
 Libr12->t1vrr_classes[7][6] = int_stack + 38101;
 Libr12->t1vrr_classes[7][7] = int_stack + 39109;
 Libr12->t1vrr_classes[7][8] = int_stack + 40405;
 Libr12->t1vrr_classes[8][5] = int_stack + 42025;
 Libr12->t1vrr_classes[8][6] = int_stack + 42970;
 Libr12->t1vrr_classes[8][7] = int_stack + 44230;
 Libr12->t1vrr_classes[8][8] = int_stack + 45850;
 Libr12->rvrr_classes[4][5] = int_stack + 47875;
 Libr12->rvrr_classes[4][6] = int_stack + 48190;
 Libr12->rvrr_classes[4][7] = int_stack + 48610;
 Libr12->rvrr_classes[4][8] = int_stack + 49150;
 Libr12->rvrr_classes[5][5] = int_stack + 49825;
 Libr12->rvrr_classes[5][6] = int_stack + 50266;
 Libr12->rvrr_classes[5][7] = int_stack + 50854;
 Libr12->rvrr_classes[5][8] = int_stack + 51610;
 Libr12->rvrr_classes[6][5] = int_stack + 52555;
 Libr12->rvrr_classes[6][6] = int_stack + 53143;
 Libr12->rvrr_classes[6][7] = int_stack + 53927;
 Libr12->rvrr_classes[6][8] = int_stack + 54935;
 Libr12->rvrr_classes[7][5] = int_stack + 56195;
 Libr12->rvrr_classes[7][6] = int_stack + 56951;
 Libr12->rvrr_classes[7][7] = int_stack + 57959;
 Libr12->rvrr_classes[7][8] = int_stack + 59255;
 Libr12->rvrr_classes[8][5] = int_stack + 60875;
 Libr12->rvrr_classes[8][6] = int_stack + 61820;
 Libr12->rvrr_classes[8][7] = int_stack + 63080;
 Libr12->rvrr_classes[8][8] = int_stack + 64700;
 Libr12->gvrr_classes[4][5] = int_stack + 66725;
 Libr12->gvrr_classes[4][6] = int_stack + 67040;
 Libr12->gvrr_classes[4][7] = int_stack + 67460;
 Libr12->gvrr_classes[4][8] = int_stack + 68000;
 Libr12->gvrr_classes[5][5] = int_stack + 68675;
 Libr12->gvrr_classes[5][6] = int_stack + 69116;
 Libr12->gvrr_classes[5][7] = int_stack + 69704;
 Libr12->gvrr_classes[5][8] = int_stack + 70460;
 Libr12->gvrr_classes[6][5] = int_stack + 71405;
 Libr12->gvrr_classes[6][6] = int_stack + 71993;
 Libr12->gvrr_classes[6][7] = int_stack + 72777;
 Libr12->gvrr_classes[6][8] = int_stack + 73785;
 Libr12->gvrr_classes[7][5] = int_stack + 75045;
 Libr12->gvrr_classes[7][6] = int_stack + 75801;
 Libr12->gvrr_classes[7][7] = int_stack + 76809;
 Libr12->gvrr_classes[7][8] = int_stack + 78105;
 Libr12->gvrr_classes[8][5] = int_stack + 79725;
 Libr12->gvrr_classes[8][6] = int_stack + 80670;
 Libr12->gvrr_classes[8][7] = int_stack + 81930;
 Libr12->gvrr_classes[8][8] = int_stack + 83550;
 memset(int_stack,0,85575*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 85575;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_gghf(Libr12, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+85575, int_stack+67040, int_stack+66725, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+86520, int_stack+67460, int_stack+67040, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+87780, int_stack+86520, int_stack+85575, 15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+89670, int_stack+69116, int_stack+68675, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+90993, int_stack+69704, int_stack+69116, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+92757, int_stack+90993, int_stack+89670, 21);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+95403, int_stack+68000, int_stack+67460, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+97023, int_stack+95403, int_stack+86520, 15);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+99543, int_stack+315, int_stack+0, int_stack+67040, int_stack+68675, int_stack+66725, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+100488, int_stack+735, int_stack+315, int_stack+67460, int_stack+69116, int_stack+67040, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+101748, int_stack+100488, int_stack+99543, int_stack+86520, int_stack+89670, int_stack+85575, 4, 0);
 /*--- compute (g0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+103638, int_stack+1275, int_stack+735, int_stack+68000, int_stack+69704, int_stack+67460, 4, 0);
 /*--- compute (g0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+105258, int_stack+103638, int_stack+100488, int_stack+95403, int_stack+90993, int_stack+86520, 4, 0);
 /*--- compute (g0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+107778, int_stack+105258, int_stack+101748, int_stack+97023, int_stack+92757, int_stack+87780, 4, 0);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+85575, int_stack+71993, int_stack+71405, 28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+99543, int_stack+72777, int_stack+71993, 28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+101895, int_stack+99543, int_stack+85575, 28);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+105423, int_stack+70460, int_stack+69704, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+110928, int_stack+105423, int_stack+90993, 21);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+2391, int_stack+1950, int_stack+69116, int_stack+71405, int_stack+68675, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+114456, int_stack+2979, int_stack+2391, int_stack+69704, int_stack+71993, int_stack+69116, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+116220, int_stack+114456, int_stack+0, int_stack+90993, int_stack+85575, int_stack+89670, 5, 0);
 /*--- compute (h0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+3735, int_stack+2979, int_stack+70460, int_stack+72777, int_stack+69704, 5, 0);
 /*--- compute (h0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+118866, int_stack+0, int_stack+114456, int_stack+105423, int_stack+99543, int_stack+90993, 5, 0);
 /*--- compute (h0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+118866, int_stack+116220, int_stack+110928, int_stack+101895, int_stack+92757, 5, 0);
 /*--- compute (gp|[r12,T2]|hf) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+114456, int_stack+0, int_stack+107778, 210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+89670, int_stack+75801, int_stack+75045, 36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+107691, int_stack+76809, int_stack+75801, 36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+123906, int_stack+107691, int_stack+89670, 36);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+128442, int_stack+73785, int_stack+72777, 28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+131466, int_stack+128442, int_stack+99543, 28);
 /*--- compute (i0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+68675, int_stack+5268, int_stack+4680, int_stack+71993, int_stack+75045, int_stack+71405, 6, 0);
 /*--- compute (i0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+136170, int_stack+6052, int_stack+5268, int_stack+72777, int_stack+75801, int_stack+71993, 6, 0);
 /*--- compute (i0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+138522, int_stack+136170, int_stack+68675, int_stack+99543, int_stack+89670, int_stack+85575, 6, 0);
 /*--- compute (i0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+142050, int_stack+7060, int_stack+6052, int_stack+73785, int_stack+76809, int_stack+72777, 6, 0);
 /*--- compute (i0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+145074, int_stack+142050, int_stack+136170, int_stack+128442, int_stack+107691, int_stack+99543, 6, 0);
 /*--- compute (i0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+149778, int_stack+145074, int_stack+138522, int_stack+131466, int_stack+123906, int_stack+101895, 6, 0);
 /*--- compute (hp|[r12,T2]|hf) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+136170, int_stack+149778, int_stack+0, 210);
 /*--- compute (gd|[r12,T2]|hf) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+155658, int_stack+136170, int_stack+114456, 210);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+114456, int_stack+80670, int_stack+79725, 45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+117291, int_stack+81930, int_stack+80670, 45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+117291, int_stack+114456, 45);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+174558, int_stack+78105, int_stack+76809, 36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+178446, int_stack+174558, int_stack+107691, 36);
 /*--- compute (k0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+121071, int_stack+9076, int_stack+8320, int_stack+75801, int_stack+79725, int_stack+75045, 7, 0);
 /*--- compute (k0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+5670, int_stack+10084, int_stack+9076, int_stack+76809, int_stack+80670, int_stack+75801, 7, 0);
 /*--- compute (k0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+184494, int_stack+5670, int_stack+121071, int_stack+107691, int_stack+114456, int_stack+89670, 7, 0);
 /*--- compute (k0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+189030, int_stack+11380, int_stack+10084, int_stack+78105, int_stack+81930, int_stack+76809, 7, 0);
 /*--- compute (k0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+192918, int_stack+189030, int_stack+5670, int_stack+174558, int_stack+117291, int_stack+107691, 7, 0);
 /*--- compute (k0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+198966, int_stack+192918, int_stack+184494, int_stack+178446, int_stack+0, int_stack+123906, 7, 0);
 /*--- compute (ip|[r12,T2]|hf) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+206526, int_stack+198966, int_stack+149778, 210);
 /*--- compute (hd|[r12,T2]|hf) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+224166, int_stack+206526, int_stack+136170, 210);
 /*--- compute (gf|[r12,T2]|hf) ---*/
   hrr1_build_gf(Libr12->ShellQuartet.AB,int_stack+250626, int_stack+224166, int_stack+155658, 210);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+136170, int_stack+15100, int_stack+13000, 55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+139635, int_stack+17900, int_stack+15100, 55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+144255, int_stack+139635, int_stack+136170, 55);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+151185, int_stack+83550, int_stack+81930, 45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+156045, int_stack+151185, int_stack+117291, 45);
 /*--- compute (l0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+121071, int_stack+16640, int_stack+14155, int_stack+80670, int_stack+13000, int_stack+79725, 8, 0);
 /*--- compute (l0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+163605, int_stack+19880, int_stack+16640, int_stack+81930, int_stack+15100, int_stack+80670, 8, 0);
 /*--- compute (l0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+167385, int_stack+163605, int_stack+121071, int_stack+117291, int_stack+136170, int_stack+114456, 8, 0);
 /*--- compute (l0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+184494, int_stack+21500, int_stack+19880, int_stack+83550, int_stack+17900, int_stack+81930, 8, 0);
 /*--- compute (l0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+79725, int_stack+184494, int_stack+163605, int_stack+151185, int_stack+139635, int_stack+117291, 8, 0);
 /*--- compute (l0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+114456, int_stack+79725, int_stack+167385, int_stack+156045, int_stack+144255, int_stack+0, 8, 0);
 /*--- compute (kp|[r12,T2]|hf) ---*/
   hrr1_build_kp(Libr12->ShellQuartet.AB,int_stack+282126, int_stack+114456, int_stack+198966, 210);
 /*--- compute (id|[r12,T2]|hf) ---*/
   hrr1_build_id(Libr12->ShellQuartet.AB,int_stack+304806, int_stack+282126, int_stack+206526, 210);
 /*--- compute (hf|[r12,T2]|hf) ---*/
   hrr1_build_hf(Libr12->ShellQuartet.AB,int_stack+340086, int_stack+304806, int_stack+224166, 210);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+282126, int_stack+97023, int_stack+87780, 15);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+285276, int_stack+110928, int_stack+92757, 21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+114456, int_stack+285276, int_stack+282126, 210);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+289686, int_stack+131466, int_stack+101895, 28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+295566, int_stack+289686, int_stack+285276, 210);
 /*--- compute (gd|hf) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+308796, int_stack+295566, int_stack+114456, 210);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+327696, int_stack+178446, int_stack+123906, 36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+184494, int_stack+327696, int_stack+289686, 210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+202134, int_stack+184494, int_stack+295566, 210);
 /*--- compute (gf|hf) ---*/
   hrr1_build_gf(Libr12->ShellQuartet.AB,int_stack+384186, int_stack+202134, int_stack+308796, 210);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+123906, int_stack+23525, int_stack+68000, 15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+335256, int_stack+123906, int_stack+95403, 15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+123906, int_stack+335256, int_stack+97023, 15);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+335256, int_stack+26300, int_stack+70460, 21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+79725, int_stack+335256, int_stack+105423, 21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+84261, int_stack+79725, int_stack+110928, 21);
 /*--- compute (gp|if) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+90141, int_stack+84261, int_stack+123906, 280);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+79725, int_stack+30185, int_stack+73785, 28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+102741, int_stack+79725, int_stack+128442, 28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+163605, int_stack+102741, int_stack+131466, 28);
 /*--- compute (hp|if) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+128106, int_stack+163605, int_stack+84261, 280);
 /*--- compute (gd|if) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+415686, int_stack+128106, int_stack+90141, 280);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+102741, int_stack+35365, int_stack+78105, 36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+145746, int_stack+102741, int_stack+174558, 36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+102741, int_stack+145746, int_stack+178446, 36);
 /*--- compute (ip|if) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+440886, int_stack+102741, int_stack+163605, 280);
 /*--- compute (hd|if) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+464406, int_stack+440886, int_stack+128106, 280);
 /*--- compute (gf|if) ---*/
   hrr1_build_gf(Libr12->ShellQuartet.AB,int_stack+499686, int_stack+464406, int_stack+415686, 280);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+145746, int_stack+156045, int_stack+0, 45);
 /*--- compute (kp|hf) ---*/
   hrr1_build_kp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+145746, int_stack+327696, 210);
 /*--- compute (id|hf) ---*/
   hrr1_build_id(Libr12->ShellQuartet.AB,int_stack+541686, int_stack+0, int_stack+184494, 210);
 /*--- compute (hf|hf) ---*/
   hrr1_build_hf(Libr12->ShellQuartet.AB,int_stack+576966, int_stack+541686, int_stack+202134, 210);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+22680, int_stack+24665, int_stack+24350, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+155196, int_stack+25085, int_stack+24665, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+156456, int_stack+155196, int_stack+22680, 15);
 /*--- compute (g0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+22680, int_stack+25625, int_stack+25085, 15);
 /*--- compute (g0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+24300, int_stack+22680, int_stack+155196, 15);
 /*--- compute (g0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+158346, int_stack+24300, int_stack+156456, 15);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+155196, int_stack+27896, int_stack+27455, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+156519, int_stack+28484, int_stack+27896, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+22680, int_stack+156519, int_stack+155196, 21);
 /*--- compute (h0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+25326, int_stack+29240, int_stack+28484, 21);
 /*--- compute (h0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+27594, int_stack+25326, int_stack+156519, 21);
 /*--- compute (h0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+335256, int_stack+27594, int_stack+22680, 21);
 /*--- compute (gp|[r12,T1]|hf) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+171445, int_stack+335256, int_stack+158346, int_stack+285276, int_stack+123906, int_stack+282126, 5, 3);
 /*--- compute (i0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+282126, int_stack+32313, int_stack+31725, 28);
 /*--- compute (i0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+123906, int_stack+33097, int_stack+32313, 28);
 /*--- compute (i0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+22680, int_stack+123906, int_stack+282126, 28);
 /*--- compute (i0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+282126, int_stack+34105, int_stack+33097, 28);
 /*--- compute (i0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+26208, int_stack+282126, int_stack+123906, 28);
 /*--- compute (i0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+30912, int_stack+26208, int_stack+22680, 28);
 /*--- compute (hp|[r12,T1]|hf) ---*/
   t1hrr1_build_hp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+228594, int_stack+30912, int_stack+335256, int_stack+289686, int_stack+84261, int_stack+285276, 5, 3);
 /*--- compute (gd|[r12,T1]|hf) ---*/
   t1hrr1_build_gd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+66725, int_stack+228594, int_stack+171445, int_stack+295566, int_stack+90141, int_stack+114456, 5, 3);
 /*--- compute (k0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+171445, int_stack+38101, int_stack+37345, 36);
 /*--- compute (k0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+173713, int_stack+39109, int_stack+38101, 36);
 /*--- compute (k0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+176737, int_stack+173713, int_stack+171445, 36);
 /*--- compute (k0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+335256, int_stack+40405, int_stack+39109, 36);
 /*--- compute (k0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+22680, int_stack+335256, int_stack+173713, 36);
 /*--- compute (k0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+282126, int_stack+22680, int_stack+176737, 36);
 /*--- compute (ip|[r12,T1]|hf) ---*/
   t1hrr1_build_ip(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+621066, int_stack+282126, int_stack+30912, int_stack+327696, int_stack+163605, int_stack+289686, 5, 3);
 /*--- compute (hd|[r12,T1]|hf) ---*/
   t1hrr1_build_hd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+155196, int_stack+621066, int_stack+228594, int_stack+184494, int_stack+128106, int_stack+295566, 5, 3);
 /*--- compute (gf|[r12,T1]|hf) ---*/
   t1hrr1_build_gf(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+112821, int_stack+155196, int_stack+66725, int_stack+202134, int_stack+415686, int_stack+308796, 5, 3);
 /*--- compute (l0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+415686, int_stack+42970, int_stack+42025, 45);
 /*--- compute (l0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+418521, int_stack+44230, int_stack+42970, 45);
 /*--- compute (l0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+422301, int_stack+418521, int_stack+415686, 45);
 /*--- compute (l0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+427971, int_stack+45850, int_stack+44230, 45);
 /*--- compute (l0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+432831, int_stack+427971, int_stack+418521, 45);
 /*--- compute (l0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+66725, int_stack+432831, int_stack+422301, 45);
 /*--- compute (kp|[r12,T1]|hf) ---*/
   t1hrr1_build_kp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+415686, int_stack+66725, int_stack+282126, int_stack+145746, int_stack+102741, int_stack+327696, 5, 3);
 /*--- compute (id|[r12,T1]|hf) ---*/
   t1hrr1_build_id(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+282126, int_stack+415686, int_stack+621066, int_stack+0, int_stack+440886, int_stack+184494, 5, 3);
 /*--- compute (hf|[r12,T1]|hf) ---*/
   t1hrr1_build_hf(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+0, int_stack+282126, int_stack+155196, int_stack+541686, int_stack+464406, int_stack+202134, 5, 3);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+541686, int_stack+48190, int_stack+47875, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+542631, int_stack+48610, int_stack+48190, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+543891, int_stack+542631, int_stack+541686, 15);
 /*--- compute (g0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+545781, int_stack+49150, int_stack+48610, 15);
 /*--- compute (g0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+547401, int_stack+545781, int_stack+542631, 15);
 /*--- compute (g0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+549921, int_stack+547401, int_stack+543891, 15);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+541686, int_stack+50266, int_stack+49825, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+543009, int_stack+50854, int_stack+50266, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+544773, int_stack+543009, int_stack+541686, 21);
 /*--- compute (h0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+547419, int_stack+51610, int_stack+50854, 21);
 /*--- compute (h0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+553071, int_stack+547419, int_stack+543009, 21);
 /*--- compute (h0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+556599, int_stack+553071, int_stack+544773, 21);
 /*--- compute (gp||hf) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+561009, int_stack+556599, int_stack+549921, 210);
 /*--- compute (i0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+541686, int_stack+53143, int_stack+52555, 28);
 /*--- compute (i0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+543450, int_stack+53927, int_stack+53143, 28);
 /*--- compute (i0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+545802, int_stack+543450, int_stack+541686, 28);
 /*--- compute (i0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+549330, int_stack+54935, int_stack+53927, 28);
 /*--- compute (i0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+570459, int_stack+549330, int_stack+543450, 28);
 /*--- compute (i0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+549330, int_stack+570459, int_stack+545802, 28);
 /*--- compute (hp||hf) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+282126, int_stack+549330, int_stack+556599, 210);
 /*--- compute (gd||hf) ---*/
   hrr1_build_gd(Libr12->ShellQuartet.AB,int_stack+295356, int_stack+282126, int_stack+561009, 210);
 /*--- compute (k0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+555210, int_stack+56951, int_stack+56195, 36);
 /*--- compute (k0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+557478, int_stack+57959, int_stack+56951, 36);
 /*--- compute (k0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+560502, int_stack+557478, int_stack+555210, 36);
 /*--- compute (k0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+565038, int_stack+59255, int_stack+57959, 36);
 /*--- compute (k0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+568926, int_stack+565038, int_stack+557478, 36);
 /*--- compute (k0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+541686, int_stack+568926, int_stack+560502, 36);
 /*--- compute (ip||hf) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+555210, int_stack+541686, int_stack+549330, 210);
 /*--- compute (hd||hf) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+415686, int_stack+555210, int_stack+282126, 210);
 /*--- compute (gf||hf) ---*/
   hrr1_build_gf(Libr12->ShellQuartet.AB,int_stack+442146, int_stack+415686, int_stack+295356, 210);
 /*--- compute (l0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+282126, int_stack+61820, int_stack+60875, 45);
 /*--- compute (l0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+284961, int_stack+63080, int_stack+61820, 45);
 /*--- compute (l0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+288741, int_stack+284961, int_stack+282126, 45);
 /*--- compute (l0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+294411, int_stack+64700, int_stack+63080, 45);
 /*--- compute (l0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+299271, int_stack+294411, int_stack+284961, 45);
 /*--- compute (l0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+306831, int_stack+299271, int_stack+288741, 45);
 /*--- compute (kp||hf) ---*/
   hrr1_build_kp(Libr12->ShellQuartet.AB,int_stack+282126, int_stack+306831, int_stack+541686, 210);
 /*--- compute (id||hf) ---*/
   hrr1_build_id(Libr12->ShellQuartet.AB,int_stack+304806, int_stack+282126, int_stack+555210, 210);
 /*--- compute (hf||hf) ---*/
   hrr1_build_hf(Libr12->ShellQuartet.AB,int_stack+44100, int_stack+304806, int_stack+415686, 210);
 /*--- compute (gg|[r12,T2]|hf) ---*/
   hrr1_build_gg(Libr12->ShellQuartet.AB,int_stack+282126, int_stack+340086, int_stack+250626, 210);
     Libr12->te_ptr[3] = int_stack + 282126;
 /*--- compute (gg|[r12,T1]|hf) ---*/
   t1hrr1_build_gg(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+329376, int_stack+0, int_stack+112821, int_stack+576966, int_stack+499686, int_stack+384186, 5, 3);
     Libr12->te_ptr[2] = int_stack + 329376;
 /*--- compute (gg||hf) ---*/
   hrr1_build_gg(Libr12->ShellQuartet.AB,int_stack+88200, int_stack+44100, int_stack+442146, 210);
     Libr12->te_ptr[1] = int_stack + 88200;
 /*--- compute (gg|hf) ---*/
   hrr1_build_gg(Libr12->ShellQuartet.AB,int_stack+0, int_stack+576966, int_stack+384186, 210);
     Libr12->te_ptr[0] = int_stack + 0;

}
