/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_hdhg(Libr12_t *, prim_data *);

  /* Computes (hd|hg) integrals for linear R12-methods */

void hrr_grt_order_hdhg(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[5][5] = int_stack + 0;
 Libr12->t2vrr_classes[5][6] = int_stack + 441;
 Libr12->t2vrr_classes[5][7] = int_stack + 1029;
 Libr12->t2vrr_classes[5][8] = int_stack + 1785;
 Libr12->t2vrr_classes[5][9] = int_stack + 2730;
 Libr12->t2vrr_classes[6][5] = int_stack + 3885;
 Libr12->t2vrr_classes[6][6] = int_stack + 4473;
 Libr12->t2vrr_classes[6][7] = int_stack + 5257;
 Libr12->t2vrr_classes[6][8] = int_stack + 6265;
 Libr12->t2vrr_classes[6][9] = int_stack + 7525;
 Libr12->gvrr_classes[8][5] = int_stack + 9065;
 Libr12->t2vrr_classes[7][5] = int_stack + 10010;
 Libr12->gvrr_classes[8][6] = int_stack + 10766;
 Libr12->t2vrr_classes[7][6] = int_stack + 12026;
 Libr12->gvrr_classes[8][7] = int_stack + 13034;
 Libr12->t2vrr_classes[7][7] = int_stack + 14654;
 Libr12->gvrr_classes[8][8] = int_stack + 15950;
 Libr12->t2vrr_classes[7][8] = int_stack + 17975;
 Libr12->t2vrr_classes[7][9] = int_stack + 19595;
 Libr12->gvrr_classes[5][10] = int_stack + 21575;
 Libr12->t1vrr_classes[5][5] = int_stack + 22961;
 Libr12->t1vrr_classes[5][6] = int_stack + 23402;
 Libr12->t1vrr_classes[5][7] = int_stack + 23990;
 Libr12->t1vrr_classes[5][8] = int_stack + 24746;
 Libr12->t1vrr_classes[5][9] = int_stack + 25691;
 Libr12->gvrr_classes[6][10] = int_stack + 26846;
 Libr12->t1vrr_classes[6][5] = int_stack + 28694;
 Libr12->t1vrr_classes[6][6] = int_stack + 29282;
 Libr12->t1vrr_classes[6][7] = int_stack + 30066;
 Libr12->t1vrr_classes[6][8] = int_stack + 31074;
 Libr12->t1vrr_classes[6][9] = int_stack + 32334;
 Libr12->t1vrr_classes[7][5] = int_stack + 33874;
 Libr12->t1vrr_classes[7][6] = int_stack + 34630;
 Libr12->t1vrr_classes[7][7] = int_stack + 35638;
 Libr12->t1vrr_classes[7][8] = int_stack + 36934;
 Libr12->t1vrr_classes[7][9] = int_stack + 38554;
 Libr12->rvrr_classes[5][5] = int_stack + 40534;
 Libr12->rvrr_classes[5][6] = int_stack + 40975;
 Libr12->rvrr_classes[5][7] = int_stack + 41563;
 Libr12->rvrr_classes[5][8] = int_stack + 42319;
 Libr12->rvrr_classes[5][9] = int_stack + 43264;
 Libr12->rvrr_classes[6][5] = int_stack + 44419;
 Libr12->rvrr_classes[6][6] = int_stack + 45007;
 Libr12->rvrr_classes[6][7] = int_stack + 45791;
 Libr12->rvrr_classes[6][8] = int_stack + 46799;
 Libr12->rvrr_classes[6][9] = int_stack + 48059;
 Libr12->rvrr_classes[7][5] = int_stack + 49599;
 Libr12->rvrr_classes[7][6] = int_stack + 50355;
 Libr12->rvrr_classes[7][7] = int_stack + 51363;
 Libr12->rvrr_classes[7][8] = int_stack + 52659;
 Libr12->rvrr_classes[7][9] = int_stack + 54279;
 Libr12->gvrr_classes[5][5] = int_stack + 56259;
 Libr12->gvrr_classes[5][6] = int_stack + 56700;
 Libr12->gvrr_classes[5][7] = int_stack + 57288;
 Libr12->gvrr_classes[5][8] = int_stack + 58044;
 Libr12->gvrr_classes[5][9] = int_stack + 58989;
 Libr12->gvrr_classes[6][5] = int_stack + 60144;
 Libr12->gvrr_classes[6][6] = int_stack + 60732;
 Libr12->gvrr_classes[6][7] = int_stack + 61516;
 Libr12->gvrr_classes[6][8] = int_stack + 62524;
 Libr12->gvrr_classes[6][9] = int_stack + 63784;
 Libr12->gvrr_classes[7][5] = int_stack + 65324;
 Libr12->gvrr_classes[7][6] = int_stack + 66080;
 Libr12->gvrr_classes[7][7] = int_stack + 67088;
 Libr12->gvrr_classes[7][8] = int_stack + 68384;
 Libr12->gvrr_classes[7][9] = int_stack + 70004;
 memset(int_stack,0,71984*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 71984;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_hdhg(Libr12, Data);
   Data++;
 }

 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+71984, int_stack+56700, int_stack+56259, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+73307, int_stack+57288, int_stack+56700, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+75071, int_stack+73307, int_stack+71984, 21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+77717, int_stack+58044, int_stack+57288, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+79985, int_stack+77717, int_stack+73307, 21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+83513, int_stack+79985, int_stack+75071, 21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+87923, int_stack+60732, int_stack+60144, 28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+89687, int_stack+61516, int_stack+60732, 28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+92039, int_stack+89687, int_stack+87923, 28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+95567, int_stack+62524, int_stack+61516, 28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+98591, int_stack+95567, int_stack+89687, 28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+103295, int_stack+98591, int_stack+92039, 28);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+109175, int_stack+58989, int_stack+58044, 21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+112010, int_stack+109175, int_stack+77717, 21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+116546, int_stack+112010, int_stack+79985, 21);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+122426, int_stack+441, int_stack+0, int_stack+56700, int_stack+60144, int_stack+56259, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+123749, int_stack+1029, int_stack+441, int_stack+57288, int_stack+60732, int_stack+56700, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+125513, int_stack+123749, int_stack+122426, int_stack+73307, int_stack+87923, int_stack+71984, 5, 0);
 /*--- compute (h0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+128159, int_stack+1785, int_stack+1029, int_stack+58044, int_stack+61516, int_stack+57288, 5, 0);
 /*--- compute (h0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+130427, int_stack+128159, int_stack+123749, int_stack+77717, int_stack+89687, int_stack+73307, 5, 0);
 /*--- compute (h0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+133955, int_stack+130427, int_stack+125513, int_stack+79985, int_stack+92039, int_stack+75071, 5, 0);
 /*--- compute (h0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+71984, int_stack+2730, int_stack+1785, int_stack+58989, int_stack+62524, int_stack+58044, 5, 0);
 /*--- compute (h0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+122426, int_stack+71984, int_stack+128159, int_stack+109175, int_stack+95567, int_stack+77717, 5, 0);
 /*--- compute (h0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+71984, int_stack+122426, int_stack+130427, int_stack+112010, int_stack+98591, int_stack+79985, 5, 0);
 /*--- compute (h0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+122426, int_stack+71984, int_stack+133955, int_stack+116546, int_stack+103295, int_stack+83513, 5, 0);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+71984, int_stack+66080, int_stack+65324, 36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+74252, int_stack+67088, int_stack+66080, 36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+77276, int_stack+74252, int_stack+71984, 36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+129041, int_stack+68384, int_stack+67088, 36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+132929, int_stack+129041, int_stack+74252, 36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+138977, int_stack+132929, int_stack+77276, 36);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+63784, int_stack+62524, 28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+146537, int_stack+0, int_stack+95567, 28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+152585, int_stack+146537, int_stack+98591, 28);
 /*--- compute (i0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+56259, int_stack+4473, int_stack+3885, int_stack+60732, int_stack+65324, int_stack+60144, 6, 0);
 /*--- compute (i0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+160425, int_stack+5257, int_stack+4473, int_stack+61516, int_stack+66080, int_stack+60732, 6, 0);
 /*--- compute (i0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+162777, int_stack+160425, int_stack+56259, int_stack+89687, int_stack+71984, int_stack+87923, 6, 0);
 /*--- compute (i0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+166305, int_stack+6265, int_stack+5257, int_stack+62524, int_stack+67088, int_stack+61516, 6, 0);
 /*--- compute (i0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+169329, int_stack+166305, int_stack+160425, int_stack+95567, int_stack+74252, int_stack+89687, 6, 0);
 /*--- compute (i0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+174033, int_stack+169329, int_stack+162777, int_stack+98591, int_stack+77276, int_stack+92039, 6, 0);
 /*--- compute (i0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+160425, int_stack+7525, int_stack+6265, int_stack+63784, int_stack+68384, int_stack+62524, 6, 0);
 /*--- compute (i0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+87923, int_stack+160425, int_stack+166305, int_stack+0, int_stack+129041, int_stack+95567, 6, 0);
 /*--- compute (i0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+160425, int_stack+87923, int_stack+169329, int_stack+146537, int_stack+132929, int_stack+98591, 6, 0);
 /*--- compute (i0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+87923, int_stack+160425, int_stack+174033, int_stack+152585, int_stack+138977, int_stack+103295, 6, 0);
 /*--- compute (hp|[r12,T2]|hg) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+160425, int_stack+87923, int_stack+122426, 315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+122426, int_stack+10766, int_stack+9065, 45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+125261, int_stack+13034, int_stack+10766, 45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+96743, int_stack+125261, int_stack+122426, 45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+3780, int_stack+15950, int_stack+13034, 45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+180270, int_stack+3780, int_stack+125261, 45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+187830, int_stack+180270, int_stack+96743, 45);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+197280, int_stack+70004, int_stack+68384, 36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+202140, int_stack+197280, int_stack+129041, 36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+209916, int_stack+202140, int_stack+132929, 36);
 /*--- compute (k0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+56259, int_stack+12026, int_stack+10010, int_stack+66080, int_stack+9065, int_stack+65324, 7, 0);
 /*--- compute (k0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+60144, int_stack+14654, int_stack+12026, int_stack+67088, int_stack+10766, int_stack+66080, 7, 0);
 /*--- compute (k0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+219996, int_stack+60144, int_stack+56259, int_stack+74252, int_stack+122426, int_stack+71984, 7, 0);
 /*--- compute (k0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+8640, int_stack+17975, int_stack+14654, int_stack+68384, int_stack+13034, int_stack+67088, 7, 0);
 /*--- compute (k0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+224532, int_stack+8640, int_stack+60144, int_stack+129041, int_stack+125261, int_stack+74252, 7, 0);
 /*--- compute (k0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+230580, int_stack+224532, int_stack+219996, int_stack+132929, int_stack+96743, int_stack+77276, 7, 0);
 /*--- compute (k0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+96743, int_stack+19595, int_stack+17975, int_stack+70004, int_stack+15950, int_stack+68384, 7, 0);
 /*--- compute (k0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+65324, int_stack+96743, int_stack+8640, int_stack+197280, int_stack+3780, int_stack+129041, 7, 0);
 /*--- compute (k0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3780, int_stack+65324, int_stack+224532, int_stack+202140, int_stack+180270, int_stack+132929, 7, 0);
 /*--- compute (k0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+65324, int_stack+3780, int_stack+230580, int_stack+209916, int_stack+187830, int_stack+138977, 7, 0);
 /*--- compute (ip|[r12,T2]|hg) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+180270, int_stack+65324, int_stack+87923, 315);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+87923, int_stack+116546, int_stack+83513, 21);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+65324, int_stack+152585, int_stack+103295, 28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+219996, int_stack+65324, int_stack+87923, 315);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+94538, int_stack+21575, int_stack+58989, 21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+98003, int_stack+94538, int_stack+109175, 21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+103673, int_stack+98003, int_stack+112010, 21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+94538, int_stack+103673, int_stack+116546, 21);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+103358, int_stack+26846, int_stack+63784, 28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+107978, int_stack+103358, int_stack+0, 28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+107978, int_stack+146537, 28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+10080, int_stack+0, int_stack+152585, 28);
 /*--- compute (hp|ig) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+103358, int_stack+10080, int_stack+94538, 420);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+146537, int_stack+209916, int_stack+138977, 36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+239841, int_stack+146537, int_stack+65324, 315);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+23402, int_stack+22961, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+1323, int_stack+23990, int_stack+23402, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+3087, int_stack+1323, int_stack+0, 21);
 /*--- compute (h0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+5733, int_stack+24746, int_stack+23990, 21);
 /*--- compute (h0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+129818, int_stack+5733, int_stack+1323, 21);
 /*--- compute (h0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+133346, int_stack+129818, int_stack+3087, 21);
 /*--- compute (h0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+25691, int_stack+24746, 21);
 /*--- compute (h0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+21840, int_stack+0, int_stack+5733, 21);
 /*--- compute (h0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+0, int_stack+21840, int_stack+129818, 21);
 /*--- compute (h0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+21840, int_stack+0, int_stack+133346, 21);
 /*--- compute (i0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+29282, int_stack+28694, 28);
 /*--- compute (i0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+1764, int_stack+30066, int_stack+29282, 28);
 /*--- compute (i0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+4116, int_stack+1764, int_stack+0, 28);
 /*--- compute (i0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+129818, int_stack+31074, int_stack+30066, 28);
 /*--- compute (i0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+132842, int_stack+129818, int_stack+1764, 28);
 /*--- compute (i0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+137546, int_stack+132842, int_stack+4116, 28);
 /*--- compute (i0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+32334, int_stack+31074, 28);
 /*--- compute (i0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+3780, int_stack+0, int_stack+129818, 28);
 /*--- compute (i0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+74144, int_stack+3780, int_stack+132842, 28);
 /*--- compute (i0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+0, int_stack+74144, int_stack+137546, 28);
 /*--- compute (hp|[r12,T1]|hg) ---*/
   t1hrr1_build_hp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+266301, int_stack+0, int_stack+21840, int_stack+65324, int_stack+94538, int_stack+87923, 5, 4);
 /*--- compute (k0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+21840, int_stack+34630, int_stack+33874, 36);
 /*--- compute (k0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+24108, int_stack+35638, int_stack+34630, 36);
 /*--- compute (k0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+27132, int_stack+24108, int_stack+21840, 36);
 /*--- compute (k0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+31668, int_stack+36934, int_stack+35638, 36);
 /*--- compute (k0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+74144, int_stack+31668, int_stack+24108, 36);
 /*--- compute (k0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+80192, int_stack+74144, int_stack+27132, 36);
 /*--- compute (k0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+21840, int_stack+38554, int_stack+36934, 36);
 /*--- compute (k0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+87752, int_stack+21840, int_stack+31668, 36);
 /*--- compute (k0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+21840, int_stack+87752, int_stack+74144, 36);
 /*--- compute (k0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+87752, int_stack+21840, int_stack+80192, 36);
 /*--- compute (ip|[r12,T1]|hg) ---*/
   t1hrr1_build_ip(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+286146, int_stack+87752, int_stack+0, int_stack+146537, int_stack+10080, int_stack+65324, 5, 4);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+40975, int_stack+40534, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+1323, int_stack+41563, int_stack+40975, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+3087, int_stack+1323, int_stack+0, 21);
 /*--- compute (h0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+5733, int_stack+42319, int_stack+41563, 21);
 /*--- compute (h0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+8001, int_stack+5733, int_stack+1323, 21);
 /*--- compute (h0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+11529, int_stack+8001, int_stack+3087, 21);
 /*--- compute (h0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+43264, int_stack+42319, 21);
 /*--- compute (h0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+15939, int_stack+0, int_stack+5733, 21);
 /*--- compute (h0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+0, int_stack+15939, int_stack+8001, 21);
 /*--- compute (h0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+15939, int_stack+0, int_stack+11529, 21);
 /*--- compute (i0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+45007, int_stack+44419, 28);
 /*--- compute (i0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+1764, int_stack+45791, int_stack+45007, 28);
 /*--- compute (i0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+4116, int_stack+1764, int_stack+0, 28);
 /*--- compute (i0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+7644, int_stack+46799, int_stack+45791, 28);
 /*--- compute (i0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+10668, int_stack+7644, int_stack+1764, 28);
 /*--- compute (i0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+22554, int_stack+10668, int_stack+4116, 28);
 /*--- compute (i0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+48059, int_stack+46799, 28);
 /*--- compute (i0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+28434, int_stack+0, int_stack+7644, 28);
 /*--- compute (i0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+0, int_stack+28434, int_stack+10668, 28);
 /*--- compute (i0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+28434, int_stack+0, int_stack+22554, 28);
 /*--- compute (hp||hg) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+129818, int_stack+28434, int_stack+15939, 315);
 /*--- compute (k0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+50355, int_stack+49599, 36);
 /*--- compute (k0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+2268, int_stack+51363, int_stack+50355, 36);
 /*--- compute (k0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+5292, int_stack+2268, int_stack+0, 36);
 /*--- compute (k0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+9828, int_stack+52659, int_stack+51363, 36);
 /*--- compute (k0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+13716, int_stack+9828, int_stack+2268, 36);
 /*--- compute (k0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+19764, int_stack+13716, int_stack+5292, 36);
 /*--- compute (k0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+54279, int_stack+52659, 36);
 /*--- compute (k0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+37254, int_stack+0, int_stack+9828, 36);
 /*--- compute (k0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+0, int_stack+37254, int_stack+13716, 36);
 /*--- compute (k0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+37254, int_stack+0, int_stack+19764, 36);
 /*--- compute (ip||hg) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+0, int_stack+37254, int_stack+28434, 315);
 /*--- compute (hd|[r12,T2]|hg) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+26460, int_stack+180270, int_stack+160425, 315);
     Libr12->te_ptr[3] = int_stack + 26460;
 /*--- compute (hd|[r12,T1]|hg) ---*/
   t1hrr1_build_hd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+149663, int_stack+286146, int_stack+266301, int_stack+239841, int_stack+103358, int_stack+219996, 5, 4);
     Libr12->te_ptr[2] = int_stack + 149663;
 /*--- compute (hd||hg) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+266301, int_stack+0, int_stack+129818, 315);
     Libr12->te_ptr[1] = int_stack + 266301;
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+66150, int_stack+239841, int_stack+219996, 315);
     Libr12->te_ptr[0] = int_stack + 66150;

}
