/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_hphd(Libr12_t *, prim_data *);

  /* Computes (hp|hd) integrals for linear R12-methods */

void hrr_grt_order_hphd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[5][5] = int_stack + 0;
 Libr12->t2vrr_classes[5][6] = int_stack + 441;
 Libr12->t2vrr_classes[5][7] = int_stack + 1029;
 Libr12->gvrr_classes[7][5] = int_stack + 1785;
 Libr12->t2vrr_classes[6][5] = int_stack + 2541;
 Libr12->gvrr_classes[7][6] = int_stack + 3129;
 Libr12->t2vrr_classes[6][6] = int_stack + 4137;
 Libr12->t2vrr_classes[6][7] = int_stack + 4921;
 Libr12->gvrr_classes[5][8] = int_stack + 5929;
 Libr12->t1vrr_classes[5][5] = int_stack + 6874;
 Libr12->t1vrr_classes[5][6] = int_stack + 7315;
 Libr12->t1vrr_classes[5][7] = int_stack + 7903;
 Libr12->t1vrr_classes[6][5] = int_stack + 8659;
 Libr12->t1vrr_classes[6][6] = int_stack + 9247;
 Libr12->t1vrr_classes[6][7] = int_stack + 10031;
 Libr12->rvrr_classes[5][5] = int_stack + 11039;
 Libr12->rvrr_classes[5][6] = int_stack + 11480;
 Libr12->rvrr_classes[5][7] = int_stack + 12068;
 Libr12->rvrr_classes[6][5] = int_stack + 12824;
 Libr12->rvrr_classes[6][6] = int_stack + 13412;
 Libr12->rvrr_classes[6][7] = int_stack + 14196;
 Libr12->gvrr_classes[5][5] = int_stack + 15204;
 Libr12->gvrr_classes[5][6] = int_stack + 15645;
 Libr12->gvrr_classes[5][7] = int_stack + 16233;
 Libr12->gvrr_classes[6][5] = int_stack + 16989;
 Libr12->gvrr_classes[6][6] = int_stack + 17577;
 Libr12->gvrr_classes[6][7] = int_stack + 18361;
 memset(int_stack,0,19369*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 19369;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_hphd(Libr12, Data);
   Data++;
 }

 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+19369, int_stack+15645, int_stack+15204, 21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+20692, int_stack+17577, int_stack+16989, 28);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+22456, int_stack+16233, int_stack+15645, 21);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+24220, int_stack+441, int_stack+0, int_stack+15645, int_stack+16989, int_stack+15204, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+25543, int_stack+1029, int_stack+441, int_stack+16233, int_stack+17577, int_stack+15645, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+27307, int_stack+25543, int_stack+24220, int_stack+22456, int_stack+20692, int_stack+19369, 5, 0);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+24220, int_stack+3129, int_stack+1785, 36);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+29953, int_stack+18361, int_stack+17577, 28);
 /*--- compute (i0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+4137, int_stack+2541, int_stack+17577, int_stack+1785, int_stack+16989, 6, 0);
 /*--- compute (i0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+32305, int_stack+4921, int_stack+4137, int_stack+18361, int_stack+3129, int_stack+17577, 6, 0);
 /*--- compute (i0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1764, int_stack+32305, int_stack+0, int_stack+29953, int_stack+24220, int_stack+20692, 6, 0);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+24220, int_stack+22456, int_stack+19369, 21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+32305, int_stack+5929, int_stack+16233, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+15204, int_stack+32305, int_stack+22456, 21);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+32305, int_stack+29953, int_stack+20692, 28);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+29953, int_stack+7315, int_stack+6874, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+0, int_stack+7903, int_stack+7315, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+18732, int_stack+0, int_stack+29953, 21);
 /*--- compute (i0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+9247, int_stack+8659, 28);
 /*--- compute (i0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+29953, int_stack+10031, int_stack+9247, 28);
 /*--- compute (i0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+5292, int_stack+29953, int_stack+0, 28);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+11480, int_stack+11039, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+29953, int_stack+12068, int_stack+11480, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+21378, int_stack+29953, int_stack+0, 21);
 /*--- compute (i0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+13412, int_stack+12824, 28);
 /*--- compute (i0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+29953, int_stack+14196, int_stack+13412, 28);
 /*--- compute (i0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+8820, int_stack+29953, int_stack+0, 28);
 /*--- compute (hp|[r12,T2]|hd) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+35833, int_stack+1764, int_stack+27307, 126);
     Libr12->te_ptr[3] = int_stack + 35833;
 /*--- compute (hp|[r12,T1]|hd) ---*/
   t1hrr1_build_hp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+43771, int_stack+5292, int_stack+18732, int_stack+32305, int_stack+15204, int_stack+24220, 5, 2);
     Libr12->te_ptr[2] = int_stack + 43771;
 /*--- compute (hp||hd) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+8820, int_stack+21378, 126);
     Libr12->te_ptr[1] = int_stack + 0;
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+7938, int_stack+32305, int_stack+24220, 126);
     Libr12->te_ptr[0] = int_stack + 7938;

}
