/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_p0gf(Libr12_t *, prim_data *);

  /* Computes (p0|gf) integrals for linear R12-methods */

void hrr_grt_order_p0gf(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[2][4] = int_stack + 0;
 Libr12->t2vrr_classes[1][4] = int_stack + 90;
 Libr12->gvrr_classes[2][5] = int_stack + 135;
 Libr12->t2vrr_classes[1][5] = int_stack + 261;
 Libr12->gvrr_classes[2][6] = int_stack + 324;
 Libr12->t2vrr_classes[1][6] = int_stack + 492;
 Libr12->t2vrr_classes[1][7] = int_stack + 576;
 Libr12->t1vrr_classes[1][4] = int_stack + 684;
 Libr12->t1vrr_classes[1][5] = int_stack + 729;
 Libr12->t1vrr_classes[1][6] = int_stack + 792;
 Libr12->t1vrr_classes[1][7] = int_stack + 876;
 Libr12->rvrr_classes[1][4] = int_stack + 984;
 Libr12->rvrr_classes[1][5] = int_stack + 1029;
 Libr12->rvrr_classes[1][6] = int_stack + 1092;
 Libr12->rvrr_classes[1][7] = int_stack + 1176;
 Libr12->gvrr_classes[1][4] = int_stack + 1284;
 Libr12->gvrr_classes[1][5] = int_stack + 1329;
 Libr12->gvrr_classes[1][6] = int_stack + 1392;
 Libr12->gvrr_classes[1][7] = int_stack + 1476;
 memset(int_stack,0,1584*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 1584;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_p0gf(Libr12, Data);
   Data++;
 }

 /*--- compute (p0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+1584, int_stack+1329, int_stack+1284, 3);
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+1719, int_stack+1392, int_stack+1329, 3);
 /*--- compute (p0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+1908, int_stack+1719, int_stack+1584, 3);
 /*--- compute (d0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+2178, int_stack+135, int_stack+0, 6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+2448, int_stack+324, int_stack+135, 6);
 /*--- compute (d0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+2826, int_stack+2448, int_stack+2178, 6);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+3366, int_stack+1476, int_stack+1392, 3);
 /*--- compute (p0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+3618, int_stack+3366, int_stack+1719, 3);
 /*--- compute (p0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3996, int_stack+261, int_stack+90, int_stack+1329, int_stack+0, int_stack+1284, 1, 0);
 /*--- compute (p0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4131, int_stack+492, int_stack+261, int_stack+1392, int_stack+135, int_stack+1329, 1, 0);
 /*--- compute (p0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+4131, int_stack+3996, int_stack+1719, int_stack+2178, int_stack+1584, 1, 0);
 /*--- compute (p0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2178, int_stack+576, int_stack+492, int_stack+1476, int_stack+324, int_stack+1392, 1, 0);
 /*--- compute (p0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1284, int_stack+2178, int_stack+4131, int_stack+3366, int_stack+2448, int_stack+1719, 1, 0);
 /*--- compute (p0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+3366, int_stack+729, int_stack+684, 3);
 /*--- compute (p0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+2178, int_stack+792, int_stack+729, 3);
 /*--- compute (p0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+2367, int_stack+2178, int_stack+3366, 3);
 /*--- compute (p0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+3366, int_stack+876, int_stack+792, 3);
 /*--- compute (p0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+3996, int_stack+3366, int_stack+2178, 3);
 /*--- compute (p0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+2178, int_stack+1029, int_stack+984, 3);
 /*--- compute (p0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+2637, int_stack+1092, int_stack+1029, 3);
 /*--- compute (p0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+4374, int_stack+2637, int_stack+2178, 3);
 /*--- compute (p0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+3366, int_stack+1176, int_stack+1092, 3);
 /*--- compute (p0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+270, int_stack+3366, int_stack+2637, 3);
 /*--- compute (p0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+648, int_stack+1284, int_stack+0, int_stack+3618, int_stack+2826, int_stack+1908, 1, 0);
     Libr12->te_ptr[3] = int_stack + 648;
 /*--- compute (p0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+2637, int_stack+3996, int_stack+2367, 3);
     Libr12->te_ptr[2] = int_stack + 2637;
 /*--- compute (p0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+3087, int_stack+270, int_stack+4374, 3);
     Libr12->te_ptr[1] = int_stack + 3087;
 /*--- compute (p0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+3996, int_stack+3618, int_stack+1908, 3);
     Libr12->te_ptr[0] = int_stack + 3996;

}
