/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_gpff(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (p0|00)^3 ---*/
 _BUILD_p000(Data,r12vrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (p0|00)^2 ---*/
 _BUILD_p000(Data,r12vrr_stack+3, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (d0|00)^2 ---*/
 _BUILD_d000(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+15, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (p0|p0)^2 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+18, r12vrr_stack+15, r12vrr_stack+12, NULL, NULL, Data->F+3);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+27, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (p0|p0)^1 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+30, r12vrr_stack+27, r12vrr_stack+15, NULL, NULL, Data->F+2);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+39, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+42, r12vrr_stack+12, r12vrr_stack+39, NULL, NULL, Data->F+4);

 /*--- compute (d0|p0)^2 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+51, r12vrr_stack+18, r12vrr_stack+42, r12vrr_stack+15, r12vrr_stack+12, r12vrr_stack+0);

 /*--- compute (d0|p0)^1 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+69, r12vrr_stack+30, r12vrr_stack+18, r12vrr_stack+27, r12vrr_stack+15, r12vrr_stack+3);

 /*--- compute (f0|p0)^1 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+87, r12vrr_stack+69, r12vrr_stack+51, r12vrr_stack+30, r12vrr_stack+18, r12vrr_stack+6);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+117, r12vrr_stack+15, r12vrr_stack+12, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+123, r12vrr_stack+27, r12vrr_stack+15, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+129, r12vrr_stack+12, r12vrr_stack+39, Data->F+3, Data->F+4, NULL);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+135, r12vrr_stack+117, r12vrr_stack+129, NULL, NULL, r12vrr_stack+12);

 /*--- compute (p0|d0)^1 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+153, r12vrr_stack+123, r12vrr_stack+117, NULL, NULL, r12vrr_stack+15);

 /*--- compute (d0|d0)^1 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+171, r12vrr_stack+153, r12vrr_stack+135, r12vrr_stack+123, r12vrr_stack+117, r12vrr_stack+18);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+207, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+210, r12vrr_stack+207, r12vrr_stack+27, Data->F+0, Data->F+1, NULL);

 /*--- compute (p0|d0)^0 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+216, r12vrr_stack+210, r12vrr_stack+123, NULL, NULL, r12vrr_stack+27);

 /*--- compute (d0|d0)^0 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+234, r12vrr_stack+216, r12vrr_stack+153, r12vrr_stack+210, r12vrr_stack+123, r12vrr_stack+30);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+30, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+33, r12vrr_stack+39, r12vrr_stack+30, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+270, r12vrr_stack+129, r12vrr_stack+33, NULL, NULL, r12vrr_stack+39);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+288, r12vrr_stack+135, r12vrr_stack+270, r12vrr_stack+117, r12vrr_stack+129, r12vrr_stack+42);

 /*--- compute (f0|d0)^1 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+324, r12vrr_stack+171, r12vrr_stack+288, r12vrr_stack+153, r12vrr_stack+135, r12vrr_stack+51);

 /*--- compute (f0|d0)^0 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+384, r12vrr_stack+234, r12vrr_stack+171, r12vrr_stack+216, r12vrr_stack+153, r12vrr_stack+69);

 /*--- compute (g0|d0)^0 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+444, r12vrr_stack+384, r12vrr_stack+324, r12vrr_stack+234, r12vrr_stack+171, r12vrr_stack+87);

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+534, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (d0|00)^3 ---*/
 _BUILD_d000(Data,r12vrr_stack+537, r12vrr_stack+0, r12vrr_stack+534, Data->F+3, Data->F+4, NULL);

 /*--- compute (f0|00)^2 ---*/
 _BUILD_f000(Data,r12vrr_stack+543, r12vrr_stack+6, r12vrr_stack+537, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+553, r12vrr_stack+39, r12vrr_stack+30, NULL, NULL, Data->F+5);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+562, r12vrr_stack+42, r12vrr_stack+553, r12vrr_stack+12, r12vrr_stack+39, r12vrr_stack+534);

 /*--- compute (f0|p0)^2 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+580, r12vrr_stack+51, r12vrr_stack+562, r12vrr_stack+18, r12vrr_stack+42, r12vrr_stack+537);

 /*--- compute (g0|p0)^1 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+610, r12vrr_stack+87, r12vrr_stack+580, r12vrr_stack+69, r12vrr_stack+51, r12vrr_stack+543);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+69, r12vrr_stack+30, r12vrr_stack+3, Data->F+5, Data->F+6, NULL);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+655, r12vrr_stack+33, r12vrr_stack+69, NULL, NULL, r12vrr_stack+30);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+673, r12vrr_stack+270, r12vrr_stack+655, r12vrr_stack+129, r12vrr_stack+33, r12vrr_stack+553);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+709, r12vrr_stack+288, r12vrr_stack+673, r12vrr_stack+135, r12vrr_stack+270, r12vrr_stack+562);

 /*--- compute (g0|d0)^1 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+769, r12vrr_stack+324, r12vrr_stack+709, r12vrr_stack+171, r12vrr_stack+288, r12vrr_stack+580);

 /*--- compute (h0|d0)^0 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+859, r12vrr_stack+444, r12vrr_stack+769, r12vrr_stack+384, r12vrr_stack+324, r12vrr_stack+610);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+75, r12vrr_stack+129, r12vrr_stack+33, r12vrr_stack+12, r12vrr_stack+39, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+985, r12vrr_stack+117, r12vrr_stack+129, r12vrr_stack+15, r12vrr_stack+12, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+995, r12vrr_stack+985, r12vrr_stack+75, NULL, NULL, r12vrr_stack+129);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+1025, r12vrr_stack+123, r12vrr_stack+117, r12vrr_stack+27, r12vrr_stack+15, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+1035, r12vrr_stack+1025, r12vrr_stack+985, NULL, NULL, r12vrr_stack+117);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+12, r12vrr_stack+33, r12vrr_stack+69, r12vrr_stack+39, r12vrr_stack+30, NULL);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+1065, r12vrr_stack+75, r12vrr_stack+12, NULL, NULL, r12vrr_stack+33);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1095, r12vrr_stack+995, r12vrr_stack+1065, r12vrr_stack+985, r12vrr_stack+75, r12vrr_stack+270);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1155, r12vrr_stack+1035, r12vrr_stack+995, r12vrr_stack+1025, r12vrr_stack+985, r12vrr_stack+135);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+1215, r12vrr_stack+1155, r12vrr_stack+1095, r12vrr_stack+1035, r12vrr_stack+995, r12vrr_stack+288);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+135, r12vrr_stack+210, r12vrr_stack+123, r12vrr_stack+207, r12vrr_stack+27, NULL);

 /*--- compute (p0|f0)^0 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+1315, r12vrr_stack+135, r12vrr_stack+1025, NULL, NULL, r12vrr_stack+123);

 /*--- compute (d0|f0)^0 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1345, r12vrr_stack+1315, r12vrr_stack+1035, r12vrr_stack+135, r12vrr_stack+1025, r12vrr_stack+153);

 /*--- compute (f0|f0)^0 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+1405, r12vrr_stack+1345, r12vrr_stack+1155, r12vrr_stack+1315, r12vrr_stack+1035, r12vrr_stack+171);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+145, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+148, r12vrr_stack+3, r12vrr_stack+145, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+154, r12vrr_stack+69, r12vrr_stack+148, r12vrr_stack+30, r12vrr_stack+3, NULL);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+164, r12vrr_stack+12, r12vrr_stack+154, NULL, NULL, r12vrr_stack+69);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1505, r12vrr_stack+1065, r12vrr_stack+164, r12vrr_stack+75, r12vrr_stack+12, r12vrr_stack+655);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+1565, r12vrr_stack+1095, r12vrr_stack+1505, r12vrr_stack+995, r12vrr_stack+1065, r12vrr_stack+673);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+1665, r12vrr_stack+1215, r12vrr_stack+1565, r12vrr_stack+1155, r12vrr_stack+1095, r12vrr_stack+709);

 /*--- compute (g0|f0)^0 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+1815, r12vrr_stack+1405, r12vrr_stack+1215, r12vrr_stack+1345, r12vrr_stack+1155, r12vrr_stack+324);
 tmp = r12vrr_stack + 1815;
 target_ptr = Libr12->gvrr_classes[4][3];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|f0)^0 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+1965, r12vrr_stack+1815, r12vrr_stack+1665, r12vrr_stack+1405, r12vrr_stack+1215, r12vrr_stack+769);
 tmp = r12vrr_stack + 1965;
 target_ptr = Libr12->gvrr_classes[5][3];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+2175, r12vrr_stack+985, r12vrr_stack+75, r12vrr_stack+117, r12vrr_stack+129, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+2190, r12vrr_stack+1025, r12vrr_stack+985, r12vrr_stack+123, r12vrr_stack+117, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+2205, r12vrr_stack+75, r12vrr_stack+12, r12vrr_stack+129, r12vrr_stack+33, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+2220, r12vrr_stack+2175, r12vrr_stack+2205, NULL, NULL, r12vrr_stack+75);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+2265, r12vrr_stack+2190, r12vrr_stack+2175, NULL, NULL, r12vrr_stack+985);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2310, r12vrr_stack+2265, r12vrr_stack+2220, r12vrr_stack+2190, r12vrr_stack+2175, r12vrr_stack+995);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+995, r12vrr_stack+135, r12vrr_stack+1025, r12vrr_stack+210, r12vrr_stack+123, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+2400, r12vrr_stack+995, r12vrr_stack+2190, NULL, NULL, r12vrr_stack+1025);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2445, r12vrr_stack+2400, r12vrr_stack+2265, r12vrr_stack+995, r12vrr_stack+2190, r12vrr_stack+1035);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1010, r12vrr_stack+12, r12vrr_stack+154, r12vrr_stack+33, r12vrr_stack+69, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+2535, r12vrr_stack+2205, r12vrr_stack+1010, NULL, NULL, r12vrr_stack+12);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2580, r12vrr_stack+2220, r12vrr_stack+2535, r12vrr_stack+2175, r12vrr_stack+2205, r12vrr_stack+1065);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2670, r12vrr_stack+2310, r12vrr_stack+2580, r12vrr_stack+2265, r12vrr_stack+2220, r12vrr_stack+1095);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2820, r12vrr_stack+2445, r12vrr_stack+2310, r12vrr_stack+2400, r12vrr_stack+2265, r12vrr_stack+1155);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2970, r12vrr_stack+2820, r12vrr_stack+2670, r12vrr_stack+2445, r12vrr_stack+2310, r12vrr_stack+1215);
 tmp = r12vrr_stack + 2970;
 target_ptr = Libr12->gvrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+1155, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+1158, r12vrr_stack+145, r12vrr_stack+1155, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+1164, r12vrr_stack+148, r12vrr_stack+1158, r12vrr_stack+3, r12vrr_stack+145, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1174, r12vrr_stack+154, r12vrr_stack+1164, r12vrr_stack+69, r12vrr_stack+148, NULL);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+3195, r12vrr_stack+1010, r12vrr_stack+1174, NULL, NULL, r12vrr_stack+154);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+3240, r12vrr_stack+2535, r12vrr_stack+3195, r12vrr_stack+2205, r12vrr_stack+1010, r12vrr_stack+164);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+3330, r12vrr_stack+2580, r12vrr_stack+3240, r12vrr_stack+2220, r12vrr_stack+2535, r12vrr_stack+1505);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+3480, r12vrr_stack+2670, r12vrr_stack+3330, r12vrr_stack+2310, r12vrr_stack+2580, r12vrr_stack+1565);

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+3705, r12vrr_stack+2970, r12vrr_stack+3480, r12vrr_stack+2820, r12vrr_stack+2670, r12vrr_stack+1665);
 tmp = r12vrr_stack + 3705;
 target_ptr = Libr12->gvrr_classes[5][4];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1189, r12vrr_stack+2175, r12vrr_stack+2205, r12vrr_stack+985, r12vrr_stack+75, NULL);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1035, r12vrr_stack+2190, r12vrr_stack+2175, r12vrr_stack+1025, r12vrr_stack+985, NULL);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+4020, r12vrr_stack+2205, r12vrr_stack+1010, r12vrr_stack+75, r12vrr_stack+12, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+4041, r12vrr_stack+1189, r12vrr_stack+4020, NULL, NULL, r12vrr_stack+2205);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+4104, r12vrr_stack+1035, r12vrr_stack+1189, NULL, NULL, r12vrr_stack+2175);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+4167, r12vrr_stack+4104, r12vrr_stack+4041, r12vrr_stack+1035, r12vrr_stack+1189, r12vrr_stack+2220);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2220, r12vrr_stack+995, r12vrr_stack+2190, r12vrr_stack+135, r12vrr_stack+1025, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+4293, r12vrr_stack+2220, r12vrr_stack+1035, NULL, NULL, r12vrr_stack+2190);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+4356, r12vrr_stack+4293, r12vrr_stack+4104, r12vrr_stack+2220, r12vrr_stack+1035, r12vrr_stack+2265);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2241, r12vrr_stack+1010, r12vrr_stack+1174, r12vrr_stack+12, r12vrr_stack+154, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+4482, r12vrr_stack+4020, r12vrr_stack+2241, NULL, NULL, r12vrr_stack+1010);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+4545, r12vrr_stack+4041, r12vrr_stack+4482, r12vrr_stack+1189, r12vrr_stack+4020, r12vrr_stack+2535);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+4671, r12vrr_stack+4167, r12vrr_stack+4545, r12vrr_stack+4104, r12vrr_stack+4041, r12vrr_stack+2580);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+4881, r12vrr_stack+4356, r12vrr_stack+4167, r12vrr_stack+4293, r12vrr_stack+4104, r12vrr_stack+2310);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+5091, r12vrr_stack+4881, r12vrr_stack+4671, r12vrr_stack+4356, r12vrr_stack+4167, r12vrr_stack+2670);
 tmp = r12vrr_stack + 5091;
 target_ptr = Libr12->gvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+1025, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+1028, r12vrr_stack+1155, r12vrr_stack+1025, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+985, r12vrr_stack+1158, r12vrr_stack+1028, r12vrr_stack+145, r12vrr_stack+1155, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+2262, r12vrr_stack+1164, r12vrr_stack+985, r12vrr_stack+148, r12vrr_stack+1158, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2277, r12vrr_stack+1174, r12vrr_stack+2262, r12vrr_stack+154, r12vrr_stack+1164, NULL);

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2298, r12vrr_stack+2241, r12vrr_stack+2277, NULL, NULL, r12vrr_stack+1174);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+5406, r12vrr_stack+4482, r12vrr_stack+2298, r12vrr_stack+4020, r12vrr_stack+2241, r12vrr_stack+3195);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+5532, r12vrr_stack+4545, r12vrr_stack+5406, r12vrr_stack+4041, r12vrr_stack+4482, r12vrr_stack+3240);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+5742, r12vrr_stack+4671, r12vrr_stack+5532, r12vrr_stack+4167, r12vrr_stack+4545, r12vrr_stack+3330);

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+6057, r12vrr_stack+5091, r12vrr_stack+5742, r12vrr_stack+4881, r12vrr_stack+4671, r12vrr_stack+3480);
 tmp = r12vrr_stack + 6057;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2361, r12vrr_stack+1189, r12vrr_stack+4020, r12vrr_stack+2175, r12vrr_stack+2205, NULL);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+6498, r12vrr_stack+1035, r12vrr_stack+1189, r12vrr_stack+2190, r12vrr_stack+2175, NULL);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+6526, r12vrr_stack+4020, r12vrr_stack+2241, r12vrr_stack+2205, r12vrr_stack+1010, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+6554, r12vrr_stack+2361, r12vrr_stack+6526, NULL, NULL, r12vrr_stack+4020);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+6638, r12vrr_stack+6498, r12vrr_stack+2361, NULL, NULL, r12vrr_stack+1189);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+6722, r12vrr_stack+6638, r12vrr_stack+6554, r12vrr_stack+6498, r12vrr_stack+2361, r12vrr_stack+4041);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+4041, r12vrr_stack+2220, r12vrr_stack+1035, r12vrr_stack+995, r12vrr_stack+2190, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+6890, r12vrr_stack+4041, r12vrr_stack+6498, NULL, NULL, r12vrr_stack+1035);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+6974, r12vrr_stack+6890, r12vrr_stack+6638, r12vrr_stack+4041, r12vrr_stack+6498, r12vrr_stack+4104);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+4069, r12vrr_stack+2241, r12vrr_stack+2277, r12vrr_stack+1010, r12vrr_stack+1174, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+7142, r12vrr_stack+6526, r12vrr_stack+4069, NULL, NULL, r12vrr_stack+2241);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+7226, r12vrr_stack+6554, r12vrr_stack+7142, r12vrr_stack+2361, r12vrr_stack+6526, r12vrr_stack+4482);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+7394, r12vrr_stack+6722, r12vrr_stack+7226, r12vrr_stack+6638, r12vrr_stack+6554, r12vrr_stack+4545);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+7674, r12vrr_stack+6974, r12vrr_stack+6722, r12vrr_stack+6890, r12vrr_stack+6638, r12vrr_stack+4167);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+7954, r12vrr_stack+7674, r12vrr_stack+7394, r12vrr_stack+6974, r12vrr_stack+6722, r12vrr_stack+4671);
 tmp = r12vrr_stack + 7954;
 target_ptr = Libr12->gvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+145, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+4097, r12vrr_stack+1025, r12vrr_stack+145, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+4103, r12vrr_stack+1028, r12vrr_stack+4097, r12vrr_stack+1155, r12vrr_stack+1025, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+4113, r12vrr_stack+985, r12vrr_stack+4103, r12vrr_stack+1158, r12vrr_stack+1028, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+4128, r12vrr_stack+2262, r12vrr_stack+4113, r12vrr_stack+1164, r12vrr_stack+985, NULL);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+4149, r12vrr_stack+2277, r12vrr_stack+4128, r12vrr_stack+1174, r12vrr_stack+2262, NULL);

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+4177, r12vrr_stack+4069, r12vrr_stack+4149, NULL, NULL, r12vrr_stack+2277);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+8374, r12vrr_stack+7142, r12vrr_stack+4177, r12vrr_stack+6526, r12vrr_stack+4069, r12vrr_stack+2298);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+8542, r12vrr_stack+7226, r12vrr_stack+8374, r12vrr_stack+6554, r12vrr_stack+7142, r12vrr_stack+5406);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+8822, r12vrr_stack+7394, r12vrr_stack+8542, r12vrr_stack+6722, r12vrr_stack+7226, r12vrr_stack+5532);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+9242, r12vrr_stack+7954, r12vrr_stack+8822, r12vrr_stack+7674, r12vrr_stack+7394, r12vrr_stack+5742);
 tmp = r12vrr_stack + 9242;
 target_ptr = Libr12->gvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2175, r12vrr_stack+2361, r12vrr_stack+6526, r12vrr_stack+1189, r12vrr_stack+4020, NULL);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9830, r12vrr_stack+6498, r12vrr_stack+2361, r12vrr_stack+1035, r12vrr_stack+1189, NULL);

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9866, r12vrr_stack+6526, r12vrr_stack+4069, r12vrr_stack+4020, r12vrr_stack+2241, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9902, r12vrr_stack+2175, r12vrr_stack+9866, NULL, NULL, r12vrr_stack+6526);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10010, r12vrr_stack+9830, r12vrr_stack+2175, NULL, NULL, r12vrr_stack+2361);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10118, r12vrr_stack+10010, r12vrr_stack+9902, r12vrr_stack+9830, r12vrr_stack+2175, r12vrr_stack+6554);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2361, r12vrr_stack+4041, r12vrr_stack+6498, r12vrr_stack+2220, r12vrr_stack+1035, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6526, r12vrr_stack+2361, r12vrr_stack+9830, NULL, NULL, r12vrr_stack+6498);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10334, r12vrr_stack+6526, r12vrr_stack+10010, r12vrr_stack+2361, r12vrr_stack+9830, r12vrr_stack+6638);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9830, r12vrr_stack+4069, r12vrr_stack+4149, r12vrr_stack+2241, r12vrr_stack+2277, NULL);

 /*--- compute (p0|k0)^3 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10550, r12vrr_stack+9866, r12vrr_stack+9830, NULL, NULL, r12vrr_stack+4069);

 /*--- compute (d0|k0)^2 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10658, r12vrr_stack+9902, r12vrr_stack+10550, r12vrr_stack+2175, r12vrr_stack+9866, r12vrr_stack+7142);

 /*--- compute (f0|k0)^1 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10874, r12vrr_stack+10118, r12vrr_stack+10658, r12vrr_stack+10010, r12vrr_stack+9902, r12vrr_stack+7226);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+11234, r12vrr_stack+10334, r12vrr_stack+10118, r12vrr_stack+6526, r12vrr_stack+10010, r12vrr_stack+6722);

 /*--- compute (g0|k0)^0 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+11594, r12vrr_stack+11234, r12vrr_stack+10874, r12vrr_stack+10334, r12vrr_stack+10118, r12vrr_stack+7394);
 tmp = r12vrr_stack + 11594;
 target_ptr = Libr12->gvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^5 ---*/
 _BUILD_p000(Data,r12vrr_stack+10334, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (d0|00)^4 ---*/
 _BUILD_d000(Data,r12vrr_stack+10337, r12vrr_stack+534, r12vrr_stack+10334, Data->F+4, Data->F+5, NULL);

 /*--- compute (f0|00)^3 ---*/
 _BUILD_f000(Data,r12vrr_stack+10343, r12vrr_stack+537, r12vrr_stack+10337, r12vrr_stack+0, r12vrr_stack+534, NULL);

 /*--- compute (g0|00)^2 ---*/
 _BUILD_g000(Data,r12vrr_stack+10353, r12vrr_stack+543, r12vrr_stack+10343, r12vrr_stack+6, r12vrr_stack+537, NULL);

 /*--- compute (p0|p0)^5 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+1155, r12vrr_stack+30, r12vrr_stack+3, NULL, NULL, Data->F+6);

 /*--- compute (d0|p0)^4 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+117, r12vrr_stack+553, r12vrr_stack+1155, r12vrr_stack+39, r12vrr_stack+30, r12vrr_stack+10334);

 /*--- compute (f0|p0)^3 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+10368, r12vrr_stack+562, r12vrr_stack+117, r12vrr_stack+42, r12vrr_stack+553, r12vrr_stack+10337);

 /*--- compute (g0|p0)^2 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+2175, r12vrr_stack+580, r12vrr_stack+10368, r12vrr_stack+51, r12vrr_stack+562, r12vrr_stack+10343);

 /*--- compute (h0|p0)^1 ---*/
 _BUILD_h0p0(Data,r12vrr_stack+10398, r12vrr_stack+610, r12vrr_stack+2175, r12vrr_stack+87, r12vrr_stack+580, r12vrr_stack+10353);

 /*--- compute (p0|d0)^5 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+10334, r12vrr_stack+69, r12vrr_stack+148, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^4 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+534, r12vrr_stack+655, r12vrr_stack+10334, r12vrr_stack+33, r12vrr_stack+69, r12vrr_stack+1155);

 /*--- compute (f0|d0)^3 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+570, r12vrr_stack+673, r12vrr_stack+534, r12vrr_stack+270, r12vrr_stack+655, r12vrr_stack+117);

 /*--- compute (g0|d0)^2 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+10010, r12vrr_stack+709, r12vrr_stack+570, r12vrr_stack+288, r12vrr_stack+673, r12vrr_stack+10368);

 /*--- compute (h0|d0)^1 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+6498, r12vrr_stack+769, r12vrr_stack+10010, r12vrr_stack+324, r12vrr_stack+709, r12vrr_stack+2175);

 /*--- compute (i0|d0)^0 ---*/
 _BUILD_i0d0(Data,r12vrr_stack+6624, r12vrr_stack+859, r12vrr_stack+6498, r12vrr_stack+444, r12vrr_stack+769, r12vrr_stack+10398);

 /*--- compute (p0|f0)^5 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+2175, r12vrr_stack+154, r12vrr_stack+1164, NULL, NULL, r12vrr_stack+148);

 /*--- compute (d0|f0)^4 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+270, r12vrr_stack+164, r12vrr_stack+2175, r12vrr_stack+12, r12vrr_stack+154, r12vrr_stack+10334);

 /*--- compute (f0|f0)^3 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+10334, r12vrr_stack+1505, r12vrr_stack+270, r12vrr_stack+1065, r12vrr_stack+164, r12vrr_stack+534);

 /*--- compute (g0|f0)^2 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+630, r12vrr_stack+1565, r12vrr_stack+10334, r12vrr_stack+1095, r12vrr_stack+1505, r12vrr_stack+570);

 /*--- compute (h0|f0)^1 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+12134, r12vrr_stack+1665, r12vrr_stack+630, r12vrr_stack+1215, r12vrr_stack+1565, r12vrr_stack+10010);

 /*--- compute (i0|f0)^0 ---*/
 _BUILD_i0f0(Data,r12vrr_stack+12344, r12vrr_stack+1965, r12vrr_stack+12134, r12vrr_stack+1815, r12vrr_stack+1665, r12vrr_stack+6498);
 tmp = r12vrr_stack + 12344;
 target_ptr = Libr12->gvrr_classes[6][3];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|g0)^5 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+6498, r12vrr_stack+1174, r12vrr_stack+2262, NULL, NULL, r12vrr_stack+1164);

 /*--- compute (d0|g0)^4 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+10010, r12vrr_stack+3195, r12vrr_stack+6498, r12vrr_stack+1010, r12vrr_stack+1174, r12vrr_stack+2175);

 /*--- compute (f0|g0)^3 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1505, r12vrr_stack+3240, r12vrr_stack+10010, r12vrr_stack+2535, r12vrr_stack+3195, r12vrr_stack+270);

 /*--- compute (g0|g0)^2 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1034, r12vrr_stack+3330, r12vrr_stack+1505, r12vrr_stack+2580, r12vrr_stack+3240, r12vrr_stack+10334);

 /*--- compute (h0|g0)^1 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+12624, r12vrr_stack+3480, r12vrr_stack+1034, r12vrr_stack+2670, r12vrr_stack+3330, r12vrr_stack+630);

 /*--- compute (i0|g0)^0 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+12939, r12vrr_stack+3705, r12vrr_stack+12624, r12vrr_stack+2970, r12vrr_stack+3480, r12vrr_stack+12134);
 tmp = r12vrr_stack + 12939;
 target_ptr = Libr12->gvrr_classes[6][4];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|h0)^5 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+12134, r12vrr_stack+2277, r12vrr_stack+4128, NULL, NULL, r12vrr_stack+2262);

 /*--- compute (d0|h0)^4 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+12197, r12vrr_stack+2298, r12vrr_stack+12134, r12vrr_stack+2241, r12vrr_stack+2277, r12vrr_stack+6498);

 /*--- compute (f0|h0)^3 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+10334, r12vrr_stack+5406, r12vrr_stack+12197, r12vrr_stack+4482, r12vrr_stack+2298, r12vrr_stack+10010);

 /*--- compute (g0|h0)^2 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+3195, r12vrr_stack+5532, r12vrr_stack+10334, r12vrr_stack+4545, r12vrr_stack+5406, r12vrr_stack+1505);

 /*--- compute (h0|h0)^1 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+13359, r12vrr_stack+5742, r12vrr_stack+3195, r12vrr_stack+4671, r12vrr_stack+5532, r12vrr_stack+1034);

 /*--- compute (i0|h0)^0 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+13800, r12vrr_stack+6057, r12vrr_stack+13359, r12vrr_stack+5091, r12vrr_stack+5742, r12vrr_stack+12624);
 tmp = r12vrr_stack + 13800;
 target_ptr = Libr12->gvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^11 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12624, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /*--- compute (00|d0)^10 ---*/
 _BUILD_00d0(Data,r12vrr_stack+10544, r12vrr_stack+145, r12vrr_stack+12624, Data->F+10, Data->F+11, NULL);

 /*--- compute (00|f0)^9 ---*/
 _BUILD_00f0(Data,r12vrr_stack+12624, r12vrr_stack+4097, r12vrr_stack+10544, r12vrr_stack+1025, r12vrr_stack+145, NULL);

 /*--- compute (00|g0)^8 ---*/
 _BUILD_00g0(Data,r12vrr_stack+145, r12vrr_stack+4103, r12vrr_stack+12624, r12vrr_stack+1028, r12vrr_stack+4097, NULL);

 /*--- compute (00|h0)^7 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2241, r12vrr_stack+4113, r12vrr_stack+145, r12vrr_stack+985, r12vrr_stack+4103, NULL);

 /*--- compute (00|i0)^6 ---*/
 _BUILD_00i0(Data,r12vrr_stack+145, r12vrr_stack+4128, r12vrr_stack+2241, r12vrr_stack+2262, r12vrr_stack+4113, NULL);

 /*--- compute (p0|i0)^5 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+12624, r12vrr_stack+4149, r12vrr_stack+145, NULL, NULL, r12vrr_stack+4128);

 /*--- compute (d0|i0)^4 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+12708, r12vrr_stack+4177, r12vrr_stack+12624, r12vrr_stack+4069, r12vrr_stack+4149, r12vrr_stack+12134);

 /*--- compute (f0|i0)^3 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+1505, r12vrr_stack+8374, r12vrr_stack+12708, r12vrr_stack+7142, r12vrr_stack+4177, r12vrr_stack+12197);

 /*--- compute (g0|i0)^2 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+5406, r12vrr_stack+8542, r12vrr_stack+1505, r12vrr_stack+7226, r12vrr_stack+8374, r12vrr_stack+10334);

 /*--- compute (h0|i0)^1 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+14388, r12vrr_stack+8822, r12vrr_stack+5406, r12vrr_stack+7394, r12vrr_stack+8542, r12vrr_stack+3195);

 /*--- compute (i0|i0)^0 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+14976, r12vrr_stack+9242, r12vrr_stack+14388, r12vrr_stack+7954, r12vrr_stack+8822, r12vrr_stack+13359);

 /*--- compute (00|k0)^5 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2241, r12vrr_stack+4149, r12vrr_stack+145, r12vrr_stack+2277, r12vrr_stack+4128, NULL);

 /*--- compute (p0|k0)^4 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10010, r12vrr_stack+9830, r12vrr_stack+2241, NULL, NULL, r12vrr_stack+4149);

 /*--- compute (d0|k0)^3 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10334, r12vrr_stack+10550, r12vrr_stack+10010, r12vrr_stack+9866, r12vrr_stack+9830, r12vrr_stack+4177);

 /*--- compute (f0|k0)^2 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+13359, r12vrr_stack+10658, r12vrr_stack+10334, r12vrr_stack+9902, r12vrr_stack+10550, r12vrr_stack+8374);

 /*--- compute (g0|k0)^1 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14388, r12vrr_stack+10874, r12vrr_stack+13359, r12vrr_stack+10118, r12vrr_stack+10658, r12vrr_stack+8542);

 /*--- compute (h0|k0)^0 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9830, r12vrr_stack+11594, r12vrr_stack+14388, r12vrr_stack+11234, r12vrr_stack+10874, r12vrr_stack+8822);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+14388, &(Data->ss_r12_ss), NULL, r12vrr_stack+207, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+14391, r12vrr_stack+14388, &(Data->ss_r12_ss), r12vrr_stack+210, r12vrr_stack+207, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+985, r12vrr_stack+14391, r12vrr_stack+14388, r12vrr_stack+135, r12vrr_stack+210, r12vrr_stack+207, NULL);

 /*--- compute (p0||f0)^0 ---*/
 _R_BUILD_p0f0(Data,r12vrr_stack+14397, r12vrr_stack+985, NULL, r12vrr_stack+1315, r12vrr_stack+135, NULL, r12vrr_stack+210);

 /*--- compute (d0||f0)^0 ---*/
 _R_BUILD_d0f0(Data,r12vrr_stack+14427, r12vrr_stack+14397, r12vrr_stack+985, r12vrr_stack+1345, r12vrr_stack+1315, r12vrr_stack+135, r12vrr_stack+216);

 /*--- compute (f0||f0)^0 ---*/
 _R_BUILD_f0f0(Data,r12vrr_stack+14487, r12vrr_stack+14427, r12vrr_stack+14397, r12vrr_stack+1405, r12vrr_stack+1345, r12vrr_stack+1315, r12vrr_stack+234);

 /*--- compute (g0||f0)^0 ---*/
 _R_BUILD_g0f0(Data,r12vrr_stack+216, r12vrr_stack+14487, r12vrr_stack+14427, r12vrr_stack+1815, r12vrr_stack+1405, r12vrr_stack+1345, r12vrr_stack+384);
 tmp = r12vrr_stack + 216;
 target_ptr = Libr12->rvrr_classes[4][3];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+14397, r12vrr_stack+985, r12vrr_stack+14391, r12vrr_stack+995, r12vrr_stack+135, r12vrr_stack+210, NULL);

 /*--- compute (p0||g0)^0 ---*/
 _R_BUILD_p0g0(Data,r12vrr_stack+2175, r12vrr_stack+14397, NULL, r12vrr_stack+2400, r12vrr_stack+995, NULL, r12vrr_stack+135);

 /*--- compute (d0||g0)^0 ---*/
 _R_BUILD_d0g0(Data,r12vrr_stack+14587, r12vrr_stack+2175, r12vrr_stack+14397, r12vrr_stack+2445, r12vrr_stack+2400, r12vrr_stack+995, r12vrr_stack+1315);

 /*--- compute (f0||g0)^0 ---*/
 _R_BUILD_f0g0(Data,r12vrr_stack+14677, r12vrr_stack+14587, r12vrr_stack+2175, r12vrr_stack+2820, r12vrr_stack+2445, r12vrr_stack+2400, r12vrr_stack+1345);

 /*--- compute (g0||g0)^0 ---*/
 _R_BUILD_g0g0(Data,r12vrr_stack+13359, r12vrr_stack+14677, r12vrr_stack+14587, r12vrr_stack+2970, r12vrr_stack+2820, r12vrr_stack+2445, r12vrr_stack+1405);
 tmp = r12vrr_stack + 13359;
 target_ptr = Libr12->rvrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+4020, r12vrr_stack+14397, r12vrr_stack+985, r12vrr_stack+2220, r12vrr_stack+995, r12vrr_stack+135, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+14587, r12vrr_stack+4020, NULL, r12vrr_stack+4293, r12vrr_stack+2220, NULL, r12vrr_stack+995);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+6498, r12vrr_stack+14587, r12vrr_stack+4020, r12vrr_stack+4356, r12vrr_stack+4293, r12vrr_stack+2220, r12vrr_stack+2400);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+12134, r12vrr_stack+6498, r12vrr_stack+14587, r12vrr_stack+4881, r12vrr_stack+4356, r12vrr_stack+4293, r12vrr_stack+2445);

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+12624, r12vrr_stack+12134, r12vrr_stack+6498, r12vrr_stack+5091, r12vrr_stack+4881, r12vrr_stack+4356, r12vrr_stack+2820);
 tmp = r12vrr_stack + 12624;
 target_ptr = Libr12->rvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+6498, r12vrr_stack+4020, r12vrr_stack+14397, r12vrr_stack+4041, r12vrr_stack+2220, r12vrr_stack+995, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+6526, r12vrr_stack+6498, NULL, r12vrr_stack+6890, r12vrr_stack+4041, NULL, r12vrr_stack+2220);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+985, r12vrr_stack+6526, r12vrr_stack+6498, r12vrr_stack+6974, r12vrr_stack+6890, r12vrr_stack+4041, r12vrr_stack+4293);

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+4020, r12vrr_stack+985, r12vrr_stack+6526, r12vrr_stack+7674, r12vrr_stack+6974, r12vrr_stack+6890, r12vrr_stack+4356);

 /*--- compute (g0||i0)^0 ---*/
 _R_BUILD_g0i0(Data,r12vrr_stack+4300, r12vrr_stack+4020, r12vrr_stack+985, r12vrr_stack+7954, r12vrr_stack+7674, r12vrr_stack+6974, r12vrr_stack+4881);
 tmp = r12vrr_stack + 4300;
 target_ptr = Libr12->rvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|f0)^0 ---*/
 _T2_BUILD_g0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+985, r12vrr_stack+1815, r12vrr_stack+2970, r12vrr_stack+1965, r12vrr_stack+859, r12vrr_stack+444);
 tmp = r12vrr_stack + 985;
 target_ptr = Libr12->t2vrr_classes[4][3];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_g0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1135, r12vrr_stack+2970, r12vrr_stack+5091, r12vrr_stack+3705, r12vrr_stack+1965, r12vrr_stack+1815);
 tmp = r12vrr_stack + 1135;
 target_ptr = Libr12->t2vrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2175, r12vrr_stack+5091, r12vrr_stack+7954, r12vrr_stack+6057, r12vrr_stack+3705, r12vrr_stack+2970);
 tmp = r12vrr_stack + 2175;
 target_ptr = Libr12->t2vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+8374, r12vrr_stack+7954, r12vrr_stack+11594, r12vrr_stack+9242, r12vrr_stack+6057, r12vrr_stack+5091);
 tmp = r12vrr_stack + 8374;
 target_ptr = Libr12->t2vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|f0)^0 ---*/
 _T2_BUILD_h0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2490, r12vrr_stack+1965, r12vrr_stack+3705, r12vrr_stack+12344, r12vrr_stack+6624, r12vrr_stack+859);
 tmp = r12vrr_stack + 2490;
 target_ptr = Libr12->t2vrr_classes[5][3];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_h0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+6498, r12vrr_stack+3705, r12vrr_stack+6057, r12vrr_stack+12939, r12vrr_stack+12344, r12vrr_stack+1965);
 tmp = r12vrr_stack + 6498;
 target_ptr = Libr12->t2vrr_classes[5][4];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+6813, r12vrr_stack+6057, r12vrr_stack+9242, r12vrr_stack+13800, r12vrr_stack+12939, r12vrr_stack+3705);
 tmp = r12vrr_stack + 6813;
 target_ptr = Libr12->t2vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+10586, r12vrr_stack+9242, r12vrr_stack+9830, r12vrr_stack+14976, r12vrr_stack+13800, r12vrr_stack+6057);
 tmp = r12vrr_stack + 10586;
 target_ptr = Libr12->t2vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|f0)^0 ---*/
 _T1_BUILD_g0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7254, r12vrr_stack+1815, r12vrr_stack+1965, r12vrr_stack+2970, r12vrr_stack+2820, r12vrr_stack+1405);
 tmp = r12vrr_stack + 7254;
 target_ptr = Libr12->t1vrr_classes[4][3];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_g0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7404, r12vrr_stack+2970, r12vrr_stack+3705, r12vrr_stack+5091, r12vrr_stack+4881, r12vrr_stack+2820);
 tmp = r12vrr_stack + 7404;
 target_ptr = Libr12->t1vrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+8794, r12vrr_stack+5091, r12vrr_stack+6057, r12vrr_stack+7954, r12vrr_stack+7674, r12vrr_stack+4881);
 tmp = r12vrr_stack + 8794;
 target_ptr = Libr12->t1vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3195, r12vrr_stack+7954, r12vrr_stack+9242, r12vrr_stack+11594, r12vrr_stack+11234, r12vrr_stack+7674);
 tmp = r12vrr_stack + 3195;
 target_ptr = Libr12->t1vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|f0)^0 ---*/
 _T1_BUILD_h0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+13584, r12vrr_stack+1965, r12vrr_stack+12344, r12vrr_stack+3705, r12vrr_stack+2970, r12vrr_stack+1815);
 tmp = r12vrr_stack + 13584;
 target_ptr = Libr12->t1vrr_classes[5][3];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_h0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+11174, r12vrr_stack+3705, r12vrr_stack+12939, r12vrr_stack+6057, r12vrr_stack+5091, r12vrr_stack+2970);
 tmp = r12vrr_stack + 11174;
 target_ptr = Libr12->t1vrr_classes[5][4];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5406, r12vrr_stack+6057, r12vrr_stack+13800, r12vrr_stack+9242, r12vrr_stack+7954, r12vrr_stack+5091);
 tmp = r12vrr_stack + 5406;
 target_ptr = Libr12->t1vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+13794, r12vrr_stack+9242, r12vrr_stack+14976, r12vrr_stack+9830, r12vrr_stack+11594, r12vrr_stack+7954);
 tmp = r12vrr_stack + 13794;
 target_ptr = Libr12->t1vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||f0)^0 ---*/
 _R_BUILD_h0f0(Data,r12vrr_stack+5847, r12vrr_stack+216, r12vrr_stack+14487, r12vrr_stack+1965, r12vrr_stack+1815, r12vrr_stack+1405, r12vrr_stack+444);
 tmp = r12vrr_stack + 5847;
 target_ptr = Libr12->rvrr_classes[5][3];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||g0)^0 ---*/
 _R_BUILD_h0g0(Data,r12vrr_stack+9830, r12vrr_stack+13359, r12vrr_stack+14677, r12vrr_stack+3705, r12vrr_stack+2970, r12vrr_stack+2820, r12vrr_stack+1815);
 tmp = r12vrr_stack + 9830;
 target_ptr = Libr12->rvrr_classes[5][4];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||h0)^0 ---*/
 _R_BUILD_h0h0(Data,r12vrr_stack+10145, r12vrr_stack+12624, r12vrr_stack+12134, r12vrr_stack+6057, r12vrr_stack+5091, r12vrr_stack+4881, r12vrr_stack+2970);
 tmp = r12vrr_stack + 10145;
 target_ptr = Libr12->rvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||i0)^0 ---*/
 _R_BUILD_h0i0(Data,r12vrr_stack+1360, r12vrr_stack+4300, r12vrr_stack+4020, r12vrr_stack+9242, r12vrr_stack+7954, r12vrr_stack+7674, r12vrr_stack+5091);
 tmp = r12vrr_stack + 1360;
 target_ptr = Libr12->rvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];


}

