/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_h0gg(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (p0|00)^3 ---*/
 _BUILD_p000(Data,r12vrr_stack+3, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (d0|00)^3 ---*/
 _BUILD_d000(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+15, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+18, r12vrr_stack+15, r12vrr_stack+12, NULL, NULL, Data->F+4);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+27, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (p0|p0)^2 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+30, r12vrr_stack+27, r12vrr_stack+15, NULL, NULL, Data->F+3);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+39, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+42, r12vrr_stack+12, r12vrr_stack+39, NULL, NULL, Data->F+5);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+51, r12vrr_stack+18, r12vrr_stack+42, r12vrr_stack+15, r12vrr_stack+12, r12vrr_stack+0);

 /*--- compute (d0|p0)^2 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+69, r12vrr_stack+30, r12vrr_stack+18, r12vrr_stack+27, r12vrr_stack+15, r12vrr_stack+3);

 /*--- compute (f0|p0)^2 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+87, r12vrr_stack+69, r12vrr_stack+51, r12vrr_stack+30, r12vrr_stack+18, r12vrr_stack+6);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+117, r12vrr_stack+15, r12vrr_stack+12, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+123, r12vrr_stack+27, r12vrr_stack+15, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+129, r12vrr_stack+12, r12vrr_stack+39, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+135, r12vrr_stack+117, r12vrr_stack+129, NULL, NULL, r12vrr_stack+12);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+153, r12vrr_stack+123, r12vrr_stack+117, NULL, NULL, r12vrr_stack+15);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+171, r12vrr_stack+153, r12vrr_stack+135, r12vrr_stack+123, r12vrr_stack+117, r12vrr_stack+18);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+207, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+210, r12vrr_stack+207, r12vrr_stack+27, Data->F+1, Data->F+2, NULL);

 /*--- compute (p0|d0)^1 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+216, r12vrr_stack+210, r12vrr_stack+123, NULL, NULL, r12vrr_stack+27);

 /*--- compute (d0|d0)^1 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+234, r12vrr_stack+216, r12vrr_stack+153, r12vrr_stack+210, r12vrr_stack+123, r12vrr_stack+30);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+30, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+33, r12vrr_stack+39, r12vrr_stack+30, Data->F+5, Data->F+6, NULL);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+270, r12vrr_stack+129, r12vrr_stack+33, NULL, NULL, r12vrr_stack+39);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+288, r12vrr_stack+135, r12vrr_stack+270, r12vrr_stack+117, r12vrr_stack+129, r12vrr_stack+42);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+324, r12vrr_stack+171, r12vrr_stack+288, r12vrr_stack+153, r12vrr_stack+135, r12vrr_stack+51);

 /*--- compute (f0|d0)^1 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+384, r12vrr_stack+234, r12vrr_stack+171, r12vrr_stack+216, r12vrr_stack+153, r12vrr_stack+69);

 /*--- compute (g0|d0)^1 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+444, r12vrr_stack+384, r12vrr_stack+324, r12vrr_stack+234, r12vrr_stack+171, r12vrr_stack+87);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+534, r12vrr_stack+117, r12vrr_stack+129, r12vrr_stack+15, r12vrr_stack+12, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+544, r12vrr_stack+123, r12vrr_stack+117, r12vrr_stack+27, r12vrr_stack+15, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+554, r12vrr_stack+544, r12vrr_stack+534, NULL, NULL, r12vrr_stack+117);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+584, r12vrr_stack+210, r12vrr_stack+123, r12vrr_stack+207, r12vrr_stack+27, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+594, r12vrr_stack+584, r12vrr_stack+544, NULL, NULL, r12vrr_stack+123);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+624, r12vrr_stack+129, r12vrr_stack+33, r12vrr_stack+12, r12vrr_stack+39, NULL);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+634, r12vrr_stack+534, r12vrr_stack+624, NULL, NULL, r12vrr_stack+129);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+664, r12vrr_stack+554, r12vrr_stack+634, r12vrr_stack+544, r12vrr_stack+534, r12vrr_stack+135);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+724, r12vrr_stack+594, r12vrr_stack+554, r12vrr_stack+584, r12vrr_stack+544, r12vrr_stack+153);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+784, r12vrr_stack+724, r12vrr_stack+664, r12vrr_stack+594, r12vrr_stack+554, r12vrr_stack+171);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+27, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+153, r12vrr_stack+27, r12vrr_stack+207, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+159, r12vrr_stack+153, r12vrr_stack+210, r12vrr_stack+27, r12vrr_stack+207, NULL);

 /*--- compute (p0|f0)^0 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+884, r12vrr_stack+159, r12vrr_stack+584, NULL, NULL, r12vrr_stack+210);

 /*--- compute (d0|f0)^0 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+914, r12vrr_stack+884, r12vrr_stack+594, r12vrr_stack+159, r12vrr_stack+584, r12vrr_stack+216);

 /*--- compute (f0|f0)^0 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+974, r12vrr_stack+914, r12vrr_stack+724, r12vrr_stack+884, r12vrr_stack+594, r12vrr_stack+234);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+207, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+216, r12vrr_stack+30, r12vrr_stack+207, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+222, r12vrr_stack+33, r12vrr_stack+216, r12vrr_stack+39, r12vrr_stack+30, NULL);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+232, r12vrr_stack+624, r12vrr_stack+222, NULL, NULL, r12vrr_stack+33);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1074, r12vrr_stack+634, r12vrr_stack+232, r12vrr_stack+534, r12vrr_stack+624, r12vrr_stack+270);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+1134, r12vrr_stack+664, r12vrr_stack+1074, r12vrr_stack+554, r12vrr_stack+634, r12vrr_stack+288);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+1234, r12vrr_stack+784, r12vrr_stack+1134, r12vrr_stack+724, r12vrr_stack+664, r12vrr_stack+324);

 /*--- compute (g0|f0)^0 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+1384, r12vrr_stack+974, r12vrr_stack+784, r12vrr_stack+914, r12vrr_stack+724, r12vrr_stack+384);

 /*--- compute (h0|f0)^0 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+1534, r12vrr_stack+1384, r12vrr_stack+1234, r12vrr_stack+974, r12vrr_stack+784, r12vrr_stack+444);

 /*--- compute (p0|00)^5 ---*/
 _BUILD_p000(Data,r12vrr_stack+15, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (d0|00)^4 ---*/
 _BUILD_d000(Data,r12vrr_stack+262, r12vrr_stack+0, r12vrr_stack+15, Data->F+4, Data->F+5, NULL);

 /*--- compute (f0|00)^3 ---*/
 _BUILD_f000(Data,r12vrr_stack+1744, r12vrr_stack+6, r12vrr_stack+262, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (p0|p0)^5 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+0, r12vrr_stack+39, r12vrr_stack+30, NULL, NULL, Data->F+6);

 /*--- compute (d0|p0)^4 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+1754, r12vrr_stack+42, r12vrr_stack+0, r12vrr_stack+12, r12vrr_stack+39, r12vrr_stack+15);

 /*--- compute (f0|p0)^3 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+1772, r12vrr_stack+51, r12vrr_stack+1754, r12vrr_stack+18, r12vrr_stack+42, r12vrr_stack+262);

 /*--- compute (g0|p0)^2 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+1802, r12vrr_stack+87, r12vrr_stack+1772, r12vrr_stack+69, r12vrr_stack+51, r12vrr_stack+1744);

 /*--- compute (p0|d0)^5 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+9, r12vrr_stack+33, r12vrr_stack+216, NULL, NULL, r12vrr_stack+30);

 /*--- compute (d0|d0)^4 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+39, r12vrr_stack+270, r12vrr_stack+9, r12vrr_stack+129, r12vrr_stack+33, r12vrr_stack+0);

 /*--- compute (f0|d0)^3 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+1847, r12vrr_stack+288, r12vrr_stack+39, r12vrr_stack+135, r12vrr_stack+270, r12vrr_stack+1754);

 /*--- compute (g0|d0)^2 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+1907, r12vrr_stack+324, r12vrr_stack+1847, r12vrr_stack+171, r12vrr_stack+288, r12vrr_stack+1772);

 /*--- compute (h0|d0)^1 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+1997, r12vrr_stack+444, r12vrr_stack+1907, r12vrr_stack+384, r12vrr_stack+324, r12vrr_stack+1802);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+135, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+138, r12vrr_stack+207, r12vrr_stack+135, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+1744, r12vrr_stack+216, r12vrr_stack+138, r12vrr_stack+30, r12vrr_stack+207, NULL);

 /*--- compute (p0|f0)^5 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+1754, r12vrr_stack+222, r12vrr_stack+1744, NULL, NULL, r12vrr_stack+216);

 /*--- compute (d0|f0)^4 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1784, r12vrr_stack+232, r12vrr_stack+1754, r12vrr_stack+624, r12vrr_stack+222, r12vrr_stack+9);

 /*--- compute (f0|f0)^3 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+262, r12vrr_stack+1074, r12vrr_stack+1784, r12vrr_stack+634, r12vrr_stack+232, r12vrr_stack+39);

 /*--- compute (g0|f0)^2 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+362, r12vrr_stack+1134, r12vrr_stack+262, r12vrr_stack+664, r12vrr_stack+1074, r12vrr_stack+1847);

 /*--- compute (h0|f0)^1 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+2123, r12vrr_stack+1234, r12vrr_stack+362, r12vrr_stack+784, r12vrr_stack+1134, r12vrr_stack+1907);

 /*--- compute (i0|f0)^0 ---*/
 _BUILD_i0f0(Data,r12vrr_stack+2333, r12vrr_stack+1534, r12vrr_stack+2123, r12vrr_stack+1384, r12vrr_stack+1234, r12vrr_stack+1997);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+39, r12vrr_stack+534, r12vrr_stack+624, r12vrr_stack+117, r12vrr_stack+129, NULL);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+54, r12vrr_stack+544, r12vrr_stack+534, r12vrr_stack+123, r12vrr_stack+117, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+69, r12vrr_stack+624, r12vrr_stack+222, r12vrr_stack+129, r12vrr_stack+33, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1844, r12vrr_stack+39, r12vrr_stack+69, NULL, NULL, r12vrr_stack+624);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1889, r12vrr_stack+54, r12vrr_stack+39, NULL, NULL, r12vrr_stack+534);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1934, r12vrr_stack+1889, r12vrr_stack+1844, r12vrr_stack+54, r12vrr_stack+39, r12vrr_stack+634);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+634, r12vrr_stack+584, r12vrr_stack+544, r12vrr_stack+210, r12vrr_stack+123, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+84, r12vrr_stack+634, r12vrr_stack+54, NULL, NULL, r12vrr_stack+544);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2024, r12vrr_stack+84, r12vrr_stack+1889, r12vrr_stack+634, r12vrr_stack+54, r12vrr_stack+554);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+649, r12vrr_stack+222, r12vrr_stack+1744, r12vrr_stack+33, r12vrr_stack+216, NULL);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+2613, r12vrr_stack+69, r12vrr_stack+649, NULL, NULL, r12vrr_stack+222);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2658, r12vrr_stack+1844, r12vrr_stack+2613, r12vrr_stack+39, r12vrr_stack+69, r12vrr_stack+232);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2748, r12vrr_stack+1934, r12vrr_stack+2658, r12vrr_stack+1889, r12vrr_stack+1844, r12vrr_stack+1074);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2898, r12vrr_stack+2024, r12vrr_stack+1934, r12vrr_stack+84, r12vrr_stack+1889, r12vrr_stack+664);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+3048, r12vrr_stack+2898, r12vrr_stack+2748, r12vrr_stack+2024, r12vrr_stack+1934, r12vrr_stack+1134);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+664, r12vrr_stack+159, r12vrr_stack+584, r12vrr_stack+153, r12vrr_stack+210, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+679, r12vrr_stack+664, r12vrr_stack+634, NULL, NULL, r12vrr_stack+584);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1074, r12vrr_stack+679, r12vrr_stack+84, r12vrr_stack+664, r12vrr_stack+634, r12vrr_stack+594);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+3273, r12vrr_stack+1074, r12vrr_stack+2024, r12vrr_stack+679, r12vrr_stack+84, r12vrr_stack+724);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+3423, r12vrr_stack+3273, r12vrr_stack+2898, r12vrr_stack+1074, r12vrr_stack+2024, r12vrr_stack+784);

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+724, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+210, r12vrr_stack+135, r12vrr_stack+724, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+727, r12vrr_stack+138, r12vrr_stack+210, r12vrr_stack+207, r12vrr_stack+135, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+737, r12vrr_stack+1744, r12vrr_stack+727, r12vrr_stack+216, r12vrr_stack+138, NULL);

 /*--- compute (p0|g0)^5 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+752, r12vrr_stack+649, r12vrr_stack+737, NULL, NULL, r12vrr_stack+1744);

 /*--- compute (d0|g0)^4 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+3648, r12vrr_stack+2613, r12vrr_stack+752, r12vrr_stack+69, r12vrr_stack+649, r12vrr_stack+1754);

 /*--- compute (f0|g0)^3 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+3738, r12vrr_stack+2658, r12vrr_stack+3648, r12vrr_stack+1844, r12vrr_stack+2613, r12vrr_stack+1784);

 /*--- compute (g0|g0)^2 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+3888, r12vrr_stack+2748, r12vrr_stack+3738, r12vrr_stack+1934, r12vrr_stack+2658, r12vrr_stack+262);

 /*--- compute (h0|g0)^1 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+4113, r12vrr_stack+3048, r12vrr_stack+3888, r12vrr_stack+2898, r12vrr_stack+2748, r12vrr_stack+362);

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+4428, r12vrr_stack+3423, r12vrr_stack+3048, r12vrr_stack+3273, r12vrr_stack+2898, r12vrr_stack+1234);
 tmp = r12vrr_stack + 4428;
 target_ptr = Libr12->gvrr_classes[5][4];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (i0|g0)^0 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+4743, r12vrr_stack+4428, r12vrr_stack+4113, r12vrr_stack+3423, r12vrr_stack+3048, r12vrr_stack+2123);
 tmp = r12vrr_stack + 4743;
 target_ptr = Libr12->gvrr_classes[6][4];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1754, r12vrr_stack+39, r12vrr_stack+69, r12vrr_stack+534, r12vrr_stack+624, NULL);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1775, r12vrr_stack+54, r12vrr_stack+39, r12vrr_stack+544, r12vrr_stack+534, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+797, r12vrr_stack+1775, r12vrr_stack+1754, NULL, NULL, r12vrr_stack+39);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1796, r12vrr_stack+634, r12vrr_stack+54, r12vrr_stack+584, r12vrr_stack+544, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1164, r12vrr_stack+1796, r12vrr_stack+1775, NULL, NULL, r12vrr_stack+54);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1817, r12vrr_stack+69, r12vrr_stack+649, r12vrr_stack+624, r12vrr_stack+222, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1227, r12vrr_stack+1754, r12vrr_stack+1817, NULL, NULL, r12vrr_stack+69);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+232, r12vrr_stack+797, r12vrr_stack+1227, r12vrr_stack+1775, r12vrr_stack+1754, r12vrr_stack+1844);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+358, r12vrr_stack+1164, r12vrr_stack+797, r12vrr_stack+1796, r12vrr_stack+1775, r12vrr_stack+1889);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2114, r12vrr_stack+358, r12vrr_stack+232, r12vrr_stack+1164, r12vrr_stack+797, r12vrr_stack+1934);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1838, r12vrr_stack+664, r12vrr_stack+634, r12vrr_stack+159, r12vrr_stack+584, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1859, r12vrr_stack+1838, r12vrr_stack+1796, NULL, NULL, r12vrr_stack+634);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+484, r12vrr_stack+1859, r12vrr_stack+1164, r12vrr_stack+1838, r12vrr_stack+1796, r12vrr_stack+84);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+5163, r12vrr_stack+484, r12vrr_stack+358, r12vrr_stack+1859, r12vrr_stack+1164, r12vrr_stack+2024);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+84, r12vrr_stack+649, r12vrr_stack+737, r12vrr_stack+222, r12vrr_stack+1744, NULL);

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1922, r12vrr_stack+1817, r12vrr_stack+84, NULL, NULL, r12vrr_stack+649);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1985, r12vrr_stack+1227, r12vrr_stack+1922, r12vrr_stack+1754, r12vrr_stack+1817, r12vrr_stack+2613);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+5373, r12vrr_stack+232, r12vrr_stack+1985, r12vrr_stack+797, r12vrr_stack+1227, r12vrr_stack+2658);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+5583, r12vrr_stack+2114, r12vrr_stack+5373, r12vrr_stack+358, r12vrr_stack+232, r12vrr_stack+2748);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+5898, r12vrr_stack+5163, r12vrr_stack+2114, r12vrr_stack+484, r12vrr_stack+358, r12vrr_stack+2898);

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+6213, r12vrr_stack+5898, r12vrr_stack+5583, r12vrr_stack+5163, r12vrr_stack+2114, r12vrr_stack+3048);
 tmp = r12vrr_stack + 6213;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+2111, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+2613, r12vrr_stack+724, r12vrr_stack+2111, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+2619, r12vrr_stack+210, r12vrr_stack+2613, r12vrr_stack+135, r12vrr_stack+724, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+2629, r12vrr_stack+727, r12vrr_stack+2619, r12vrr_stack+138, r12vrr_stack+210, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2644, r12vrr_stack+737, r12vrr_stack+2629, r12vrr_stack+1744, r12vrr_stack+727, NULL);

 /*--- compute (p0|h0)^5 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2665, r12vrr_stack+84, r12vrr_stack+2644, NULL, NULL, r12vrr_stack+737);

 /*--- compute (d0|h0)^4 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+2728, r12vrr_stack+1922, r12vrr_stack+2665, r12vrr_stack+1817, r12vrr_stack+84, r12vrr_stack+752);

 /*--- compute (f0|h0)^3 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2854, r12vrr_stack+1985, r12vrr_stack+2728, r12vrr_stack+1227, r12vrr_stack+1922, r12vrr_stack+3648);

 /*--- compute (g0|h0)^2 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+6654, r12vrr_stack+5373, r12vrr_stack+2854, r12vrr_stack+232, r12vrr_stack+1985, r12vrr_stack+3738);

 /*--- compute (h0|h0)^1 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+6969, r12vrr_stack+5583, r12vrr_stack+6654, r12vrr_stack+2114, r12vrr_stack+5373, r12vrr_stack+3888);

 /*--- compute (i0|h0)^0 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+7410, r12vrr_stack+6213, r12vrr_stack+6969, r12vrr_stack+5898, r12vrr_stack+5583, r12vrr_stack+4113);
 tmp = r12vrr_stack + 7410;
 target_ptr = Libr12->gvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3648, r12vrr_stack+1754, r12vrr_stack+1817, r12vrr_stack+39, r12vrr_stack+69, NULL);

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3676, r12vrr_stack+1775, r12vrr_stack+1754, r12vrr_stack+54, r12vrr_stack+39, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3704, r12vrr_stack+3676, r12vrr_stack+3648, NULL, NULL, r12vrr_stack+1754);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3788, r12vrr_stack+1796, r12vrr_stack+1775, r12vrr_stack+634, r12vrr_stack+54, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3816, r12vrr_stack+3788, r12vrr_stack+3676, NULL, NULL, r12vrr_stack+1775);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3900, r12vrr_stack+1817, r12vrr_stack+84, r12vrr_stack+69, r12vrr_stack+649, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3928, r12vrr_stack+3648, r12vrr_stack+3900, NULL, NULL, r12vrr_stack+1817);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+4012, r12vrr_stack+3704, r12vrr_stack+3928, r12vrr_stack+3676, r12vrr_stack+3648, r12vrr_stack+1227);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+4180, r12vrr_stack+3816, r12vrr_stack+3704, r12vrr_stack+3788, r12vrr_stack+3676, r12vrr_stack+797);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+7998, r12vrr_stack+4180, r12vrr_stack+4012, r12vrr_stack+3816, r12vrr_stack+3704, r12vrr_stack+232);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1227, r12vrr_stack+1838, r12vrr_stack+1796, r12vrr_stack+664, r12vrr_stack+634, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1255, r12vrr_stack+1227, r12vrr_stack+3788, NULL, NULL, r12vrr_stack+1796);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3064, r12vrr_stack+1255, r12vrr_stack+3816, r12vrr_stack+1227, r12vrr_stack+3788, r12vrr_stack+1164);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+8278, r12vrr_stack+3064, r12vrr_stack+4180, r12vrr_stack+1255, r12vrr_stack+3816, r12vrr_stack+358);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1164, r12vrr_stack+84, r12vrr_stack+2644, r12vrr_stack+649, r12vrr_stack+737, NULL);

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+752, r12vrr_stack+3900, r12vrr_stack+1164, NULL, NULL, r12vrr_stack+84);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+216, r12vrr_stack+3928, r12vrr_stack+752, r12vrr_stack+3648, r12vrr_stack+3900, r12vrr_stack+1922);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+8558, r12vrr_stack+4012, r12vrr_stack+216, r12vrr_stack+3704, r12vrr_stack+3928, r12vrr_stack+1985);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+8838, r12vrr_stack+7998, r12vrr_stack+8558, r12vrr_stack+4180, r12vrr_stack+4012, r12vrr_stack+5373);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+9258, r12vrr_stack+8278, r12vrr_stack+7998, r12vrr_stack+3064, r12vrr_stack+4180, r12vrr_stack+2114);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+9678, r12vrr_stack+9258, r12vrr_stack+8838, r12vrr_stack+8278, r12vrr_stack+7998, r12vrr_stack+5583);
 tmp = r12vrr_stack + 9678;
 target_ptr = Libr12->gvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^11 ---*/
 _BUILD_00p0(Data,r12vrr_stack+2114, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /*--- compute (00|d0)^10 ---*/
 _BUILD_00d0(Data,r12vrr_stack+2117, r12vrr_stack+2111, r12vrr_stack+2114, Data->F+10, Data->F+11, NULL);

 /*--- compute (00|f0)^9 ---*/
 _BUILD_00f0(Data,r12vrr_stack+1744, r12vrr_stack+2613, r12vrr_stack+2117, r12vrr_stack+724, r12vrr_stack+2111, NULL);

 /*--- compute (00|g0)^8 ---*/
 _BUILD_00g0(Data,r12vrr_stack+2123, r12vrr_stack+2619, r12vrr_stack+1744, r12vrr_stack+210, r12vrr_stack+2613, NULL);

 /*--- compute (00|h0)^7 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2138, r12vrr_stack+2629, r12vrr_stack+2123, r12vrr_stack+727, r12vrr_stack+2619, NULL);

 /*--- compute (00|i0)^6 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2159, r12vrr_stack+2644, r12vrr_stack+2138, r12vrr_stack+737, r12vrr_stack+2629, NULL);

 /*--- compute (p0|i0)^5 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+2187, r12vrr_stack+1164, r12vrr_stack+2159, NULL, NULL, r12vrr_stack+2644);

 /*--- compute (d0|i0)^4 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+5373, r12vrr_stack+752, r12vrr_stack+2187, r12vrr_stack+3900, r12vrr_stack+1164, r12vrr_stack+2665);

 /*--- compute (f0|i0)^3 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+5541, r12vrr_stack+216, r12vrr_stack+5373, r12vrr_stack+3928, r12vrr_stack+752, r12vrr_stack+2728);

 /*--- compute (g0|i0)^2 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+10266, r12vrr_stack+8558, r12vrr_stack+5541, r12vrr_stack+4012, r12vrr_stack+216, r12vrr_stack+2854);

 /*--- compute (h0|i0)^1 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+10686, r12vrr_stack+8838, r12vrr_stack+10266, r12vrr_stack+7998, r12vrr_stack+8558, r12vrr_stack+6654);

 /*--- compute (i0|i0)^0 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+11274, r12vrr_stack+9678, r12vrr_stack+10686, r12vrr_stack+9258, r12vrr_stack+8838, r12vrr_stack+6969);
 tmp = r12vrr_stack + 11274;
 target_ptr = Libr12->gvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6654, r12vrr_stack+3648, r12vrr_stack+3900, r12vrr_stack+1754, r12vrr_stack+1817, NULL);

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6690, r12vrr_stack+3676, r12vrr_stack+3648, r12vrr_stack+1775, r12vrr_stack+1754, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6726, r12vrr_stack+6690, r12vrr_stack+6654, NULL, NULL, r12vrr_stack+3648);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6834, r12vrr_stack+3788, r12vrr_stack+3676, r12vrr_stack+1796, r12vrr_stack+1775, NULL);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6870, r12vrr_stack+6834, r12vrr_stack+6690, NULL, NULL, r12vrr_stack+3676);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1754, r12vrr_stack+3900, r12vrr_stack+1164, r12vrr_stack+1817, r12vrr_stack+84, NULL);

 /*--- compute (p0|k0)^3 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6978, r12vrr_stack+6654, r12vrr_stack+1754, NULL, NULL, r12vrr_stack+3900);

 /*--- compute (d0|k0)^2 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+7086, r12vrr_stack+6726, r12vrr_stack+6978, r12vrr_stack+6690, r12vrr_stack+6654, r12vrr_stack+3928);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2665, r12vrr_stack+6870, r12vrr_stack+6726, r12vrr_stack+6834, r12vrr_stack+6690, r12vrr_stack+3704);

 /*--- compute (f0|k0)^1 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+12058, r12vrr_stack+2665, r12vrr_stack+7086, r12vrr_stack+6870, r12vrr_stack+6726, r12vrr_stack+4012);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3704, r12vrr_stack+1227, r12vrr_stack+3788, r12vrr_stack+1838, r12vrr_stack+1796, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+7302, r12vrr_stack+3704, r12vrr_stack+6834, NULL, NULL, r12vrr_stack+3788);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3928, r12vrr_stack+7302, r12vrr_stack+6870, r12vrr_stack+3704, r12vrr_stack+6834, r12vrr_stack+3816);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+12418, r12vrr_stack+3928, r12vrr_stack+2665, r12vrr_stack+7302, r12vrr_stack+6870, r12vrr_stack+4180);

 /*--- compute (00|k0)^5 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3816, r12vrr_stack+1164, r12vrr_stack+2159, r12vrr_stack+84, r12vrr_stack+2644, NULL);

 /*--- compute (p0|k0)^4 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4144, r12vrr_stack+1754, r12vrr_stack+3816, NULL, NULL, r12vrr_stack+1164);

 /*--- compute (d0|k0)^3 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+12778, r12vrr_stack+6978, r12vrr_stack+4144, r12vrr_stack+6654, r12vrr_stack+1754, r12vrr_stack+752);

 /*--- compute (f0|k0)^2 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+12994, r12vrr_stack+7086, r12vrr_stack+12778, r12vrr_stack+6726, r12vrr_stack+6978, r12vrr_stack+216);

 /*--- compute (g0|k0)^1 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+13354, r12vrr_stack+12058, r12vrr_stack+12994, r12vrr_stack+2665, r12vrr_stack+7086, r12vrr_stack+8558);

 /*--- compute (g0|k0)^0 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+13894, r12vrr_stack+12418, r12vrr_stack+12058, r12vrr_stack+3928, r12vrr_stack+2665, r12vrr_stack+7998);

 /*--- compute (h0|k0)^0 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14434, r12vrr_stack+13894, r12vrr_stack+13354, r12vrr_stack+12418, r12vrr_stack+12058, r12vrr_stack+8838);
 tmp = r12vrr_stack + 14434;
 target_ptr = Libr12->gvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^12 ---*/
 _BUILD_00p0(Data,r12vrr_stack+7998, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /*--- compute (00|d0)^11 ---*/
 _BUILD_00d0(Data,r12vrr_stack+8001, r12vrr_stack+2114, r12vrr_stack+7998, Data->F+11, Data->F+12, NULL);

 /*--- compute (00|f0)^10 ---*/
 _BUILD_00f0(Data,r12vrr_stack+8007, r12vrr_stack+2117, r12vrr_stack+8001, r12vrr_stack+2111, r12vrr_stack+2114, NULL);

 /*--- compute (00|g0)^9 ---*/
 _BUILD_00g0(Data,r12vrr_stack+8017, r12vrr_stack+1744, r12vrr_stack+8007, r12vrr_stack+2613, r12vrr_stack+2117, NULL);

 /*--- compute (00|h0)^8 ---*/
 _BUILD_00h0(Data,r12vrr_stack+8032, r12vrr_stack+2123, r12vrr_stack+8017, r12vrr_stack+2619, r12vrr_stack+1744, NULL);

 /*--- compute (00|i0)^7 ---*/
 _BUILD_00i0(Data,r12vrr_stack+8053, r12vrr_stack+2138, r12vrr_stack+8032, r12vrr_stack+2629, r12vrr_stack+2123, NULL);

 /*--- compute (00|k0)^6 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8081, r12vrr_stack+2159, r12vrr_stack+8053, r12vrr_stack+2644, r12vrr_stack+2138, NULL);

 /*--- compute (p0|k0)^5 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8117, r12vrr_stack+3816, r12vrr_stack+8081, NULL, NULL, r12vrr_stack+2159);

 /*--- compute (d0|k0)^4 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8558, r12vrr_stack+4144, r12vrr_stack+8117, r12vrr_stack+1754, r12vrr_stack+3816, r12vrr_stack+2187);

 /*--- compute (f0|k0)^3 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8774, r12vrr_stack+12778, r12vrr_stack+8558, r12vrr_stack+6978, r12vrr_stack+4144, r12vrr_stack+5373);

 /*--- compute (g0|k0)^2 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+15190, r12vrr_stack+12994, r12vrr_stack+8774, r12vrr_stack+7086, r12vrr_stack+12778, r12vrr_stack+5541);

 /*--- compute (h0|k0)^1 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+15730, r12vrr_stack+13354, r12vrr_stack+15190, r12vrr_stack+12058, r12vrr_stack+12994, r12vrr_stack+10266);

 /*--- compute (i0|k0)^0 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+16486, r12vrr_stack+14434, r12vrr_stack+15730, r12vrr_stack+13894, r12vrr_stack+13354, r12vrr_stack+10686);
 tmp = r12vrr_stack + 16486;
 target_ptr = Libr12->gvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|l0)^3 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1339, r12vrr_stack+6654, r12vrr_stack+1754, r12vrr_stack+3648, r12vrr_stack+3900, NULL);

 /*--- compute (00|l0)^2 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+10266, r12vrr_stack+6690, r12vrr_stack+6654, r12vrr_stack+3676, r12vrr_stack+3648, NULL);

 /*--- compute (p0|l0)^2 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+10311, r12vrr_stack+10266, r12vrr_stack+1339, NULL, NULL, r12vrr_stack+6654);

 /*--- compute (00|l0)^1 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+10446, r12vrr_stack+6834, r12vrr_stack+6690, r12vrr_stack+3788, r12vrr_stack+3676, NULL);

 /*--- compute (p0|l0)^1 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+10491, r12vrr_stack+10446, r12vrr_stack+10266, NULL, NULL, r12vrr_stack+6690);

 /*--- compute (00|l0)^4 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+3648, r12vrr_stack+1754, r12vrr_stack+3816, r12vrr_stack+3900, r12vrr_stack+1164, NULL);

 /*--- compute (p0|l0)^3 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+10626, r12vrr_stack+1339, r12vrr_stack+3648, NULL, NULL, r12vrr_stack+1754);

 /*--- compute (d0|l0)^2 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+10761, r12vrr_stack+10311, r12vrr_stack+10626, r12vrr_stack+10266, r12vrr_stack+1339, r12vrr_stack+6978);

 /*--- compute (d0|l0)^1 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+5373, r12vrr_stack+10491, r12vrr_stack+10311, r12vrr_stack+10446, r12vrr_stack+10266, r12vrr_stack+6726);

 /*--- compute (f0|l0)^1 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+17494, r12vrr_stack+5373, r12vrr_stack+10761, r12vrr_stack+10491, r12vrr_stack+10311, r12vrr_stack+7086);

 /*--- compute (00|l0)^0 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+6726, r12vrr_stack+3704, r12vrr_stack+6834, r12vrr_stack+1227, r12vrr_stack+3788, NULL);

 /*--- compute (p0|l0)^0 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+6978, r12vrr_stack+6726, r12vrr_stack+10446, NULL, NULL, r12vrr_stack+6834);

 /*--- compute (d0|l0)^0 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+169, r12vrr_stack+6978, r12vrr_stack+10491, r12vrr_stack+6726, r12vrr_stack+10446, r12vrr_stack+6870);

 /*--- compute (f0|l0)^0 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+17944, r12vrr_stack+169, r12vrr_stack+5373, r12vrr_stack+6978, r12vrr_stack+10491, r12vrr_stack+2665);

 /*--- compute (00|l0)^5 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+439, r12vrr_stack+3816, r12vrr_stack+8081, r12vrr_stack+1164, r12vrr_stack+2159, NULL);

 /*--- compute (p0|l0)^4 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7113, r12vrr_stack+3648, r12vrr_stack+439, NULL, NULL, r12vrr_stack+3816);

 /*--- compute (d0|l0)^3 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+2613, r12vrr_stack+10626, r12vrr_stack+7113, r12vrr_stack+1339, r12vrr_stack+3648, r12vrr_stack+4144);

 /*--- compute (f0|l0)^2 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+18394, r12vrr_stack+10761, r12vrr_stack+2613, r12vrr_stack+10311, r12vrr_stack+10626, r12vrr_stack+12778);

 /*--- compute (g0|l0)^1 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+18844, r12vrr_stack+17494, r12vrr_stack+18394, r12vrr_stack+5373, r12vrr_stack+10761, r12vrr_stack+12994);

 /*--- compute (g0|l0)^0 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+19519, r12vrr_stack+17944, r12vrr_stack+17494, r12vrr_stack+169, r12vrr_stack+5373, r12vrr_stack+12058);

 /*--- compute (h0|l0)^0 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+20194, r12vrr_stack+19519, r12vrr_stack+18844, r12vrr_stack+17944, r12vrr_stack+17494, r12vrr_stack+13354);
 tmp = r12vrr_stack + 20194;
 target_ptr = Libr12->gvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^13 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12058, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /*--- compute (00|d0)^12 ---*/
 _BUILD_00d0(Data,r12vrr_stack+12061, r12vrr_stack+7998, r12vrr_stack+12058, Data->F+12, Data->F+13, NULL);

 /*--- compute (00|f0)^11 ---*/
 _BUILD_00f0(Data,r12vrr_stack+12067, r12vrr_stack+8001, r12vrr_stack+12061, r12vrr_stack+2114, r12vrr_stack+7998, NULL);

 /*--- compute (00|g0)^10 ---*/
 _BUILD_00g0(Data,r12vrr_stack+12077, r12vrr_stack+8007, r12vrr_stack+12067, r12vrr_stack+2117, r12vrr_stack+8001, NULL);

 /*--- compute (00|h0)^9 ---*/
 _BUILD_00h0(Data,r12vrr_stack+12092, r12vrr_stack+8017, r12vrr_stack+12077, r12vrr_stack+1744, r12vrr_stack+8007, NULL);

 /*--- compute (00|i0)^8 ---*/
 _BUILD_00i0(Data,r12vrr_stack+12058, r12vrr_stack+8032, r12vrr_stack+12092, r12vrr_stack+2123, r12vrr_stack+8017, NULL);

 /*--- compute (00|k0)^7 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+12086, r12vrr_stack+8053, r12vrr_stack+12058, r12vrr_stack+2138, r12vrr_stack+8032, NULL);

 /*--- compute (00|l0)^6 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7998, r12vrr_stack+8081, r12vrr_stack+12086, r12vrr_stack+2159, r12vrr_stack+8053, NULL);

 /*--- compute (p0|l0)^5 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+12058, r12vrr_stack+439, r12vrr_stack+7998, NULL, NULL, r12vrr_stack+8081);

 /*--- compute (d0|l0)^4 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+12778, r12vrr_stack+7113, r12vrr_stack+12058, r12vrr_stack+3648, r12vrr_stack+439, r12vrr_stack+8117);

 /*--- compute (f0|l0)^3 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13048, r12vrr_stack+2613, r12vrr_stack+12778, r12vrr_stack+10626, r12vrr_stack+7113, r12vrr_stack+8558);

 /*--- compute (g0|l0)^2 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+21139, r12vrr_stack+18394, r12vrr_stack+13048, r12vrr_stack+10761, r12vrr_stack+2613, r12vrr_stack+8774);

 /*--- compute (h0|l0)^1 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+12778, r12vrr_stack+18844, r12vrr_stack+21139, r12vrr_stack+17494, r12vrr_stack+18394, r12vrr_stack+15190);

 /*--- compute (i0|l0)^0 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+21139, r12vrr_stack+20194, r12vrr_stack+12778, r12vrr_stack+19519, r12vrr_stack+18844, r12vrr_stack+15730);

 /*--- compute (00|m0)^3 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+12778, r12vrr_stack+1339, r12vrr_stack+3648, r12vrr_stack+6654, r12vrr_stack+1754, NULL);

 /*--- compute (00|m0)^2 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+12833, r12vrr_stack+10266, r12vrr_stack+1339, r12vrr_stack+6690, r12vrr_stack+6654, NULL);

 /*--- compute (p0|m0)^2 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+12888, r12vrr_stack+12833, r12vrr_stack+12778, NULL, NULL, r12vrr_stack+1339);

 /*--- compute (00|m0)^1 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13053, r12vrr_stack+10446, r12vrr_stack+10266, r12vrr_stack+6834, r12vrr_stack+6690, NULL);

 /*--- compute (p0|m0)^1 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13108, r12vrr_stack+13053, r12vrr_stack+12833, NULL, NULL, r12vrr_stack+10266);

 /*--- compute (00|m0)^4 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+6654, r12vrr_stack+3648, r12vrr_stack+439, r12vrr_stack+1754, r12vrr_stack+3816, NULL);

 /*--- compute (p0|m0)^3 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13273, r12vrr_stack+12778, r12vrr_stack+6654, NULL, NULL, r12vrr_stack+3648);

 /*--- compute (d0|m0)^2 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13438, r12vrr_stack+12888, r12vrr_stack+13273, r12vrr_stack+12833, r12vrr_stack+12778, r12vrr_stack+10626);

 /*--- compute (d0|m0)^1 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+15190, r12vrr_stack+13108, r12vrr_stack+12888, r12vrr_stack+13053, r12vrr_stack+12833, r12vrr_stack+10311);

 /*--- compute (f0|m0)^1 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+15520, r12vrr_stack+15190, r12vrr_stack+13438, r12vrr_stack+13108, r12vrr_stack+12888, r12vrr_stack+10761);

 /*--- compute (00|m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+12833, r12vrr_stack+6726, r12vrr_stack+10446, r12vrr_stack+3704, r12vrr_stack+6834, NULL);

 /*--- compute (p0|m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+10626, r12vrr_stack+12833, r12vrr_stack+13053, NULL, NULL, r12vrr_stack+10446);

 /*--- compute (d0|m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+10791, r12vrr_stack+10626, r12vrr_stack+13108, r12vrr_stack+12833, r12vrr_stack+13053, r12vrr_stack+10491);

 /*--- compute (f0|m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+22399, r12vrr_stack+10791, r12vrr_stack+15190, r12vrr_stack+10626, r12vrr_stack+13108, r12vrr_stack+5373);

 /*--- compute (00|m0)^5 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+12833, r12vrr_stack+439, r12vrr_stack+7998, r12vrr_stack+3816, r12vrr_stack+8081, NULL);

 /*--- compute (p0|m0)^4 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+7998, r12vrr_stack+6654, r12vrr_stack+12833, NULL, NULL, r12vrr_stack+439);

 /*--- compute (d0|m0)^3 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+5373, r12vrr_stack+13273, r12vrr_stack+7998, r12vrr_stack+12778, r12vrr_stack+6654, r12vrr_stack+7113);

 /*--- compute (f0|m0)^2 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+8558, r12vrr_stack+13438, r12vrr_stack+5373, r12vrr_stack+12888, r12vrr_stack+13273, r12vrr_stack+2613);

 /*--- compute (g0|m0)^1 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+22949, r12vrr_stack+15520, r12vrr_stack+8558, r12vrr_stack+15190, r12vrr_stack+13438, r12vrr_stack+18394);

 /*--- compute (g0|m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+12778, r12vrr_stack+22399, r12vrr_stack+15520, r12vrr_stack+10791, r12vrr_stack+15190, r12vrr_stack+17494);

 /*--- compute (h0|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+23774, r12vrr_stack+12778, r12vrr_stack+22949, r12vrr_stack+22399, r12vrr_stack+15520, r12vrr_stack+18844);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+22399, &(Data->ss_r12_ss), NULL, r12vrr_stack+27, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+22402, r12vrr_stack+22399, &(Data->ss_r12_ss), r12vrr_stack+153, r12vrr_stack+27, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+22408, r12vrr_stack+22402, r12vrr_stack+22399, r12vrr_stack+159, r12vrr_stack+153, r12vrr_stack+27, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+22418, r12vrr_stack+22408, r12vrr_stack+22402, r12vrr_stack+664, r12vrr_stack+159, r12vrr_stack+153, NULL);

 /*--- compute (p0||g0)^0 ---*/
 _R_BUILD_p0g0(Data,r12vrr_stack+439, r12vrr_stack+22418, NULL, r12vrr_stack+679, r12vrr_stack+664, NULL, r12vrr_stack+159);

 /*--- compute (d0||g0)^0 ---*/
 _R_BUILD_d0g0(Data,r12vrr_stack+22433, r12vrr_stack+439, r12vrr_stack+22418, r12vrr_stack+1074, r12vrr_stack+679, r12vrr_stack+664, r12vrr_stack+884);

 /*--- compute (f0||g0)^0 ---*/
 _R_BUILD_f0g0(Data,r12vrr_stack+22523, r12vrr_stack+22433, r12vrr_stack+439, r12vrr_stack+3273, r12vrr_stack+1074, r12vrr_stack+679, r12vrr_stack+914);

 /*--- compute (g0||g0)^0 ---*/
 _R_BUILD_g0g0(Data,r12vrr_stack+22673, r12vrr_stack+22523, r12vrr_stack+22433, r12vrr_stack+3423, r12vrr_stack+3273, r12vrr_stack+1074, r12vrr_stack+974);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+22433, r12vrr_stack+22418, r12vrr_stack+22408, r12vrr_stack+1838, r12vrr_stack+664, r12vrr_stack+159, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+1164, r12vrr_stack+22433, NULL, r12vrr_stack+1859, r12vrr_stack+1838, NULL, r12vrr_stack+664);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+22898, r12vrr_stack+1164, r12vrr_stack+22433, r12vrr_stack+484, r12vrr_stack+1859, r12vrr_stack+1838, r12vrr_stack+679);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+679, r12vrr_stack+22898, r12vrr_stack+1164, r12vrr_stack+5163, r12vrr_stack+484, r12vrr_stack+1859, r12vrr_stack+1074);

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+889, r12vrr_stack+679, r12vrr_stack+22898, r12vrr_stack+5898, r12vrr_stack+5163, r12vrr_stack+484, r12vrr_stack+3273);

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+22898, r12vrr_stack+22433, r12vrr_stack+22418, r12vrr_stack+1227, r12vrr_stack+1838, r12vrr_stack+664, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+22926, r12vrr_stack+22898, NULL, r12vrr_stack+1255, r12vrr_stack+1227, NULL, r12vrr_stack+1838);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+23010, r12vrr_stack+22926, r12vrr_stack+22898, r12vrr_stack+3064, r12vrr_stack+1255, r12vrr_stack+1227, r12vrr_stack+1859);

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+7998, r12vrr_stack+23010, r12vrr_stack+22926, r12vrr_stack+8278, r12vrr_stack+3064, r12vrr_stack+1255, r12vrr_stack+484);

 /*--- compute (g0||i0)^0 ---*/
 _R_BUILD_g0i0(Data,r12vrr_stack+1859, r12vrr_stack+7998, r12vrr_stack+23010, r12vrr_stack+9258, r12vrr_stack+8278, r12vrr_stack+3064, r12vrr_stack+5163);

 /*--- compute (00||k0)^0 ---*/
 _R_BUILD_00k0(Data,r12vrr_stack+22926, r12vrr_stack+22898, r12vrr_stack+22433, r12vrr_stack+3704, r12vrr_stack+1227, r12vrr_stack+1838, NULL);

 /*--- compute (p0||k0)^0 ---*/
 _R_BUILD_p0k0(Data,r12vrr_stack+22962, r12vrr_stack+22926, NULL, r12vrr_stack+7302, r12vrr_stack+3704, NULL, r12vrr_stack+1227);

 /*--- compute (d0||k0)^0 ---*/
 _R_BUILD_d0k0(Data,r12vrr_stack+23070, r12vrr_stack+22962, r12vrr_stack+22926, r12vrr_stack+3928, r12vrr_stack+7302, r12vrr_stack+3704, r12vrr_stack+1255);

 /*--- compute (f0||k0)^0 ---*/
 _R_BUILD_f0k0(Data,r12vrr_stack+12058, r12vrr_stack+23070, r12vrr_stack+22962, r12vrr_stack+12418, r12vrr_stack+3928, r12vrr_stack+7302, r12vrr_stack+3064);

 /*--- compute (g0||k0)^0 ---*/
 _R_BUILD_g0k0(Data,r12vrr_stack+15190, r12vrr_stack+12058, r12vrr_stack+23070, r12vrr_stack+13894, r12vrr_stack+12418, r12vrr_stack+3928, r12vrr_stack+8278);

 /*--- compute (00||l0)^0 ---*/
 _R_BUILD_00l0(Data,r12vrr_stack+22962, r12vrr_stack+22926, r12vrr_stack+22898, r12vrr_stack+6726, r12vrr_stack+3704, r12vrr_stack+1227, NULL);

 /*--- compute (p0||l0)^0 ---*/
 _R_BUILD_p0l0(Data,r12vrr_stack+23007, r12vrr_stack+22962, NULL, r12vrr_stack+6978, r12vrr_stack+6726, NULL, r12vrr_stack+3704);

 /*--- compute (d0||l0)^0 ---*/
 _R_BUILD_d0l0(Data,r12vrr_stack+23142, r12vrr_stack+23007, r12vrr_stack+22962, r12vrr_stack+169, r12vrr_stack+6978, r12vrr_stack+6726, r12vrr_stack+7302);

 /*--- compute (f0||l0)^0 ---*/
 _R_BUILD_f0l0(Data,r12vrr_stack+17494, r12vrr_stack+23142, r12vrr_stack+23007, r12vrr_stack+17944, r12vrr_stack+169, r12vrr_stack+6978, r12vrr_stack+3928);

 /*--- compute (g0||l0)^0 ---*/
 _R_BUILD_g0l0(Data,r12vrr_stack+15730, r12vrr_stack+17494, r12vrr_stack+23142, r12vrr_stack+19519, r12vrr_stack+17944, r12vrr_stack+169, r12vrr_stack+12418);

 /*--- compute (h0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_h0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+22898, r12vrr_stack+4428, r12vrr_stack+6213, r12vrr_stack+4743, r12vrr_stack+2333, r12vrr_stack+1534);
 tmp = r12vrr_stack + 22898;
 target_ptr = Libr12->t2vrr_classes[5][4];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+23213, r12vrr_stack+6213, r12vrr_stack+9678, r12vrr_stack+7410, r12vrr_stack+4743, r12vrr_stack+4428);
 tmp = r12vrr_stack + 23213;
 target_ptr = Libr12->t2vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2279, r12vrr_stack+9678, r12vrr_stack+14434, r12vrr_stack+11274, r12vrr_stack+7410, r12vrr_stack+6213);
 tmp = r12vrr_stack + 2279;
 target_ptr = Libr12->t2vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_h0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+6654, r12vrr_stack+14434, r12vrr_stack+20194, r12vrr_stack+16486, r12vrr_stack+11274, r12vrr_stack+9678);
 tmp = r12vrr_stack + 6654;
 target_ptr = Libr12->t2vrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_h0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+18394, r12vrr_stack+20194, r12vrr_stack+23774, r12vrr_stack+21139, r12vrr_stack+16486, r12vrr_stack+14434);
 tmp = r12vrr_stack + 18394;
 target_ptr = Libr12->t2vrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_h0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1534, r12vrr_stack+4428, r12vrr_stack+4743, r12vrr_stack+6213, r12vrr_stack+5898, r12vrr_stack+3423);
 tmp = r12vrr_stack + 1534;
 target_ptr = Libr12->t1vrr_classes[5][4];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+8558, r12vrr_stack+6213, r12vrr_stack+7410, r12vrr_stack+9678, r12vrr_stack+9258, r12vrr_stack+5898);
 tmp = r12vrr_stack + 8558;
 target_ptr = Libr12->t1vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7410, r12vrr_stack+9678, r12vrr_stack+11274, r12vrr_stack+14434, r12vrr_stack+13894, r12vrr_stack+9258);
 tmp = r12vrr_stack + 7410;
 target_ptr = Libr12->t1vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_h0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3648, r12vrr_stack+14434, r12vrr_stack+16486, r12vrr_stack+20194, r12vrr_stack+19519, r12vrr_stack+13894);
 tmp = r12vrr_stack + 3648;
 target_ptr = Libr12->t1vrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_h0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+16405, r12vrr_stack+20194, r12vrr_stack+21139, r12vrr_stack+23774, r12vrr_stack+12778, r12vrr_stack+19519);
 tmp = r12vrr_stack + 16405;
 target_ptr = Libr12->t1vrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||g0)^0 ---*/
 _R_BUILD_h0g0(Data,r12vrr_stack+12778, r12vrr_stack+22673, r12vrr_stack+22523, r12vrr_stack+4428, r12vrr_stack+3423, r12vrr_stack+3273, r12vrr_stack+1384);
 tmp = r12vrr_stack + 12778;
 target_ptr = Libr12->rvrr_classes[5][4];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||h0)^0 ---*/
 _R_BUILD_h0h0(Data,r12vrr_stack+13093, r12vrr_stack+889, r12vrr_stack+679, r12vrr_stack+6213, r12vrr_stack+5898, r12vrr_stack+5163, r12vrr_stack+3423);
 tmp = r12vrr_stack + 13093;
 target_ptr = Libr12->rvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||i0)^0 ---*/
 _R_BUILD_h0i0(Data,r12vrr_stack+21139, r12vrr_stack+1859, r12vrr_stack+7998, r12vrr_stack+9678, r12vrr_stack+9258, r12vrr_stack+8278, r12vrr_stack+5898);
 tmp = r12vrr_stack + 21139;
 target_ptr = Libr12->rvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||k0)^0 ---*/
 _R_BUILD_h0k0(Data,r12vrr_stack+9678, r12vrr_stack+15190, r12vrr_stack+12058, r12vrr_stack+14434, r12vrr_stack+13894, r12vrr_stack+12418, r12vrr_stack+9258);
 tmp = r12vrr_stack + 9678;
 target_ptr = Libr12->rvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||l0)^0 ---*/
 _R_BUILD_h0l0(Data,r12vrr_stack+14434, r12vrr_stack+15730, r12vrr_stack+17494, r12vrr_stack+20194, r12vrr_stack+19519, r12vrr_stack+17944, r12vrr_stack+13894);
 tmp = r12vrr_stack + 14434;
 target_ptr = Libr12->rvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];


}

