/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_pphg(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+9, r12vrr_stack+0, r12vrr_stack+6, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+3, r12vrr_stack+0, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+21, r12vrr_stack+15, r12vrr_stack+9, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+31, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+34, r12vrr_stack+6, r12vrr_stack+31, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+40, r12vrr_stack+9, r12vrr_stack+34, r12vrr_stack+0, r12vrr_stack+6, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+50, r12vrr_stack+21, r12vrr_stack+40, r12vrr_stack+15, r12vrr_stack+9, NULL);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+65, r12vrr_stack+0, r12vrr_stack+3, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+71, r12vrr_stack+65, r12vrr_stack+15, r12vrr_stack+0, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+81, r12vrr_stack+71, r12vrr_stack+21, r12vrr_stack+65, r12vrr_stack+15, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+96, r12vrr_stack+81, r12vrr_stack+50, NULL, NULL, r12vrr_stack+21);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+141, r12vrr_stack+21, r12vrr_stack+40, NULL, NULL, r12vrr_stack+9);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+31, r12vrr_stack+3, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+171, r12vrr_stack+34, r12vrr_stack+15, r12vrr_stack+6, r12vrr_stack+31, NULL);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+181, r12vrr_stack+40, r12vrr_stack+171, r12vrr_stack+9, r12vrr_stack+34, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+196, r12vrr_stack+50, r12vrr_stack+181, NULL, NULL, r12vrr_stack+40);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+241, r12vrr_stack+96, r12vrr_stack+196, r12vrr_stack+81, r12vrr_stack+50, r12vrr_stack+141);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+331, r12vrr_stack+50, r12vrr_stack+181, r12vrr_stack+21, r12vrr_stack+40, NULL);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+352, r12vrr_stack+81, r12vrr_stack+50, r12vrr_stack+71, r12vrr_stack+21, NULL);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+373, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+376, r12vrr_stack+3, r12vrr_stack+373, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+382, r12vrr_stack+15, r12vrr_stack+376, r12vrr_stack+31, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+392, r12vrr_stack+171, r12vrr_stack+382, r12vrr_stack+34, r12vrr_stack+15, NULL);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+407, r12vrr_stack+181, r12vrr_stack+392, r12vrr_stack+40, r12vrr_stack+171, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+428, r12vrr_stack+331, r12vrr_stack+407, NULL, NULL, r12vrr_stack+181);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+491, r12vrr_stack+352, r12vrr_stack+331, NULL, NULL, r12vrr_stack+50);
 tmp = r12vrr_stack + 491;
 target_ptr = Libr12->gvrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+554, r12vrr_stack+491, r12vrr_stack+428, r12vrr_stack+352, r12vrr_stack+331, r12vrr_stack+196);
 tmp = r12vrr_stack + 554;
 target_ptr = Libr12->gvrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+680, r12vrr_stack+331, r12vrr_stack+407, r12vrr_stack+50, r12vrr_stack+181, NULL);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+708, r12vrr_stack+352, r12vrr_stack+331, r12vrr_stack+81, r12vrr_stack+50, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+736, r12vrr_stack+708, r12vrr_stack+680, NULL, NULL, r12vrr_stack+331);
 tmp = r12vrr_stack + 736;
 target_ptr = Libr12->gvrr_classes[1][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+31, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+820, r12vrr_stack+373, r12vrr_stack+31, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+826, r12vrr_stack+376, r12vrr_stack+820, r12vrr_stack+3, r12vrr_stack+373, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+836, r12vrr_stack+382, r12vrr_stack+826, r12vrr_stack+15, r12vrr_stack+376, NULL);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+851, r12vrr_stack+392, r12vrr_stack+836, r12vrr_stack+171, r12vrr_stack+382, NULL);

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+872, r12vrr_stack+407, r12vrr_stack+851, r12vrr_stack+181, r12vrr_stack+392, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+900, r12vrr_stack+680, r12vrr_stack+872, NULL, NULL, r12vrr_stack+407);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+984, r12vrr_stack+736, r12vrr_stack+900, r12vrr_stack+708, r12vrr_stack+680, r12vrr_stack+428);
 tmp = r12vrr_stack + 984;
 target_ptr = Libr12->gvrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1152, r12vrr_stack+680, r12vrr_stack+872, r12vrr_stack+331, r12vrr_stack+407, NULL);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1188, r12vrr_stack+708, r12vrr_stack+680, r12vrr_stack+352, r12vrr_stack+331, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1224, r12vrr_stack+1188, r12vrr_stack+1152, NULL, NULL, r12vrr_stack+680);
 tmp = r12vrr_stack + 1224;
 target_ptr = Libr12->gvrr_classes[1][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+31, r12vrr_stack+3, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+1332, r12vrr_stack+820, r12vrr_stack+15, r12vrr_stack+373, r12vrr_stack+31, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1342, r12vrr_stack+826, r12vrr_stack+1332, r12vrr_stack+376, r12vrr_stack+820, NULL);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1357, r12vrr_stack+836, r12vrr_stack+1342, r12vrr_stack+382, r12vrr_stack+826, NULL);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1378, r12vrr_stack+851, r12vrr_stack+1357, r12vrr_stack+392, r12vrr_stack+836, NULL);

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1406, r12vrr_stack+872, r12vrr_stack+1378, r12vrr_stack+407, r12vrr_stack+851, NULL);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1442, r12vrr_stack+1152, r12vrr_stack+1406, NULL, NULL, r12vrr_stack+872);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1550, r12vrr_stack+1224, r12vrr_stack+1442, r12vrr_stack+1188, r12vrr_stack+1152, r12vrr_stack+900);
 tmp = r12vrr_stack + 1550;
 target_ptr = Libr12->gvrr_classes[2][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|l0)^1 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1766, r12vrr_stack+1152, r12vrr_stack+1406, r12vrr_stack+680, r12vrr_stack+872, NULL);

 /*--- compute (00|l0)^0 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1811, r12vrr_stack+1188, r12vrr_stack+1152, r12vrr_stack+708, r12vrr_stack+680, NULL);

 /*--- compute (p0|l0)^0 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1856, r12vrr_stack+1811, r12vrr_stack+1766, NULL, NULL, r12vrr_stack+1152);
 tmp = r12vrr_stack + 1856;
 target_ptr = Libr12->gvrr_classes[1][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+373, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+376, r12vrr_stack+3, r12vrr_stack+373, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+382, r12vrr_stack+15, r12vrr_stack+376, r12vrr_stack+31, r12vrr_stack+3, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1991, r12vrr_stack+1332, r12vrr_stack+382, r12vrr_stack+820, r12vrr_stack+15, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2006, r12vrr_stack+1342, r12vrr_stack+1991, r12vrr_stack+826, r12vrr_stack+1332, NULL);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2027, r12vrr_stack+1357, r12vrr_stack+2006, r12vrr_stack+836, r12vrr_stack+1342, NULL);

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2055, r12vrr_stack+1378, r12vrr_stack+2027, r12vrr_stack+851, r12vrr_stack+1357, NULL);

 /*--- compute (00|l0)^2 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+2091, r12vrr_stack+1406, r12vrr_stack+2055, r12vrr_stack+872, r12vrr_stack+1378, NULL);

 /*--- compute (p0|l0)^1 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+2136, r12vrr_stack+1766, r12vrr_stack+2091, NULL, NULL, r12vrr_stack+1406);

 /*--- compute (d0|l0)^0 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+2271, r12vrr_stack+1856, r12vrr_stack+2136, r12vrr_stack+1811, r12vrr_stack+1766, r12vrr_stack+1442);
 tmp = r12vrr_stack + 2271;
 target_ptr = Libr12->gvrr_classes[2][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|m0)^1 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+2541, r12vrr_stack+1766, r12vrr_stack+2091, r12vrr_stack+1152, r12vrr_stack+1406, NULL);

 /*--- compute (00|m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+2596, r12vrr_stack+1811, r12vrr_stack+1766, r12vrr_stack+1188, r12vrr_stack+1152, NULL);

 /*--- compute (p0|m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+2651, r12vrr_stack+2596, r12vrr_stack+2541, NULL, NULL, r12vrr_stack+1766);
 tmp = r12vrr_stack + 2651;
 target_ptr = Libr12->gvrr_classes[1][9];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+31, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+820, r12vrr_stack+373, r12vrr_stack+31, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+826, r12vrr_stack+376, r12vrr_stack+820, r12vrr_stack+3, r12vrr_stack+373, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+836, r12vrr_stack+382, r12vrr_stack+826, r12vrr_stack+15, r12vrr_stack+376, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2816, r12vrr_stack+1991, r12vrr_stack+836, r12vrr_stack+1332, r12vrr_stack+382, NULL);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2837, r12vrr_stack+2006, r12vrr_stack+2816, r12vrr_stack+1342, r12vrr_stack+1991, NULL);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2865, r12vrr_stack+2027, r12vrr_stack+2837, r12vrr_stack+1357, r12vrr_stack+2006, NULL);

 /*--- compute (00|l0)^3 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1332, r12vrr_stack+2055, r12vrr_stack+2865, r12vrr_stack+1378, r12vrr_stack+2027, NULL);

 /*--- compute (00|m0)^2 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+2901, r12vrr_stack+2091, r12vrr_stack+1332, r12vrr_stack+1406, r12vrr_stack+2055, NULL);

 /*--- compute (p0|m0)^1 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+2956, r12vrr_stack+2541, r12vrr_stack+2901, NULL, NULL, r12vrr_stack+2091);

 /*--- compute (d0|m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+3121, r12vrr_stack+2651, r12vrr_stack+2956, r12vrr_stack+2596, r12vrr_stack+2541, r12vrr_stack+2136);
 tmp = r12vrr_stack + 3121;
 target_ptr = Libr12->gvrr_classes[2][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|n0)^1 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+3451, r12vrr_stack+2541, r12vrr_stack+2901, r12vrr_stack+1766, r12vrr_stack+2091, NULL);

 /*--- compute (00|n0)^0 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+3517, r12vrr_stack+2596, r12vrr_stack+2541, r12vrr_stack+1811, r12vrr_stack+1766, NULL);

 /*--- compute (p0|n0)^0 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+3583, r12vrr_stack+3517, r12vrr_stack+3451, NULL, NULL, r12vrr_stack+2541);
 tmp = r12vrr_stack + 3583;
 target_ptr = Libr12->gvrr_classes[1][10];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+3781, r12vrr_stack+9, r12vrr_stack+34, NULL, NULL, r12vrr_stack+6);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+3799, r12vrr_stack+40, r12vrr_stack+171, NULL, NULL, r12vrr_stack+34);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+3829, r12vrr_stack+141, r12vrr_stack+3799, r12vrr_stack+21, r12vrr_stack+40, r12vrr_stack+3781);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+3889, r12vrr_stack+181, r12vrr_stack+392, NULL, NULL, r12vrr_stack+171);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+3934, r12vrr_stack+196, r12vrr_stack+3889, r12vrr_stack+50, r12vrr_stack+181, r12vrr_stack+3799);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+4024, r12vrr_stack+241, r12vrr_stack+3934, r12vrr_stack+96, r12vrr_stack+196, r12vrr_stack+3829);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+3781, r12vrr_stack+407, r12vrr_stack+851, NULL, NULL, r12vrr_stack+392);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+4174, r12vrr_stack+428, r12vrr_stack+3781, r12vrr_stack+331, r12vrr_stack+407, r12vrr_stack+3889);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+4300, r12vrr_stack+554, r12vrr_stack+4174, r12vrr_stack+491, r12vrr_stack+428, r12vrr_stack+3934);
 tmp = r12vrr_stack + 4300;
 target_ptr = Libr12->gvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+392, r12vrr_stack+872, r12vrr_stack+1378, NULL, NULL, r12vrr_stack+851);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3844, r12vrr_stack+900, r12vrr_stack+392, r12vrr_stack+680, r12vrr_stack+872, r12vrr_stack+3781);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+4510, r12vrr_stack+984, r12vrr_stack+3844, r12vrr_stack+736, r12vrr_stack+900, r12vrr_stack+4174);
 tmp = r12vrr_stack + 4510;
 target_ptr = Libr12->gvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4174, r12vrr_stack+1406, r12vrr_stack+2055, NULL, NULL, r12vrr_stack+1378);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4790, r12vrr_stack+1442, r12vrr_stack+4174, r12vrr_stack+1152, r12vrr_stack+1406, r12vrr_stack+392);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5006, r12vrr_stack+1550, r12vrr_stack+4790, r12vrr_stack+1224, r12vrr_stack+1442, r12vrr_stack+3844);
 tmp = r12vrr_stack + 5006;
 target_ptr = Libr12->gvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|l0)^2 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+3781, r12vrr_stack+2091, r12vrr_stack+1332, NULL, NULL, r12vrr_stack+2055);

 /*--- compute (d0|l0)^1 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+5366, r12vrr_stack+2136, r12vrr_stack+3781, r12vrr_stack+1766, r12vrr_stack+2091, r12vrr_stack+4174);

 /*--- compute (f0|l0)^0 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+5636, r12vrr_stack+2271, r12vrr_stack+5366, r12vrr_stack+1856, r12vrr_stack+2136, r12vrr_stack+4790);
 tmp = r12vrr_stack + 5636;
 target_ptr = Libr12->gvrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^11 ---*/
 _BUILD_00p0(Data,r12vrr_stack+4790, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /*--- compute (00|d0)^10 ---*/
 _BUILD_00d0(Data,r12vrr_stack+4793, r12vrr_stack+31, r12vrr_stack+4790, Data->F+10, Data->F+11, NULL);

 /*--- compute (00|f0)^9 ---*/
 _BUILD_00f0(Data,r12vrr_stack+4799, r12vrr_stack+820, r12vrr_stack+4793, r12vrr_stack+373, r12vrr_stack+31, NULL);

 /*--- compute (00|g0)^8 ---*/
 _BUILD_00g0(Data,r12vrr_stack+4809, r12vrr_stack+826, r12vrr_stack+4799, r12vrr_stack+376, r12vrr_stack+820, NULL);

 /*--- compute (00|h0)^7 ---*/
 _BUILD_00h0(Data,r12vrr_stack+331, r12vrr_stack+836, r12vrr_stack+4809, r12vrr_stack+382, r12vrr_stack+826, NULL);

 /*--- compute (00|i0)^6 ---*/
 _BUILD_00i0(Data,r12vrr_stack+680, r12vrr_stack+2816, r12vrr_stack+331, r12vrr_stack+1991, r12vrr_stack+836, NULL);

 /*--- compute (00|k0)^5 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1152, r12vrr_stack+2837, r12vrr_stack+680, r12vrr_stack+2006, r12vrr_stack+2816, NULL);

 /*--- compute (00|l0)^4 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1766, r12vrr_stack+2865, r12vrr_stack+1152, r12vrr_stack+2027, r12vrr_stack+2837, NULL);

 /*--- compute (00|m0)^3 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+1991, r12vrr_stack+1332, r12vrr_stack+1766, r12vrr_stack+2055, r12vrr_stack+2865, NULL);

 /*--- compute (p0|m0)^2 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+4790, r12vrr_stack+2901, r12vrr_stack+1991, NULL, NULL, r12vrr_stack+1332);

 /*--- compute (d0|m0)^1 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+6086, r12vrr_stack+2956, r12vrr_stack+4790, r12vrr_stack+2541, r12vrr_stack+2901, r12vrr_stack+3781);

 /*--- compute (f0|m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+6416, r12vrr_stack+3121, r12vrr_stack+6086, r12vrr_stack+2651, r12vrr_stack+2956, r12vrr_stack+5366);

 /*--- compute (00|n0)^2 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+5366, r12vrr_stack+2901, r12vrr_stack+1991, r12vrr_stack+2091, r12vrr_stack+1332, NULL);

 /*--- compute (p0|n0)^1 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+1332, r12vrr_stack+3451, r12vrr_stack+5366, NULL, NULL, r12vrr_stack+2901);

 /*--- compute (d0|n0)^0 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+6966, r12vrr_stack+3583, r12vrr_stack+1332, r12vrr_stack+3517, r12vrr_stack+3451, r12vrr_stack+2956);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+3451, &(Data->ss_r12_ss), NULL, r12vrr_stack+0, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+3454, r12vrr_stack+3451, &(Data->ss_r12_ss), r12vrr_stack+65, r12vrr_stack+0, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+3460, r12vrr_stack+3454, r12vrr_stack+3451, r12vrr_stack+71, r12vrr_stack+65, r12vrr_stack+0, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+0, r12vrr_stack+3460, r12vrr_stack+3454, r12vrr_stack+81, r12vrr_stack+71, r12vrr_stack+65, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+331, r12vrr_stack+0, r12vrr_stack+3460, r12vrr_stack+352, r12vrr_stack+81, r12vrr_stack+71, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+15, r12vrr_stack+331, NULL, r12vrr_stack+491, r12vrr_stack+352, NULL, r12vrr_stack+81);
 tmp = r12vrr_stack + 15;
 target_ptr = Libr12->rvrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+680, r12vrr_stack+331, r12vrr_stack+0, r12vrr_stack+708, r12vrr_stack+352, r12vrr_stack+81, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+1332, r12vrr_stack+680, NULL, r12vrr_stack+736, r12vrr_stack+708, NULL, r12vrr_stack+352);
 tmp = r12vrr_stack + 1332;
 target_ptr = Libr12->rvrr_classes[1][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||k0)^0 ---*/
 _R_BUILD_00k0(Data,r12vrr_stack+1152, r12vrr_stack+680, r12vrr_stack+331, r12vrr_stack+1188, r12vrr_stack+708, r12vrr_stack+352, NULL);

 /*--- compute (p0||k0)^0 ---*/
 _R_BUILD_p0k0(Data,r12vrr_stack+1416, r12vrr_stack+1152, NULL, r12vrr_stack+1224, r12vrr_stack+1188, NULL, r12vrr_stack+708);
 tmp = r12vrr_stack + 1416;
 target_ptr = Libr12->rvrr_classes[1][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||l0)^0 ---*/
 _R_BUILD_00l0(Data,r12vrr_stack+1766, r12vrr_stack+1152, r12vrr_stack+680, r12vrr_stack+1811, r12vrr_stack+1188, r12vrr_stack+708, NULL);

 /*--- compute (p0||l0)^0 ---*/
 _R_BUILD_p0l0(Data,r12vrr_stack+5366, r12vrr_stack+1766, NULL, r12vrr_stack+1856, r12vrr_stack+1811, NULL, r12vrr_stack+1188);
 tmp = r12vrr_stack + 5366;
 target_ptr = Libr12->rvrr_classes[1][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+2541, r12vrr_stack+1766, r12vrr_stack+1152, r12vrr_stack+2596, r12vrr_stack+1811, r12vrr_stack+1188, NULL);

 /*--- compute (p0||m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+1991, r12vrr_stack+2541, NULL, r12vrr_stack+2651, r12vrr_stack+2596, NULL, r12vrr_stack+1811);
 tmp = r12vrr_stack + 1991;
 target_ptr = Libr12->rvrr_classes[1][9];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_p0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3451, r12vrr_stack+491, r12vrr_stack+736, r12vrr_stack+554, r12vrr_stack+241, r12vrr_stack+96);
 tmp = r12vrr_stack + 3451;
 target_ptr = Libr12->t2vrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_p0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5501, r12vrr_stack+736, r12vrr_stack+1224, r12vrr_stack+984, r12vrr_stack+554, r12vrr_stack+491);
 tmp = r12vrr_stack + 5501;
 target_ptr = Libr12->t2vrr_classes[1][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_p0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2156, r12vrr_stack+1224, r12vrr_stack+1856, r12vrr_stack+1550, r12vrr_stack+984, r12vrr_stack+736);
 tmp = r12vrr_stack + 2156;
 target_ptr = Libr12->t2vrr_classes[1][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_p0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+6086, r12vrr_stack+1856, r12vrr_stack+2651, r12vrr_stack+2271, r12vrr_stack+1550, r12vrr_stack+1224);
 tmp = r12vrr_stack + 6086;
 target_ptr = Libr12->t2vrr_classes[1][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T2]|m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+6221, r12vrr_stack+2651, r12vrr_stack+3583, r12vrr_stack+3121, r12vrr_stack+2271, r12vrr_stack+1856);
 tmp = r12vrr_stack + 6221;
 target_ptr = Libr12->t2vrr_classes[1][9];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_d0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+4174, r12vrr_stack+554, r12vrr_stack+984, r12vrr_stack+4300, r12vrr_stack+4024, r12vrr_stack+241);
 tmp = r12vrr_stack + 4174;
 target_ptr = Libr12->t2vrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_d0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3781, r12vrr_stack+984, r12vrr_stack+1550, r12vrr_stack+4510, r12vrr_stack+4300, r12vrr_stack+554);
 tmp = r12vrr_stack + 3781;
 target_ptr = Libr12->t2vrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_d0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+4790, r12vrr_stack+1550, r12vrr_stack+2271, r12vrr_stack+5006, r12vrr_stack+4510, r12vrr_stack+984);
 tmp = r12vrr_stack + 4790;
 target_ptr = Libr12->t2vrr_classes[2][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_d0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2816, r12vrr_stack+2271, r12vrr_stack+3121, r12vrr_stack+5636, r12vrr_stack+5006, r12vrr_stack+1550);
 tmp = r12vrr_stack + 2816;
 target_ptr = Libr12->t2vrr_classes[2][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T2]|m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+7362, r12vrr_stack+3121, r12vrr_stack+6966, r12vrr_stack+6416, r12vrr_stack+5636, r12vrr_stack+2271);
 tmp = r12vrr_stack + 7362;
 target_ptr = Libr12->t2vrr_classes[2][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_p0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3949, r12vrr_stack+491, r12vrr_stack+554, r12vrr_stack+736, r12vrr_stack+708, r12vrr_stack+352);
 tmp = r12vrr_stack + 3949;
 target_ptr = Libr12->t1vrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_p0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+4012, r12vrr_stack+736, r12vrr_stack+984, r12vrr_stack+1224, r12vrr_stack+1188, r12vrr_stack+708);
 tmp = r12vrr_stack + 4012;
 target_ptr = Libr12->t1vrr_classes[1][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_p0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+820, r12vrr_stack+1224, r12vrr_stack+1550, r12vrr_stack+1856, r12vrr_stack+1811, r12vrr_stack+1188);
 tmp = r12vrr_stack + 820;
 target_ptr = Libr12->t1vrr_classes[1][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_p0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+141, r12vrr_stack+1856, r12vrr_stack+2271, r12vrr_stack+2651, r12vrr_stack+2596, r12vrr_stack+1811);
 tmp = r12vrr_stack + 141;
 target_ptr = Libr12->t1vrr_classes[1][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+7692, r12vrr_stack+2651, r12vrr_stack+3121, r12vrr_stack+3583, r12vrr_stack+3517, r12vrr_stack+2596);
 tmp = r12vrr_stack + 7692;
 target_ptr = Libr12->t1vrr_classes[1][9];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_d0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7857, r12vrr_stack+554, r12vrr_stack+4300, r12vrr_stack+984, r12vrr_stack+736, r12vrr_stack+491);
 tmp = r12vrr_stack + 7857;
 target_ptr = Libr12->t1vrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_d0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+4300, r12vrr_stack+984, r12vrr_stack+4510, r12vrr_stack+1550, r12vrr_stack+1224, r12vrr_stack+736);
 tmp = r12vrr_stack + 4300;
 target_ptr = Libr12->t1vrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_d0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+4468, r12vrr_stack+1550, r12vrr_stack+5006, r12vrr_stack+2271, r12vrr_stack+1856, r12vrr_stack+1224);
 tmp = r12vrr_stack + 4468;
 target_ptr = Libr12->t1vrr_classes[2][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_d0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5006, r12vrr_stack+2271, r12vrr_stack+5636, r12vrr_stack+3121, r12vrr_stack+2651, r12vrr_stack+1856);
 tmp = r12vrr_stack + 5006;
 target_ptr = Libr12->t1vrr_classes[2][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|[r12,T1]|m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+5585, r12vrr_stack+3121, r12vrr_stack+6416, r12vrr_stack+6966, r12vrr_stack+3583, r12vrr_stack+2651);
 tmp = r12vrr_stack + 5585;
 target_ptr = Libr12->t1vrr_classes[2][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+3514, r12vrr_stack+15, r12vrr_stack+331, r12vrr_stack+554, r12vrr_stack+491, r12vrr_stack+352, r12vrr_stack+96);
 tmp = r12vrr_stack + 3514;
 target_ptr = Libr12->rvrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+5915, r12vrr_stack+1332, r12vrr_stack+680, r12vrr_stack+984, r12vrr_stack+736, r12vrr_stack+708, r12vrr_stack+491);
 tmp = r12vrr_stack + 5915;
 target_ptr = Libr12->rvrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0||k0)^0 ---*/
 _R_BUILD_d0k0(Data,r12vrr_stack+6386, r12vrr_stack+1416, r12vrr_stack+1152, r12vrr_stack+1550, r12vrr_stack+1224, r12vrr_stack+1188, r12vrr_stack+736);
 tmp = r12vrr_stack + 6386;
 target_ptr = Libr12->rvrr_classes[2][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0||l0)^0 ---*/
 _R_BUILD_d0l0(Data,r12vrr_stack+1332, r12vrr_stack+5366, r12vrr_stack+1766, r12vrr_stack+2271, r12vrr_stack+1856, r12vrr_stack+1811, r12vrr_stack+1224);
 tmp = r12vrr_stack + 1332;
 target_ptr = Libr12->rvrr_classes[2][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0||m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+6602, r12vrr_stack+1991, r12vrr_stack+2541, r12vrr_stack+3121, r12vrr_stack+2651, r12vrr_stack+2596, r12vrr_stack+1856);
 tmp = r12vrr_stack + 6602;
 target_ptr = Libr12->rvrr_classes[2][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];


}

