/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_d0hg(Libderiv_t *, prim_data *);

  /* Computes derivatives of (d0|hg) integrals */

void d12hrr_order_d0hg(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[2][9][11] = int_stack + 0;
 Libderiv->deriv_classes[2][9][10] = int_stack + 330;
 Libderiv->deriv_classes[2][9][9] = int_stack + 660;
 Libderiv->deriv_classes[2][9][8] = int_stack + 990;
 Libderiv->deriv_classes[2][9][7] = int_stack + 1320;
 Libderiv->dvrr_classes[2][8] = int_stack + 1650;
 Libderiv->deriv_classes[2][9][6] = int_stack + 1920;
 Libderiv->deriv_classes[2][9][2] = int_stack + 2250;
 Libderiv->deriv_classes[2][9][1] = int_stack + 2580;
 Libderiv->deriv_classes[2][9][0] = int_stack + 2910;
 Libderiv->deriv2_classes[2][5][143] = int_stack + 3240;
 Libderiv->deriv2_classes[2][6][143] = int_stack + 3366;
 Libderiv->deriv2_classes[2][7][143] = int_stack + 3534;
 Libderiv->deriv2_classes[2][8][143] = int_stack + 3750;
 Libderiv->deriv2_classes[2][9][143] = int_stack + 4020;
 Libderiv->deriv2_classes[2][5][131] = int_stack + 4350;
 Libderiv->deriv2_classes[2][6][131] = int_stack + 4476;
 Libderiv->deriv2_classes[2][7][131] = int_stack + 4644;
 Libderiv->deriv2_classes[2][8][131] = int_stack + 4860;
 Libderiv->deriv2_classes[2][9][131] = int_stack + 5130;
 Libderiv->deriv2_classes[2][5][130] = int_stack + 5460;
 Libderiv->deriv2_classes[2][6][130] = int_stack + 5586;
 Libderiv->deriv2_classes[2][7][130] = int_stack + 5754;
 Libderiv->deriv2_classes[2][8][130] = int_stack + 5970;
 Libderiv->deriv2_classes[2][9][130] = int_stack + 6240;
 Libderiv->deriv2_classes[2][5][119] = int_stack + 6570;
 Libderiv->deriv2_classes[2][6][119] = int_stack + 6696;
 Libderiv->deriv2_classes[2][7][119] = int_stack + 6864;
 Libderiv->deriv2_classes[2][8][119] = int_stack + 7080;
 Libderiv->deriv2_classes[2][9][119] = int_stack + 7350;
 Libderiv->deriv2_classes[2][5][118] = int_stack + 7680;
 Libderiv->deriv2_classes[2][6][118] = int_stack + 7806;
 Libderiv->deriv2_classes[2][7][118] = int_stack + 7974;
 Libderiv->deriv2_classes[2][8][118] = int_stack + 8190;
 Libderiv->deriv2_classes[2][9][118] = int_stack + 8460;
 Libderiv->deriv2_classes[2][5][117] = int_stack + 8790;
 Libderiv->deriv2_classes[2][6][117] = int_stack + 8916;
 Libderiv->deriv2_classes[2][7][117] = int_stack + 9084;
 Libderiv->deriv2_classes[2][8][117] = int_stack + 9300;
 Libderiv->deriv2_classes[2][9][117] = int_stack + 9570;
 Libderiv->deriv2_classes[2][5][107] = int_stack + 9900;
 Libderiv->deriv2_classes[2][6][107] = int_stack + 10026;
 Libderiv->deriv2_classes[2][7][107] = int_stack + 10194;
 Libderiv->deriv2_classes[2][8][107] = int_stack + 10410;
 Libderiv->deriv2_classes[2][9][107] = int_stack + 10680;
 Libderiv->deriv2_classes[2][5][106] = int_stack + 11010;
 Libderiv->deriv2_classes[2][6][106] = int_stack + 11136;
 Libderiv->deriv2_classes[2][7][106] = int_stack + 11304;
 Libderiv->deriv2_classes[2][8][106] = int_stack + 11520;
 Libderiv->deriv2_classes[2][9][106] = int_stack + 11790;
 Libderiv->deriv2_classes[2][5][105] = int_stack + 12120;
 Libderiv->deriv2_classes[2][6][105] = int_stack + 12246;
 Libderiv->deriv2_classes[2][7][105] = int_stack + 12414;
 Libderiv->deriv2_classes[2][8][105] = int_stack + 12630;
 Libderiv->deriv2_classes[2][9][105] = int_stack + 12900;
 Libderiv->deriv2_classes[2][5][104] = int_stack + 13230;
 Libderiv->deriv2_classes[2][6][104] = int_stack + 13356;
 Libderiv->deriv2_classes[2][7][104] = int_stack + 13524;
 Libderiv->deriv2_classes[2][8][104] = int_stack + 13740;
 Libderiv->deriv2_classes[2][9][104] = int_stack + 14010;
 Libderiv->deriv2_classes[2][5][95] = int_stack + 14340;
 Libderiv->deriv2_classes[2][6][95] = int_stack + 14466;
 Libderiv->deriv2_classes[2][7][95] = int_stack + 14634;
 Libderiv->deriv2_classes[2][8][95] = int_stack + 14850;
 Libderiv->deriv2_classes[2][9][95] = int_stack + 15120;
 Libderiv->deriv2_classes[2][5][94] = int_stack + 15450;
 Libderiv->deriv2_classes[2][6][94] = int_stack + 15576;
 Libderiv->deriv2_classes[2][7][94] = int_stack + 15744;
 Libderiv->deriv2_classes[2][8][94] = int_stack + 15960;
 Libderiv->deriv2_classes[2][9][94] = int_stack + 16230;
 Libderiv->deriv2_classes[2][5][93] = int_stack + 16560;
 Libderiv->deriv2_classes[2][6][93] = int_stack + 16686;
 Libderiv->deriv2_classes[2][7][93] = int_stack + 16854;
 Libderiv->deriv2_classes[2][8][93] = int_stack + 17070;
 Libderiv->deriv2_classes[2][9][93] = int_stack + 17340;
 Libderiv->deriv2_classes[2][5][92] = int_stack + 17670;
 Libderiv->deriv2_classes[2][6][92] = int_stack + 17796;
 Libderiv->deriv2_classes[2][7][92] = int_stack + 17964;
 Libderiv->deriv2_classes[2][8][92] = int_stack + 18180;
 Libderiv->deriv2_classes[2][9][92] = int_stack + 18450;
 Libderiv->deriv2_classes[2][5][91] = int_stack + 18780;
 Libderiv->deriv2_classes[2][6][91] = int_stack + 18906;
 Libderiv->deriv2_classes[2][7][91] = int_stack + 19074;
 Libderiv->deriv2_classes[2][8][91] = int_stack + 19290;
 Libderiv->deriv2_classes[2][9][91] = int_stack + 19560;
 Libderiv->deriv_classes[2][5][11] = int_stack + 19890;
 Libderiv->deriv2_classes[2][5][83] = int_stack + 20016;
 Libderiv->deriv_classes[2][6][11] = int_stack + 20142;
 Libderiv->deriv2_classes[2][6][83] = int_stack + 20310;
 Libderiv->deriv_classes[2][7][11] = int_stack + 20478;
 Libderiv->deriv2_classes[2][7][83] = int_stack + 20694;
 Libderiv->deriv_classes[2][8][11] = int_stack + 20910;
 Libderiv->deriv2_classes[2][8][83] = int_stack + 21180;
 Libderiv->deriv2_classes[2][9][83] = int_stack + 21450;
 Libderiv->deriv_classes[2][5][10] = int_stack + 21780;
 Libderiv->deriv2_classes[2][5][82] = int_stack + 21906;
 Libderiv->deriv_classes[2][6][10] = int_stack + 22032;
 Libderiv->deriv2_classes[2][6][82] = int_stack + 22200;
 Libderiv->deriv_classes[2][7][10] = int_stack + 22368;
 Libderiv->deriv2_classes[2][7][82] = int_stack + 22584;
 Libderiv->deriv_classes[2][8][10] = int_stack + 22800;
 Libderiv->deriv2_classes[2][8][82] = int_stack + 23070;
 Libderiv->deriv2_classes[2][9][82] = int_stack + 23340;
 Libderiv->deriv_classes[2][5][9] = int_stack + 23670;
 Libderiv->deriv2_classes[2][5][81] = int_stack + 23796;
 Libderiv->deriv_classes[2][6][9] = int_stack + 23922;
 Libderiv->deriv2_classes[2][6][81] = int_stack + 24090;
 Libderiv->deriv_classes[2][7][9] = int_stack + 24258;
 Libderiv->deriv2_classes[2][7][81] = int_stack + 24474;
 Libderiv->deriv_classes[2][8][9] = int_stack + 24690;
 Libderiv->deriv2_classes[2][8][81] = int_stack + 24960;
 Libderiv->deriv2_classes[2][9][81] = int_stack + 25230;
 Libderiv->deriv_classes[2][5][8] = int_stack + 25560;
 Libderiv->deriv2_classes[2][5][80] = int_stack + 25686;
 Libderiv->deriv_classes[2][6][8] = int_stack + 25812;
 Libderiv->deriv2_classes[2][6][80] = int_stack + 25980;
 Libderiv->deriv_classes[2][7][8] = int_stack + 26148;
 Libderiv->deriv2_classes[2][7][80] = int_stack + 26364;
 Libderiv->deriv_classes[2][8][8] = int_stack + 26580;
 Libderiv->deriv2_classes[2][8][80] = int_stack + 26850;
 Libderiv->deriv2_classes[2][9][80] = int_stack + 27120;
 Libderiv->deriv_classes[2][5][7] = int_stack + 27450;
 Libderiv->deriv2_classes[2][5][79] = int_stack + 27576;
 Libderiv->deriv_classes[2][6][7] = int_stack + 27702;
 Libderiv->deriv2_classes[2][6][79] = int_stack + 27870;
 Libderiv->deriv_classes[2][7][7] = int_stack + 28038;
 Libderiv->deriv2_classes[2][7][79] = int_stack + 28254;
 Libderiv->deriv_classes[2][8][7] = int_stack + 28470;
 Libderiv->deriv2_classes[2][8][79] = int_stack + 28740;
 Libderiv->deriv2_classes[2][9][79] = int_stack + 29010;
 Libderiv->dvrr_classes[2][5] = int_stack + 29340;
 Libderiv->deriv_classes[2][5][6] = int_stack + 29466;
 Libderiv->deriv2_classes[2][5][78] = int_stack + 29592;
 Libderiv->dvrr_classes[2][6] = int_stack + 29718;
 Libderiv->deriv_classes[2][6][6] = int_stack + 29886;
 Libderiv->deriv2_classes[2][6][78] = int_stack + 30054;
 Libderiv->dvrr_classes[2][7] = int_stack + 30222;
 Libderiv->deriv_classes[2][7][6] = int_stack + 30438;
 Libderiv->deriv2_classes[2][7][78] = int_stack + 30654;
 Libderiv->deriv_classes[2][8][6] = int_stack + 30870;
 Libderiv->deriv2_classes[2][8][78] = int_stack + 31140;
 Libderiv->deriv2_classes[2][9][78] = int_stack + 31410;
 Libderiv->deriv2_classes[2][5][35] = int_stack + 31740;
 Libderiv->deriv2_classes[2][6][35] = int_stack + 31866;
 Libderiv->deriv2_classes[2][7][35] = int_stack + 32034;
 Libderiv->deriv2_classes[2][8][35] = int_stack + 32250;
 Libderiv->deriv2_classes[2][9][35] = int_stack + 32520;
 Libderiv->deriv2_classes[2][5][34] = int_stack + 32850;
 Libderiv->deriv2_classes[2][6][34] = int_stack + 32976;
 Libderiv->deriv2_classes[2][7][34] = int_stack + 33144;
 Libderiv->deriv2_classes[2][8][34] = int_stack + 33360;
 Libderiv->deriv2_classes[2][9][34] = int_stack + 33630;
 Libderiv->deriv2_classes[2][5][33] = int_stack + 33960;
 Libderiv->deriv2_classes[2][6][33] = int_stack + 34086;
 Libderiv->deriv2_classes[2][7][33] = int_stack + 34254;
 Libderiv->deriv2_classes[2][8][33] = int_stack + 34470;
 Libderiv->deriv2_classes[2][9][33] = int_stack + 34740;
 Libderiv->deriv2_classes[2][5][32] = int_stack + 35070;
 Libderiv->deriv2_classes[2][6][32] = int_stack + 35196;
 Libderiv->deriv2_classes[2][7][32] = int_stack + 35364;
 Libderiv->deriv2_classes[2][8][32] = int_stack + 35580;
 Libderiv->deriv2_classes[2][9][32] = int_stack + 35850;
 Libderiv->deriv2_classes[2][5][31] = int_stack + 36180;
 Libderiv->deriv2_classes[2][6][31] = int_stack + 36306;
 Libderiv->deriv2_classes[2][7][31] = int_stack + 36474;
 Libderiv->deriv2_classes[2][8][31] = int_stack + 36690;
 Libderiv->deriv2_classes[2][9][31] = int_stack + 36960;
 Libderiv->deriv_classes[2][5][2] = int_stack + 37290;
 Libderiv->deriv2_classes[2][5][30] = int_stack + 37416;
 Libderiv->deriv_classes[2][6][2] = int_stack + 37542;
 Libderiv->deriv2_classes[2][6][30] = int_stack + 37710;
 Libderiv->deriv_classes[2][7][2] = int_stack + 37878;
 Libderiv->deriv2_classes[2][7][30] = int_stack + 38094;
 Libderiv->deriv_classes[2][8][2] = int_stack + 38310;
 Libderiv->deriv2_classes[2][8][30] = int_stack + 38580;
 Libderiv->deriv2_classes[2][9][30] = int_stack + 38850;
 Libderiv->deriv2_classes[2][5][26] = int_stack + 39180;
 Libderiv->deriv2_classes[2][6][26] = int_stack + 39306;
 Libderiv->deriv2_classes[2][7][26] = int_stack + 39474;
 Libderiv->deriv2_classes[2][8][26] = int_stack + 39690;
 Libderiv->deriv2_classes[2][9][26] = int_stack + 39960;
 Libderiv->deriv2_classes[2][5][23] = int_stack + 40290;
 Libderiv->deriv2_classes[2][6][23] = int_stack + 40416;
 Libderiv->deriv2_classes[2][7][23] = int_stack + 40584;
 Libderiv->deriv2_classes[2][8][23] = int_stack + 40800;
 Libderiv->deriv2_classes[2][9][23] = int_stack + 41070;
 Libderiv->deriv2_classes[2][5][22] = int_stack + 41400;
 Libderiv->deriv2_classes[2][6][22] = int_stack + 41526;
 Libderiv->deriv2_classes[2][7][22] = int_stack + 41694;
 Libderiv->deriv2_classes[2][8][22] = int_stack + 41910;
 Libderiv->deriv2_classes[2][9][22] = int_stack + 42180;
 Libderiv->deriv2_classes[2][5][21] = int_stack + 42510;
 Libderiv->deriv2_classes[2][6][21] = int_stack + 42636;
 Libderiv->deriv2_classes[2][7][21] = int_stack + 42804;
 Libderiv->deriv2_classes[2][8][21] = int_stack + 43020;
 Libderiv->deriv2_classes[2][9][21] = int_stack + 43290;
 Libderiv->deriv2_classes[2][5][20] = int_stack + 43620;
 Libderiv->deriv2_classes[2][6][20] = int_stack + 43746;
 Libderiv->deriv2_classes[2][7][20] = int_stack + 43914;
 Libderiv->deriv2_classes[2][8][20] = int_stack + 44130;
 Libderiv->deriv2_classes[2][9][20] = int_stack + 44400;
 Libderiv->deriv2_classes[2][5][19] = int_stack + 44730;
 Libderiv->deriv2_classes[2][6][19] = int_stack + 44856;
 Libderiv->deriv2_classes[2][7][19] = int_stack + 45024;
 Libderiv->deriv2_classes[2][8][19] = int_stack + 45240;
 Libderiv->deriv2_classes[2][9][19] = int_stack + 45510;
 Libderiv->deriv_classes[2][5][1] = int_stack + 45840;
 Libderiv->deriv2_classes[2][5][18] = int_stack + 45966;
 Libderiv->deriv_classes[2][6][1] = int_stack + 46092;
 Libderiv->deriv2_classes[2][6][18] = int_stack + 46260;
 Libderiv->deriv_classes[2][7][1] = int_stack + 46428;
 Libderiv->deriv2_classes[2][7][18] = int_stack + 46644;
 Libderiv->deriv_classes[2][8][1] = int_stack + 46860;
 Libderiv->deriv2_classes[2][8][18] = int_stack + 47130;
 Libderiv->deriv2_classes[2][9][18] = int_stack + 47400;
 Libderiv->deriv2_classes[2][5][14] = int_stack + 47730;
 Libderiv->deriv2_classes[2][6][14] = int_stack + 47856;
 Libderiv->deriv2_classes[2][7][14] = int_stack + 48024;
 Libderiv->deriv2_classes[2][8][14] = int_stack + 48240;
 Libderiv->deriv2_classes[2][9][14] = int_stack + 48510;
 Libderiv->deriv2_classes[2][5][13] = int_stack + 48840;
 Libderiv->deriv2_classes[2][6][13] = int_stack + 48966;
 Libderiv->deriv2_classes[2][7][13] = int_stack + 49134;
 Libderiv->deriv2_classes[2][8][13] = int_stack + 49350;
 Libderiv->deriv2_classes[2][9][13] = int_stack + 49620;
 Libderiv->deriv2_classes[2][5][11] = int_stack + 49950;
 Libderiv->deriv2_classes[2][6][11] = int_stack + 50076;
 Libderiv->deriv2_classes[2][7][11] = int_stack + 50244;
 Libderiv->deriv2_classes[2][8][11] = int_stack + 50460;
 Libderiv->deriv2_classes[2][9][11] = int_stack + 50730;
 Libderiv->deriv2_classes[2][5][10] = int_stack + 51060;
 Libderiv->deriv2_classes[2][6][10] = int_stack + 51186;
 Libderiv->deriv2_classes[2][7][10] = int_stack + 51354;
 Libderiv->deriv2_classes[2][8][10] = int_stack + 51570;
 Libderiv->deriv2_classes[2][9][10] = int_stack + 51840;
 Libderiv->deriv2_classes[2][5][9] = int_stack + 52170;
 Libderiv->deriv2_classes[2][6][9] = int_stack + 52296;
 Libderiv->deriv2_classes[2][7][9] = int_stack + 52464;
 Libderiv->deriv2_classes[2][8][9] = int_stack + 52680;
 Libderiv->deriv2_classes[2][9][9] = int_stack + 52950;
 Libderiv->deriv2_classes[2][5][8] = int_stack + 53280;
 Libderiv->deriv2_classes[2][6][8] = int_stack + 53406;
 Libderiv->deriv2_classes[2][7][8] = int_stack + 53574;
 Libderiv->deriv2_classes[2][8][8] = int_stack + 53790;
 Libderiv->deriv2_classes[2][9][8] = int_stack + 54060;
 Libderiv->deriv2_classes[2][5][7] = int_stack + 54390;
 Libderiv->deriv2_classes[2][6][7] = int_stack + 54516;
 Libderiv->deriv2_classes[2][7][7] = int_stack + 54684;
 Libderiv->deriv2_classes[2][8][7] = int_stack + 54900;
 Libderiv->deriv2_classes[2][9][7] = int_stack + 55170;
 Libderiv->deriv_classes[2][5][0] = int_stack + 55500;
 Libderiv->deriv2_classes[2][5][6] = int_stack + 55626;
 Libderiv->deriv_classes[2][6][0] = int_stack + 55752;
 Libderiv->deriv2_classes[2][6][6] = int_stack + 55920;
 Libderiv->deriv_classes[2][7][0] = int_stack + 56088;
 Libderiv->deriv2_classes[2][7][6] = int_stack + 56304;
 Libderiv->deriv_classes[2][8][0] = int_stack + 56520;
 Libderiv->deriv2_classes[2][8][6] = int_stack + 56790;
 Libderiv->deriv2_classes[2][9][6] = int_stack + 57060;
 Libderiv->deriv2_classes[2][5][2] = int_stack + 57390;
 Libderiv->deriv2_classes[2][6][2] = int_stack + 57516;
 Libderiv->deriv2_classes[2][7][2] = int_stack + 57684;
 Libderiv->deriv2_classes[2][8][2] = int_stack + 57900;
 Libderiv->deriv2_classes[2][9][2] = int_stack + 58170;
 Libderiv->deriv2_classes[2][5][1] = int_stack + 58500;
 Libderiv->deriv2_classes[2][6][1] = int_stack + 58626;
 Libderiv->deriv2_classes[2][7][1] = int_stack + 58794;
 Libderiv->deriv2_classes[2][8][1] = int_stack + 59010;
 Libderiv->deriv2_classes[2][9][1] = int_stack + 59280;
 Libderiv->deriv2_classes[2][5][0] = int_stack + 59610;
 Libderiv->deriv2_classes[2][6][0] = int_stack + 59736;
 Libderiv->deriv2_classes[2][7][0] = int_stack + 59904;
 Libderiv->deriv2_classes[2][8][0] = int_stack + 60120;
 Libderiv->deriv2_classes[2][9][0] = int_stack + 60390;
 memset(int_stack,0,485760);

 Libderiv->dvrr_stack = int_stack + 177438;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_d0hg(Libderiv, Data);
   Data++;
 }

 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+60720,int_stack+29718,int_stack+29340,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+61098,int_stack+30222,int_stack+29718,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+61602,int_stack+61098,int_stack+60720,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+62358,int_stack+1650,int_stack+30222,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+63006,int_stack+62358,int_stack+61098,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+64014,int_stack+63006,int_stack+61602,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+65274,int_stack+20142,int_stack+19890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29340,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+65652,int_stack+20478,int_stack+20142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29718,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+66156,int_stack+65652,int_stack+65274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60720,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+66912,int_stack+20910,int_stack+20478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30222,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+67560,int_stack+66912,int_stack+65652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61098,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+68568,int_stack+67560,int_stack+66156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61602,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+69828,int_stack+0,int_stack+20910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1650,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+70638,int_stack+69828,int_stack+66912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62358,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+71934,int_stack+70638,int_stack+67560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63006,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+69828,int_stack+22032,int_stack+21780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29340, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+70206,int_stack+22368,int_stack+22032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29718, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+70710,int_stack+70206,int_stack+69828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60720, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+73614,int_stack+22800,int_stack+22368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30222, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+74262,int_stack+73614,int_stack+70206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61098, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+75270,int_stack+74262,int_stack+70710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61602, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+76530,int_stack+330,int_stack+22800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1650, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+77340,int_stack+76530,int_stack+73614, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62358, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+78636,int_stack+77340,int_stack+74262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63006, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+76530,int_stack+23922,int_stack+23670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29340, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+76908,int_stack+24258,int_stack+23922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29718, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+77412,int_stack+76908,int_stack+76530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60720, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+24690,int_stack+24258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30222, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+80316,int_stack+0,int_stack+76908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61098, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+81324,int_stack+80316,int_stack+77412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61602, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+82584,int_stack+660,int_stack+24690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1650, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+83394,int_stack+82584,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62358, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+84690,int_stack+83394,int_stack+80316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63006, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+82584,int_stack+25812,int_stack+25560, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+82962,int_stack+26148,int_stack+25812, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29718, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+83466,int_stack+82962,int_stack+82584, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+60720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+86370,int_stack+26580,int_stack+26148, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+87018,int_stack+86370,int_stack+82962, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+88026,int_stack+87018,int_stack+83466, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+89286,int_stack+990,int_stack+26580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+90096,int_stack+89286,int_stack+86370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+91392,int_stack+90096,int_stack+87018, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+89286,int_stack+27702,int_stack+27450, 0.0, zero_stack, 1.0, int_stack+29340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+89664,int_stack+28038,int_stack+27702, 0.0, zero_stack, 1.0, int_stack+29718, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+90168,int_stack+89664,int_stack+89286, 0.0, zero_stack, 1.0, int_stack+60720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+648,int_stack+28470,int_stack+28038, 0.0, zero_stack, 1.0, int_stack+30222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+93072,int_stack+648,int_stack+89664, 0.0, zero_stack, 1.0, int_stack+61098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+94080,int_stack+93072,int_stack+90168, 0.0, zero_stack, 1.0, int_stack+61602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+95340,int_stack+1320,int_stack+28470, 0.0, zero_stack, 1.0, int_stack+1650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+96150,int_stack+95340,int_stack+648, 0.0, zero_stack, 1.0, int_stack+62358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+97446,int_stack+96150,int_stack+93072, 0.0, zero_stack, 1.0, int_stack+63006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+95340,int_stack+29886,int_stack+29466, 1.0, int_stack+29340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+95718,int_stack+30438,int_stack+29886, 1.0, int_stack+29718, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+96222,int_stack+95718,int_stack+95340, 1.0, int_stack+60720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+99126,int_stack+30870,int_stack+30438, 1.0, int_stack+30222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+99774,int_stack+99126,int_stack+95718, 1.0, int_stack+61098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+100782,int_stack+99774,int_stack+96222, 1.0, int_stack+61602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+60720,int_stack+1920,int_stack+30870, 1.0, int_stack+1650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+102042,int_stack+60720,int_stack+99126, 1.0, int_stack+62358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+60720,int_stack+102042,int_stack+99774, 1.0, int_stack+63006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+102042,int_stack+37542,int_stack+37290,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+102420,int_stack+37878,int_stack+37542,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+102924,int_stack+102420,int_stack+102042,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+62400,int_stack+38310,int_stack+37878,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+103680,int_stack+62400,int_stack+102420,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+104688,int_stack+103680,int_stack+102924,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+63048,int_stack+2250,int_stack+38310,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+105948,int_stack+63048,int_stack+62400,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+107244,int_stack+105948,int_stack+103680,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+105948,int_stack+46092,int_stack+45840,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+106326,int_stack+46428,int_stack+46092,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+63048,int_stack+106326,int_stack+105948,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1296,int_stack+46860,int_stack+46428,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+108924,int_stack+1296,int_stack+106326,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+109932,int_stack+108924,int_stack+63048,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+111192,int_stack+2580,int_stack+46860,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+112002,int_stack+111192,int_stack+1296,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+113298,int_stack+112002,int_stack+108924,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+111192,int_stack+55752,int_stack+55500,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+111570,int_stack+56088,int_stack+55752,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+112074,int_stack+111570,int_stack+111192,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1944,int_stack+56520,int_stack+56088,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+114978,int_stack+1944,int_stack+111570,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+115986,int_stack+114978,int_stack+112074,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+117246,int_stack+2910,int_stack+56520,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+118056,int_stack+117246,int_stack+1944,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+119352,int_stack+118056,int_stack+114978,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+117246,int_stack+3366,int_stack+3240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+19890,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+117624,int_stack+3534,int_stack+3366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+20142,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+118128,int_stack+117624,int_stack+117246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+65274,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+3750,int_stack+3534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+20478,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2592,int_stack+121032,int_stack+117624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+65652,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+121680,int_stack+2592,int_stack+118128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+66156,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+117246,int_stack+4020,int_stack+3750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+20910,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+118056,int_stack+117246,int_stack+121032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+66912,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+122940,int_stack+118056,int_stack+2592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+67560,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2592,int_stack+4476,int_stack+4350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19890, 1.0, int_stack+21780,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2970,int_stack+4644,int_stack+4476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20142, 1.0, int_stack+22032,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3474,int_stack+2970,int_stack+2592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65274, 1.0, int_stack+69828,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+4860,int_stack+4644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20478, 1.0, int_stack+22368,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+117246,int_stack+121032,int_stack+2970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65652, 1.0, int_stack+70206,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+124620,int_stack+117246,int_stack+3474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66156, 1.0, int_stack+70710,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2592,int_stack+5130,int_stack+4860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20910, 1.0, int_stack+22800,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3402,int_stack+2592,int_stack+121032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66912, 1.0, int_stack+73614,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+125880,int_stack+3402,int_stack+117246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67560, 1.0, int_stack+74262,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+117246,int_stack+5586,int_stack+5460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+21780, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+117624,int_stack+5754,int_stack+5586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+22032, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+118128,int_stack+117624,int_stack+117246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+69828, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+5970,int_stack+5754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+22368, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2592,int_stack+121032,int_stack+117624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+70206, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3600,int_stack+2592,int_stack+118128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+70710, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+117246,int_stack+6240,int_stack+5970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+22800, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+118056,int_stack+117246,int_stack+121032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+73614, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4860,int_stack+118056,int_stack+2592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+74262, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2592,int_stack+6696,int_stack+6570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19890, 0.0, zero_stack, 1.0, int_stack+23670,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2970,int_stack+6864,int_stack+6696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20142, 0.0, zero_stack, 1.0, int_stack+23922,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+117246,int_stack+2970,int_stack+2592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65274, 0.0, zero_stack, 1.0, int_stack+76530,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+7080,int_stack+6864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20478, 0.0, zero_stack, 1.0, int_stack+24258,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+118002,int_stack+121032,int_stack+2970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65652, 0.0, zero_stack, 1.0, int_stack+76908,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+127560,int_stack+118002,int_stack+117246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66156, 0.0, zero_stack, 1.0, int_stack+77412,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2592,int_stack+7350,int_stack+7080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20910, 0.0, zero_stack, 1.0, int_stack+24690,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+128820,int_stack+2592,int_stack+121032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66912, 0.0, zero_stack, 1.0, int_stack+0,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+130116,int_stack+128820,int_stack+118002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67560, 0.0, zero_stack, 1.0, int_stack+80316,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+128820,int_stack+7806,int_stack+7680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21780, 1.0, int_stack+23670, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+129198,int_stack+7974,int_stack+7806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22032, 1.0, int_stack+23922, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2592,int_stack+129198,int_stack+128820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69828, 1.0, int_stack+76530, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+8190,int_stack+7974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22368, 1.0, int_stack+24258, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+117246,int_stack+121032,int_stack+129198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70206, 1.0, int_stack+76908, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+128820,int_stack+117246,int_stack+2592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70710, 1.0, int_stack+77412, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2592,int_stack+8460,int_stack+8190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22800, 1.0, int_stack+24690, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6540,int_stack+2592,int_stack+121032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73614, 1.0, int_stack+0, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+131796,int_stack+6540,int_stack+117246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74262, 1.0, int_stack+80316, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+117246,int_stack+8916,int_stack+8790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+23670, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+117624,int_stack+9084,int_stack+8916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+23922, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+118128,int_stack+117624,int_stack+117246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+76530, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+9300,int_stack+9084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+24258, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2592,int_stack+121032,int_stack+117624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+76908, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6540,int_stack+2592,int_stack+118128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+77412, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+117246,int_stack+9570,int_stack+9300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+24690, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+118056,int_stack+117246,int_stack+121032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7800,int_stack+118056,int_stack+2592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+80316, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2592,int_stack+10026,int_stack+9900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25560,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2970,int_stack+10194,int_stack+10026, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20142, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+25812,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+117246,int_stack+2970,int_stack+2592, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82584,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+10410,int_stack+10194, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20478, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26148,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+118002,int_stack+121032,int_stack+2970, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65652, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82962,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+133476,int_stack+118002,int_stack+117246, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66156, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83466,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2592,int_stack+10680,int_stack+10410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20910, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26580,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+9480,int_stack+2592,int_stack+121032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66912, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+86370,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+134736,int_stack+9480,int_stack+118002, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67560, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87018,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9480,int_stack+11136,int_stack+11010, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21780, 0.0, zero_stack, 1.0, int_stack+25560, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+9858,int_stack+11304,int_stack+11136, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22032, 0.0, zero_stack, 1.0, int_stack+25812, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10362,int_stack+9858,int_stack+9480, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69828, 0.0, zero_stack, 1.0, int_stack+82584, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+11520,int_stack+11304, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22368, 0.0, zero_stack, 1.0, int_stack+26148, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2592,int_stack+121032,int_stack+9858, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70206, 0.0, zero_stack, 1.0, int_stack+82962, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+117246,int_stack+2592,int_stack+10362, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70710, 0.0, zero_stack, 1.0, int_stack+83466, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9480,int_stack+11790,int_stack+11520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22800, 0.0, zero_stack, 1.0, int_stack+26580, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10290,int_stack+9480,int_stack+121032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73614, 0.0, zero_stack, 1.0, int_stack+86370, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+136416,int_stack+10290,int_stack+2592, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74262, 0.0, zero_stack, 1.0, int_stack+87018, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2592,int_stack+12246,int_stack+12120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23670, 1.0, int_stack+25560, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2970,int_stack+12414,int_stack+12246, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23922, 1.0, int_stack+25812, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9480,int_stack+2970,int_stack+2592, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76530, 1.0, int_stack+82584, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+12630,int_stack+12414, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24258, 1.0, int_stack+26148, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10236,int_stack+121032,int_stack+2970, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76908, 1.0, int_stack+82962, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+11244,int_stack+10236,int_stack+9480, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77412, 1.0, int_stack+83466, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2592,int_stack+12900,int_stack+12630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24690, 1.0, int_stack+26580, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+138096,int_stack+2592,int_stack+121032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+86370, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+139392,int_stack+138096,int_stack+10236, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80316, 1.0, int_stack+87018, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+138096,int_stack+13356,int_stack+13230, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+25560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+138474,int_stack+13524,int_stack+13356, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+25812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2592,int_stack+138474,int_stack+138096, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+82584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+13740,int_stack+13524, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+26148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+9480,int_stack+121032,int_stack+138474, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+82962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+138096,int_stack+9480,int_stack+2592, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+83466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2592,int_stack+14010,int_stack+13740, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+26580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+12504,int_stack+2592,int_stack+121032, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+86370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+141072,int_stack+12504,int_stack+9480, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+87018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9480,int_stack+14466,int_stack+14340, 0.0, zero_stack, 1.0, int_stack+19890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27450,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+9858,int_stack+14634,int_stack+14466, 0.0, zero_stack, 1.0, int_stack+20142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27702,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10362,int_stack+9858,int_stack+9480, 0.0, zero_stack, 1.0, int_stack+65274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89286,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+14850,int_stack+14634, 0.0, zero_stack, 1.0, int_stack+20478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28038,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2592,int_stack+121032,int_stack+9858, 0.0, zero_stack, 1.0, int_stack+65652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89664,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12504,int_stack+2592,int_stack+10362, 0.0, zero_stack, 1.0, int_stack+66156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90168,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9480,int_stack+15120,int_stack+14850, 0.0, zero_stack, 1.0, int_stack+20910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28470,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+13764,int_stack+9480,int_stack+121032, 0.0, zero_stack, 1.0, int_stack+66912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+648,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+9480,int_stack+13764,int_stack+2592, 0.0, zero_stack, 1.0, int_stack+67560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93072,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2592,int_stack+15576,int_stack+15450, 0.0, zero_stack, 1.0, int_stack+21780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27450, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2970,int_stack+15744,int_stack+15576, 0.0, zero_stack, 1.0, int_stack+22032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+27702, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13764,int_stack+2970,int_stack+2592, 0.0, zero_stack, 1.0, int_stack+69828, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89286, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+15960,int_stack+15744, 0.0, zero_stack, 1.0, int_stack+22368, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28038, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+14520,int_stack+121032,int_stack+2970, 0.0, zero_stack, 1.0, int_stack+70206, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89664, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+142752,int_stack+14520,int_stack+13764, 0.0, zero_stack, 1.0, int_stack+70710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90168, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2592,int_stack+16230,int_stack+15960, 0.0, zero_stack, 1.0, int_stack+22800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28470, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+144012,int_stack+2592,int_stack+121032, 0.0, zero_stack, 1.0, int_stack+73614, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+648, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+145308,int_stack+144012,int_stack+14520, 0.0, zero_stack, 1.0, int_stack+74262, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93072, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+144012,int_stack+16686,int_stack+16560, 0.0, zero_stack, 1.0, int_stack+23670, 0.0, zero_stack, 1.0, int_stack+27450, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+144390,int_stack+16854,int_stack+16686, 0.0, zero_stack, 1.0, int_stack+23922, 0.0, zero_stack, 1.0, int_stack+27702, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2592,int_stack+144390,int_stack+144012, 0.0, zero_stack, 1.0, int_stack+76530, 0.0, zero_stack, 1.0, int_stack+89286, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+17070,int_stack+16854, 0.0, zero_stack, 1.0, int_stack+24258, 0.0, zero_stack, 1.0, int_stack+28038, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13764,int_stack+121032,int_stack+144390, 0.0, zero_stack, 1.0, int_stack+76908, 0.0, zero_stack, 1.0, int_stack+89664, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+144012,int_stack+13764,int_stack+2592, 0.0, zero_stack, 1.0, int_stack+77412, 0.0, zero_stack, 1.0, int_stack+90168, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2592,int_stack+17340,int_stack+17070, 0.0, zero_stack, 1.0, int_stack+24690, 0.0, zero_stack, 1.0, int_stack+28470, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+14772,int_stack+2592,int_stack+121032, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+648, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+146988,int_stack+14772,int_stack+13764, 0.0, zero_stack, 1.0, int_stack+80316, 0.0, zero_stack, 1.0, int_stack+93072, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13764,int_stack+17796,int_stack+17670, 0.0, zero_stack, 1.0, int_stack+25560, 1.0, int_stack+27450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+14142,int_stack+17964,int_stack+17796, 0.0, zero_stack, 1.0, int_stack+25812, 1.0, int_stack+27702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+14646,int_stack+14142,int_stack+13764, 0.0, zero_stack, 1.0, int_stack+82584, 1.0, int_stack+89286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+18180,int_stack+17964, 0.0, zero_stack, 1.0, int_stack+26148, 1.0, int_stack+28038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2592,int_stack+121032,int_stack+14142, 0.0, zero_stack, 1.0, int_stack+82962, 1.0, int_stack+89664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+15402,int_stack+2592,int_stack+14646, 0.0, zero_stack, 1.0, int_stack+83466, 1.0, int_stack+90168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13764,int_stack+18450,int_stack+18180, 0.0, zero_stack, 1.0, int_stack+26580, 1.0, int_stack+28470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+16662,int_stack+13764,int_stack+121032, 0.0, zero_stack, 1.0, int_stack+86370, 1.0, int_stack+648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+148668,int_stack+16662,int_stack+2592, 0.0, zero_stack, 1.0, int_stack+87018, 1.0, int_stack+93072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2592,int_stack+18906,int_stack+18780, 0.0, zero_stack, 2.0, int_stack+27450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2970,int_stack+19074,int_stack+18906, 0.0, zero_stack, 2.0, int_stack+27702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+16662,int_stack+2970,int_stack+2592, 0.0, zero_stack, 2.0, int_stack+89286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+19290,int_stack+19074, 0.0, zero_stack, 2.0, int_stack+28038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+17418,int_stack+121032,int_stack+2970, 0.0, zero_stack, 2.0, int_stack+89664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13764,int_stack+17418,int_stack+16662, 0.0, zero_stack, 2.0, int_stack+90168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2592,int_stack+19560,int_stack+19290, 0.0, zero_stack, 2.0, int_stack+28470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+18426,int_stack+2592,int_stack+121032, 0.0, zero_stack, 2.0, int_stack+648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+150348,int_stack+18426,int_stack+17418, 0.0, zero_stack, 2.0, int_stack+93072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+20310,int_stack+20016, 1.0, int_stack+19890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29466,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+121032,int_stack+20694,int_stack+20310, 1.0, int_stack+20142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29886,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2592,int_stack+121032,int_stack+15024, 1.0, int_stack+65274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95340,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+16662,int_stack+21180,int_stack+20694, 1.0, int_stack+20478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30438,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+17310,int_stack+16662,int_stack+121032, 1.0, int_stack+65652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95718,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+18318,int_stack+17310,int_stack+2592, 1.0, int_stack+66156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96222,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2592,int_stack+21450,int_stack+21180, 1.0, int_stack+20910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30870,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+65274,int_stack+2592,int_stack+16662, 1.0, int_stack+66912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99126,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+19578,int_stack+65274,int_stack+17310, 1.0, int_stack+67560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99774,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+22200,int_stack+21906, 1.0, int_stack+21780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29466, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+65274,int_stack+22584,int_stack+22200, 1.0, int_stack+22032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29886, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+65778,int_stack+65274,int_stack+15024, 1.0, int_stack+69828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95340, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+23070,int_stack+22584, 1.0, int_stack+22368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30438, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2592,int_stack+121032,int_stack+65274, 1.0, int_stack+70206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95718, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+66534,int_stack+2592,int_stack+65778, 1.0, int_stack+70710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96222, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+65274,int_stack+23340,int_stack+23070, 1.0, int_stack+22800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30870, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+69828,int_stack+65274,int_stack+121032, 1.0, int_stack+73614, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99126, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+21258,int_stack+69828,int_stack+2592, 1.0, int_stack+74262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99774, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+24090,int_stack+23796, 1.0, int_stack+23670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29466, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2592,int_stack+24474,int_stack+24090, 1.0, int_stack+23922, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29886, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+69828,int_stack+2592,int_stack+15024, 1.0, int_stack+76530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95340, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+24960,int_stack+24474, 1.0, int_stack+24258, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30438, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+70584,int_stack+121032,int_stack+2592, 1.0, int_stack+76908, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95718, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+65274,int_stack+70584,int_stack+69828, 1.0, int_stack+77412, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96222, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2592,int_stack+25230,int_stack+24960, 1.0, int_stack+24690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+30870, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+76530,int_stack+2592,int_stack+121032, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99126, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+22938,int_stack+76530,int_stack+70584, 1.0, int_stack+80316, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99774, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+25980,int_stack+25686, 1.0, int_stack+25560, 0.0, zero_stack, 1.0, int_stack+29466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+80316,int_stack+26364,int_stack+25980, 1.0, int_stack+25812, 0.0, zero_stack, 1.0, int_stack+29886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+80316,int_stack+15024, 1.0, int_stack+82584, 0.0, zero_stack, 1.0, int_stack+95340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+26850,int_stack+26364, 1.0, int_stack+26148, 0.0, zero_stack, 1.0, int_stack+30438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2592,int_stack+0,int_stack+80316, 1.0, int_stack+82962, 0.0, zero_stack, 1.0, int_stack+95718, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+77286,int_stack+2592,int_stack+76530, 1.0, int_stack+83466, 0.0, zero_stack, 1.0, int_stack+96222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+80316,int_stack+27120,int_stack+26850, 1.0, int_stack+26580, 0.0, zero_stack, 1.0, int_stack+30870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+82584,int_stack+80316,int_stack+0, 1.0, int_stack+86370, 0.0, zero_stack, 1.0, int_stack+99126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+69828,int_stack+82584,int_stack+2592, 1.0, int_stack+87018, 0.0, zero_stack, 1.0, int_stack+99774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+27870,int_stack+27576, 1.0, int_stack+27450, 1.0, int_stack+29466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2592,int_stack+28254,int_stack+27870, 1.0, int_stack+27702, 1.0, int_stack+29886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+2592,int_stack+15024, 1.0, int_stack+89286, 1.0, int_stack+95340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+28740,int_stack+28254, 1.0, int_stack+28038, 1.0, int_stack+30438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+80316,int_stack+0,int_stack+2592, 1.0, int_stack+89664, 1.0, int_stack+95718, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+82584,int_stack+80316,int_stack+76530, 1.0, int_stack+90168, 1.0, int_stack+96222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2592,int_stack+29010,int_stack+28740, 1.0, int_stack+28470, 1.0, int_stack+30870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+89286,int_stack+2592,int_stack+0, 1.0, int_stack+648, 1.0, int_stack+99126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+24618,int_stack+89286,int_stack+80316, 1.0, int_stack+93072, 1.0, int_stack+99774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+30054,int_stack+29592, 2.0, int_stack+29466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93072,int_stack+30654,int_stack+30054, 2.0, int_stack+29886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+93072,int_stack+15024, 2.0, int_stack+95340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+31140,int_stack+30654, 2.0, int_stack+30438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+80316,int_stack+121032,int_stack+93072, 2.0, int_stack+95718, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+89286,int_stack+80316,int_stack+76530, 2.0, int_stack+96222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+93072,int_stack+31410,int_stack+31140, 2.0, int_stack+30870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+93072,int_stack+121032, 2.0, int_stack+99126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+95340,int_stack+0,int_stack+80316, 2.0, int_stack+99774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+31866,int_stack+31740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37290,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+80316,int_stack+32034,int_stack+31866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37542,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+80316,int_stack+15024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102042,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+32250,int_stack+32034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37878,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+93072,int_stack+121032,int_stack+80316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102420,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+93072,int_stack+76530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102924,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+80316,int_stack+32520,int_stack+32250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38310,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+99126,int_stack+80316,int_stack+121032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62400,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+26298,int_stack+99126,int_stack+93072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103680,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+32976,int_stack+32850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37290, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93072,int_stack+33144,int_stack+32976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37542, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+93072,int_stack+15024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102042, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+33360,int_stack+33144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37878, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+80316,int_stack+121032,int_stack+93072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102420, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+99126,int_stack+80316,int_stack+76530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102924, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+93072,int_stack+33630,int_stack+33360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38310, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+86370,int_stack+93072,int_stack+121032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62400, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+27978,int_stack+86370,int_stack+80316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103680, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+34086,int_stack+33960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37290, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+80316,int_stack+34254,int_stack+34086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37542, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+80316,int_stack+15024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102042, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+34470,int_stack+34254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37878, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+93072,int_stack+121032,int_stack+80316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102420, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+86370,int_stack+93072,int_stack+76530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102924, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+80316,int_stack+34740,int_stack+34470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38310, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+73614,int_stack+80316,int_stack+121032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62400, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+29658,int_stack+73614,int_stack+93072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103680, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+35196,int_stack+35070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93072,int_stack+35364,int_stack+35196, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+93072,int_stack+15024, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+35580,int_stack+35364, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+80316,int_stack+121032,int_stack+93072, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+73614,int_stack+80316,int_stack+76530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+93072,int_stack+35850,int_stack+35580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+16662,int_stack+93072,int_stack+121032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+31338,int_stack+16662,int_stack+80316, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+36306,int_stack+36180, 0.0, zero_stack, 1.0, int_stack+37290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+80316,int_stack+36474,int_stack+36306, 0.0, zero_stack, 1.0, int_stack+37542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+80316,int_stack+15024, 0.0, zero_stack, 1.0, int_stack+102042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+36690,int_stack+36474, 0.0, zero_stack, 1.0, int_stack+37878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+93072,int_stack+121032,int_stack+80316, 0.0, zero_stack, 1.0, int_stack+102420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+16662,int_stack+93072,int_stack+76530, 0.0, zero_stack, 1.0, int_stack+102924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+80316,int_stack+36960,int_stack+36690, 0.0, zero_stack, 1.0, int_stack+38310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+33018,int_stack+80316,int_stack+121032, 0.0, zero_stack, 1.0, int_stack+62400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+34314,int_stack+33018,int_stack+93072, 0.0, zero_stack, 1.0, int_stack+103680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+37710,int_stack+37416, 1.0, int_stack+37290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93072,int_stack+38094,int_stack+37710, 1.0, int_stack+37542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+93072,int_stack+15024, 1.0, int_stack+102042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+38580,int_stack+38094, 1.0, int_stack+37878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+80316,int_stack+121032,int_stack+93072, 1.0, int_stack+102420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+33018,int_stack+80316,int_stack+76530, 1.0, int_stack+102924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+93072,int_stack+38850,int_stack+38580, 1.0, int_stack+38310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+102042,int_stack+93072,int_stack+121032, 1.0, int_stack+62400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+35994,int_stack+102042,int_stack+80316, 1.0, int_stack+103680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+39306,int_stack+39180,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+80316,int_stack+39474,int_stack+39306,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+80316,int_stack+15024,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+62400,int_stack+39690,int_stack+39474,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+93072,int_stack+62400,int_stack+80316,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+102042,int_stack+93072,int_stack+76530,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+80316,int_stack+39960,int_stack+39690,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+103302,int_stack+80316,int_stack+62400,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+37674,int_stack+103302,int_stack+93072,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+40416,int_stack+40290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45840,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93072,int_stack+40584,int_stack+40416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46092,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+93072,int_stack+15024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105948,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+62400,int_stack+40800,int_stack+40584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46428,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+80316,int_stack+62400,int_stack+93072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106326,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+103302,int_stack+80316,int_stack+76530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63048,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+93072,int_stack+41070,int_stack+40800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46860,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+39354,int_stack+93072,int_stack+62400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1296,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+152028,int_stack+39354,int_stack+80316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108924,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+41526,int_stack+41400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45840, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+80316,int_stack+41694,int_stack+41526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46092, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+80316,int_stack+15024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105948, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+62400,int_stack+41910,int_stack+41694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46428, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+93072,int_stack+62400,int_stack+80316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106326, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+39354,int_stack+93072,int_stack+76530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63048, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+80316,int_stack+42180,int_stack+41910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46860, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+40614,int_stack+80316,int_stack+62400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1296, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+153708,int_stack+40614,int_stack+93072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108924, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+42636,int_stack+42510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45840, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93072,int_stack+42804,int_stack+42636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46092, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+93072,int_stack+15024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105948, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+62400,int_stack+43020,int_stack+42804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46428, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+80316,int_stack+62400,int_stack+93072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106326, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+40614,int_stack+80316,int_stack+76530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63048, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+93072,int_stack+43290,int_stack+43020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46860, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+41874,int_stack+93072,int_stack+62400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1296, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+155388,int_stack+41874,int_stack+80316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108924, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+43746,int_stack+43620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+80316,int_stack+43914,int_stack+43746, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+80316,int_stack+15024, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+62400,int_stack+44130,int_stack+43914, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+93072,int_stack+62400,int_stack+80316, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+41874,int_stack+93072,int_stack+76530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+80316,int_stack+44400,int_stack+44130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+43134,int_stack+80316,int_stack+62400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+157068,int_stack+43134,int_stack+93072, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+44856,int_stack+44730, 0.0, zero_stack, 1.0, int_stack+45840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93072,int_stack+45024,int_stack+44856, 0.0, zero_stack, 1.0, int_stack+46092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+93072,int_stack+15024, 0.0, zero_stack, 1.0, int_stack+105948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+62400,int_stack+45240,int_stack+45024, 0.0, zero_stack, 1.0, int_stack+46428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+80316,int_stack+62400,int_stack+93072, 0.0, zero_stack, 1.0, int_stack+106326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+43134,int_stack+80316,int_stack+76530, 0.0, zero_stack, 1.0, int_stack+63048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+93072,int_stack+45510,int_stack+45240, 0.0, zero_stack, 1.0, int_stack+46860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+44394,int_stack+93072,int_stack+62400, 0.0, zero_stack, 1.0, int_stack+1296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+158748,int_stack+44394,int_stack+80316, 0.0, zero_stack, 1.0, int_stack+108924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+46260,int_stack+45966, 1.0, int_stack+45840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+80316,int_stack+46644,int_stack+46260, 1.0, int_stack+46092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+80316,int_stack+15024, 1.0, int_stack+105948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+62400,int_stack+47130,int_stack+46644, 1.0, int_stack+46428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+93072,int_stack+62400,int_stack+80316, 1.0, int_stack+106326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+105948,int_stack+93072,int_stack+76530, 1.0, int_stack+63048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+63048,int_stack+47400,int_stack+47130, 1.0, int_stack+46860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+44394,int_stack+63048,int_stack+62400, 1.0, int_stack+1296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+45690,int_stack+44394,int_stack+93072, 1.0, int_stack+108924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+47856,int_stack+47730,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+108924,int_stack+48024,int_stack+47856,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+108924,int_stack+15024,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+48240,int_stack+48024,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+93072,int_stack+121032,int_stack+108924,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+44394,int_stack+93072,int_stack+76530,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+108924,int_stack+48510,int_stack+48240,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+62400,int_stack+108924,int_stack+121032,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+160428,int_stack+62400,int_stack+93072,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+48966,int_stack+48840,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+93072,int_stack+49134,int_stack+48966,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+93072,int_stack+15024,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+49350,int_stack+49134,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+108924,int_stack+121032,int_stack+93072,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+62400,int_stack+108924,int_stack+76530,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+93072,int_stack+49620,int_stack+49350,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+47370,int_stack+93072,int_stack+121032,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+162108,int_stack+47370,int_stack+108924,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+50076,int_stack+49950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55500,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+108924,int_stack+50244,int_stack+50076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55752,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+108924,int_stack+15024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111192,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+50460,int_stack+50244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56088,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+93072,int_stack+121032,int_stack+108924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111570,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+47370,int_stack+93072,int_stack+76530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112074,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+108924,int_stack+50730,int_stack+50460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56520,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+48630,int_stack+108924,int_stack+121032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1944,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+163788,int_stack+48630,int_stack+93072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114978,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+51186,int_stack+51060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55500, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93072,int_stack+51354,int_stack+51186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55752, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+93072,int_stack+15024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111192, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+51570,int_stack+51354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56088, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+108924,int_stack+121032,int_stack+93072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111570, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48630,int_stack+108924,int_stack+76530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112074, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+93072,int_stack+51840,int_stack+51570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56520, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+49890,int_stack+93072,int_stack+121032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1944, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+165468,int_stack+49890,int_stack+108924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114978, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+52296,int_stack+52170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55500, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+108924,int_stack+52464,int_stack+52296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55752, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+108924,int_stack+15024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111192, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+52680,int_stack+52464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56088, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+93072,int_stack+121032,int_stack+108924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111570, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+49890,int_stack+93072,int_stack+76530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112074, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+108924,int_stack+52950,int_stack+52680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56520, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+51150,int_stack+108924,int_stack+121032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1944, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+167148,int_stack+51150,int_stack+93072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114978, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+53406,int_stack+53280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93072,int_stack+53574,int_stack+53406, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+55752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+93072,int_stack+15024, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+53790,int_stack+53574, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+108924,int_stack+121032,int_stack+93072, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+51150,int_stack+108924,int_stack+76530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+93072,int_stack+54060,int_stack+53790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+52410,int_stack+93072,int_stack+121032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+168828,int_stack+52410,int_stack+108924, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+54516,int_stack+54390, 0.0, zero_stack, 1.0, int_stack+55500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+108924,int_stack+54684,int_stack+54516, 0.0, zero_stack, 1.0, int_stack+55752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+108924,int_stack+15024, 0.0, zero_stack, 1.0, int_stack+111192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+54900,int_stack+54684, 0.0, zero_stack, 1.0, int_stack+56088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+93072,int_stack+121032,int_stack+108924, 0.0, zero_stack, 1.0, int_stack+111570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+52410,int_stack+93072,int_stack+76530, 0.0, zero_stack, 1.0, int_stack+112074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+108924,int_stack+55170,int_stack+54900, 0.0, zero_stack, 1.0, int_stack+56520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+53670,int_stack+108924,int_stack+121032, 0.0, zero_stack, 1.0, int_stack+1944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+170508,int_stack+53670,int_stack+93072, 0.0, zero_stack, 1.0, int_stack+114978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+55920,int_stack+55626, 1.0, int_stack+55500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+93072,int_stack+56304,int_stack+55920, 1.0, int_stack+55752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+93072,int_stack+15024, 1.0, int_stack+111192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+56790,int_stack+56304, 1.0, int_stack+56088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+108924,int_stack+121032,int_stack+93072, 1.0, int_stack+111570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+53670,int_stack+108924,int_stack+76530, 1.0, int_stack+112074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+93072,int_stack+57060,int_stack+56790, 1.0, int_stack+56520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+111192,int_stack+93072,int_stack+121032, 1.0, int_stack+1944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+54930,int_stack+111192,int_stack+108924, 1.0, int_stack+114978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+57516,int_stack+57390,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+114978,int_stack+57684,int_stack+57516,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+114978,int_stack+15024,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+57900,int_stack+57684,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+108924,int_stack+121032,int_stack+114978,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+111192,int_stack+108924,int_stack+76530,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+114978,int_stack+58170,int_stack+57900,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+56610,int_stack+114978,int_stack+121032,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1260,int_stack+56610,int_stack+108924,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+58626,int_stack+58500,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+108924,int_stack+58794,int_stack+58626,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+108924,int_stack+15024,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+59010,int_stack+58794,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+114978,int_stack+121032,int_stack+108924,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+56610,int_stack+114978,int_stack+76530,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+108924,int_stack+59280,int_stack+59010,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+57870,int_stack+108924,int_stack+121032,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+172188,int_stack+57870,int_stack+114978,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+15024,int_stack+59736,int_stack+59610,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+114978,int_stack+59904,int_stack+59736,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+76530,int_stack+114978,int_stack+15024,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+121032,int_stack+60120,int_stack+59904,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+108924,int_stack+121032,int_stack+114978,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+57870,int_stack+108924,int_stack+76530,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+114978,int_stack+60390,int_stack+60120,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+59130,int_stack+114978,int_stack+121032,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+173868,int_stack+59130,int_stack+108924,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+175548,int_stack+71934,int_stack+68568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64014,6);
     Libderiv->ABCD[11] = int_stack + 175548;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+71508,int_stack+78636,int_stack+75270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64014, 0.0, zero_stack,6);
     Libderiv->ABCD[10] = int_stack + 71508;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+78546,int_stack+84690,int_stack+81324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64014, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[9] = int_stack + 78546;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+83844,int_stack+91392,int_stack+88026, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+64014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[8] = int_stack + 83844;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+90546,int_stack+97446,int_stack+94080, 0.0, zero_stack, 1.0, int_stack+64014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[7] = int_stack + 90546;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+97020,int_stack+60720,int_stack+100782, 1.0, int_stack+64014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[6] = int_stack + 97020;
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+59130,int_stack+107244,int_stack+104688,6);
     Libderiv->ABCD[2] = int_stack + 59130;
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+107208,int_stack+113298,int_stack+109932,6);
     Libderiv->ABCD[1] = int_stack + 107208;
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+112452,int_stack+119352,int_stack+115986,6);
     Libderiv->ABCD[0] = int_stack + 112452;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+118506,int_stack+122940,int_stack+121680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+68568,6);
     Libderiv->ABCD[155] = int_stack + 118506;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+120396,int_stack+125880,int_stack+124620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68568, 1.0, int_stack+75270,6);
     Libderiv->ABCD[143] = int_stack + 120396;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+122286,int_stack+4860,int_stack+3600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+75270, 0.0, zero_stack,6);
     Libderiv->ABCD[142] = int_stack + 122286;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2940,int_stack+130116,int_stack+127560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68568, 0.0, zero_stack, 1.0, int_stack+81324,6);
     Libderiv->ABCD[131] = int_stack + 2940;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+124176,int_stack+131796,int_stack+128820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75270, 1.0, int_stack+81324, 0.0, zero_stack,6);
     Libderiv->ABCD[130] = int_stack + 124176;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+126066,int_stack+7800,int_stack+6540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+81324, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[129] = int_stack + 126066;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4830,int_stack+134736,int_stack+133476, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68568, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88026,6);
     Libderiv->ABCD[119] = int_stack + 4830;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6720,int_stack+136416,int_stack+117246, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75270, 0.0, zero_stack, 1.0, int_stack+88026, 0.0, zero_stack,6);
     Libderiv->ABCD[118] = int_stack + 6720;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+127956,int_stack+139392,int_stack+11244, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81324, 1.0, int_stack+88026, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[117] = int_stack + 127956;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+129846,int_stack+141072,int_stack+138096, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+88026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[116] = int_stack + 129846;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+131736,int_stack+9480,int_stack+12504, 0.0, zero_stack, 1.0, int_stack+68568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94080,6);
     Libderiv->ABCD[107] = int_stack + 131736;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8610,int_stack+145308,int_stack+142752, 0.0, zero_stack, 1.0, int_stack+75270, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94080, 0.0, zero_stack,6);
     Libderiv->ABCD[106] = int_stack + 8610;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10500,int_stack+146988,int_stack+144012, 0.0, zero_stack, 1.0, int_stack+81324, 0.0, zero_stack, 1.0, int_stack+94080, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[105] = int_stack + 10500;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+133626,int_stack+148668,int_stack+15402, 0.0, zero_stack, 1.0, int_stack+88026, 1.0, int_stack+94080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[104] = int_stack + 133626;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+135516,int_stack+150348,int_stack+13764, 0.0, zero_stack, 2.0, int_stack+94080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[103] = int_stack + 135516;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+12390,int_stack+19578,int_stack+18318, 1.0, int_stack+68568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100782,6);
     Libderiv->ABCD[95] = int_stack + 12390;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+17922,int_stack+21258,int_stack+66534, 1.0, int_stack+75270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100782, 0.0, zero_stack,6);
     Libderiv->ABCD[94] = int_stack + 17922;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+66534,int_stack+22938,int_stack+65274, 1.0, int_stack+81324, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100782, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[93] = int_stack + 66534;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+63660,int_stack+69828,int_stack+77286, 1.0, int_stack+88026, 0.0, zero_stack, 1.0, int_stack+100782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[92] = int_stack + 63660;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+68424,int_stack+24618,int_stack+82584, 1.0, int_stack+94080, 1.0, int_stack+100782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[91] = int_stack + 68424;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+19812,int_stack+95340,int_stack+89286, 2.0, int_stack+100782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[90] = int_stack + 19812;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+21702,int_stack+26298,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104688,6);
     Libderiv->ABCD[47] = int_stack + 21702;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+23592,int_stack+27978,int_stack+99126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104688, 0.0, zero_stack,6);
     Libderiv->ABCD[46] = int_stack + 23592;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+25482,int_stack+29658,int_stack+86370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104688, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[45] = int_stack + 25482;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+27372,int_stack+31338,int_stack+73614, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[44] = int_stack + 27372;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+29262,int_stack+34314,int_stack+16662, 0.0, zero_stack, 1.0, int_stack+104688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[43] = int_stack + 29262;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+14280,int_stack+35994,int_stack+33018, 1.0, int_stack+104688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[42] = int_stack + 14280;
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+31152,int_stack+37674,int_stack+102042,6);
     Libderiv->ABCD[38] = int_stack + 31152;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+33042,int_stack+152028,int_stack+103302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109932,6);
     Libderiv->ABCD[35] = int_stack + 33042;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+34932,int_stack+153708,int_stack+39354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109932, 0.0, zero_stack,6);
     Libderiv->ABCD[34] = int_stack + 34932;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+36822,int_stack+155388,int_stack+40614, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109932, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[33] = int_stack + 36822;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+38712,int_stack+157068,int_stack+41874, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[32] = int_stack + 38712;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+40602,int_stack+158748,int_stack+43134, 0.0, zero_stack, 1.0, int_stack+109932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[31] = int_stack + 40602;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+42492,int_stack+45690,int_stack+105948, 1.0, int_stack+109932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[30] = int_stack + 42492;
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+109098,int_stack+160428,int_stack+44394,6);
     Libderiv->ABCD[26] = int_stack + 109098;
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+44382,int_stack+162108,int_stack+62400,6);
     Libderiv->ABCD[25] = int_stack + 44382;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+61020,int_stack+163788,int_stack+47370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115986,6);
     Libderiv->ABCD[23] = int_stack + 61020;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+46272,int_stack+165468,int_stack+48630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115986, 0.0, zero_stack,6);
     Libderiv->ABCD[22] = int_stack + 46272;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+98910,int_stack+167148,int_stack+49890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115986, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[21] = int_stack + 98910;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+48162,int_stack+168828,int_stack+51150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[20] = int_stack + 48162;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+50052,int_stack+170508,int_stack+52410, 0.0, zero_stack, 1.0, int_stack+115986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[19] = int_stack + 50052;
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+100800,int_stack+54930,int_stack+53670, 1.0, int_stack+115986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
     Libderiv->ABCD[18] = int_stack + 100800;
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+114342,int_stack+1260,int_stack+111192,6);
     Libderiv->ABCD[14] = int_stack + 114342;
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+0,int_stack+172188,int_stack+56610,6);
     Libderiv->ABCD[13] = int_stack + 0;
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+116232,int_stack+173868,int_stack+57870,6);
     Libderiv->ABCD[12] = int_stack + 116232;

}
