/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_fdhf(Libderiv_t *, prim_data *);

  /* Computes derivatives of (fd|hf) integrals */

void d12hrr_order_fdhf(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[5][8][11] = int_stack + 0;
 Libderiv->deriv_classes[5][8][10] = int_stack + 945;
 Libderiv->deriv_classes[5][8][9] = int_stack + 1890;
 Libderiv->deriv_classes[5][8][8] = int_stack + 2835;
 Libderiv->deriv_classes[5][8][7] = int_stack + 3780;
 Libderiv->dvrr_classes[5][7] = int_stack + 4725;
 Libderiv->deriv_classes[5][8][6] = int_stack + 5481;
 Libderiv->deriv_classes[5][8][2] = int_stack + 6426;
 Libderiv->deriv_classes[5][8][1] = int_stack + 7371;
 Libderiv->dvrr_classes[4][8] = int_stack + 8316;
 Libderiv->deriv_classes[5][8][0] = int_stack + 8991;
 Libderiv->deriv2_classes[3][5][143] = int_stack + 9936;
 Libderiv->deriv2_classes[3][6][143] = int_stack + 10146;
 Libderiv->deriv2_classes[3][7][143] = int_stack + 10426;
 Libderiv->deriv2_classes[3][8][143] = int_stack + 10786;
 Libderiv->deriv2_classes[4][5][143] = int_stack + 11236;
 Libderiv->deriv2_classes[4][6][143] = int_stack + 11551;
 Libderiv->deriv2_classes[4][7][143] = int_stack + 11971;
 Libderiv->deriv2_classes[4][8][143] = int_stack + 12511;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 13186;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 13627;
 Libderiv->deriv2_classes[5][7][143] = int_stack + 14215;
 Libderiv->deriv2_classes[5][8][143] = int_stack + 14971;
 Libderiv->deriv2_classes[3][5][131] = int_stack + 15916;
 Libderiv->deriv2_classes[3][6][131] = int_stack + 16126;
 Libderiv->deriv2_classes[3][7][131] = int_stack + 16406;
 Libderiv->deriv2_classes[3][8][131] = int_stack + 16766;
 Libderiv->deriv2_classes[4][5][131] = int_stack + 17216;
 Libderiv->deriv2_classes[4][6][131] = int_stack + 17531;
 Libderiv->deriv2_classes[4][7][131] = int_stack + 17951;
 Libderiv->deriv2_classes[4][8][131] = int_stack + 18491;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 19166;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 19607;
 Libderiv->deriv2_classes[5][7][131] = int_stack + 20195;
 Libderiv->deriv2_classes[5][8][131] = int_stack + 20951;
 Libderiv->deriv2_classes[3][5][130] = int_stack + 21896;
 Libderiv->deriv2_classes[3][6][130] = int_stack + 22106;
 Libderiv->deriv2_classes[3][7][130] = int_stack + 22386;
 Libderiv->deriv2_classes[3][8][130] = int_stack + 22746;
 Libderiv->deriv2_classes[4][5][130] = int_stack + 23196;
 Libderiv->deriv2_classes[4][6][130] = int_stack + 23511;
 Libderiv->deriv2_classes[4][7][130] = int_stack + 23931;
 Libderiv->deriv2_classes[4][8][130] = int_stack + 24471;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 25146;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 25587;
 Libderiv->deriv2_classes[5][7][130] = int_stack + 26175;
 Libderiv->deriv2_classes[5][8][130] = int_stack + 26931;
 Libderiv->deriv2_classes[3][5][119] = int_stack + 27876;
 Libderiv->deriv2_classes[3][6][119] = int_stack + 28086;
 Libderiv->deriv2_classes[3][7][119] = int_stack + 28366;
 Libderiv->deriv2_classes[3][8][119] = int_stack + 28726;
 Libderiv->deriv2_classes[4][5][119] = int_stack + 29176;
 Libderiv->deriv2_classes[4][6][119] = int_stack + 29491;
 Libderiv->deriv2_classes[4][7][119] = int_stack + 29911;
 Libderiv->deriv2_classes[4][8][119] = int_stack + 30451;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 31126;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 31567;
 Libderiv->deriv2_classes[5][7][119] = int_stack + 32155;
 Libderiv->deriv2_classes[5][8][119] = int_stack + 32911;
 Libderiv->deriv2_classes[3][5][118] = int_stack + 33856;
 Libderiv->deriv2_classes[3][6][118] = int_stack + 34066;
 Libderiv->deriv2_classes[3][7][118] = int_stack + 34346;
 Libderiv->deriv2_classes[3][8][118] = int_stack + 34706;
 Libderiv->deriv2_classes[4][5][118] = int_stack + 35156;
 Libderiv->deriv2_classes[4][6][118] = int_stack + 35471;
 Libderiv->deriv2_classes[4][7][118] = int_stack + 35891;
 Libderiv->deriv2_classes[4][8][118] = int_stack + 36431;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 37106;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 37547;
 Libderiv->deriv2_classes[5][7][118] = int_stack + 38135;
 Libderiv->deriv2_classes[5][8][118] = int_stack + 38891;
 Libderiv->deriv2_classes[3][5][117] = int_stack + 39836;
 Libderiv->deriv2_classes[3][6][117] = int_stack + 40046;
 Libderiv->deriv2_classes[3][7][117] = int_stack + 40326;
 Libderiv->deriv2_classes[3][8][117] = int_stack + 40686;
 Libderiv->deriv2_classes[4][5][117] = int_stack + 41136;
 Libderiv->deriv2_classes[4][6][117] = int_stack + 41451;
 Libderiv->deriv2_classes[4][7][117] = int_stack + 41871;
 Libderiv->deriv2_classes[4][8][117] = int_stack + 42411;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 43086;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 43527;
 Libderiv->deriv2_classes[5][7][117] = int_stack + 44115;
 Libderiv->deriv2_classes[5][8][117] = int_stack + 44871;
 Libderiv->deriv2_classes[3][5][107] = int_stack + 45816;
 Libderiv->deriv2_classes[3][6][107] = int_stack + 46026;
 Libderiv->deriv2_classes[3][7][107] = int_stack + 46306;
 Libderiv->deriv2_classes[3][8][107] = int_stack + 46666;
 Libderiv->deriv2_classes[4][5][107] = int_stack + 47116;
 Libderiv->deriv2_classes[4][6][107] = int_stack + 47431;
 Libderiv->deriv2_classes[4][7][107] = int_stack + 47851;
 Libderiv->deriv2_classes[4][8][107] = int_stack + 48391;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 49066;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 49507;
 Libderiv->deriv2_classes[5][7][107] = int_stack + 50095;
 Libderiv->deriv2_classes[5][8][107] = int_stack + 50851;
 Libderiv->deriv2_classes[3][5][106] = int_stack + 51796;
 Libderiv->deriv2_classes[3][6][106] = int_stack + 52006;
 Libderiv->deriv2_classes[3][7][106] = int_stack + 52286;
 Libderiv->deriv2_classes[3][8][106] = int_stack + 52646;
 Libderiv->deriv2_classes[4][5][106] = int_stack + 53096;
 Libderiv->deriv2_classes[4][6][106] = int_stack + 53411;
 Libderiv->deriv2_classes[4][7][106] = int_stack + 53831;
 Libderiv->deriv2_classes[4][8][106] = int_stack + 54371;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 55046;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 55487;
 Libderiv->deriv2_classes[5][7][106] = int_stack + 56075;
 Libderiv->deriv2_classes[5][8][106] = int_stack + 56831;
 Libderiv->deriv2_classes[3][5][105] = int_stack + 57776;
 Libderiv->deriv2_classes[3][6][105] = int_stack + 57986;
 Libderiv->deriv2_classes[3][7][105] = int_stack + 58266;
 Libderiv->deriv2_classes[3][8][105] = int_stack + 58626;
 Libderiv->deriv2_classes[4][5][105] = int_stack + 59076;
 Libderiv->deriv2_classes[4][6][105] = int_stack + 59391;
 Libderiv->deriv2_classes[4][7][105] = int_stack + 59811;
 Libderiv->deriv2_classes[4][8][105] = int_stack + 60351;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 61026;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 61467;
 Libderiv->deriv2_classes[5][7][105] = int_stack + 62055;
 Libderiv->deriv2_classes[5][8][105] = int_stack + 62811;
 Libderiv->deriv2_classes[3][5][104] = int_stack + 63756;
 Libderiv->deriv2_classes[3][6][104] = int_stack + 63966;
 Libderiv->deriv2_classes[3][7][104] = int_stack + 64246;
 Libderiv->deriv2_classes[3][8][104] = int_stack + 64606;
 Libderiv->deriv2_classes[4][5][104] = int_stack + 65056;
 Libderiv->deriv2_classes[4][6][104] = int_stack + 65371;
 Libderiv->deriv2_classes[4][7][104] = int_stack + 65791;
 Libderiv->deriv2_classes[4][8][104] = int_stack + 66331;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 67006;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 67447;
 Libderiv->deriv2_classes[5][7][104] = int_stack + 68035;
 Libderiv->deriv2_classes[5][8][104] = int_stack + 68791;
 Libderiv->deriv2_classes[3][5][95] = int_stack + 69736;
 Libderiv->deriv2_classes[3][6][95] = int_stack + 69946;
 Libderiv->deriv2_classes[3][7][95] = int_stack + 70226;
 Libderiv->deriv2_classes[3][8][95] = int_stack + 70586;
 Libderiv->deriv2_classes[4][5][95] = int_stack + 71036;
 Libderiv->deriv2_classes[4][6][95] = int_stack + 71351;
 Libderiv->deriv2_classes[4][7][95] = int_stack + 71771;
 Libderiv->deriv2_classes[4][8][95] = int_stack + 72311;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 72986;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 73427;
 Libderiv->deriv2_classes[5][7][95] = int_stack + 74015;
 Libderiv->deriv2_classes[5][8][95] = int_stack + 74771;
 Libderiv->deriv2_classes[3][5][94] = int_stack + 75716;
 Libderiv->deriv2_classes[3][6][94] = int_stack + 75926;
 Libderiv->deriv2_classes[3][7][94] = int_stack + 76206;
 Libderiv->deriv2_classes[3][8][94] = int_stack + 76566;
 Libderiv->deriv2_classes[4][5][94] = int_stack + 77016;
 Libderiv->deriv2_classes[4][6][94] = int_stack + 77331;
 Libderiv->deriv2_classes[4][7][94] = int_stack + 77751;
 Libderiv->deriv2_classes[4][8][94] = int_stack + 78291;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 78966;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 79407;
 Libderiv->deriv2_classes[5][7][94] = int_stack + 79995;
 Libderiv->deriv2_classes[5][8][94] = int_stack + 80751;
 Libderiv->deriv2_classes[3][5][93] = int_stack + 81696;
 Libderiv->deriv2_classes[3][6][93] = int_stack + 81906;
 Libderiv->deriv2_classes[3][7][93] = int_stack + 82186;
 Libderiv->deriv2_classes[3][8][93] = int_stack + 82546;
 Libderiv->deriv2_classes[4][5][93] = int_stack + 82996;
 Libderiv->deriv2_classes[4][6][93] = int_stack + 83311;
 Libderiv->deriv2_classes[4][7][93] = int_stack + 83731;
 Libderiv->deriv2_classes[4][8][93] = int_stack + 84271;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 84946;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 85387;
 Libderiv->deriv2_classes[5][7][93] = int_stack + 85975;
 Libderiv->deriv2_classes[5][8][93] = int_stack + 86731;
 Libderiv->deriv2_classes[3][5][92] = int_stack + 87676;
 Libderiv->deriv2_classes[3][6][92] = int_stack + 87886;
 Libderiv->deriv2_classes[3][7][92] = int_stack + 88166;
 Libderiv->deriv2_classes[3][8][92] = int_stack + 88526;
 Libderiv->deriv2_classes[4][5][92] = int_stack + 88976;
 Libderiv->deriv2_classes[4][6][92] = int_stack + 89291;
 Libderiv->deriv2_classes[4][7][92] = int_stack + 89711;
 Libderiv->deriv2_classes[4][8][92] = int_stack + 90251;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 90926;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 91367;
 Libderiv->deriv2_classes[5][7][92] = int_stack + 91955;
 Libderiv->deriv2_classes[5][8][92] = int_stack + 92711;
 Libderiv->deriv2_classes[3][5][91] = int_stack + 93656;
 Libderiv->deriv2_classes[3][6][91] = int_stack + 93866;
 Libderiv->deriv2_classes[3][7][91] = int_stack + 94146;
 Libderiv->deriv2_classes[3][8][91] = int_stack + 94506;
 Libderiv->deriv2_classes[4][5][91] = int_stack + 94956;
 Libderiv->deriv2_classes[4][6][91] = int_stack + 95271;
 Libderiv->deriv2_classes[4][7][91] = int_stack + 95691;
 Libderiv->deriv2_classes[4][8][91] = int_stack + 96231;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 96906;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 97347;
 Libderiv->deriv2_classes[5][7][91] = int_stack + 97935;
 Libderiv->deriv2_classes[5][8][91] = int_stack + 98691;
 Libderiv->deriv2_classes[3][5][83] = int_stack + 99636;
 Libderiv->deriv2_classes[3][6][83] = int_stack + 99846;
 Libderiv->deriv2_classes[3][7][83] = int_stack + 100126;
 Libderiv->deriv2_classes[3][8][83] = int_stack + 100486;
 Libderiv->deriv2_classes[4][5][83] = int_stack + 100936;
 Libderiv->deriv2_classes[4][6][83] = int_stack + 101251;
 Libderiv->deriv2_classes[4][7][83] = int_stack + 101671;
 Libderiv->deriv2_classes[4][8][83] = int_stack + 102211;
 Libderiv->deriv_classes[5][5][11] = int_stack + 102886;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 103327;
 Libderiv->deriv_classes[5][6][11] = int_stack + 103768;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 104356;
 Libderiv->deriv_classes[5][7][11] = int_stack + 104944;
 Libderiv->deriv2_classes[5][7][83] = int_stack + 105700;
 Libderiv->deriv2_classes[5][8][83] = int_stack + 106456;
 Libderiv->deriv2_classes[3][5][82] = int_stack + 107401;
 Libderiv->deriv2_classes[3][6][82] = int_stack + 107611;
 Libderiv->deriv2_classes[3][7][82] = int_stack + 107891;
 Libderiv->deriv2_classes[3][8][82] = int_stack + 108251;
 Libderiv->deriv2_classes[4][5][82] = int_stack + 108701;
 Libderiv->deriv2_classes[4][6][82] = int_stack + 109016;
 Libderiv->deriv2_classes[4][7][82] = int_stack + 109436;
 Libderiv->deriv2_classes[4][8][82] = int_stack + 109976;
 Libderiv->deriv_classes[5][5][10] = int_stack + 110651;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 111092;
 Libderiv->deriv_classes[5][6][10] = int_stack + 111533;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 112121;
 Libderiv->deriv_classes[5][7][10] = int_stack + 112709;
 Libderiv->deriv2_classes[5][7][82] = int_stack + 113465;
 Libderiv->deriv2_classes[5][8][82] = int_stack + 114221;
 Libderiv->deriv2_classes[3][5][81] = int_stack + 115166;
 Libderiv->deriv2_classes[3][6][81] = int_stack + 115376;
 Libderiv->deriv2_classes[3][7][81] = int_stack + 115656;
 Libderiv->deriv2_classes[3][8][81] = int_stack + 116016;
 Libderiv->deriv2_classes[4][5][81] = int_stack + 116466;
 Libderiv->deriv2_classes[4][6][81] = int_stack + 116781;
 Libderiv->deriv2_classes[4][7][81] = int_stack + 117201;
 Libderiv->deriv2_classes[4][8][81] = int_stack + 117741;
 Libderiv->deriv_classes[5][5][9] = int_stack + 118416;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 118857;
 Libderiv->deriv_classes[5][6][9] = int_stack + 119298;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 119886;
 Libderiv->deriv_classes[5][7][9] = int_stack + 120474;
 Libderiv->deriv2_classes[5][7][81] = int_stack + 121230;
 Libderiv->deriv2_classes[5][8][81] = int_stack + 121986;
 Libderiv->deriv2_classes[3][5][80] = int_stack + 122931;
 Libderiv->deriv2_classes[3][6][80] = int_stack + 123141;
 Libderiv->deriv2_classes[3][7][80] = int_stack + 123421;
 Libderiv->deriv2_classes[3][8][80] = int_stack + 123781;
 Libderiv->deriv2_classes[4][5][80] = int_stack + 124231;
 Libderiv->deriv2_classes[4][6][80] = int_stack + 124546;
 Libderiv->deriv2_classes[4][7][80] = int_stack + 124966;
 Libderiv->deriv2_classes[4][8][80] = int_stack + 125506;
 Libderiv->deriv_classes[5][5][8] = int_stack + 126181;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 126622;
 Libderiv->deriv_classes[5][6][8] = int_stack + 127063;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 127651;
 Libderiv->deriv_classes[5][7][8] = int_stack + 128239;
 Libderiv->deriv2_classes[5][7][80] = int_stack + 128995;
 Libderiv->deriv2_classes[5][8][80] = int_stack + 129751;
 Libderiv->deriv2_classes[3][5][79] = int_stack + 130696;
 Libderiv->deriv2_classes[3][6][79] = int_stack + 130906;
 Libderiv->deriv2_classes[3][7][79] = int_stack + 131186;
 Libderiv->deriv2_classes[3][8][79] = int_stack + 131546;
 Libderiv->deriv2_classes[4][5][79] = int_stack + 131996;
 Libderiv->deriv2_classes[4][6][79] = int_stack + 132311;
 Libderiv->deriv2_classes[4][7][79] = int_stack + 132731;
 Libderiv->deriv2_classes[4][8][79] = int_stack + 133271;
 Libderiv->deriv_classes[5][5][7] = int_stack + 133946;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 134387;
 Libderiv->deriv_classes[5][6][7] = int_stack + 134828;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 135416;
 Libderiv->deriv_classes[5][7][7] = int_stack + 136004;
 Libderiv->deriv2_classes[5][7][79] = int_stack + 136760;
 Libderiv->deriv2_classes[5][8][79] = int_stack + 137516;
 Libderiv->deriv2_classes[3][5][78] = int_stack + 138461;
 Libderiv->deriv2_classes[3][6][78] = int_stack + 138671;
 Libderiv->deriv2_classes[3][7][78] = int_stack + 138951;
 Libderiv->deriv2_classes[3][8][78] = int_stack + 139311;
 Libderiv->deriv2_classes[4][5][78] = int_stack + 139761;
 Libderiv->deriv2_classes[4][6][78] = int_stack + 140076;
 Libderiv->deriv2_classes[4][7][78] = int_stack + 140496;
 Libderiv->deriv2_classes[4][8][78] = int_stack + 141036;
 Libderiv->dvrr_classes[5][5] = int_stack + 141711;
 Libderiv->deriv_classes[5][5][6] = int_stack + 142152;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 142593;
 Libderiv->dvrr_classes[5][6] = int_stack + 143034;
 Libderiv->deriv_classes[5][6][6] = int_stack + 143622;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 144210;
 Libderiv->deriv_classes[5][7][6] = int_stack + 144798;
 Libderiv->deriv2_classes[5][7][78] = int_stack + 145554;
 Libderiv->deriv2_classes[5][8][78] = int_stack + 146310;
 Libderiv->deriv2_classes[3][5][35] = int_stack + 147255;
 Libderiv->deriv2_classes[3][6][35] = int_stack + 147465;
 Libderiv->deriv2_classes[3][7][35] = int_stack + 147745;
 Libderiv->deriv2_classes[3][8][35] = int_stack + 148105;
 Libderiv->deriv2_classes[4][5][35] = int_stack + 148555;
 Libderiv->deriv2_classes[4][6][35] = int_stack + 148870;
 Libderiv->deriv2_classes[4][7][35] = int_stack + 149290;
 Libderiv->deriv2_classes[4][8][35] = int_stack + 149830;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 150505;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 150946;
 Libderiv->deriv2_classes[5][7][35] = int_stack + 151534;
 Libderiv->deriv2_classes[5][8][35] = int_stack + 152290;
 Libderiv->deriv2_classes[3][5][34] = int_stack + 153235;
 Libderiv->deriv2_classes[3][6][34] = int_stack + 153445;
 Libderiv->deriv2_classes[3][7][34] = int_stack + 153725;
 Libderiv->deriv2_classes[3][8][34] = int_stack + 154085;
 Libderiv->deriv2_classes[4][5][34] = int_stack + 154535;
 Libderiv->deriv2_classes[4][6][34] = int_stack + 154850;
 Libderiv->deriv2_classes[4][7][34] = int_stack + 155270;
 Libderiv->deriv2_classes[4][8][34] = int_stack + 155810;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 156485;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 156926;
 Libderiv->deriv2_classes[5][7][34] = int_stack + 157514;
 Libderiv->deriv2_classes[5][8][34] = int_stack + 158270;
 Libderiv->deriv2_classes[3][5][33] = int_stack + 159215;
 Libderiv->deriv2_classes[3][6][33] = int_stack + 159425;
 Libderiv->deriv2_classes[3][7][33] = int_stack + 159705;
 Libderiv->deriv2_classes[3][8][33] = int_stack + 160065;
 Libderiv->deriv2_classes[4][5][33] = int_stack + 160515;
 Libderiv->deriv2_classes[4][6][33] = int_stack + 160830;
 Libderiv->deriv2_classes[4][7][33] = int_stack + 161250;
 Libderiv->deriv2_classes[4][8][33] = int_stack + 161790;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 162465;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 162906;
 Libderiv->deriv2_classes[5][7][33] = int_stack + 163494;
 Libderiv->deriv2_classes[5][8][33] = int_stack + 164250;
 Libderiv->deriv2_classes[3][5][32] = int_stack + 165195;
 Libderiv->deriv2_classes[3][6][32] = int_stack + 165405;
 Libderiv->deriv2_classes[3][7][32] = int_stack + 165685;
 Libderiv->deriv2_classes[3][8][32] = int_stack + 166045;
 Libderiv->deriv2_classes[4][5][32] = int_stack + 166495;
 Libderiv->deriv2_classes[4][6][32] = int_stack + 166810;
 Libderiv->deriv2_classes[4][7][32] = int_stack + 167230;
 Libderiv->deriv2_classes[4][8][32] = int_stack + 167770;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 168445;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 168886;
 Libderiv->deriv2_classes[5][7][32] = int_stack + 169474;
 Libderiv->deriv2_classes[5][8][32] = int_stack + 170230;
 Libderiv->deriv2_classes[3][5][31] = int_stack + 171175;
 Libderiv->deriv2_classes[3][6][31] = int_stack + 171385;
 Libderiv->deriv2_classes[3][7][31] = int_stack + 171665;
 Libderiv->deriv2_classes[3][8][31] = int_stack + 172025;
 Libderiv->deriv2_classes[4][5][31] = int_stack + 172475;
 Libderiv->deriv2_classes[4][6][31] = int_stack + 172790;
 Libderiv->deriv2_classes[4][7][31] = int_stack + 173210;
 Libderiv->deriv2_classes[4][8][31] = int_stack + 173750;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 174425;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 174866;
 Libderiv->deriv2_classes[5][7][31] = int_stack + 175454;
 Libderiv->deriv2_classes[5][8][31] = int_stack + 176210;
 Libderiv->deriv2_classes[3][5][30] = int_stack + 177155;
 Libderiv->deriv2_classes[3][6][30] = int_stack + 177365;
 Libderiv->deriv2_classes[3][7][30] = int_stack + 177645;
 Libderiv->deriv2_classes[3][8][30] = int_stack + 178005;
 Libderiv->deriv2_classes[4][5][30] = int_stack + 178455;
 Libderiv->deriv2_classes[4][6][30] = int_stack + 178770;
 Libderiv->deriv2_classes[4][7][30] = int_stack + 179190;
 Libderiv->deriv2_classes[4][8][30] = int_stack + 179730;
 Libderiv->deriv_classes[5][5][2] = int_stack + 180405;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 180846;
 Libderiv->deriv_classes[5][6][2] = int_stack + 181287;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 181875;
 Libderiv->deriv_classes[5][7][2] = int_stack + 182463;
 Libderiv->deriv2_classes[5][7][30] = int_stack + 183219;
 Libderiv->deriv2_classes[5][8][30] = int_stack + 183975;
 Libderiv->deriv2_classes[3][5][26] = int_stack + 184920;
 Libderiv->deriv2_classes[3][6][26] = int_stack + 185130;
 Libderiv->deriv2_classes[3][7][26] = int_stack + 185410;
 Libderiv->deriv2_classes[3][8][26] = int_stack + 185770;
 Libderiv->deriv2_classes[4][5][26] = int_stack + 186220;
 Libderiv->deriv2_classes[4][6][26] = int_stack + 186535;
 Libderiv->deriv2_classes[4][7][26] = int_stack + 186955;
 Libderiv->deriv2_classes[4][8][26] = int_stack + 187495;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 188170;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 188611;
 Libderiv->deriv2_classes[5][7][26] = int_stack + 189199;
 Libderiv->deriv2_classes[5][8][26] = int_stack + 189955;
 Libderiv->deriv2_classes[3][5][23] = int_stack + 190900;
 Libderiv->deriv2_classes[3][6][23] = int_stack + 191110;
 Libderiv->deriv2_classes[3][7][23] = int_stack + 191390;
 Libderiv->deriv2_classes[3][8][23] = int_stack + 191750;
 Libderiv->deriv2_classes[4][5][23] = int_stack + 192200;
 Libderiv->deriv2_classes[4][6][23] = int_stack + 192515;
 Libderiv->deriv2_classes[4][7][23] = int_stack + 192935;
 Libderiv->deriv2_classes[4][8][23] = int_stack + 193475;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 194150;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 194591;
 Libderiv->deriv2_classes[5][7][23] = int_stack + 195179;
 Libderiv->deriv2_classes[5][8][23] = int_stack + 195935;
 Libderiv->deriv2_classes[3][5][22] = int_stack + 196880;
 Libderiv->deriv2_classes[3][6][22] = int_stack + 197090;
 Libderiv->deriv2_classes[3][7][22] = int_stack + 197370;
 Libderiv->deriv2_classes[3][8][22] = int_stack + 197730;
 Libderiv->deriv2_classes[4][5][22] = int_stack + 198180;
 Libderiv->deriv2_classes[4][6][22] = int_stack + 198495;
 Libderiv->deriv2_classes[4][7][22] = int_stack + 198915;
 Libderiv->deriv2_classes[4][8][22] = int_stack + 199455;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 200130;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 200571;
 Libderiv->deriv2_classes[5][7][22] = int_stack + 201159;
 Libderiv->deriv2_classes[5][8][22] = int_stack + 201915;
 Libderiv->deriv2_classes[3][5][21] = int_stack + 202860;
 Libderiv->deriv2_classes[3][6][21] = int_stack + 203070;
 Libderiv->deriv2_classes[3][7][21] = int_stack + 203350;
 Libderiv->deriv2_classes[3][8][21] = int_stack + 203710;
 Libderiv->deriv2_classes[4][5][21] = int_stack + 204160;
 Libderiv->deriv2_classes[4][6][21] = int_stack + 204475;
 Libderiv->deriv2_classes[4][7][21] = int_stack + 204895;
 Libderiv->deriv2_classes[4][8][21] = int_stack + 205435;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 206110;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 206551;
 Libderiv->deriv2_classes[5][7][21] = int_stack + 207139;
 Libderiv->deriv2_classes[5][8][21] = int_stack + 207895;
 Libderiv->deriv2_classes[3][5][20] = int_stack + 208840;
 Libderiv->deriv2_classes[3][6][20] = int_stack + 209050;
 Libderiv->deriv2_classes[3][7][20] = int_stack + 209330;
 Libderiv->deriv2_classes[3][8][20] = int_stack + 209690;
 Libderiv->deriv2_classes[4][5][20] = int_stack + 210140;
 Libderiv->deriv2_classes[4][6][20] = int_stack + 210455;
 Libderiv->deriv2_classes[4][7][20] = int_stack + 210875;
 Libderiv->deriv2_classes[4][8][20] = int_stack + 211415;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 212090;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 212531;
 Libderiv->deriv2_classes[5][7][20] = int_stack + 213119;
 Libderiv->deriv2_classes[5][8][20] = int_stack + 213875;
 Libderiv->deriv2_classes[3][5][19] = int_stack + 214820;
 Libderiv->deriv2_classes[3][6][19] = int_stack + 215030;
 Libderiv->deriv2_classes[3][7][19] = int_stack + 215310;
 Libderiv->deriv2_classes[3][8][19] = int_stack + 215670;
 Libderiv->deriv2_classes[4][5][19] = int_stack + 216120;
 Libderiv->deriv2_classes[4][6][19] = int_stack + 216435;
 Libderiv->deriv2_classes[4][7][19] = int_stack + 216855;
 Libderiv->deriv2_classes[4][8][19] = int_stack + 217395;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 218070;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 218511;
 Libderiv->deriv2_classes[5][7][19] = int_stack + 219099;
 Libderiv->deriv2_classes[5][8][19] = int_stack + 219855;
 Libderiv->deriv2_classes[3][5][18] = int_stack + 220800;
 Libderiv->deriv2_classes[3][6][18] = int_stack + 221010;
 Libderiv->deriv2_classes[3][7][18] = int_stack + 221290;
 Libderiv->deriv2_classes[3][8][18] = int_stack + 221650;
 Libderiv->deriv2_classes[4][5][18] = int_stack + 222100;
 Libderiv->deriv2_classes[4][6][18] = int_stack + 222415;
 Libderiv->deriv2_classes[4][7][18] = int_stack + 222835;
 Libderiv->deriv2_classes[4][8][18] = int_stack + 223375;
 Libderiv->deriv_classes[5][5][1] = int_stack + 224050;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 224491;
 Libderiv->deriv_classes[5][6][1] = int_stack + 224932;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 225520;
 Libderiv->deriv_classes[5][7][1] = int_stack + 226108;
 Libderiv->deriv2_classes[5][7][18] = int_stack + 226864;
 Libderiv->deriv2_classes[5][8][18] = int_stack + 227620;
 Libderiv->deriv2_classes[3][5][14] = int_stack + 228565;
 Libderiv->deriv2_classes[3][6][14] = int_stack + 228775;
 Libderiv->deriv2_classes[3][7][14] = int_stack + 229055;
 Libderiv->deriv2_classes[3][8][14] = int_stack + 229415;
 Libderiv->deriv2_classes[4][5][14] = int_stack + 229865;
 Libderiv->deriv2_classes[4][6][14] = int_stack + 230180;
 Libderiv->deriv2_classes[4][7][14] = int_stack + 230600;
 Libderiv->deriv2_classes[4][8][14] = int_stack + 231140;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 231815;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 232256;
 Libderiv->deriv2_classes[5][7][14] = int_stack + 232844;
 Libderiv->deriv2_classes[5][8][14] = int_stack + 233600;
 Libderiv->deriv2_classes[3][5][13] = int_stack + 234545;
 Libderiv->deriv2_classes[3][6][13] = int_stack + 234755;
 Libderiv->deriv2_classes[3][7][13] = int_stack + 235035;
 Libderiv->deriv2_classes[3][8][13] = int_stack + 235395;
 Libderiv->deriv2_classes[4][5][13] = int_stack + 235845;
 Libderiv->deriv2_classes[4][6][13] = int_stack + 236160;
 Libderiv->deriv2_classes[4][7][13] = int_stack + 236580;
 Libderiv->deriv2_classes[4][8][13] = int_stack + 237120;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 237795;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 238236;
 Libderiv->deriv2_classes[5][7][13] = int_stack + 238824;
 Libderiv->deriv2_classes[5][8][13] = int_stack + 239580;
 Libderiv->deriv_classes[3][5][11] = int_stack + 240525;
 Libderiv->deriv_classes[3][6][11] = int_stack + 240735;
 Libderiv->deriv_classes[3][7][11] = int_stack + 241015;
 Libderiv->deriv_classes[3][8][11] = int_stack + 241375;
 Libderiv->deriv2_classes[3][5][11] = int_stack + 241825;
 Libderiv->deriv2_classes[3][6][11] = int_stack + 242035;
 Libderiv->deriv2_classes[3][7][11] = int_stack + 242315;
 Libderiv->deriv2_classes[3][8][11] = int_stack + 242675;
 Libderiv->deriv_classes[4][5][11] = int_stack + 243125;
 Libderiv->deriv_classes[4][6][11] = int_stack + 243440;
 Libderiv->deriv_classes[4][7][11] = int_stack + 243860;
 Libderiv->deriv_classes[4][8][11] = int_stack + 244400;
 Libderiv->deriv2_classes[4][5][11] = int_stack + 245075;
 Libderiv->deriv2_classes[4][6][11] = int_stack + 245390;
 Libderiv->deriv2_classes[4][7][11] = int_stack + 245810;
 Libderiv->deriv2_classes[4][8][11] = int_stack + 246350;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 247025;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 247466;
 Libderiv->deriv2_classes[5][7][11] = int_stack + 248054;
 Libderiv->deriv2_classes[5][8][11] = int_stack + 248810;
 Libderiv->deriv_classes[3][5][10] = int_stack + 249755;
 Libderiv->deriv_classes[3][6][10] = int_stack + 249965;
 Libderiv->deriv_classes[3][7][10] = int_stack + 250245;
 Libderiv->deriv_classes[3][8][10] = int_stack + 250605;
 Libderiv->deriv2_classes[3][5][10] = int_stack + 251055;
 Libderiv->deriv2_classes[3][6][10] = int_stack + 251265;
 Libderiv->deriv2_classes[3][7][10] = int_stack + 251545;
 Libderiv->deriv2_classes[3][8][10] = int_stack + 251905;
 Libderiv->deriv_classes[4][5][10] = int_stack + 252355;
 Libderiv->deriv_classes[4][6][10] = int_stack + 252670;
 Libderiv->deriv_classes[4][7][10] = int_stack + 253090;
 Libderiv->deriv_classes[4][8][10] = int_stack + 253630;
 Libderiv->deriv2_classes[4][5][10] = int_stack + 254305;
 Libderiv->deriv2_classes[4][6][10] = int_stack + 254620;
 Libderiv->deriv2_classes[4][7][10] = int_stack + 255040;
 Libderiv->deriv2_classes[4][8][10] = int_stack + 255580;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 256255;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 256696;
 Libderiv->deriv2_classes[5][7][10] = int_stack + 257284;
 Libderiv->deriv2_classes[5][8][10] = int_stack + 258040;
 Libderiv->deriv_classes[3][5][9] = int_stack + 258985;
 Libderiv->deriv_classes[3][6][9] = int_stack + 259195;
 Libderiv->deriv_classes[3][7][9] = int_stack + 259475;
 Libderiv->deriv_classes[3][8][9] = int_stack + 259835;
 Libderiv->deriv2_classes[3][5][9] = int_stack + 260285;
 Libderiv->deriv2_classes[3][6][9] = int_stack + 260495;
 Libderiv->deriv2_classes[3][7][9] = int_stack + 260775;
 Libderiv->deriv2_classes[3][8][9] = int_stack + 261135;
 Libderiv->deriv_classes[4][5][9] = int_stack + 261585;
 Libderiv->deriv_classes[4][6][9] = int_stack + 261900;
 Libderiv->deriv_classes[4][7][9] = int_stack + 262320;
 Libderiv->deriv_classes[4][8][9] = int_stack + 262860;
 Libderiv->deriv2_classes[4][5][9] = int_stack + 263535;
 Libderiv->deriv2_classes[4][6][9] = int_stack + 263850;
 Libderiv->deriv2_classes[4][7][9] = int_stack + 264270;
 Libderiv->deriv2_classes[4][8][9] = int_stack + 264810;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 265485;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 265926;
 Libderiv->deriv2_classes[5][7][9] = int_stack + 266514;
 Libderiv->deriv2_classes[5][8][9] = int_stack + 267270;
 Libderiv->deriv_classes[3][5][8] = int_stack + 268215;
 Libderiv->deriv_classes[3][6][8] = int_stack + 268425;
 Libderiv->deriv_classes[3][7][8] = int_stack + 268705;
 Libderiv->deriv_classes[3][8][8] = int_stack + 269065;
 Libderiv->deriv2_classes[3][5][8] = int_stack + 269515;
 Libderiv->deriv2_classes[3][6][8] = int_stack + 269725;
 Libderiv->deriv2_classes[3][7][8] = int_stack + 270005;
 Libderiv->deriv2_classes[3][8][8] = int_stack + 270365;
 Libderiv->deriv_classes[4][5][8] = int_stack + 270815;
 Libderiv->deriv_classes[4][6][8] = int_stack + 271130;
 Libderiv->deriv_classes[4][7][8] = int_stack + 271550;
 Libderiv->deriv_classes[4][8][8] = int_stack + 272090;
 Libderiv->deriv2_classes[4][5][8] = int_stack + 272765;
 Libderiv->deriv2_classes[4][6][8] = int_stack + 273080;
 Libderiv->deriv2_classes[4][7][8] = int_stack + 273500;
 Libderiv->deriv2_classes[4][8][8] = int_stack + 274040;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 274715;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 275156;
 Libderiv->deriv2_classes[5][7][8] = int_stack + 275744;
 Libderiv->deriv2_classes[5][8][8] = int_stack + 276500;
 Libderiv->deriv_classes[3][5][7] = int_stack + 277445;
 Libderiv->deriv_classes[3][6][7] = int_stack + 277655;
 Libderiv->deriv_classes[3][7][7] = int_stack + 277935;
 Libderiv->deriv_classes[3][8][7] = int_stack + 278295;
 Libderiv->deriv2_classes[3][5][7] = int_stack + 278745;
 Libderiv->deriv2_classes[3][6][7] = int_stack + 278955;
 Libderiv->deriv2_classes[3][7][7] = int_stack + 279235;
 Libderiv->deriv2_classes[3][8][7] = int_stack + 279595;
 Libderiv->deriv_classes[4][5][7] = int_stack + 280045;
 Libderiv->deriv_classes[4][6][7] = int_stack + 280360;
 Libderiv->deriv_classes[4][7][7] = int_stack + 280780;
 Libderiv->deriv_classes[4][8][7] = int_stack + 281320;
 Libderiv->deriv2_classes[4][5][7] = int_stack + 281995;
 Libderiv->deriv2_classes[4][6][7] = int_stack + 282310;
 Libderiv->deriv2_classes[4][7][7] = int_stack + 282730;
 Libderiv->deriv2_classes[4][8][7] = int_stack + 283270;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 283945;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 284386;
 Libderiv->deriv2_classes[5][7][7] = int_stack + 284974;
 Libderiv->deriv2_classes[5][8][7] = int_stack + 285730;
 Libderiv->deriv_classes[3][5][6] = int_stack + 286675;
 Libderiv->deriv_classes[3][6][6] = int_stack + 286885;
 Libderiv->deriv_classes[3][7][6] = int_stack + 287165;
 Libderiv->deriv_classes[3][8][6] = int_stack + 287525;
 Libderiv->deriv2_classes[3][5][6] = int_stack + 287975;
 Libderiv->deriv2_classes[3][6][6] = int_stack + 288185;
 Libderiv->deriv2_classes[3][7][6] = int_stack + 288465;
 Libderiv->deriv2_classes[3][8][6] = int_stack + 288825;
 Libderiv->dvrr_classes[4][5] = int_stack + 289275;
 Libderiv->deriv_classes[4][5][6] = int_stack + 289590;
 Libderiv->dvrr_classes[4][6] = int_stack + 289905;
 Libderiv->deriv_classes[4][6][6] = int_stack + 290325;
 Libderiv->dvrr_classes[4][7] = int_stack + 290745;
 Libderiv->deriv_classes[4][7][6] = int_stack + 291285;
 Libderiv->deriv_classes[4][8][6] = int_stack + 291825;
 Libderiv->deriv2_classes[4][5][6] = int_stack + 292500;
 Libderiv->deriv2_classes[4][6][6] = int_stack + 292815;
 Libderiv->deriv2_classes[4][7][6] = int_stack + 293235;
 Libderiv->deriv2_classes[4][8][6] = int_stack + 293775;
 Libderiv->deriv_classes[5][5][0] = int_stack + 294450;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 294891;
 Libderiv->deriv_classes[5][6][0] = int_stack + 295332;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 295920;
 Libderiv->deriv_classes[5][7][0] = int_stack + 296508;
 Libderiv->deriv2_classes[5][7][6] = int_stack + 297264;
 Libderiv->deriv2_classes[5][8][6] = int_stack + 298020;
 Libderiv->deriv_classes[3][5][2] = int_stack + 298965;
 Libderiv->deriv_classes[3][6][2] = int_stack + 299175;
 Libderiv->deriv_classes[3][7][2] = int_stack + 299455;
 Libderiv->deriv_classes[3][8][2] = int_stack + 299815;
 Libderiv->deriv2_classes[3][5][2] = int_stack + 300265;
 Libderiv->deriv2_classes[3][6][2] = int_stack + 300475;
 Libderiv->deriv2_classes[3][7][2] = int_stack + 300755;
 Libderiv->deriv2_classes[3][8][2] = int_stack + 301115;
 Libderiv->deriv_classes[4][5][2] = int_stack + 301565;
 Libderiv->deriv_classes[4][6][2] = int_stack + 301880;
 Libderiv->deriv_classes[4][7][2] = int_stack + 302300;
 Libderiv->deriv_classes[4][8][2] = int_stack + 302840;
 Libderiv->deriv2_classes[4][5][2] = int_stack + 303515;
 Libderiv->deriv2_classes[4][6][2] = int_stack + 303830;
 Libderiv->deriv2_classes[4][7][2] = int_stack + 304250;
 Libderiv->deriv2_classes[4][8][2] = int_stack + 304790;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 305465;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 305906;
 Libderiv->deriv2_classes[5][7][2] = int_stack + 306494;
 Libderiv->deriv2_classes[5][8][2] = int_stack + 307250;
 Libderiv->deriv_classes[3][5][1] = int_stack + 308195;
 Libderiv->deriv_classes[3][6][1] = int_stack + 308405;
 Libderiv->deriv_classes[3][7][1] = int_stack + 308685;
 Libderiv->deriv_classes[3][8][1] = int_stack + 309045;
 Libderiv->deriv2_classes[3][5][1] = int_stack + 309495;
 Libderiv->deriv2_classes[3][6][1] = int_stack + 309705;
 Libderiv->deriv2_classes[3][7][1] = int_stack + 309985;
 Libderiv->deriv2_classes[3][8][1] = int_stack + 310345;
 Libderiv->deriv_classes[4][5][1] = int_stack + 310795;
 Libderiv->deriv_classes[4][6][1] = int_stack + 311110;
 Libderiv->deriv_classes[4][7][1] = int_stack + 311530;
 Libderiv->deriv_classes[4][8][1] = int_stack + 312070;
 Libderiv->deriv2_classes[4][5][1] = int_stack + 312745;
 Libderiv->deriv2_classes[4][6][1] = int_stack + 313060;
 Libderiv->deriv2_classes[4][7][1] = int_stack + 313480;
 Libderiv->deriv2_classes[4][8][1] = int_stack + 314020;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 314695;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 315136;
 Libderiv->deriv2_classes[5][7][1] = int_stack + 315724;
 Libderiv->deriv2_classes[5][8][1] = int_stack + 316480;
 Libderiv->dvrr_classes[3][5] = int_stack + 317425;
 Libderiv->dvrr_classes[3][6] = int_stack + 317635;
 Libderiv->dvrr_classes[3][7] = int_stack + 317915;
 Libderiv->dvrr_classes[3][8] = int_stack + 318275;
 Libderiv->deriv_classes[3][5][0] = int_stack + 318725;
 Libderiv->deriv_classes[3][6][0] = int_stack + 318935;
 Libderiv->deriv_classes[3][7][0] = int_stack + 319215;
 Libderiv->deriv_classes[3][8][0] = int_stack + 319575;
 Libderiv->deriv2_classes[3][5][0] = int_stack + 320025;
 Libderiv->deriv2_classes[3][6][0] = int_stack + 320235;
 Libderiv->deriv2_classes[3][7][0] = int_stack + 320515;
 Libderiv->deriv2_classes[3][8][0] = int_stack + 320875;
 Libderiv->deriv_classes[4][5][0] = int_stack + 321325;
 Libderiv->deriv_classes[4][6][0] = int_stack + 321640;
 Libderiv->deriv_classes[4][7][0] = int_stack + 322060;
 Libderiv->deriv_classes[4][8][0] = int_stack + 322600;
 Libderiv->deriv2_classes[4][5][0] = int_stack + 323275;
 Libderiv->deriv2_classes[4][6][0] = int_stack + 323590;
 Libderiv->deriv2_classes[4][7][0] = int_stack + 324010;
 Libderiv->deriv2_classes[4][8][0] = int_stack + 324550;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 325225;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 325666;
 Libderiv->deriv2_classes[5][7][0] = int_stack + 326254;
 Libderiv->deriv2_classes[5][8][0] = int_stack + 327010;
 memset(int_stack,0,2623640);

 Libderiv->dvrr_stack = int_stack + 1008235;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_fdhf(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+327955,int_stack+317635,int_stack+317425,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+328585,int_stack+317915,int_stack+317635,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+329425,int_stack+328585,int_stack+327955,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+330685,int_stack+240735,int_stack+240525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317425,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+331315,int_stack+241015,int_stack+240735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317635,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+332155,int_stack+331315,int_stack+330685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+327955,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+333415,int_stack+241375,int_stack+241015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317915,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+334495,int_stack+333415,int_stack+331315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+328585,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+336175,int_stack+334495,int_stack+332155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+329425,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+333415,int_stack+289905,int_stack+289275,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+334360,int_stack+290745,int_stack+289905,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+338275,int_stack+334360,int_stack+333415,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+340165,int_stack+243440,int_stack+243125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289275,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+341110,int_stack+243860,int_stack+243440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289905,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+342370,int_stack+341110,int_stack+340165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333415,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+344260,int_stack+244400,int_stack+243860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290745,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+345880,int_stack+344260,int_stack+341110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334360,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+348400,int_stack+345880,int_stack+342370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338275,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+351550,int_stack+348400,int_stack+336175,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+344260,int_stack+143034,int_stack+141711,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+345583,int_stack+4725,int_stack+143034,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+357850,int_stack+345583,int_stack+344260,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+360496,int_stack+103768,int_stack+102886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141711,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+361819,int_stack+104944,int_stack+103768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143034,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+363583,int_stack+361819,int_stack+360496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344260,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+366229,int_stack+0,int_stack+104944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4725,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+368497,int_stack+366229,int_stack+361819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345583,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+372025,int_stack+368497,int_stack+363583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357850,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+376435,int_stack+372025,int_stack+348400,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+366229,int_stack+249965,int_stack+249755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317425, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+366859,int_stack+250245,int_stack+249965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317635, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+367699,int_stack+366859,int_stack+366229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+327955, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+368959,int_stack+250605,int_stack+250245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317915, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+370039,int_stack+368959,int_stack+366859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+328585, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+371719,int_stack+370039,int_stack+367699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+329425, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+252670,int_stack+252355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289275, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+368959,int_stack+253090,int_stack+252670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289905, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+373819,int_stack+368959,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333415, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+385885,int_stack+253630,int_stack+253090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290745, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+387505,int_stack+385885,int_stack+368959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334360, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+390025,int_stack+387505,int_stack+373819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338275, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+393175,int_stack+390025,int_stack+371719,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+385885,int_stack+111533,int_stack+110651, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141711, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+387208,int_stack+112709,int_stack+111533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143034, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+399475,int_stack+387208,int_stack+385885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344260, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+402121,int_stack+945,int_stack+112709, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4725, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+404389,int_stack+402121,int_stack+387208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345583, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+407917,int_stack+404389,int_stack+399475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357850, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+412327,int_stack+407917,int_stack+390025,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+402121,int_stack+259195,int_stack+258985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317425, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+402751,int_stack+259475,int_stack+259195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317635, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+403591,int_stack+402751,int_stack+402121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+327955, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+404851,int_stack+259835,int_stack+259475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317915, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+405931,int_stack+404851,int_stack+402751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+328585, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+407611,int_stack+405931,int_stack+403591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+329425, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+945,int_stack+261900,int_stack+261585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289275, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+404851,int_stack+262320,int_stack+261900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289905, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+409711,int_stack+404851,int_stack+945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333415, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+421777,int_stack+262860,int_stack+262320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290745, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+423397,int_stack+421777,int_stack+404851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334360, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+425917,int_stack+423397,int_stack+409711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338275, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+429067,int_stack+425917,int_stack+407611,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+421777,int_stack+119298,int_stack+118416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141711, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+423100,int_stack+120474,int_stack+119298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143034, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+435367,int_stack+423100,int_stack+421777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344260, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+438013,int_stack+1890,int_stack+120474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4725, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+440281,int_stack+438013,int_stack+423100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345583, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+443809,int_stack+440281,int_stack+435367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357850, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+448219,int_stack+443809,int_stack+425917,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+438013,int_stack+268425,int_stack+268215, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+438643,int_stack+268705,int_stack+268425, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+439483,int_stack+438643,int_stack+438013, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+327955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+440743,int_stack+269065,int_stack+268705, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+441823,int_stack+440743,int_stack+438643, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+328585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+443503,int_stack+441823,int_stack+439483, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+329425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1890,int_stack+271130,int_stack+270815, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+440743,int_stack+271550,int_stack+271130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+445603,int_stack+440743,int_stack+1890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+457669,int_stack+272090,int_stack+271550, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+459289,int_stack+457669,int_stack+440743, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+461809,int_stack+459289,int_stack+445603, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+464959,int_stack+461809,int_stack+443503,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+457669,int_stack+127063,int_stack+126181, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+458992,int_stack+128239,int_stack+127063, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+471259,int_stack+458992,int_stack+457669, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+473905,int_stack+2835,int_stack+128239, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+476173,int_stack+473905,int_stack+458992, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+479701,int_stack+476173,int_stack+471259, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+484111,int_stack+479701,int_stack+461809,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+473905,int_stack+277655,int_stack+277445, 0.0, zero_stack, 1.0, int_stack+317425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+474535,int_stack+277935,int_stack+277655, 0.0, zero_stack, 1.0, int_stack+317635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+475375,int_stack+474535,int_stack+473905, 0.0, zero_stack, 1.0, int_stack+327955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+476635,int_stack+278295,int_stack+277935, 0.0, zero_stack, 1.0, int_stack+317915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477715,int_stack+476635,int_stack+474535, 0.0, zero_stack, 1.0, int_stack+328585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+479395,int_stack+477715,int_stack+475375, 0.0, zero_stack, 1.0, int_stack+329425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2835,int_stack+280360,int_stack+280045, 0.0, zero_stack, 1.0, int_stack+289275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+476635,int_stack+280780,int_stack+280360, 0.0, zero_stack, 1.0, int_stack+289905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+481495,int_stack+476635,int_stack+2835, 0.0, zero_stack, 1.0, int_stack+333415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+493561,int_stack+281320,int_stack+280780, 0.0, zero_stack, 1.0, int_stack+290745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+495181,int_stack+493561,int_stack+476635, 0.0, zero_stack, 1.0, int_stack+334360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+497701,int_stack+495181,int_stack+481495, 0.0, zero_stack, 1.0, int_stack+338275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+500851,int_stack+497701,int_stack+479395,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+493561,int_stack+134828,int_stack+133946, 0.0, zero_stack, 1.0, int_stack+141711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+494884,int_stack+136004,int_stack+134828, 0.0, zero_stack, 1.0, int_stack+143034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+507151,int_stack+494884,int_stack+493561, 0.0, zero_stack, 1.0, int_stack+344260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+509797,int_stack+3780,int_stack+136004, 0.0, zero_stack, 1.0, int_stack+4725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+512065,int_stack+509797,int_stack+494884, 0.0, zero_stack, 1.0, int_stack+345583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+515593,int_stack+512065,int_stack+507151, 0.0, zero_stack, 1.0, int_stack+357850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+520003,int_stack+515593,int_stack+497701,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+509797,int_stack+286885,int_stack+286675, 1.0, int_stack+317425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+510427,int_stack+287165,int_stack+286885, 1.0, int_stack+317635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+511267,int_stack+510427,int_stack+509797, 1.0, int_stack+327955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+512527,int_stack+287525,int_stack+287165, 1.0, int_stack+317915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+513607,int_stack+512527,int_stack+510427, 1.0, int_stack+328585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+515287,int_stack+513607,int_stack+511267, 1.0, int_stack+329425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3780,int_stack+290325,int_stack+289590, 1.0, int_stack+289275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+512527,int_stack+291285,int_stack+290325, 1.0, int_stack+289905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+517387,int_stack+512527,int_stack+3780, 1.0, int_stack+333415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+529453,int_stack+291825,int_stack+291285, 1.0, int_stack+290745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+531073,int_stack+529453,int_stack+512527, 1.0, int_stack+334360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+533593,int_stack+531073,int_stack+517387, 1.0, int_stack+338275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+536743,int_stack+533593,int_stack+515287,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+529453,int_stack+143622,int_stack+142152, 1.0, int_stack+141711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+530776,int_stack+144798,int_stack+143622, 1.0, int_stack+143034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+543043,int_stack+530776,int_stack+529453, 1.0, int_stack+344260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+545689,int_stack+5481,int_stack+144798, 1.0, int_stack+4725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+547957,int_stack+545689,int_stack+530776, 1.0, int_stack+345583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+551485,int_stack+547957,int_stack+543043, 1.0, int_stack+357850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+555895,int_stack+551485,int_stack+533593,210);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+357850,int_stack+318275,int_stack+317915,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+545689,int_stack+357850,int_stack+328585,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+357850,int_stack+545689,int_stack+329425,10);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+545689,int_stack+8316,int_stack+290745,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+547309,int_stack+545689,int_stack+334360,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+549829,int_stack+547309,int_stack+338275,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+565345,int_stack+549829,int_stack+357850,210);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+338275,int_stack+299175,int_stack+298965,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+338905,int_stack+299455,int_stack+299175,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+545689,int_stack+338905,int_stack+338275,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+546949,int_stack+299815,int_stack+299455,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+548029,int_stack+546949,int_stack+338905,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+552979,int_stack+548029,int_stack+545689,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+546949,int_stack+301880,int_stack+301565,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+547894,int_stack+302300,int_stack+301880,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+344260,int_stack+547894,int_stack+546949,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4725,int_stack+302840,int_stack+302300,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+333415,int_stack+4725,int_stack+547894,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+571645,int_stack+333415,int_stack+344260,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+574795,int_stack+571645,int_stack+552979, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+333415,int_stack+181287,int_stack+180405,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+346150,int_stack+182463,int_stack+181287,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+327955,int_stack+346150,int_stack+333415,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+581095,int_stack+6426,int_stack+182463,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+583363,int_stack+581095,int_stack+346150,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+586891,int_stack+583363,int_stack+327955,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+591301,int_stack+586891,int_stack+571645, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+549829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+581095,int_stack+308405,int_stack+308195,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+581725,int_stack+308685,int_stack+308405,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+582565,int_stack+581725,int_stack+581095,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+583825,int_stack+309045,int_stack+308685,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+584905,int_stack+583825,int_stack+581725,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+586585,int_stack+584905,int_stack+582565,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+583825,int_stack+311110,int_stack+310795,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+584770,int_stack+311530,int_stack+311110,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+588685,int_stack+584770,int_stack+583825,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+4725,int_stack+312070,int_stack+311530,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+600751,int_stack+4725,int_stack+584770,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+603271,int_stack+600751,int_stack+588685,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+606421,int_stack+603271,int_stack+586585, 0.0, zero_stack, 1.0, int_stack+357850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+600751,int_stack+224932,int_stack+224050,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4725,int_stack+226108,int_stack+224932,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+612721,int_stack+4725,int_stack+600751,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+615367,int_stack+7371,int_stack+226108,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+617635,int_stack+615367,int_stack+4725,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+621163,int_stack+617635,int_stack+612721,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+625573,int_stack+621163,int_stack+603271, 0.0, zero_stack, 1.0, int_stack+549829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+615367,int_stack+318935,int_stack+318725,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+615997,int_stack+319215,int_stack+318935,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+616837,int_stack+615997,int_stack+615367,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+618097,int_stack+319575,int_stack+319215,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+619177,int_stack+618097,int_stack+615997,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+620857,int_stack+619177,int_stack+616837,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+618097,int_stack+321640,int_stack+321325,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+619042,int_stack+322060,int_stack+321640,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+622957,int_stack+619042,int_stack+618097,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6489,int_stack+322600,int_stack+322060,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+635023,int_stack+6489,int_stack+619042,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+637543,int_stack+635023,int_stack+622957,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+640693,int_stack+637543,int_stack+620857, 1.0, int_stack+357850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+357850,int_stack+295332,int_stack+294450,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+635023,int_stack+296508,int_stack+295332,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+646993,int_stack+635023,int_stack+357850,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6489,int_stack+8991,int_stack+296508,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+649639,int_stack+6489,int_stack+635023,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+653167,int_stack+649639,int_stack+646993,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+657577,int_stack+653167,int_stack+637543, 1.0, int_stack+549829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+649639,int_stack+10146,int_stack+9936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+240525,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+650269,int_stack+10426,int_stack+10146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+240735,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+651109,int_stack+650269,int_stack+649639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+330685,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+652369,int_stack+10786,int_stack+10426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+241015,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+653449,int_stack+652369,int_stack+650269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+331315,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+655129,int_stack+653449,int_stack+651109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+332155,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+649639,int_stack+11551,int_stack+11236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+243125,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+650584,int_stack+11971,int_stack+11551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+243440,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+651844,int_stack+650584,int_stack+649639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+340165,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6489,int_stack+12511,int_stack+11971, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+243860,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8109,int_stack+6489,int_stack+650584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+341110,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+549154,int_stack+8109,int_stack+651844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+342370,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+6489,int_stack+549154,int_stack+655129,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359173,int_stack+13627,int_stack+13186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+102886,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+649639,int_stack+14215,int_stack+13627, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+103768,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+651403,int_stack+649639,int_stack+359173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+360496,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+654049,int_stack+14971,int_stack+14215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+104944,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+667027,int_stack+654049,int_stack+649639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+361819,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+670555,int_stack+667027,int_stack+651403, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+363583,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+674965,int_stack+670555,int_stack+549154,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+549154,int_stack+16126,int_stack+15916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240525, 1.0, int_stack+249755,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+549784,int_stack+16406,int_stack+16126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240735, 1.0, int_stack+249965,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+550624,int_stack+549784,int_stack+549154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330685, 1.0, int_stack+366229,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+551884,int_stack+16766,int_stack+16406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+241015, 1.0, int_stack+250245,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+667027,int_stack+551884,int_stack+549784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331315, 1.0, int_stack+366859,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+668707,int_stack+667027,int_stack+550624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332155, 1.0, int_stack+367699,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+667027,int_stack+17531,int_stack+17216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243125, 1.0, int_stack+252355,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+549154,int_stack+17951,int_stack+17531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243440, 1.0, int_stack+252670,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+550414,int_stack+549154,int_stack+667027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+340165, 1.0, int_stack+0,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+667027,int_stack+18491,int_stack+17951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243860, 1.0, int_stack+253090,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+670807,int_stack+667027,int_stack+549154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+341110, 1.0, int_stack+368959,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+649639,int_stack+670807,int_stack+550414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342370, 1.0, int_stack+373819,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+12789,int_stack+649639,int_stack+668707,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359173,int_stack+19607,int_stack+19166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102886, 1.0, int_stack+110651,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+549154,int_stack+20195,int_stack+19607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103768, 1.0, int_stack+111533,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+667027,int_stack+549154,int_stack+359173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360496, 1.0, int_stack+385885,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+669673,int_stack+20951,int_stack+20195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104944, 1.0, int_stack+112709,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+652789,int_stack+669673,int_stack+549154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+361819, 1.0, int_stack+387208,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+669673,int_stack+652789,int_stack+667027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363583, 1.0, int_stack+399475,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+684415,int_stack+669673,int_stack+649639,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+649639,int_stack+22106,int_stack+21896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+249755, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+650269,int_stack+22386,int_stack+22106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+249965, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+651109,int_stack+650269,int_stack+649639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+366229, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+652369,int_stack+22746,int_stack+22386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+250245, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+653449,int_stack+652369,int_stack+650269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+366859, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+655129,int_stack+653449,int_stack+651109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+367699, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+649639,int_stack+23511,int_stack+23196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+252355, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+650584,int_stack+23931,int_stack+23511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+252670, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+651844,int_stack+650584,int_stack+649639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+667027,int_stack+24471,int_stack+23931, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+253090, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+668647,int_stack+667027,int_stack+650584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+368959, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+671167,int_stack+668647,int_stack+651844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+373819, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+693865,int_stack+671167,int_stack+655129,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359173,int_stack+25587,int_stack+25146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+110651, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+667027,int_stack+26175,int_stack+25587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+111533, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+649639,int_stack+667027,int_stack+359173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+385885, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+668791,int_stack+26931,int_stack+26175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+112709, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+652285,int_stack+668791,int_stack+667027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+387208, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+19089,int_stack+652285,int_stack+649639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+399475, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+700165,int_stack+19089,int_stack+671167,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+19089,int_stack+28086,int_stack+27876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240525, 0.0, zero_stack, 1.0, int_stack+258985,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+19719,int_stack+28366,int_stack+28086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240735, 0.0, zero_stack, 1.0, int_stack+259195,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+20559,int_stack+19719,int_stack+19089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330685, 0.0, zero_stack, 1.0, int_stack+402121,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+21819,int_stack+28726,int_stack+28366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+241015, 0.0, zero_stack, 1.0, int_stack+259475,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+22899,int_stack+21819,int_stack+19719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331315, 0.0, zero_stack, 1.0, int_stack+402751,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+24579,int_stack+22899,int_stack+20559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332155, 0.0, zero_stack, 1.0, int_stack+403591,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+19089,int_stack+29491,int_stack+29176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243125, 0.0, zero_stack, 1.0, int_stack+261585,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+20034,int_stack+29911,int_stack+29491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243440, 0.0, zero_stack, 1.0, int_stack+261900,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+21294,int_stack+20034,int_stack+19089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+340165, 0.0, zero_stack, 1.0, int_stack+945,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+26679,int_stack+30451,int_stack+29911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243860, 0.0, zero_stack, 1.0, int_stack+262320,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+28299,int_stack+26679,int_stack+20034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+341110, 0.0, zero_stack, 1.0, int_stack+404851,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+649639,int_stack+28299,int_stack+21294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342370, 0.0, zero_stack, 1.0, int_stack+409711,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+667027,int_stack+649639,int_stack+24579,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359173,int_stack+31567,int_stack+31126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102886, 0.0, zero_stack, 1.0, int_stack+118416,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+19089,int_stack+32155,int_stack+31567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103768, 0.0, zero_stack, 1.0, int_stack+119298,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+20853,int_stack+19089,int_stack+359173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360496, 0.0, zero_stack, 1.0, int_stack+421777,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+23499,int_stack+32911,int_stack+32155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104944, 0.0, zero_stack, 1.0, int_stack+120474,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+25767,int_stack+23499,int_stack+19089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+361819, 0.0, zero_stack, 1.0, int_stack+423100,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+29295,int_stack+25767,int_stack+20853, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363583, 0.0, zero_stack, 1.0, int_stack+435367,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+19089,int_stack+29295,int_stack+649639,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+649639,int_stack+34066,int_stack+33856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+249755, 1.0, int_stack+258985, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+650269,int_stack+34346,int_stack+34066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+249965, 1.0, int_stack+259195, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+651109,int_stack+650269,int_stack+649639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366229, 1.0, int_stack+402121, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+652369,int_stack+34706,int_stack+34346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250245, 1.0, int_stack+259475, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+653449,int_stack+652369,int_stack+650269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366859, 1.0, int_stack+402751, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+655129,int_stack+653449,int_stack+651109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367699, 1.0, int_stack+403591, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+649639,int_stack+35471,int_stack+35156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252355, 1.0, int_stack+261585, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+650584,int_stack+35891,int_stack+35471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252670, 1.0, int_stack+261900, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+651844,int_stack+650584,int_stack+649639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+945, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+36431,int_stack+35891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+253090, 1.0, int_stack+262320, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+30159,int_stack+28539,int_stack+650584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368959, 1.0, int_stack+404851, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+32679,int_stack+30159,int_stack+651844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373819, 1.0, int_stack+409711, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+709615,int_stack+32679,int_stack+655129,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359173,int_stack+37547,int_stack+37106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110651, 1.0, int_stack+118416, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+28539,int_stack+38135,int_stack+37547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111533, 1.0, int_stack+119298, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+649639,int_stack+28539,int_stack+359173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385885, 1.0, int_stack+421777, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+30303,int_stack+38891,int_stack+38135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112709, 1.0, int_stack+120474, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+652285,int_stack+30303,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+387208, 1.0, int_stack+423100, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+715915,int_stack+652285,int_stack+649639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399475, 1.0, int_stack+435367, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+720325,int_stack+715915,int_stack+32679,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+715915,int_stack+40046,int_stack+39836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+258985, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+716545,int_stack+40326,int_stack+40046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+259195, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+717385,int_stack+716545,int_stack+715915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+402121, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+718645,int_stack+40686,int_stack+40326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+259475, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+649639,int_stack+718645,int_stack+716545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+402751, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+651319,int_stack+649639,int_stack+717385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+403591, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+649639,int_stack+41451,int_stack+41136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+261585, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+715915,int_stack+41871,int_stack+41451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+261900, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+717175,int_stack+715915,int_stack+649639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+945, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+649639,int_stack+42411,int_stack+41871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+262320, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+653419,int_stack+649639,int_stack+715915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+404851, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+653419,int_stack+717175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+409711, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+31689,int_stack+28539,int_stack+651319,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359173,int_stack+43527,int_stack+43086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+118416, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+715915,int_stack+44115,int_stack+43527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+119298, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+717679,int_stack+715915,int_stack+359173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+421777, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+649639,int_stack+44871,int_stack+44115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+120474, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+651907,int_stack+649639,int_stack+715915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+423100, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+37989,int_stack+651907,int_stack+717679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+435367, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+729775,int_stack+37989,int_stack+28539,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+46026,int_stack+45816, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240525, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268215,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+46306,int_stack+46026, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240735, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268425,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+438013,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+37989,int_stack+46666,int_stack+46306, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+241015, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268705,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+39069,int_stack+37989,int_stack+29169, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+438643,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+40749,int_stack+39069,int_stack+30009, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332155, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+439483,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+37989,int_stack+47431,int_stack+47116, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243125, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+270815,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38934,int_stack+47851,int_stack+47431, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271130,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+28539,int_stack+38934,int_stack+37989, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+340165, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1890,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+42849,int_stack+48391,int_stack+47851, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243860, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271550,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+44469,int_stack+42849,int_stack+38934, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+341110, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+440743,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+715915,int_stack+44469,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+445603,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+649639,int_stack+715915,int_stack+40749,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359173,int_stack+49507,int_stack+49066, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102886, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126181,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+28539,int_stack+50095,int_stack+49507, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103768, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127063,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+37989,int_stack+28539,int_stack+359173, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360496, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457669,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+40635,int_stack+50851,int_stack+50095, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104944, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128239,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+42903,int_stack+40635,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+361819, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458992,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+46431,int_stack+42903,int_stack+37989, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363583, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+471259,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+739225,int_stack+46431,int_stack+715915,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+715915,int_stack+52006,int_stack+51796, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+249755, 0.0, zero_stack, 1.0, int_stack+268215, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+716545,int_stack+52286,int_stack+52006, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+249965, 0.0, zero_stack, 1.0, int_stack+268425, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+717385,int_stack+716545,int_stack+715915, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366229, 0.0, zero_stack, 1.0, int_stack+438013, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+718645,int_stack+52646,int_stack+52286, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250245, 0.0, zero_stack, 1.0, int_stack+268705, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+37989,int_stack+718645,int_stack+716545, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366859, 0.0, zero_stack, 1.0, int_stack+438643, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+39669,int_stack+37989,int_stack+717385, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367699, 0.0, zero_stack, 1.0, int_stack+439483, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+37989,int_stack+53411,int_stack+53096, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252355, 0.0, zero_stack, 1.0, int_stack+270815, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+715915,int_stack+53831,int_stack+53411, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252670, 0.0, zero_stack, 1.0, int_stack+271130, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+717175,int_stack+715915,int_stack+37989, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+1890, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+37989,int_stack+54371,int_stack+53831, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+253090, 0.0, zero_stack, 1.0, int_stack+271550, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+41769,int_stack+37989,int_stack+715915, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368959, 0.0, zero_stack, 1.0, int_stack+440743, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+41769,int_stack+717175, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373819, 0.0, zero_stack, 1.0, int_stack+445603, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+41769,int_stack+28539,int_stack+39669,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359173,int_stack+55487,int_stack+55046, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110651, 0.0, zero_stack, 1.0, int_stack+126181, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+48069,int_stack+56075,int_stack+55487, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111533, 0.0, zero_stack, 1.0, int_stack+127063, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+49833,int_stack+48069,int_stack+359173, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385885, 0.0, zero_stack, 1.0, int_stack+457669, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+52479,int_stack+56831,int_stack+56075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112709, 0.0, zero_stack, 1.0, int_stack+128239, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+715915,int_stack+52479,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+387208, 0.0, zero_stack, 1.0, int_stack+458992, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+52479,int_stack+715915,int_stack+49833, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399475, 0.0, zero_stack, 1.0, int_stack+471259, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+748675,int_stack+52479,int_stack+28539,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+57986,int_stack+57776, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+258985, 1.0, int_stack+268215, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+58266,int_stack+57986, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259195, 1.0, int_stack+268425, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+402121, 1.0, int_stack+438013, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+58626,int_stack+58266, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259475, 1.0, int_stack+268705, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+716995,int_stack+715915,int_stack+29169, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+402751, 1.0, int_stack+438643, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+716995,int_stack+30009, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+403591, 1.0, int_stack+439483, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+715915,int_stack+59391,int_stack+59076, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261585, 1.0, int_stack+270815, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+716860,int_stack+59811,int_stack+59391, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261900, 1.0, int_stack+271130, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+718120,int_stack+716860,int_stack+715915, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+945, 1.0, int_stack+1890, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+60351,int_stack+59811, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262320, 1.0, int_stack+271550, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+50169,int_stack+28539,int_stack+716860, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404851, 1.0, int_stack+440743, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+50169,int_stack+718120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409711, 1.0, int_stack+445603, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+50169,int_stack+28539,int_stack+48069,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359173,int_stack+61467,int_stack+61026, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118416, 1.0, int_stack+126181, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+48069,int_stack+62055,int_stack+61467, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+119298, 1.0, int_stack+127063, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+56469,int_stack+48069,int_stack+359173, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+421777, 1.0, int_stack+457669, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+59115,int_stack+62811,int_stack+62055, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120474, 1.0, int_stack+128239, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+715915,int_stack+59115,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+423100, 1.0, int_stack+458992, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+59115,int_stack+715915,int_stack+56469, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+435367, 1.0, int_stack+471259, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+758125,int_stack+59115,int_stack+28539,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+63966,int_stack+63756, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+268215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+64246,int_stack+63966, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+268425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+438013, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+56469,int_stack+64606,int_stack+64246, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+268705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+57549,int_stack+56469,int_stack+29169, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+438643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+57549,int_stack+30009, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+439483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+56469,int_stack+65371,int_stack+65056, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+270815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+57414,int_stack+65791,int_stack+65371, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+271130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+58674,int_stack+57414,int_stack+56469, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+60564,int_stack+66331,int_stack+65791, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+271550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+62184,int_stack+60564,int_stack+57414, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+440743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+62184,int_stack+58674, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+445603, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+56469,int_stack+28539,int_stack+48069,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359173,int_stack+67447,int_stack+67006, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+126181, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+48069,int_stack+68035,int_stack+67447, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+127063, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+62769,int_stack+48069,int_stack+359173, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+457669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+65415,int_stack+68791,int_stack+68035, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+128239, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+715915,int_stack+65415,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+458992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+715915,int_stack+62769, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+471259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+771985,int_stack+767575,int_stack+28539,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+69946,int_stack+69736, 0.0, zero_stack, 1.0, int_stack+240525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277445,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+70226,int_stack+69946, 0.0, zero_stack, 1.0, int_stack+240735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277655,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 1.0, int_stack+330685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+473905,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+70586,int_stack+70226, 0.0, zero_stack, 1.0, int_stack+241015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277935,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+768655,int_stack+767575,int_stack+29169, 0.0, zero_stack, 1.0, int_stack+331315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+474535,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+768655,int_stack+30009, 0.0, zero_stack, 1.0, int_stack+332155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475375,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+767575,int_stack+71351,int_stack+71036, 0.0, zero_stack, 1.0, int_stack+243125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280045,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+768520,int_stack+71771,int_stack+71351, 0.0, zero_stack, 1.0, int_stack+243440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280360,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+769780,int_stack+768520,int_stack+767575, 0.0, zero_stack, 1.0, int_stack+340165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2835,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+72311,int_stack+71771, 0.0, zero_stack, 1.0, int_stack+243860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280780,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+62769,int_stack+28539,int_stack+768520, 0.0, zero_stack, 1.0, int_stack+341110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476635,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+62769,int_stack+769780, 0.0, zero_stack, 1.0, int_stack+342370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+481495,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+62769,int_stack+28539,int_stack+48069,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359173,int_stack+73427,int_stack+72986, 0.0, zero_stack, 1.0, int_stack+102886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+133946,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+48069,int_stack+74015,int_stack+73427, 0.0, zero_stack, 1.0, int_stack+103768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134828,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+69069,int_stack+48069,int_stack+359173, 0.0, zero_stack, 1.0, int_stack+360496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493561,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+71715,int_stack+74771,int_stack+74015, 0.0, zero_stack, 1.0, int_stack+104944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136004,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+767575,int_stack+71715,int_stack+48069, 0.0, zero_stack, 1.0, int_stack+361819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+494884,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+715915,int_stack+767575,int_stack+69069, 0.0, zero_stack, 1.0, int_stack+363583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507151,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+781435,int_stack+715915,int_stack+28539,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+75926,int_stack+75716, 0.0, zero_stack, 1.0, int_stack+249755, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277445, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+76206,int_stack+75926, 0.0, zero_stack, 1.0, int_stack+249965, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277655, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 1.0, int_stack+366229, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+473905, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+76566,int_stack+76206, 0.0, zero_stack, 1.0, int_stack+250245, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277935, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+716995,int_stack+715915,int_stack+29169, 0.0, zero_stack, 1.0, int_stack+366859, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+474535, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+716995,int_stack+30009, 0.0, zero_stack, 1.0, int_stack+367699, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475375, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+715915,int_stack+77331,int_stack+77016, 0.0, zero_stack, 1.0, int_stack+252355, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280045, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+716860,int_stack+77751,int_stack+77331, 0.0, zero_stack, 1.0, int_stack+252670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280360, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+718120,int_stack+716860,int_stack+715915, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2835, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+78291,int_stack+77751, 0.0, zero_stack, 1.0, int_stack+253090, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280780, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+69069,int_stack+28539,int_stack+716860, 0.0, zero_stack, 1.0, int_stack+368959, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476635, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+69069,int_stack+718120, 0.0, zero_stack, 1.0, int_stack+373819, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+481495, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+69069,int_stack+28539,int_stack+48069,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359173,int_stack+79407,int_stack+78966, 0.0, zero_stack, 1.0, int_stack+110651, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+133946, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+48069,int_stack+79995,int_stack+79407, 0.0, zero_stack, 1.0, int_stack+111533, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+134828, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+75369,int_stack+48069,int_stack+359173, 0.0, zero_stack, 1.0, int_stack+385885, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493561, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+80751,int_stack+79995, 0.0, zero_stack, 1.0, int_stack+112709, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136004, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+78015,int_stack+715915,int_stack+48069, 0.0, zero_stack, 1.0, int_stack+387208, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+494884, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+715915,int_stack+78015,int_stack+75369, 0.0, zero_stack, 1.0, int_stack+399475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507151, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+790885,int_stack+715915,int_stack+28539,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+81906,int_stack+81696, 0.0, zero_stack, 1.0, int_stack+258985, 0.0, zero_stack, 1.0, int_stack+277445, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+82186,int_stack+81906, 0.0, zero_stack, 1.0, int_stack+259195, 0.0, zero_stack, 1.0, int_stack+277655, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 1.0, int_stack+402121, 0.0, zero_stack, 1.0, int_stack+473905, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+82546,int_stack+82186, 0.0, zero_stack, 1.0, int_stack+259475, 0.0, zero_stack, 1.0, int_stack+277935, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+716995,int_stack+715915,int_stack+29169, 0.0, zero_stack, 1.0, int_stack+402751, 0.0, zero_stack, 1.0, int_stack+474535, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+716995,int_stack+30009, 0.0, zero_stack, 1.0, int_stack+403591, 0.0, zero_stack, 1.0, int_stack+475375, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+715915,int_stack+83311,int_stack+82996, 0.0, zero_stack, 1.0, int_stack+261585, 0.0, zero_stack, 1.0, int_stack+280045, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+716860,int_stack+83731,int_stack+83311, 0.0, zero_stack, 1.0, int_stack+261900, 0.0, zero_stack, 1.0, int_stack+280360, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+718120,int_stack+716860,int_stack+715915, 0.0, zero_stack, 1.0, int_stack+945, 0.0, zero_stack, 1.0, int_stack+2835, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+84271,int_stack+83731, 0.0, zero_stack, 1.0, int_stack+262320, 0.0, zero_stack, 1.0, int_stack+280780, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+75369,int_stack+28539,int_stack+716860, 0.0, zero_stack, 1.0, int_stack+404851, 0.0, zero_stack, 1.0, int_stack+476635, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+75369,int_stack+718120, 0.0, zero_stack, 1.0, int_stack+409711, 0.0, zero_stack, 1.0, int_stack+481495, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+75369,int_stack+28539,int_stack+48069,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359173,int_stack+85387,int_stack+84946, 0.0, zero_stack, 1.0, int_stack+118416, 0.0, zero_stack, 1.0, int_stack+133946, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+48069,int_stack+85975,int_stack+85387, 0.0, zero_stack, 1.0, int_stack+119298, 0.0, zero_stack, 1.0, int_stack+134828, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+81669,int_stack+48069,int_stack+359173, 0.0, zero_stack, 1.0, int_stack+421777, 0.0, zero_stack, 1.0, int_stack+493561, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+86731,int_stack+85975, 0.0, zero_stack, 1.0, int_stack+120474, 0.0, zero_stack, 1.0, int_stack+136004, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+767575,int_stack+715915,int_stack+48069, 0.0, zero_stack, 1.0, int_stack+423100, 0.0, zero_stack, 1.0, int_stack+494884, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+715915,int_stack+767575,int_stack+81669, 0.0, zero_stack, 1.0, int_stack+435367, 0.0, zero_stack, 1.0, int_stack+507151, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+800335,int_stack+715915,int_stack+28539,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+87886,int_stack+87676, 0.0, zero_stack, 1.0, int_stack+268215, 1.0, int_stack+277445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+88166,int_stack+87886, 0.0, zero_stack, 1.0, int_stack+268425, 1.0, int_stack+277655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 1.0, int_stack+438013, 1.0, int_stack+473905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+88526,int_stack+88166, 0.0, zero_stack, 1.0, int_stack+268705, 1.0, int_stack+277935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+716995,int_stack+715915,int_stack+29169, 0.0, zero_stack, 1.0, int_stack+438643, 1.0, int_stack+474535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+716995,int_stack+30009, 0.0, zero_stack, 1.0, int_stack+439483, 1.0, int_stack+475375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+715915,int_stack+89291,int_stack+88976, 0.0, zero_stack, 1.0, int_stack+270815, 1.0, int_stack+280045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+716860,int_stack+89711,int_stack+89291, 0.0, zero_stack, 1.0, int_stack+271130, 1.0, int_stack+280360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+718120,int_stack+716860,int_stack+715915, 0.0, zero_stack, 1.0, int_stack+1890, 1.0, int_stack+2835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+90251,int_stack+89711, 0.0, zero_stack, 1.0, int_stack+271550, 1.0, int_stack+280780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+81669,int_stack+28539,int_stack+716860, 0.0, zero_stack, 1.0, int_stack+440743, 1.0, int_stack+476635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+81669,int_stack+718120, 0.0, zero_stack, 1.0, int_stack+445603, 1.0, int_stack+481495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+81669,int_stack+28539,int_stack+48069,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359173,int_stack+91367,int_stack+90926, 0.0, zero_stack, 1.0, int_stack+126181, 1.0, int_stack+133946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+48069,int_stack+91955,int_stack+91367, 0.0, zero_stack, 1.0, int_stack+127063, 1.0, int_stack+134828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+87969,int_stack+48069,int_stack+359173, 0.0, zero_stack, 1.0, int_stack+457669, 1.0, int_stack+493561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+92711,int_stack+91955, 0.0, zero_stack, 1.0, int_stack+128239, 1.0, int_stack+136004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+767575,int_stack+715915,int_stack+48069, 0.0, zero_stack, 1.0, int_stack+458992, 1.0, int_stack+494884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+715915,int_stack+767575,int_stack+87969, 0.0, zero_stack, 1.0, int_stack+471259, 1.0, int_stack+507151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+809785,int_stack+715915,int_stack+28539,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+93866,int_stack+93656, 0.0, zero_stack, 2.0, int_stack+277445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+94146,int_stack+93866, 0.0, zero_stack, 2.0, int_stack+277655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 2.0, int_stack+473905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+94506,int_stack+94146, 0.0, zero_stack, 2.0, int_stack+277935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+716995,int_stack+715915,int_stack+29169, 0.0, zero_stack, 2.0, int_stack+474535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+716995,int_stack+30009, 0.0, zero_stack, 2.0, int_stack+475375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+715915,int_stack+95271,int_stack+94956, 0.0, zero_stack, 2.0, int_stack+280045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+716860,int_stack+95691,int_stack+95271, 0.0, zero_stack, 2.0, int_stack+280360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+718120,int_stack+716860,int_stack+715915, 0.0, zero_stack, 2.0, int_stack+2835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+96231,int_stack+95691, 0.0, zero_stack, 2.0, int_stack+280780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+87969,int_stack+28539,int_stack+716860, 0.0, zero_stack, 2.0, int_stack+476635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+87969,int_stack+718120, 0.0, zero_stack, 2.0, int_stack+481495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+87969,int_stack+28539,int_stack+48069,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359173,int_stack+97347,int_stack+96906, 0.0, zero_stack, 2.0, int_stack+133946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+48069,int_stack+97935,int_stack+97347, 0.0, zero_stack, 2.0, int_stack+134828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+94269,int_stack+48069,int_stack+359173, 0.0, zero_stack, 2.0, int_stack+493561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+98691,int_stack+97935, 0.0, zero_stack, 2.0, int_stack+136004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+767575,int_stack+715915,int_stack+48069, 0.0, zero_stack, 2.0, int_stack+494884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+715915,int_stack+767575,int_stack+94269, 0.0, zero_stack, 2.0, int_stack+507151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+819235,int_stack+715915,int_stack+28539,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+99846,int_stack+99636, 1.0, int_stack+240525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+286675,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+100126,int_stack+99846, 1.0, int_stack+240735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+286885,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 1.0, int_stack+330685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+509797,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+100486,int_stack+100126, 1.0, int_stack+241015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+287165,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+716995,int_stack+715915,int_stack+29169, 1.0, int_stack+331315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+510427,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+716995,int_stack+30009, 1.0, int_stack+332155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511267,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+715915,int_stack+101251,int_stack+100936, 1.0, int_stack+243125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289590,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+716860,int_stack+101671,int_stack+101251, 1.0, int_stack+243440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290325,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+718120,int_stack+716860,int_stack+715915, 1.0, int_stack+340165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+102211,int_stack+101671, 1.0, int_stack+243860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+291285,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+94269,int_stack+28539,int_stack+716860, 1.0, int_stack+341110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512527,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+94269,int_stack+718120, 1.0, int_stack+342370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+517387,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+94269,int_stack+28539,int_stack+48069,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359173,int_stack+104356,int_stack+103327, 1.0, int_stack+102886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142152,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+48069,int_stack+105700,int_stack+104356, 1.0, int_stack+103768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143622,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+100569,int_stack+48069,int_stack+359173, 1.0, int_stack+360496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+529453,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+359173,int_stack+106456,int_stack+105700, 1.0, int_stack+104944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144798,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+103215,int_stack+359173,int_stack+48069, 1.0, int_stack+361819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530776,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+359173,int_stack+103215,int_stack+100569, 1.0, int_stack+363583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+543043,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+828685,int_stack+359173,int_stack+28539,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+107611,int_stack+107401, 1.0, int_stack+249755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+286675, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+107891,int_stack+107611, 1.0, int_stack+249965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+286885, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 1.0, int_stack+366229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+509797, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+359173,int_stack+108251,int_stack+107891, 1.0, int_stack+250245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+287165, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+360253,int_stack+359173,int_stack+29169, 1.0, int_stack+366859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+510427, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+360253,int_stack+30009, 1.0, int_stack+367699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511267, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359173,int_stack+109016,int_stack+108701, 1.0, int_stack+252355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289590, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+360118,int_stack+109436,int_stack+109016, 1.0, int_stack+252670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290325, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+361378,int_stack+360118,int_stack+359173, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+363268,int_stack+109976,int_stack+109436, 1.0, int_stack+253090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+291285, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+364888,int_stack+363268,int_stack+360118, 1.0, int_stack+368959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512527, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+364888,int_stack+361378, 1.0, int_stack+373819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+517387, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+359173,int_stack+28539,int_stack+48069,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+112121,int_stack+111092, 1.0, int_stack+110651, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142152, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+373819,int_stack+113465,int_stack+112121, 1.0, int_stack+111533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143622, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+365473,int_stack+373819,int_stack+48069, 1.0, int_stack+385885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+529453, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+368119,int_stack+114221,int_stack+113465, 1.0, int_stack+112709, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144798, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+100569,int_stack+368119,int_stack+373819, 1.0, int_stack+387208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530776, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+715915,int_stack+100569,int_stack+365473, 1.0, int_stack+399475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+543043, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+100569,int_stack+715915,int_stack+28539,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+115376,int_stack+115166, 1.0, int_stack+258985, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+286675, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+115656,int_stack+115376, 1.0, int_stack+259195, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+286885, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 1.0, int_stack+402121, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+509797, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+116016,int_stack+115656, 1.0, int_stack+259475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+287165, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+716995,int_stack+715915,int_stack+29169, 1.0, int_stack+402751, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+510427, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+716995,int_stack+30009, 1.0, int_stack+403591, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511267, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+116781,int_stack+116466, 1.0, int_stack+261585, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289590, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+715915,int_stack+117201,int_stack+116781, 1.0, int_stack+261900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290325, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+717175,int_stack+715915,int_stack+0, 1.0, int_stack+945, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+117741,int_stack+117201, 1.0, int_stack+262320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+291285, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+28539,int_stack+0,int_stack+715915, 1.0, int_stack+404851, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512527, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+399475,int_stack+28539,int_stack+717175, 1.0, int_stack+409711, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+517387, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+110019,int_stack+399475,int_stack+48069,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+119886,int_stack+118857, 1.0, int_stack+118416, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+142152, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+409711,int_stack+121230,int_stack+119886, 1.0, int_stack+119298, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143622, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+28539,int_stack+409711,int_stack+48069, 1.0, int_stack+421777, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+529453, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+121986,int_stack+121230, 1.0, int_stack+120474, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144798, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+402625,int_stack+715915,int_stack+409711, 1.0, int_stack+423100, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530776, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+715915,int_stack+402625,int_stack+28539, 1.0, int_stack+435367, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+543043, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+838135,int_stack+715915,int_stack+399475,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+399475,int_stack+123141,int_stack+122931, 1.0, int_stack+268215, 0.0, zero_stack, 1.0, int_stack+286675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+400105,int_stack+123421,int_stack+123141, 1.0, int_stack+268425, 0.0, zero_stack, 1.0, int_stack+286885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+400945,int_stack+400105,int_stack+399475, 1.0, int_stack+438013, 0.0, zero_stack, 1.0, int_stack+509797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+402205,int_stack+123781,int_stack+123421, 1.0, int_stack+268705, 0.0, zero_stack, 1.0, int_stack+287165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+403285,int_stack+402205,int_stack+400105, 1.0, int_stack+438643, 0.0, zero_stack, 1.0, int_stack+510427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+403285,int_stack+400945, 1.0, int_stack+439483, 0.0, zero_stack, 1.0, int_stack+511267, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+399475,int_stack+124546,int_stack+124231, 1.0, int_stack+270815, 0.0, zero_stack, 1.0, int_stack+289590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+400420,int_stack+124966,int_stack+124546, 1.0, int_stack+271130, 0.0, zero_stack, 1.0, int_stack+290325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+400420,int_stack+399475, 1.0, int_stack+1890, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+401680,int_stack+125506,int_stack+124966, 1.0, int_stack+271550, 0.0, zero_stack, 1.0, int_stack+291285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+403300,int_stack+401680,int_stack+400420, 1.0, int_stack+440743, 0.0, zero_stack, 1.0, int_stack+512527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+403300,int_stack+0, 1.0, int_stack+445603, 0.0, zero_stack, 1.0, int_stack+517387, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+399475,int_stack+28539,int_stack+48069,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+127651,int_stack+126622, 1.0, int_stack+126181, 0.0, zero_stack, 1.0, int_stack+142152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+445603,int_stack+128995,int_stack+127651, 1.0, int_stack+127063, 0.0, zero_stack, 1.0, int_stack+143622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+445603,int_stack+48069, 1.0, int_stack+457669, 0.0, zero_stack, 1.0, int_stack+529453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+129751,int_stack+128995, 1.0, int_stack+128239, 0.0, zero_stack, 1.0, int_stack+144798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+435367,int_stack+715915,int_stack+445603, 1.0, int_stack+458992, 0.0, zero_stack, 1.0, int_stack+530776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+715915,int_stack+435367,int_stack+0, 1.0, int_stack+471259, 0.0, zero_stack, 1.0, int_stack+543043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+116319,int_stack+715915,int_stack+28539,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+130906,int_stack+130696, 1.0, int_stack+277445, 1.0, int_stack+286675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+131186,int_stack+130906, 1.0, int_stack+277655, 1.0, int_stack+286885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 1.0, int_stack+473905, 1.0, int_stack+509797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+131546,int_stack+131186, 1.0, int_stack+277935, 1.0, int_stack+287165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+716995,int_stack+715915,int_stack+29169, 1.0, int_stack+474535, 1.0, int_stack+510427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+716995,int_stack+30009, 1.0, int_stack+475375, 1.0, int_stack+511267, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+715915,int_stack+132311,int_stack+131996, 1.0, int_stack+280045, 1.0, int_stack+289590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+716860,int_stack+132731,int_stack+132311, 1.0, int_stack+280360, 1.0, int_stack+290325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+718120,int_stack+716860,int_stack+715915, 1.0, int_stack+2835, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+133271,int_stack+132731, 1.0, int_stack+280780, 1.0, int_stack+291285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+471259,int_stack+28539,int_stack+716860, 1.0, int_stack+476635, 1.0, int_stack+512527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+471259,int_stack+718120, 1.0, int_stack+481495, 1.0, int_stack+517387, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+471259,int_stack+28539,int_stack+48069,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+135416,int_stack+134387, 1.0, int_stack+133946, 1.0, int_stack+142152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+481495,int_stack+136760,int_stack+135416, 1.0, int_stack+134828, 1.0, int_stack+143622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+715915,int_stack+481495,int_stack+48069, 1.0, int_stack+493561, 1.0, int_stack+529453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+137516,int_stack+136760, 1.0, int_stack+136004, 1.0, int_stack+144798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+435367,int_stack+0,int_stack+481495, 1.0, int_stack+494884, 1.0, int_stack+530776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+435367,int_stack+715915, 1.0, int_stack+507151, 1.0, int_stack+543043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+125769,int_stack+767575,int_stack+28539,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+138671,int_stack+138461, 2.0, int_stack+286675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+138951,int_stack+138671, 2.0, int_stack+286885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 2.0, int_stack+509797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+139311,int_stack+138951, 2.0, int_stack+287165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+768655,int_stack+767575,int_stack+29169, 2.0, int_stack+510427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+768655,int_stack+30009, 2.0, int_stack+511267, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+767575,int_stack+140076,int_stack+139761, 2.0, int_stack+289590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+768520,int_stack+140496,int_stack+140076, 2.0, int_stack+290325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+769780,int_stack+768520,int_stack+767575, 2.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+141036,int_stack+140496, 2.0, int_stack+291285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+507151,int_stack+28539,int_stack+768520, 2.0, int_stack+512527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+507151,int_stack+769780, 2.0, int_stack+517387, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+507151,int_stack+28539,int_stack+48069,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+144210,int_stack+142593, 2.0, int_stack+142152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+517387,int_stack+145554,int_stack+144210, 2.0, int_stack+143622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+767575,int_stack+517387,int_stack+48069, 2.0, int_stack+529453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+146310,int_stack+145554, 2.0, int_stack+144798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+435367,int_stack+715915,int_stack+517387, 2.0, int_stack+530776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+715915,int_stack+435367,int_stack+767575, 2.0, int_stack+543043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+135219,int_stack+715915,int_stack+28539,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+147465,int_stack+147255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298965,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+147745,int_stack+147465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+299175,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338275,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+148105,int_stack+147745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+299455,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+716995,int_stack+715915,int_stack+29169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338905,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+716995,int_stack+30009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+545689,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+715915,int_stack+148870,int_stack+148555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+301565,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+716860,int_stack+149290,int_stack+148870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+301880,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+718120,int_stack+716860,int_stack+715915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546949,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+149830,int_stack+149290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+302300,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+543043,int_stack+28539,int_stack+716860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+547894,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+543043,int_stack+718120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344260,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+435367,int_stack+28539,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+336175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+150946,int_stack+150505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+180405,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+543043,int_stack+151534,int_stack+150946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181287,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+715915,int_stack+543043,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333415,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+152290,int_stack+151534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182463,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+529453,int_stack+767575,int_stack+543043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346150,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+529453,int_stack+715915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+327955,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+847585,int_stack+767575,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+348400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+153445,int_stack+153235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298965, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+153725,int_stack+153445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+299175, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338275, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+154085,int_stack+153725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+299455, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+768655,int_stack+767575,int_stack+29169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338905, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+768655,int_stack+30009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+545689, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+767575,int_stack+154850,int_stack+154535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+301565, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+768520,int_stack+155270,int_stack+154850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+301880, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+769780,int_stack+768520,int_stack+767575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546949, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+155810,int_stack+155270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+302300, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+715915,int_stack+28539,int_stack+768520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+547894, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+715915,int_stack+769780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344260, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+144669,int_stack+28539,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+156926,int_stack+156485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+180405, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+715915,int_stack+157514,int_stack+156926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181287, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+717679,int_stack+715915,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333415, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+158270,int_stack+157514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182463, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+529453,int_stack+767575,int_stack+715915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346150, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+529453,int_stack+717679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+327955, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+857035,int_stack+767575,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+159425,int_stack+159215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298965, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+159705,int_stack+159425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+299175, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338275, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+160065,int_stack+159705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+299455, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+768655,int_stack+767575,int_stack+29169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338905, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+768655,int_stack+30009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+545689, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+767575,int_stack+160830,int_stack+160515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+301565, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+768520,int_stack+161250,int_stack+160830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+301880, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+769780,int_stack+768520,int_stack+767575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546949, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+161790,int_stack+161250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+302300, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+529453,int_stack+28539,int_stack+768520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+547894, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+529453,int_stack+769780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344260, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+150969,int_stack+28539,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+407611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+162906,int_stack+162465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+180405, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+529453,int_stack+163494,int_stack+162906, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181287, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+543043,int_stack+529453,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333415, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+531217,int_stack+164250,int_stack+163494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182463, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+767575,int_stack+531217,int_stack+529453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346150, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+715915,int_stack+767575,int_stack+543043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+327955, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+866485,int_stack+715915,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+425917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+165405,int_stack+165195, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+165685,int_stack+165405, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+299175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+166045,int_stack+165685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+299455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+716995,int_stack+715915,int_stack+29169, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+716995,int_stack+30009, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+545689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+715915,int_stack+166810,int_stack+166495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+301565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+716860,int_stack+167230,int_stack+166810, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+301880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+718120,int_stack+716860,int_stack+715915, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+167770,int_stack+167230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+302300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+543043,int_stack+28539,int_stack+716860, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+547894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+543043,int_stack+718120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+157269,int_stack+28539,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443503, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+168886,int_stack+168445, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+180405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+543043,int_stack+169474,int_stack+168886, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+715915,int_stack+543043,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+170230,int_stack+169474, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+529453,int_stack+767575,int_stack+543043, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+529453,int_stack+715915, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+327955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+875935,int_stack+767575,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+461809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+171385,int_stack+171175, 0.0, zero_stack, 1.0, int_stack+298965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+171665,int_stack+171385, 0.0, zero_stack, 1.0, int_stack+299175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 1.0, int_stack+338275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+172025,int_stack+171665, 0.0, zero_stack, 1.0, int_stack+299455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+768655,int_stack+767575,int_stack+29169, 0.0, zero_stack, 1.0, int_stack+338905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+768655,int_stack+30009, 0.0, zero_stack, 1.0, int_stack+545689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+767575,int_stack+172790,int_stack+172475, 0.0, zero_stack, 1.0, int_stack+301565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+768520,int_stack+173210,int_stack+172790, 0.0, zero_stack, 1.0, int_stack+301880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+769780,int_stack+768520,int_stack+767575, 0.0, zero_stack, 1.0, int_stack+546949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+173750,int_stack+173210, 0.0, zero_stack, 1.0, int_stack+302300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+715915,int_stack+28539,int_stack+768520, 0.0, zero_stack, 1.0, int_stack+547894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+715915,int_stack+769780, 0.0, zero_stack, 1.0, int_stack+344260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+163569,int_stack+28539,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+479395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+174866,int_stack+174425, 0.0, zero_stack, 1.0, int_stack+180405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+715915,int_stack+175454,int_stack+174866, 0.0, zero_stack, 1.0, int_stack+181287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+717679,int_stack+715915,int_stack+48069, 0.0, zero_stack, 1.0, int_stack+333415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+176210,int_stack+175454, 0.0, zero_stack, 1.0, int_stack+182463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+529453,int_stack+767575,int_stack+715915, 0.0, zero_stack, 1.0, int_stack+346150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+529453,int_stack+717679, 0.0, zero_stack, 1.0, int_stack+327955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+885385,int_stack+767575,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+497701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+177365,int_stack+177155, 1.0, int_stack+298965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+177645,int_stack+177365, 1.0, int_stack+299175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 1.0, int_stack+338275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+178005,int_stack+177645, 1.0, int_stack+299455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+768655,int_stack+767575,int_stack+29169, 1.0, int_stack+338905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+768655,int_stack+30009, 1.0, int_stack+545689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+767575,int_stack+178770,int_stack+178455, 1.0, int_stack+301565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+768520,int_stack+179190,int_stack+178770, 1.0, int_stack+301880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+769780,int_stack+768520,int_stack+767575, 1.0, int_stack+546949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+338275,int_stack+179730,int_stack+179190, 1.0, int_stack+302300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+339895,int_stack+338275,int_stack+768520, 1.0, int_stack+547894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+339895,int_stack+769780, 1.0, int_stack+344260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+338275,int_stack+28539,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+515287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+181875,int_stack+180846, 1.0, int_stack+180405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+767575,int_stack+183219,int_stack+181875, 1.0, int_stack+181287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+769339,int_stack+767575,int_stack+48069, 1.0, int_stack+333415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+529453,int_stack+183975,int_stack+183219, 1.0, int_stack+182463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+715915,int_stack+529453,int_stack+767575, 1.0, int_stack+346150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+543043,int_stack+715915,int_stack+769339, 1.0, int_stack+327955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+169869,int_stack+543043,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533593, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+185130,int_stack+184920,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+185410,int_stack+185130,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+543043,int_stack+185770,int_stack+185410,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+544123,int_stack+543043,int_stack+29169,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+544123,int_stack+30009,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+543043,int_stack+186535,int_stack+186220,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+543988,int_stack+186955,int_stack+186535,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+545248,int_stack+543988,int_stack+543043,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+547138,int_stack+187495,int_stack+186955,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+548758,int_stack+547138,int_stack+543988,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+548758,int_stack+545248,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+543043,int_stack+28539,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+552979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+188611,int_stack+188170,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+549343,int_stack+189199,int_stack+188611,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+327955,int_stack+549343,int_stack+48069,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+330601,int_stack+189955,int_stack+189199,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+715915,int_stack+330601,int_stack+549343,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+715915,int_stack+327955,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+179319,int_stack+767575,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+571645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+191110,int_stack+190900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308195,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+191390,int_stack+191110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308405,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581095,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+191750,int_stack+191390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308685,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+768655,int_stack+767575,int_stack+29169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581725,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+768655,int_stack+30009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+582565,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+767575,int_stack+192515,int_stack+192200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+310795,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+768520,int_stack+192935,int_stack+192515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311110,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+769780,int_stack+768520,int_stack+767575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+583825,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+193475,int_stack+192935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311530,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+327955,int_stack+28539,int_stack+768520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+584770,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+327955,int_stack+769780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588685,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+327955,int_stack+28539,int_stack+48069, 0.0, zero_stack, 1.0, int_stack+336175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+194591,int_stack+194150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224050,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+334255,int_stack+195179,int_stack+194591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224932,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+767575,int_stack+334255,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+600751,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+195935,int_stack+195179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226108,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+549343,int_stack+715915,int_stack+334255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4725,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+715915,int_stack+549343,int_stack+767575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+612721,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+894835,int_stack+715915,int_stack+28539, 0.0, zero_stack, 1.0, int_stack+348400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+197090,int_stack+196880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308195, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+197370,int_stack+197090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308405, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581095, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+197730,int_stack+197370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308685, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+716995,int_stack+715915,int_stack+29169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581725, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+716995,int_stack+30009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+582565, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+715915,int_stack+198495,int_stack+198180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+310795, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+716860,int_stack+198915,int_stack+198495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311110, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+718120,int_stack+716860,int_stack+715915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+583825, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+199455,int_stack+198915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311530, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+767575,int_stack+28539,int_stack+716860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+584770, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+767575,int_stack+718120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588685, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+188769,int_stack+28539,int_stack+48069, 0.0, zero_stack, 1.0, int_stack+371719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+200571,int_stack+200130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224050, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+767575,int_stack+201159,int_stack+200571, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224932, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+769339,int_stack+767575,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+600751, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+201915,int_stack+201159, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226108, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+549343,int_stack+715915,int_stack+767575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4725, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+715915,int_stack+549343,int_stack+769339, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+612721, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+904285,int_stack+715915,int_stack+28539, 0.0, zero_stack, 1.0, int_stack+390025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+203070,int_stack+202860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308195, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+203350,int_stack+203070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308405, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581095, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+203710,int_stack+203350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308685, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+716995,int_stack+715915,int_stack+29169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581725, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+716995,int_stack+30009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+582565, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+715915,int_stack+204475,int_stack+204160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+310795, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+716860,int_stack+204895,int_stack+204475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311110, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+718120,int_stack+716860,int_stack+715915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+583825, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+205435,int_stack+204895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311530, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+549343,int_stack+28539,int_stack+716860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+584770, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+549343,int_stack+718120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588685, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+195069,int_stack+28539,int_stack+48069, 0.0, zero_stack, 1.0, int_stack+407611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+206551,int_stack+206110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224050, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+549343,int_stack+207139,int_stack+206551, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224932, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+715915,int_stack+549343,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+600751, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+207895,int_stack+207139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226108, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+529453,int_stack+767575,int_stack+549343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4725, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+529453,int_stack+715915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+612721, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+913735,int_stack+767575,int_stack+28539, 0.0, zero_stack, 1.0, int_stack+425917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+209050,int_stack+208840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+209330,int_stack+209050, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+209690,int_stack+209330, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+768655,int_stack+767575,int_stack+29169, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+768655,int_stack+30009, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+582565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+767575,int_stack+210455,int_stack+210140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+310795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+768520,int_stack+210875,int_stack+210455, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+769780,int_stack+768520,int_stack+767575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+583825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+211415,int_stack+210875, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+715915,int_stack+28539,int_stack+768520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+584770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+715915,int_stack+769780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+201369,int_stack+28539,int_stack+48069, 0.0, zero_stack, 1.0, int_stack+443503, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+212531,int_stack+212090, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+715915,int_stack+213119,int_stack+212531, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+717679,int_stack+715915,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+600751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+213875,int_stack+213119, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+529453,int_stack+767575,int_stack+715915, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+529453,int_stack+717679, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+612721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+923185,int_stack+767575,int_stack+28539, 0.0, zero_stack, 1.0, int_stack+461809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+215030,int_stack+214820, 0.0, zero_stack, 1.0, int_stack+308195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+215310,int_stack+215030, 0.0, zero_stack, 1.0, int_stack+308405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 1.0, int_stack+581095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+215670,int_stack+215310, 0.0, zero_stack, 1.0, int_stack+308685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+768655,int_stack+767575,int_stack+29169, 0.0, zero_stack, 1.0, int_stack+581725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+768655,int_stack+30009, 0.0, zero_stack, 1.0, int_stack+582565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+767575,int_stack+216435,int_stack+216120, 0.0, zero_stack, 1.0, int_stack+310795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+768520,int_stack+216855,int_stack+216435, 0.0, zero_stack, 1.0, int_stack+311110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+769780,int_stack+768520,int_stack+767575, 0.0, zero_stack, 1.0, int_stack+583825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+217395,int_stack+216855, 0.0, zero_stack, 1.0, int_stack+311530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+529453,int_stack+28539,int_stack+768520, 0.0, zero_stack, 1.0, int_stack+584770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+529453,int_stack+769780, 0.0, zero_stack, 1.0, int_stack+588685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+207669,int_stack+28539,int_stack+48069, 0.0, zero_stack, 1.0, int_stack+479395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+218511,int_stack+218070, 0.0, zero_stack, 1.0, int_stack+224050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+529453,int_stack+219099,int_stack+218511, 0.0, zero_stack, 1.0, int_stack+224932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+767575,int_stack+529453,int_stack+48069, 0.0, zero_stack, 1.0, int_stack+600751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+531217,int_stack+219855,int_stack+219099, 0.0, zero_stack, 1.0, int_stack+226108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+715915,int_stack+531217,int_stack+529453, 0.0, zero_stack, 1.0, int_stack+4725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+715915,int_stack+767575, 0.0, zero_stack, 1.0, int_stack+612721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+932635,int_stack+0,int_stack+28539, 0.0, zero_stack, 1.0, int_stack+497701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+221010,int_stack+220800, 1.0, int_stack+308195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+221290,int_stack+221010, 1.0, int_stack+308405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 1.0, int_stack+581095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+221650,int_stack+221290, 1.0, int_stack+308685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1080,int_stack+0,int_stack+29169, 1.0, int_stack+581725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+1080,int_stack+30009, 1.0, int_stack+582565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+222415,int_stack+222100, 1.0, int_stack+310795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+945,int_stack+222835,int_stack+222415, 1.0, int_stack+311110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2205,int_stack+945,int_stack+0, 1.0, int_stack+583825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+581095,int_stack+223375,int_stack+222835, 1.0, int_stack+311530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+28539,int_stack+581095,int_stack+945, 1.0, int_stack+584770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+581095,int_stack+28539,int_stack+2205, 1.0, int_stack+588685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+213969,int_stack+581095,int_stack+48069, 0.0, zero_stack, 1.0, int_stack+515287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+225520,int_stack+224491, 1.0, int_stack+224050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+588685,int_stack+226864,int_stack+225520, 1.0, int_stack+224932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+28539,int_stack+588685,int_stack+48069, 1.0, int_stack+600751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+600751,int_stack+227620,int_stack+226864, 1.0, int_stack+226108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+600751,int_stack+588685, 1.0, int_stack+4725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+0,int_stack+28539, 1.0, int_stack+612721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+942085,int_stack+767575,int_stack+581095, 0.0, zero_stack, 1.0, int_stack+533593, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+581095,int_stack+228775,int_stack+228565,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+581725,int_stack+229055,int_stack+228775,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+582565,int_stack+581725,int_stack+581095,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+583825,int_stack+229415,int_stack+229055,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+584905,int_stack+583825,int_stack+581725,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+584905,int_stack+582565,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+581095,int_stack+230180,int_stack+229865,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+582040,int_stack+230600,int_stack+230180,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+583300,int_stack+582040,int_stack+581095,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+231140,int_stack+230600,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+600751,int_stack+767575,int_stack+582040,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+600751,int_stack+583300,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+0,int_stack+28539,int_stack+48069, 0.0, zero_stack, 1.0, int_stack+552979, 1.0, int_stack+586585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+232256,int_stack+231815,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+600751,int_stack+232844,int_stack+232256,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+612721,int_stack+600751,int_stack+48069,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+233600,int_stack+232844,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+581095,int_stack+767575,int_stack+600751,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+581095,int_stack+612721,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+220269,int_stack+767575,int_stack+28539, 0.0, zero_stack, 1.0, int_stack+571645, 1.0, int_stack+603271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+234755,int_stack+234545,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+235035,int_stack+234755,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+235395,int_stack+235035,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+768655,int_stack+767575,int_stack+29169,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+768655,int_stack+30009,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+767575,int_stack+236160,int_stack+235845,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+768520,int_stack+236580,int_stack+236160,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+769780,int_stack+768520,int_stack+767575,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+237120,int_stack+236580,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+600751,int_stack+28539,int_stack+768520,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+600751,int_stack+769780,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+229719,int_stack+28539,int_stack+48069, 0.0, zero_stack, 2.0, int_stack+586585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+238236,int_stack+237795,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+600751,int_stack+238824,int_stack+238236,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+612721,int_stack+600751,int_stack+48069,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+239580,int_stack+238824,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+581095,int_stack+767575,int_stack+600751,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+581095,int_stack+612721,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+951535,int_stack+767575,int_stack+28539, 0.0, zero_stack, 2.0, int_stack+603271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+242035,int_stack+241825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+318725,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+242315,int_stack+242035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+318935,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615367,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+242675,int_stack+242315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319215,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+768655,int_stack+767575,int_stack+29169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615997,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+768655,int_stack+30009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+616837,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+767575,int_stack+245390,int_stack+245075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321325,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+768520,int_stack+245810,int_stack+245390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321640,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+769780,int_stack+768520,int_stack+767575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+618097,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+246350,int_stack+245810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322060,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+600751,int_stack+28539,int_stack+768520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+619042,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+600751,int_stack+769780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622957,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+236019,int_stack+28539,int_stack+48069, 1.0, int_stack+336175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+247466,int_stack+247025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+294450,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+600751,int_stack+248054,int_stack+247466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+295332,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+612721,int_stack+600751,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357850,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+248810,int_stack+248054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+296508,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+581095,int_stack+767575,int_stack+600751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635023,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+581095,int_stack+612721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646993,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+960985,int_stack+767575,int_stack+28539, 1.0, int_stack+348400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+251265,int_stack+251055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+318725, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+251545,int_stack+251265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+318935, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615367, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+251905,int_stack+251545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319215, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+768655,int_stack+767575,int_stack+29169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615997, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+768655,int_stack+30009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+616837, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+767575,int_stack+254620,int_stack+254305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321325, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+768520,int_stack+255040,int_stack+254620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321640, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+769780,int_stack+768520,int_stack+767575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+618097, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+255580,int_stack+255040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322060, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+600751,int_stack+28539,int_stack+768520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+619042, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+600751,int_stack+769780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622957, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+344575,int_stack+28539,int_stack+48069, 1.0, int_stack+371719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+256696,int_stack+256255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+294450, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+600751,int_stack+257284,int_stack+256696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+295332, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+612721,int_stack+600751,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357850, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+258040,int_stack+257284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+296508, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+581095,int_stack+767575,int_stack+600751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635023, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+581095,int_stack+612721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646993, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+365473,int_stack+767575,int_stack+28539, 1.0, int_stack+390025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+260495,int_stack+260285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+318725, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+260775,int_stack+260495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+318935, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615367, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+261135,int_stack+260775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319215, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+768655,int_stack+767575,int_stack+29169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615997, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+768655,int_stack+30009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+616837, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+767575,int_stack+263850,int_stack+263535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321325, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+768520,int_stack+264270,int_stack+263850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321640, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+769780,int_stack+768520,int_stack+767575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+618097, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+264810,int_stack+264270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322060, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+600751,int_stack+28539,int_stack+768520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+619042, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+600751,int_stack+769780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622957, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+242319,int_stack+28539,int_stack+48069, 1.0, int_stack+407611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+265926,int_stack+265485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+294450, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+600751,int_stack+266514,int_stack+265926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+295332, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+612721,int_stack+600751,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357850, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+267270,int_stack+266514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+296508, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+581095,int_stack+767575,int_stack+600751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635023, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+581095,int_stack+612721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646993, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+248619,int_stack+767575,int_stack+28539, 1.0, int_stack+425917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+269725,int_stack+269515, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+318725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+270005,int_stack+269725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+318935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+270365,int_stack+270005, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+768655,int_stack+767575,int_stack+29169, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615997, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+768655,int_stack+30009, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+616837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+767575,int_stack+273080,int_stack+272765, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+768520,int_stack+273500,int_stack+273080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+769780,int_stack+768520,int_stack+767575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+618097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+274040,int_stack+273500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+600751,int_stack+28539,int_stack+768520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+619042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+600751,int_stack+769780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+405775,int_stack+28539,int_stack+48069, 1.0, int_stack+443503, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+275156,int_stack+274715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+294450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+600751,int_stack+275744,int_stack+275156, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+295332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+612721,int_stack+600751,int_stack+48069, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+276500,int_stack+275744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+296508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+581095,int_stack+767575,int_stack+600751, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635023, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+581095,int_stack+612721, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646993, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+258069,int_stack+767575,int_stack+28539, 1.0, int_stack+461809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+278955,int_stack+278745, 0.0, zero_stack, 1.0, int_stack+318725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+279235,int_stack+278955, 0.0, zero_stack, 1.0, int_stack+318935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 0.0, zero_stack, 1.0, int_stack+615367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+279595,int_stack+279235, 0.0, zero_stack, 1.0, int_stack+319215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+768655,int_stack+767575,int_stack+29169, 0.0, zero_stack, 1.0, int_stack+615997, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+768655,int_stack+30009, 0.0, zero_stack, 1.0, int_stack+616837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+767575,int_stack+282310,int_stack+281995, 0.0, zero_stack, 1.0, int_stack+321325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+768520,int_stack+282730,int_stack+282310, 0.0, zero_stack, 1.0, int_stack+321640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+769780,int_stack+768520,int_stack+767575, 0.0, zero_stack, 1.0, int_stack+618097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+283270,int_stack+282730, 0.0, zero_stack, 1.0, int_stack+322060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+600751,int_stack+28539,int_stack+768520, 0.0, zero_stack, 1.0, int_stack+619042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+600751,int_stack+769780, 0.0, zero_stack, 1.0, int_stack+622957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+441667,int_stack+28539,int_stack+48069, 1.0, int_stack+479395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+284386,int_stack+283945, 0.0, zero_stack, 1.0, int_stack+294450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+600751,int_stack+284974,int_stack+284386, 0.0, zero_stack, 1.0, int_stack+295332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+612721,int_stack+600751,int_stack+48069, 0.0, zero_stack, 1.0, int_stack+357850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+285730,int_stack+284974, 0.0, zero_stack, 1.0, int_stack+296508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+581095,int_stack+767575,int_stack+600751, 0.0, zero_stack, 1.0, int_stack+635023, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+581095,int_stack+612721, 0.0, zero_stack, 1.0, int_stack+646993, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+267519,int_stack+767575,int_stack+28539, 1.0, int_stack+497701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+288185,int_stack+287975, 1.0, int_stack+318725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+288465,int_stack+288185, 1.0, int_stack+318935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539, 1.0, int_stack+615367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+288825,int_stack+288465, 1.0, int_stack+319215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+768655,int_stack+767575,int_stack+29169, 1.0, int_stack+615997, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+768655,int_stack+30009, 1.0, int_stack+616837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+767575,int_stack+292815,int_stack+292500, 1.0, int_stack+321325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+768520,int_stack+293235,int_stack+292815, 1.0, int_stack+321640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+769780,int_stack+768520,int_stack+767575, 1.0, int_stack+618097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+293775,int_stack+293235, 1.0, int_stack+322060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+600751,int_stack+28539,int_stack+768520, 1.0, int_stack+619042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+600751,int_stack+769780, 1.0, int_stack+622957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+612721,int_stack+28539,int_stack+48069, 1.0, int_stack+515287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48069,int_stack+295920,int_stack+294891, 1.0, int_stack+294450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+622957,int_stack+297264,int_stack+295920, 1.0, int_stack+295332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+767575,int_stack+622957,int_stack+48069, 1.0, int_stack+357850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+600751,int_stack+298020,int_stack+297264, 1.0, int_stack+296508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+581095,int_stack+600751,int_stack+622957, 1.0, int_stack+635023, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+715915,int_stack+581095,int_stack+767575, 1.0, int_stack+646993, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+276969,int_stack+715915,int_stack+28539, 1.0, int_stack+533593, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+300475,int_stack+300265,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+300755,int_stack+300475,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+301115,int_stack+300755,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+716995,int_stack+715915,int_stack+29169,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+716995,int_stack+30009,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+715915,int_stack+303830,int_stack+303515,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+716860,int_stack+304250,int_stack+303830,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+718120,int_stack+716860,int_stack+715915,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+304790,int_stack+304250,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+635023,int_stack+28539,int_stack+716860,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+635023,int_stack+718120,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+529453,int_stack+28539,int_stack+48069, 1.0, int_stack+552979, 0.0, zero_stack, 1.0, int_stack+620857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+357850,int_stack+305906,int_stack+305465,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+48069,int_stack+306494,int_stack+305906,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+646993,int_stack+48069,int_stack+357850,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+635023,int_stack+307250,int_stack+306494,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+715915,int_stack+635023,int_stack+48069,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+715915,int_stack+646993,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+286419,int_stack+767575,int_stack+28539, 1.0, int_stack+571645, 0.0, zero_stack, 1.0, int_stack+637543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+571645,int_stack+309705,int_stack+309495,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+572275,int_stack+309985,int_stack+309705,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+573115,int_stack+572275,int_stack+571645,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+310345,int_stack+309985,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+29619,int_stack+28539,int_stack+572275,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+29619,int_stack+573115,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+313060,int_stack+312745,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+29484,int_stack+313480,int_stack+313060,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+571645,int_stack+29484,int_stack+28539,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+767575,int_stack+314020,int_stack+313480,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+635023,int_stack+767575,int_stack+29484,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+635023,int_stack+571645,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+549343,int_stack+28539,int_stack+48069, 1.0, int_stack+586585, 1.0, int_stack+620857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+357850,int_stack+315136,int_stack+314695,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+48069,int_stack+315724,int_stack+315136,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+646993,int_stack+48069,int_stack+357850,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+571645,int_stack+316480,int_stack+315724,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+767575,int_stack+571645,int_stack+48069,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+715915,int_stack+767575,int_stack+646993,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+581095,int_stack+715915,int_stack+28539, 1.0, int_stack+603271, 1.0, int_stack+637543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+28539,int_stack+320235,int_stack+320025,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+29169,int_stack+320515,int_stack+320235,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+30009,int_stack+29169,int_stack+28539,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+715915,int_stack+320875,int_stack+320515,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+716995,int_stack+715915,int_stack+29169,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+48069,int_stack+716995,int_stack+30009,10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+715915,int_stack+323590,int_stack+323275,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+716860,int_stack+324010,int_stack+323590,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+718120,int_stack+716860,int_stack+715915,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+28539,int_stack+324550,int_stack+324010,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+635023,int_stack+28539,int_stack+716860,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+28539,int_stack+635023,int_stack+718120,15);
 /*--- compute (fp|hf) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+513451,int_stack+28539,int_stack+48069, 2.0, int_stack+620857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+357850,int_stack+325666,int_stack+325225,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+48069,int_stack+326254,int_stack+325666,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+646993,int_stack+48069,int_stack+357850,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+635023,int_stack+327010,int_stack+326254,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+715915,int_stack+635023,int_stack+48069,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+767575,int_stack+715915,int_stack+646993,21);
 /*--- compute (gp|hf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+295869,int_stack+767575,int_stack+28539, 2.0, int_stack+637543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+305319,int_stack+376435,int_stack+351550,210);
     Libderiv->ABCD[11] = int_stack + 305319;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+374923,int_stack+412327,int_stack+393175,210);
     Libderiv->ABCD[10] = int_stack + 374923;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+412075,int_stack+448219,int_stack+429067,210);
     Libderiv->ABCD[9] = int_stack + 412075;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+447967,int_stack+484111,int_stack+464959,210);
     Libderiv->ABCD[8] = int_stack + 447967;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+477559,int_stack+520003,int_stack+500851,210);
     Libderiv->ABCD[7] = int_stack + 477559;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+970435,int_stack+555895,int_stack+536743,210);
     Libderiv->ABCD[6] = int_stack + 970435;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+983035,int_stack+591301,int_stack+574795, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+565345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[2] = int_stack + 983035;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+590545,int_stack+625573,int_stack+606421, 0.0, zero_stack, 1.0, int_stack+565345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[1] = int_stack + 590545;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+619021,int_stack+657577,int_stack+640693, 1.0, int_stack+565345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[0] = int_stack + 619021;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+555643,int_stack+674965,int_stack+6489,210);
     Libderiv->ABCD[155] = int_stack + 555643;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+995635,int_stack+684415,int_stack+12789,210);
     Libderiv->ABCD[143] = int_stack + 995635;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+6300,int_stack+700165,int_stack+693865,210);
     Libderiv->ABCD[142] = int_stack + 6300;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+673327,int_stack+19089,int_stack+667027,210);
     Libderiv->ABCD[131] = int_stack + 673327;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+18900,int_stack+720325,int_stack+709615,210);
     Libderiv->ABCD[130] = int_stack + 18900;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+655939,int_stack+729775,int_stack+31689,210);
     Libderiv->ABCD[129] = int_stack + 655939;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+685927,int_stack+739225,int_stack+649639,210);
     Libderiv->ABCD[119] = int_stack + 685927;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+698527,int_stack+748675,int_stack+41769,210);
     Libderiv->ABCD[118] = int_stack + 698527;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+31500,int_stack+758125,int_stack+50169,210);
     Libderiv->ABCD[117] = int_stack + 31500;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+711127,int_stack+771985,int_stack+56469,210);
     Libderiv->ABCD[116] = int_stack + 711127;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+44100,int_stack+781435,int_stack+62769,210);
     Libderiv->ABCD[107] = int_stack + 44100;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+723727,int_stack+790885,int_stack+69069,210);
     Libderiv->ABCD[106] = int_stack + 723727;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+56700,int_stack+800335,int_stack+75369,210);
     Libderiv->ABCD[105] = int_stack + 56700;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+736327,int_stack+809785,int_stack+81669,210);
     Libderiv->ABCD[104] = int_stack + 736327;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+69300,int_stack+819235,int_stack+87969,210);
     Libderiv->ABCD[103] = int_stack + 69300;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+748927,int_stack+828685,int_stack+94269,210);
     Libderiv->ABCD[95] = int_stack + 748927;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+81900,int_stack+100569,int_stack+359173,210);
     Libderiv->ABCD[94] = int_stack + 81900;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+94500,int_stack+838135,int_stack+110019,210);
     Libderiv->ABCD[93] = int_stack + 94500;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+761527,int_stack+116319,int_stack+399475,210);
     Libderiv->ABCD[92] = int_stack + 761527;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+107100,int_stack+125769,int_stack+471259,210);
     Libderiv->ABCD[91] = int_stack + 107100;
 /*--- compute (fd|hf) ---*/
   hrr1_build_fd(Libderiv->AB,int_stack+119700,int_stack+135219,int_stack+507151,210);
     Libderiv->ABCD[90] = int_stack + 119700;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+774127,int_stack+847585,int_stack+435367, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+351550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[47] = int_stack + 774127;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+786727,int_stack+857035,int_stack+144669, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[46] = int_stack + 786727;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+132300,int_stack+866485,int_stack+150969, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[45] = int_stack + 132300;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+799327,int_stack+875935,int_stack+157269, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[44] = int_stack + 799327;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+144900,int_stack+885385,int_stack+163569, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+500851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[43] = int_stack + 144900;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+811927,int_stack+169869,int_stack+338275, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+536743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[42] = int_stack + 811927;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+157500,int_stack+179319,int_stack+543043, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+574795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[38] = int_stack + 157500;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+170100,int_stack+894835,int_stack+327955, 0.0, zero_stack, 1.0, int_stack+351550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[35] = int_stack + 170100;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+317919,int_stack+904285,int_stack+188769, 0.0, zero_stack, 1.0, int_stack+393175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[34] = int_stack + 317919;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+330519,int_stack+913735,int_stack+195069, 0.0, zero_stack, 1.0, int_stack+429067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[33] = int_stack + 330519;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+182700,int_stack+923185,int_stack+201369, 0.0, zero_stack, 1.0, int_stack+464959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[32] = int_stack + 182700;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+824527,int_stack+932635,int_stack+207669, 0.0, zero_stack, 1.0, int_stack+500851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[31] = int_stack + 824527;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+195300,int_stack+942085,int_stack+213969, 0.0, zero_stack, 1.0, int_stack+536743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[30] = int_stack + 195300;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+837127,int_stack+220269,int_stack+0, 0.0, zero_stack, 1.0, int_stack+574795, 1.0, int_stack+606421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[26] = int_stack + 837127;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+207900,int_stack+951535,int_stack+229719, 0.0, zero_stack, 2.0, int_stack+606421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[25] = int_stack + 207900;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+220500,int_stack+960985,int_stack+236019, 1.0, int_stack+351550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[23] = int_stack + 220500;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+350875,int_stack+365473,int_stack+344575, 1.0, int_stack+393175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[22] = int_stack + 350875;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+387523,int_stack+248619,int_stack+242319, 1.0, int_stack+429067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[21] = int_stack + 387523;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+233100,int_stack+258069,int_stack+405775, 1.0, int_stack+464959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[20] = int_stack + 233100;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+245700,int_stack+267519,int_stack+441667, 1.0, int_stack+500851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[19] = int_stack + 245700;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+258300,int_stack+276969,int_stack+612721, 1.0, int_stack+536743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[18] = int_stack + 258300;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+270900,int_stack+286419,int_stack+529453, 1.0, int_stack+574795, 0.0, zero_stack, 1.0, int_stack+640693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[14] = int_stack + 270900;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+568243,int_stack+581095,int_stack+549343, 1.0, int_stack+606421, 1.0, int_stack+640693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[13] = int_stack + 568243;
 /*--- compute (fd|hf) ---*/
   d1hrr1_build_fd(Libderiv->AB,int_stack+603145,int_stack+295869,int_stack+513451, 2.0, int_stack+640693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[12] = int_stack + 603145;

}
