/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_gfgf(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gf|gf) integrals */

void d12hrr_order_gfgf(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[7][7][11] = int_stack + 0;
 Libderiv->deriv_classes[7][7][10] = int_stack + 1296;
 Libderiv->deriv_classes[7][7][9] = int_stack + 2592;
 Libderiv->deriv_classes[7][7][8] = int_stack + 3888;
 Libderiv->deriv_classes[7][7][7] = int_stack + 5184;
 Libderiv->dvrr_classes[7][6] = int_stack + 6480;
 Libderiv->deriv_classes[7][7][6] = int_stack + 7488;
 Libderiv->deriv_classes[7][7][2] = int_stack + 8784;
 Libderiv->deriv_classes[7][7][1] = int_stack + 10080;
 Libderiv->dvrr_classes[6][7] = int_stack + 11376;
 Libderiv->deriv_classes[7][7][0] = int_stack + 12384;
 Libderiv->deriv2_classes[4][4][143] = int_stack + 13680;
 Libderiv->deriv2_classes[4][5][143] = int_stack + 13905;
 Libderiv->deriv2_classes[4][6][143] = int_stack + 14220;
 Libderiv->deriv2_classes[4][7][143] = int_stack + 14640;
 Libderiv->deriv2_classes[5][4][143] = int_stack + 15180;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 15495;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 15936;
 Libderiv->deriv2_classes[5][7][143] = int_stack + 16524;
 Libderiv->deriv2_classes[6][4][143] = int_stack + 17280;
 Libderiv->deriv2_classes[6][5][143] = int_stack + 17700;
 Libderiv->deriv2_classes[6][6][143] = int_stack + 18288;
 Libderiv->deriv2_classes[6][7][143] = int_stack + 19072;
 Libderiv->deriv2_classes[7][4][143] = int_stack + 20080;
 Libderiv->deriv2_classes[7][5][143] = int_stack + 20620;
 Libderiv->deriv2_classes[7][6][143] = int_stack + 21376;
 Libderiv->deriv2_classes[7][7][143] = int_stack + 22384;
 Libderiv->deriv2_classes[4][4][131] = int_stack + 23680;
 Libderiv->deriv2_classes[4][5][131] = int_stack + 23905;
 Libderiv->deriv2_classes[4][6][131] = int_stack + 24220;
 Libderiv->deriv2_classes[4][7][131] = int_stack + 24640;
 Libderiv->deriv2_classes[5][4][131] = int_stack + 25180;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 25495;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 25936;
 Libderiv->deriv2_classes[5][7][131] = int_stack + 26524;
 Libderiv->deriv2_classes[6][4][131] = int_stack + 27280;
 Libderiv->deriv2_classes[6][5][131] = int_stack + 27700;
 Libderiv->deriv2_classes[6][6][131] = int_stack + 28288;
 Libderiv->deriv2_classes[6][7][131] = int_stack + 29072;
 Libderiv->deriv2_classes[7][4][131] = int_stack + 30080;
 Libderiv->deriv2_classes[7][5][131] = int_stack + 30620;
 Libderiv->deriv2_classes[7][6][131] = int_stack + 31376;
 Libderiv->deriv2_classes[7][7][131] = int_stack + 32384;
 Libderiv->deriv2_classes[4][4][130] = int_stack + 33680;
 Libderiv->deriv2_classes[4][5][130] = int_stack + 33905;
 Libderiv->deriv2_classes[4][6][130] = int_stack + 34220;
 Libderiv->deriv2_classes[4][7][130] = int_stack + 34640;
 Libderiv->deriv2_classes[5][4][130] = int_stack + 35180;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 35495;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 35936;
 Libderiv->deriv2_classes[5][7][130] = int_stack + 36524;
 Libderiv->deriv2_classes[6][4][130] = int_stack + 37280;
 Libderiv->deriv2_classes[6][5][130] = int_stack + 37700;
 Libderiv->deriv2_classes[6][6][130] = int_stack + 38288;
 Libderiv->deriv2_classes[6][7][130] = int_stack + 39072;
 Libderiv->deriv2_classes[7][4][130] = int_stack + 40080;
 Libderiv->deriv2_classes[7][5][130] = int_stack + 40620;
 Libderiv->deriv2_classes[7][6][130] = int_stack + 41376;
 Libderiv->deriv2_classes[7][7][130] = int_stack + 42384;
 Libderiv->deriv2_classes[4][4][119] = int_stack + 43680;
 Libderiv->deriv2_classes[4][5][119] = int_stack + 43905;
 Libderiv->deriv2_classes[4][6][119] = int_stack + 44220;
 Libderiv->deriv2_classes[4][7][119] = int_stack + 44640;
 Libderiv->deriv2_classes[5][4][119] = int_stack + 45180;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 45495;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 45936;
 Libderiv->deriv2_classes[5][7][119] = int_stack + 46524;
 Libderiv->deriv2_classes[6][4][119] = int_stack + 47280;
 Libderiv->deriv2_classes[6][5][119] = int_stack + 47700;
 Libderiv->deriv2_classes[6][6][119] = int_stack + 48288;
 Libderiv->deriv2_classes[6][7][119] = int_stack + 49072;
 Libderiv->deriv2_classes[7][4][119] = int_stack + 50080;
 Libderiv->deriv2_classes[7][5][119] = int_stack + 50620;
 Libderiv->deriv2_classes[7][6][119] = int_stack + 51376;
 Libderiv->deriv2_classes[7][7][119] = int_stack + 52384;
 Libderiv->deriv2_classes[4][4][118] = int_stack + 53680;
 Libderiv->deriv2_classes[4][5][118] = int_stack + 53905;
 Libderiv->deriv2_classes[4][6][118] = int_stack + 54220;
 Libderiv->deriv2_classes[4][7][118] = int_stack + 54640;
 Libderiv->deriv2_classes[5][4][118] = int_stack + 55180;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 55495;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 55936;
 Libderiv->deriv2_classes[5][7][118] = int_stack + 56524;
 Libderiv->deriv2_classes[6][4][118] = int_stack + 57280;
 Libderiv->deriv2_classes[6][5][118] = int_stack + 57700;
 Libderiv->deriv2_classes[6][6][118] = int_stack + 58288;
 Libderiv->deriv2_classes[6][7][118] = int_stack + 59072;
 Libderiv->deriv2_classes[7][4][118] = int_stack + 60080;
 Libderiv->deriv2_classes[7][5][118] = int_stack + 60620;
 Libderiv->deriv2_classes[7][6][118] = int_stack + 61376;
 Libderiv->deriv2_classes[7][7][118] = int_stack + 62384;
 Libderiv->deriv2_classes[4][4][117] = int_stack + 63680;
 Libderiv->deriv2_classes[4][5][117] = int_stack + 63905;
 Libderiv->deriv2_classes[4][6][117] = int_stack + 64220;
 Libderiv->deriv2_classes[4][7][117] = int_stack + 64640;
 Libderiv->deriv2_classes[5][4][117] = int_stack + 65180;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 65495;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 65936;
 Libderiv->deriv2_classes[5][7][117] = int_stack + 66524;
 Libderiv->deriv2_classes[6][4][117] = int_stack + 67280;
 Libderiv->deriv2_classes[6][5][117] = int_stack + 67700;
 Libderiv->deriv2_classes[6][6][117] = int_stack + 68288;
 Libderiv->deriv2_classes[6][7][117] = int_stack + 69072;
 Libderiv->deriv2_classes[7][4][117] = int_stack + 70080;
 Libderiv->deriv2_classes[7][5][117] = int_stack + 70620;
 Libderiv->deriv2_classes[7][6][117] = int_stack + 71376;
 Libderiv->deriv2_classes[7][7][117] = int_stack + 72384;
 Libderiv->deriv2_classes[4][4][107] = int_stack + 73680;
 Libderiv->deriv2_classes[4][5][107] = int_stack + 73905;
 Libderiv->deriv2_classes[4][6][107] = int_stack + 74220;
 Libderiv->deriv2_classes[4][7][107] = int_stack + 74640;
 Libderiv->deriv2_classes[5][4][107] = int_stack + 75180;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 75495;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 75936;
 Libderiv->deriv2_classes[5][7][107] = int_stack + 76524;
 Libderiv->deriv2_classes[6][4][107] = int_stack + 77280;
 Libderiv->deriv2_classes[6][5][107] = int_stack + 77700;
 Libderiv->deriv2_classes[6][6][107] = int_stack + 78288;
 Libderiv->deriv2_classes[6][7][107] = int_stack + 79072;
 Libderiv->deriv2_classes[7][4][107] = int_stack + 80080;
 Libderiv->deriv2_classes[7][5][107] = int_stack + 80620;
 Libderiv->deriv2_classes[7][6][107] = int_stack + 81376;
 Libderiv->deriv2_classes[7][7][107] = int_stack + 82384;
 Libderiv->deriv2_classes[4][4][106] = int_stack + 83680;
 Libderiv->deriv2_classes[4][5][106] = int_stack + 83905;
 Libderiv->deriv2_classes[4][6][106] = int_stack + 84220;
 Libderiv->deriv2_classes[4][7][106] = int_stack + 84640;
 Libderiv->deriv2_classes[5][4][106] = int_stack + 85180;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 85495;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 85936;
 Libderiv->deriv2_classes[5][7][106] = int_stack + 86524;
 Libderiv->deriv2_classes[6][4][106] = int_stack + 87280;
 Libderiv->deriv2_classes[6][5][106] = int_stack + 87700;
 Libderiv->deriv2_classes[6][6][106] = int_stack + 88288;
 Libderiv->deriv2_classes[6][7][106] = int_stack + 89072;
 Libderiv->deriv2_classes[7][4][106] = int_stack + 90080;
 Libderiv->deriv2_classes[7][5][106] = int_stack + 90620;
 Libderiv->deriv2_classes[7][6][106] = int_stack + 91376;
 Libderiv->deriv2_classes[7][7][106] = int_stack + 92384;
 Libderiv->deriv2_classes[4][4][105] = int_stack + 93680;
 Libderiv->deriv2_classes[4][5][105] = int_stack + 93905;
 Libderiv->deriv2_classes[4][6][105] = int_stack + 94220;
 Libderiv->deriv2_classes[4][7][105] = int_stack + 94640;
 Libderiv->deriv2_classes[5][4][105] = int_stack + 95180;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 95495;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 95936;
 Libderiv->deriv2_classes[5][7][105] = int_stack + 96524;
 Libderiv->deriv2_classes[6][4][105] = int_stack + 97280;
 Libderiv->deriv2_classes[6][5][105] = int_stack + 97700;
 Libderiv->deriv2_classes[6][6][105] = int_stack + 98288;
 Libderiv->deriv2_classes[6][7][105] = int_stack + 99072;
 Libderiv->deriv2_classes[7][4][105] = int_stack + 100080;
 Libderiv->deriv2_classes[7][5][105] = int_stack + 100620;
 Libderiv->deriv2_classes[7][6][105] = int_stack + 101376;
 Libderiv->deriv2_classes[7][7][105] = int_stack + 102384;
 Libderiv->deriv2_classes[4][4][104] = int_stack + 103680;
 Libderiv->deriv2_classes[4][5][104] = int_stack + 103905;
 Libderiv->deriv2_classes[4][6][104] = int_stack + 104220;
 Libderiv->deriv2_classes[4][7][104] = int_stack + 104640;
 Libderiv->deriv2_classes[5][4][104] = int_stack + 105180;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 105495;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 105936;
 Libderiv->deriv2_classes[5][7][104] = int_stack + 106524;
 Libderiv->deriv2_classes[6][4][104] = int_stack + 107280;
 Libderiv->deriv2_classes[6][5][104] = int_stack + 107700;
 Libderiv->deriv2_classes[6][6][104] = int_stack + 108288;
 Libderiv->deriv2_classes[6][7][104] = int_stack + 109072;
 Libderiv->deriv2_classes[7][4][104] = int_stack + 110080;
 Libderiv->deriv2_classes[7][5][104] = int_stack + 110620;
 Libderiv->deriv2_classes[7][6][104] = int_stack + 111376;
 Libderiv->deriv2_classes[7][7][104] = int_stack + 112384;
 Libderiv->deriv2_classes[4][4][95] = int_stack + 113680;
 Libderiv->deriv2_classes[4][5][95] = int_stack + 113905;
 Libderiv->deriv2_classes[4][6][95] = int_stack + 114220;
 Libderiv->deriv2_classes[4][7][95] = int_stack + 114640;
 Libderiv->deriv2_classes[5][4][95] = int_stack + 115180;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 115495;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 115936;
 Libderiv->deriv2_classes[5][7][95] = int_stack + 116524;
 Libderiv->deriv2_classes[6][4][95] = int_stack + 117280;
 Libderiv->deriv2_classes[6][5][95] = int_stack + 117700;
 Libderiv->deriv2_classes[6][6][95] = int_stack + 118288;
 Libderiv->deriv2_classes[6][7][95] = int_stack + 119072;
 Libderiv->deriv2_classes[7][4][95] = int_stack + 120080;
 Libderiv->deriv2_classes[7][5][95] = int_stack + 120620;
 Libderiv->deriv2_classes[7][6][95] = int_stack + 121376;
 Libderiv->deriv2_classes[7][7][95] = int_stack + 122384;
 Libderiv->deriv2_classes[4][4][94] = int_stack + 123680;
 Libderiv->deriv2_classes[4][5][94] = int_stack + 123905;
 Libderiv->deriv2_classes[4][6][94] = int_stack + 124220;
 Libderiv->deriv2_classes[4][7][94] = int_stack + 124640;
 Libderiv->deriv2_classes[5][4][94] = int_stack + 125180;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 125495;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 125936;
 Libderiv->deriv2_classes[5][7][94] = int_stack + 126524;
 Libderiv->deriv2_classes[6][4][94] = int_stack + 127280;
 Libderiv->deriv2_classes[6][5][94] = int_stack + 127700;
 Libderiv->deriv2_classes[6][6][94] = int_stack + 128288;
 Libderiv->deriv2_classes[6][7][94] = int_stack + 129072;
 Libderiv->deriv2_classes[7][4][94] = int_stack + 130080;
 Libderiv->deriv2_classes[7][5][94] = int_stack + 130620;
 Libderiv->deriv2_classes[7][6][94] = int_stack + 131376;
 Libderiv->deriv2_classes[7][7][94] = int_stack + 132384;
 Libderiv->deriv2_classes[4][4][93] = int_stack + 133680;
 Libderiv->deriv2_classes[4][5][93] = int_stack + 133905;
 Libderiv->deriv2_classes[4][6][93] = int_stack + 134220;
 Libderiv->deriv2_classes[4][7][93] = int_stack + 134640;
 Libderiv->deriv2_classes[5][4][93] = int_stack + 135180;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 135495;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 135936;
 Libderiv->deriv2_classes[5][7][93] = int_stack + 136524;
 Libderiv->deriv2_classes[6][4][93] = int_stack + 137280;
 Libderiv->deriv2_classes[6][5][93] = int_stack + 137700;
 Libderiv->deriv2_classes[6][6][93] = int_stack + 138288;
 Libderiv->deriv2_classes[6][7][93] = int_stack + 139072;
 Libderiv->deriv2_classes[7][4][93] = int_stack + 140080;
 Libderiv->deriv2_classes[7][5][93] = int_stack + 140620;
 Libderiv->deriv2_classes[7][6][93] = int_stack + 141376;
 Libderiv->deriv2_classes[7][7][93] = int_stack + 142384;
 Libderiv->deriv2_classes[4][4][92] = int_stack + 143680;
 Libderiv->deriv2_classes[4][5][92] = int_stack + 143905;
 Libderiv->deriv2_classes[4][6][92] = int_stack + 144220;
 Libderiv->deriv2_classes[4][7][92] = int_stack + 144640;
 Libderiv->deriv2_classes[5][4][92] = int_stack + 145180;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 145495;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 145936;
 Libderiv->deriv2_classes[5][7][92] = int_stack + 146524;
 Libderiv->deriv2_classes[6][4][92] = int_stack + 147280;
 Libderiv->deriv2_classes[6][5][92] = int_stack + 147700;
 Libderiv->deriv2_classes[6][6][92] = int_stack + 148288;
 Libderiv->deriv2_classes[6][7][92] = int_stack + 149072;
 Libderiv->deriv2_classes[7][4][92] = int_stack + 150080;
 Libderiv->deriv2_classes[7][5][92] = int_stack + 150620;
 Libderiv->deriv2_classes[7][6][92] = int_stack + 151376;
 Libderiv->deriv2_classes[7][7][92] = int_stack + 152384;
 Libderiv->deriv2_classes[4][4][91] = int_stack + 153680;
 Libderiv->deriv2_classes[4][5][91] = int_stack + 153905;
 Libderiv->deriv2_classes[4][6][91] = int_stack + 154220;
 Libderiv->deriv2_classes[4][7][91] = int_stack + 154640;
 Libderiv->deriv2_classes[5][4][91] = int_stack + 155180;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 155495;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 155936;
 Libderiv->deriv2_classes[5][7][91] = int_stack + 156524;
 Libderiv->deriv2_classes[6][4][91] = int_stack + 157280;
 Libderiv->deriv2_classes[6][5][91] = int_stack + 157700;
 Libderiv->deriv2_classes[6][6][91] = int_stack + 158288;
 Libderiv->deriv2_classes[6][7][91] = int_stack + 159072;
 Libderiv->deriv2_classes[7][4][91] = int_stack + 160080;
 Libderiv->deriv2_classes[7][5][91] = int_stack + 160620;
 Libderiv->deriv2_classes[7][6][91] = int_stack + 161376;
 Libderiv->deriv2_classes[7][7][91] = int_stack + 162384;
 Libderiv->deriv2_classes[4][4][83] = int_stack + 163680;
 Libderiv->deriv2_classes[4][5][83] = int_stack + 163905;
 Libderiv->deriv2_classes[4][6][83] = int_stack + 164220;
 Libderiv->deriv2_classes[4][7][83] = int_stack + 164640;
 Libderiv->deriv2_classes[5][4][83] = int_stack + 165180;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 165495;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 165936;
 Libderiv->deriv2_classes[5][7][83] = int_stack + 166524;
 Libderiv->deriv2_classes[6][4][83] = int_stack + 167280;
 Libderiv->deriv2_classes[6][5][83] = int_stack + 167700;
 Libderiv->deriv2_classes[6][6][83] = int_stack + 168288;
 Libderiv->deriv2_classes[6][7][83] = int_stack + 169072;
 Libderiv->deriv_classes[7][4][11] = int_stack + 170080;
 Libderiv->deriv2_classes[7][4][83] = int_stack + 170620;
 Libderiv->deriv_classes[7][5][11] = int_stack + 171160;
 Libderiv->deriv2_classes[7][5][83] = int_stack + 171916;
 Libderiv->deriv_classes[7][6][11] = int_stack + 172672;
 Libderiv->deriv2_classes[7][6][83] = int_stack + 173680;
 Libderiv->deriv2_classes[7][7][83] = int_stack + 174688;
 Libderiv->deriv2_classes[4][4][82] = int_stack + 175984;
 Libderiv->deriv2_classes[4][5][82] = int_stack + 176209;
 Libderiv->deriv2_classes[4][6][82] = int_stack + 176524;
 Libderiv->deriv2_classes[4][7][82] = int_stack + 176944;
 Libderiv->deriv2_classes[5][4][82] = int_stack + 177484;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 177799;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 178240;
 Libderiv->deriv2_classes[5][7][82] = int_stack + 178828;
 Libderiv->deriv2_classes[6][4][82] = int_stack + 179584;
 Libderiv->deriv2_classes[6][5][82] = int_stack + 180004;
 Libderiv->deriv2_classes[6][6][82] = int_stack + 180592;
 Libderiv->deriv2_classes[6][7][82] = int_stack + 181376;
 Libderiv->deriv_classes[7][4][10] = int_stack + 182384;
 Libderiv->deriv2_classes[7][4][82] = int_stack + 182924;
 Libderiv->deriv_classes[7][5][10] = int_stack + 183464;
 Libderiv->deriv2_classes[7][5][82] = int_stack + 184220;
 Libderiv->deriv_classes[7][6][10] = int_stack + 184976;
 Libderiv->deriv2_classes[7][6][82] = int_stack + 185984;
 Libderiv->deriv2_classes[7][7][82] = int_stack + 186992;
 Libderiv->deriv2_classes[4][4][81] = int_stack + 188288;
 Libderiv->deriv2_classes[4][5][81] = int_stack + 188513;
 Libderiv->deriv2_classes[4][6][81] = int_stack + 188828;
 Libderiv->deriv2_classes[4][7][81] = int_stack + 189248;
 Libderiv->deriv2_classes[5][4][81] = int_stack + 189788;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 190103;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 190544;
 Libderiv->deriv2_classes[5][7][81] = int_stack + 191132;
 Libderiv->deriv2_classes[6][4][81] = int_stack + 191888;
 Libderiv->deriv2_classes[6][5][81] = int_stack + 192308;
 Libderiv->deriv2_classes[6][6][81] = int_stack + 192896;
 Libderiv->deriv2_classes[6][7][81] = int_stack + 193680;
 Libderiv->deriv_classes[7][4][9] = int_stack + 194688;
 Libderiv->deriv2_classes[7][4][81] = int_stack + 195228;
 Libderiv->deriv_classes[7][5][9] = int_stack + 195768;
 Libderiv->deriv2_classes[7][5][81] = int_stack + 196524;
 Libderiv->deriv_classes[7][6][9] = int_stack + 197280;
 Libderiv->deriv2_classes[7][6][81] = int_stack + 198288;
 Libderiv->deriv2_classes[7][7][81] = int_stack + 199296;
 Libderiv->deriv2_classes[4][4][80] = int_stack + 200592;
 Libderiv->deriv2_classes[4][5][80] = int_stack + 200817;
 Libderiv->deriv2_classes[4][6][80] = int_stack + 201132;
 Libderiv->deriv2_classes[4][7][80] = int_stack + 201552;
 Libderiv->deriv2_classes[5][4][80] = int_stack + 202092;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 202407;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 202848;
 Libderiv->deriv2_classes[5][7][80] = int_stack + 203436;
 Libderiv->deriv2_classes[6][4][80] = int_stack + 204192;
 Libderiv->deriv2_classes[6][5][80] = int_stack + 204612;
 Libderiv->deriv2_classes[6][6][80] = int_stack + 205200;
 Libderiv->deriv2_classes[6][7][80] = int_stack + 205984;
 Libderiv->deriv_classes[7][4][8] = int_stack + 206992;
 Libderiv->deriv2_classes[7][4][80] = int_stack + 207532;
 Libderiv->deriv_classes[7][5][8] = int_stack + 208072;
 Libderiv->deriv2_classes[7][5][80] = int_stack + 208828;
 Libderiv->deriv_classes[7][6][8] = int_stack + 209584;
 Libderiv->deriv2_classes[7][6][80] = int_stack + 210592;
 Libderiv->deriv2_classes[7][7][80] = int_stack + 211600;
 Libderiv->deriv2_classes[4][4][79] = int_stack + 212896;
 Libderiv->deriv2_classes[4][5][79] = int_stack + 213121;
 Libderiv->deriv2_classes[4][6][79] = int_stack + 213436;
 Libderiv->deriv2_classes[4][7][79] = int_stack + 213856;
 Libderiv->deriv2_classes[5][4][79] = int_stack + 214396;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 214711;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 215152;
 Libderiv->deriv2_classes[5][7][79] = int_stack + 215740;
 Libderiv->deriv2_classes[6][4][79] = int_stack + 216496;
 Libderiv->deriv2_classes[6][5][79] = int_stack + 216916;
 Libderiv->deriv2_classes[6][6][79] = int_stack + 217504;
 Libderiv->deriv2_classes[6][7][79] = int_stack + 218288;
 Libderiv->deriv_classes[7][4][7] = int_stack + 219296;
 Libderiv->deriv2_classes[7][4][79] = int_stack + 219836;
 Libderiv->deriv_classes[7][5][7] = int_stack + 220376;
 Libderiv->deriv2_classes[7][5][79] = int_stack + 221132;
 Libderiv->deriv_classes[7][6][7] = int_stack + 221888;
 Libderiv->deriv2_classes[7][6][79] = int_stack + 222896;
 Libderiv->deriv2_classes[7][7][79] = int_stack + 223904;
 Libderiv->deriv2_classes[4][4][78] = int_stack + 225200;
 Libderiv->deriv2_classes[4][5][78] = int_stack + 225425;
 Libderiv->deriv2_classes[4][6][78] = int_stack + 225740;
 Libderiv->deriv2_classes[4][7][78] = int_stack + 226160;
 Libderiv->deriv2_classes[5][4][78] = int_stack + 226700;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 227015;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 227456;
 Libderiv->deriv2_classes[5][7][78] = int_stack + 228044;
 Libderiv->deriv2_classes[6][4][78] = int_stack + 228800;
 Libderiv->deriv2_classes[6][5][78] = int_stack + 229220;
 Libderiv->deriv2_classes[6][6][78] = int_stack + 229808;
 Libderiv->deriv2_classes[6][7][78] = int_stack + 230592;
 Libderiv->dvrr_classes[7][4] = int_stack + 231600;
 Libderiv->deriv_classes[7][4][6] = int_stack + 232140;
 Libderiv->deriv2_classes[7][4][78] = int_stack + 232680;
 Libderiv->dvrr_classes[7][5] = int_stack + 233220;
 Libderiv->deriv_classes[7][5][6] = int_stack + 233976;
 Libderiv->deriv2_classes[7][5][78] = int_stack + 234732;
 Libderiv->deriv_classes[7][6][6] = int_stack + 235488;
 Libderiv->deriv2_classes[7][6][78] = int_stack + 236496;
 Libderiv->deriv2_classes[7][7][78] = int_stack + 237504;
 Libderiv->deriv2_classes[4][4][35] = int_stack + 238800;
 Libderiv->deriv2_classes[4][5][35] = int_stack + 239025;
 Libderiv->deriv2_classes[4][6][35] = int_stack + 239340;
 Libderiv->deriv2_classes[4][7][35] = int_stack + 239760;
 Libderiv->deriv2_classes[5][4][35] = int_stack + 240300;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 240615;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 241056;
 Libderiv->deriv2_classes[5][7][35] = int_stack + 241644;
 Libderiv->deriv2_classes[6][4][35] = int_stack + 242400;
 Libderiv->deriv2_classes[6][5][35] = int_stack + 242820;
 Libderiv->deriv2_classes[6][6][35] = int_stack + 243408;
 Libderiv->deriv2_classes[6][7][35] = int_stack + 244192;
 Libderiv->deriv2_classes[7][4][35] = int_stack + 245200;
 Libderiv->deriv2_classes[7][5][35] = int_stack + 245740;
 Libderiv->deriv2_classes[7][6][35] = int_stack + 246496;
 Libderiv->deriv2_classes[7][7][35] = int_stack + 247504;
 Libderiv->deriv2_classes[4][4][34] = int_stack + 248800;
 Libderiv->deriv2_classes[4][5][34] = int_stack + 249025;
 Libderiv->deriv2_classes[4][6][34] = int_stack + 249340;
 Libderiv->deriv2_classes[4][7][34] = int_stack + 249760;
 Libderiv->deriv2_classes[5][4][34] = int_stack + 250300;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 250615;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 251056;
 Libderiv->deriv2_classes[5][7][34] = int_stack + 251644;
 Libderiv->deriv2_classes[6][4][34] = int_stack + 252400;
 Libderiv->deriv2_classes[6][5][34] = int_stack + 252820;
 Libderiv->deriv2_classes[6][6][34] = int_stack + 253408;
 Libderiv->deriv2_classes[6][7][34] = int_stack + 254192;
 Libderiv->deriv2_classes[7][4][34] = int_stack + 255200;
 Libderiv->deriv2_classes[7][5][34] = int_stack + 255740;
 Libderiv->deriv2_classes[7][6][34] = int_stack + 256496;
 Libderiv->deriv2_classes[7][7][34] = int_stack + 257504;
 Libderiv->deriv2_classes[4][4][33] = int_stack + 258800;
 Libderiv->deriv2_classes[4][5][33] = int_stack + 259025;
 Libderiv->deriv2_classes[4][6][33] = int_stack + 259340;
 Libderiv->deriv2_classes[4][7][33] = int_stack + 259760;
 Libderiv->deriv2_classes[5][4][33] = int_stack + 260300;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 260615;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 261056;
 Libderiv->deriv2_classes[5][7][33] = int_stack + 261644;
 Libderiv->deriv2_classes[6][4][33] = int_stack + 262400;
 Libderiv->deriv2_classes[6][5][33] = int_stack + 262820;
 Libderiv->deriv2_classes[6][6][33] = int_stack + 263408;
 Libderiv->deriv2_classes[6][7][33] = int_stack + 264192;
 Libderiv->deriv2_classes[7][4][33] = int_stack + 265200;
 Libderiv->deriv2_classes[7][5][33] = int_stack + 265740;
 Libderiv->deriv2_classes[7][6][33] = int_stack + 266496;
 Libderiv->deriv2_classes[7][7][33] = int_stack + 267504;
 Libderiv->deriv2_classes[4][4][32] = int_stack + 268800;
 Libderiv->deriv2_classes[4][5][32] = int_stack + 269025;
 Libderiv->deriv2_classes[4][6][32] = int_stack + 269340;
 Libderiv->deriv2_classes[4][7][32] = int_stack + 269760;
 Libderiv->deriv2_classes[5][4][32] = int_stack + 270300;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 270615;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 271056;
 Libderiv->deriv2_classes[5][7][32] = int_stack + 271644;
 Libderiv->deriv2_classes[6][4][32] = int_stack + 272400;
 Libderiv->deriv2_classes[6][5][32] = int_stack + 272820;
 Libderiv->deriv2_classes[6][6][32] = int_stack + 273408;
 Libderiv->deriv2_classes[6][7][32] = int_stack + 274192;
 Libderiv->deriv2_classes[7][4][32] = int_stack + 275200;
 Libderiv->deriv2_classes[7][5][32] = int_stack + 275740;
 Libderiv->deriv2_classes[7][6][32] = int_stack + 276496;
 Libderiv->deriv2_classes[7][7][32] = int_stack + 277504;
 Libderiv->deriv2_classes[4][4][31] = int_stack + 278800;
 Libderiv->deriv2_classes[4][5][31] = int_stack + 279025;
 Libderiv->deriv2_classes[4][6][31] = int_stack + 279340;
 Libderiv->deriv2_classes[4][7][31] = int_stack + 279760;
 Libderiv->deriv2_classes[5][4][31] = int_stack + 280300;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 280615;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 281056;
 Libderiv->deriv2_classes[5][7][31] = int_stack + 281644;
 Libderiv->deriv2_classes[6][4][31] = int_stack + 282400;
 Libderiv->deriv2_classes[6][5][31] = int_stack + 282820;
 Libderiv->deriv2_classes[6][6][31] = int_stack + 283408;
 Libderiv->deriv2_classes[6][7][31] = int_stack + 284192;
 Libderiv->deriv2_classes[7][4][31] = int_stack + 285200;
 Libderiv->deriv2_classes[7][5][31] = int_stack + 285740;
 Libderiv->deriv2_classes[7][6][31] = int_stack + 286496;
 Libderiv->deriv2_classes[7][7][31] = int_stack + 287504;
 Libderiv->deriv2_classes[4][4][30] = int_stack + 288800;
 Libderiv->deriv2_classes[4][5][30] = int_stack + 289025;
 Libderiv->deriv2_classes[4][6][30] = int_stack + 289340;
 Libderiv->deriv2_classes[4][7][30] = int_stack + 289760;
 Libderiv->deriv2_classes[5][4][30] = int_stack + 290300;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 290615;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 291056;
 Libderiv->deriv2_classes[5][7][30] = int_stack + 291644;
 Libderiv->deriv2_classes[6][4][30] = int_stack + 292400;
 Libderiv->deriv2_classes[6][5][30] = int_stack + 292820;
 Libderiv->deriv2_classes[6][6][30] = int_stack + 293408;
 Libderiv->deriv2_classes[6][7][30] = int_stack + 294192;
 Libderiv->deriv_classes[7][4][2] = int_stack + 295200;
 Libderiv->deriv2_classes[7][4][30] = int_stack + 295740;
 Libderiv->deriv_classes[7][5][2] = int_stack + 296280;
 Libderiv->deriv2_classes[7][5][30] = int_stack + 297036;
 Libderiv->deriv_classes[7][6][2] = int_stack + 297792;
 Libderiv->deriv2_classes[7][6][30] = int_stack + 298800;
 Libderiv->deriv2_classes[7][7][30] = int_stack + 299808;
 Libderiv->deriv2_classes[4][4][26] = int_stack + 301104;
 Libderiv->deriv2_classes[4][5][26] = int_stack + 301329;
 Libderiv->deriv2_classes[4][6][26] = int_stack + 301644;
 Libderiv->deriv2_classes[4][7][26] = int_stack + 302064;
 Libderiv->deriv2_classes[5][4][26] = int_stack + 302604;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 302919;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 303360;
 Libderiv->deriv2_classes[5][7][26] = int_stack + 303948;
 Libderiv->deriv2_classes[6][4][26] = int_stack + 304704;
 Libderiv->deriv2_classes[6][5][26] = int_stack + 305124;
 Libderiv->deriv2_classes[6][6][26] = int_stack + 305712;
 Libderiv->deriv2_classes[6][7][26] = int_stack + 306496;
 Libderiv->deriv2_classes[7][4][26] = int_stack + 307504;
 Libderiv->deriv2_classes[7][5][26] = int_stack + 308044;
 Libderiv->deriv2_classes[7][6][26] = int_stack + 308800;
 Libderiv->deriv2_classes[7][7][26] = int_stack + 309808;
 Libderiv->deriv2_classes[4][4][23] = int_stack + 311104;
 Libderiv->deriv2_classes[4][5][23] = int_stack + 311329;
 Libderiv->deriv2_classes[4][6][23] = int_stack + 311644;
 Libderiv->deriv2_classes[4][7][23] = int_stack + 312064;
 Libderiv->deriv2_classes[5][4][23] = int_stack + 312604;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 312919;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 313360;
 Libderiv->deriv2_classes[5][7][23] = int_stack + 313948;
 Libderiv->deriv2_classes[6][4][23] = int_stack + 314704;
 Libderiv->deriv2_classes[6][5][23] = int_stack + 315124;
 Libderiv->deriv2_classes[6][6][23] = int_stack + 315712;
 Libderiv->deriv2_classes[6][7][23] = int_stack + 316496;
 Libderiv->deriv2_classes[7][4][23] = int_stack + 317504;
 Libderiv->deriv2_classes[7][5][23] = int_stack + 318044;
 Libderiv->deriv2_classes[7][6][23] = int_stack + 318800;
 Libderiv->deriv2_classes[7][7][23] = int_stack + 319808;
 Libderiv->deriv2_classes[4][4][22] = int_stack + 321104;
 Libderiv->deriv2_classes[4][5][22] = int_stack + 321329;
 Libderiv->deriv2_classes[4][6][22] = int_stack + 321644;
 Libderiv->deriv2_classes[4][7][22] = int_stack + 322064;
 Libderiv->deriv2_classes[5][4][22] = int_stack + 322604;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 322919;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 323360;
 Libderiv->deriv2_classes[5][7][22] = int_stack + 323948;
 Libderiv->deriv2_classes[6][4][22] = int_stack + 324704;
 Libderiv->deriv2_classes[6][5][22] = int_stack + 325124;
 Libderiv->deriv2_classes[6][6][22] = int_stack + 325712;
 Libderiv->deriv2_classes[6][7][22] = int_stack + 326496;
 Libderiv->deriv2_classes[7][4][22] = int_stack + 327504;
 Libderiv->deriv2_classes[7][5][22] = int_stack + 328044;
 Libderiv->deriv2_classes[7][6][22] = int_stack + 328800;
 Libderiv->deriv2_classes[7][7][22] = int_stack + 329808;
 Libderiv->deriv2_classes[4][4][21] = int_stack + 331104;
 Libderiv->deriv2_classes[4][5][21] = int_stack + 331329;
 Libderiv->deriv2_classes[4][6][21] = int_stack + 331644;
 Libderiv->deriv2_classes[4][7][21] = int_stack + 332064;
 Libderiv->deriv2_classes[5][4][21] = int_stack + 332604;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 332919;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 333360;
 Libderiv->deriv2_classes[5][7][21] = int_stack + 333948;
 Libderiv->deriv2_classes[6][4][21] = int_stack + 334704;
 Libderiv->deriv2_classes[6][5][21] = int_stack + 335124;
 Libderiv->deriv2_classes[6][6][21] = int_stack + 335712;
 Libderiv->deriv2_classes[6][7][21] = int_stack + 336496;
 Libderiv->deriv2_classes[7][4][21] = int_stack + 337504;
 Libderiv->deriv2_classes[7][5][21] = int_stack + 338044;
 Libderiv->deriv2_classes[7][6][21] = int_stack + 338800;
 Libderiv->deriv2_classes[7][7][21] = int_stack + 339808;
 Libderiv->deriv2_classes[4][4][20] = int_stack + 341104;
 Libderiv->deriv2_classes[4][5][20] = int_stack + 341329;
 Libderiv->deriv2_classes[4][6][20] = int_stack + 341644;
 Libderiv->deriv2_classes[4][7][20] = int_stack + 342064;
 Libderiv->deriv2_classes[5][4][20] = int_stack + 342604;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 342919;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 343360;
 Libderiv->deriv2_classes[5][7][20] = int_stack + 343948;
 Libderiv->deriv2_classes[6][4][20] = int_stack + 344704;
 Libderiv->deriv2_classes[6][5][20] = int_stack + 345124;
 Libderiv->deriv2_classes[6][6][20] = int_stack + 345712;
 Libderiv->deriv2_classes[6][7][20] = int_stack + 346496;
 Libderiv->deriv2_classes[7][4][20] = int_stack + 347504;
 Libderiv->deriv2_classes[7][5][20] = int_stack + 348044;
 Libderiv->deriv2_classes[7][6][20] = int_stack + 348800;
 Libderiv->deriv2_classes[7][7][20] = int_stack + 349808;
 Libderiv->deriv2_classes[4][4][19] = int_stack + 351104;
 Libderiv->deriv2_classes[4][5][19] = int_stack + 351329;
 Libderiv->deriv2_classes[4][6][19] = int_stack + 351644;
 Libderiv->deriv2_classes[4][7][19] = int_stack + 352064;
 Libderiv->deriv2_classes[5][4][19] = int_stack + 352604;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 352919;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 353360;
 Libderiv->deriv2_classes[5][7][19] = int_stack + 353948;
 Libderiv->deriv2_classes[6][4][19] = int_stack + 354704;
 Libderiv->deriv2_classes[6][5][19] = int_stack + 355124;
 Libderiv->deriv2_classes[6][6][19] = int_stack + 355712;
 Libderiv->deriv2_classes[6][7][19] = int_stack + 356496;
 Libderiv->deriv2_classes[7][4][19] = int_stack + 357504;
 Libderiv->deriv2_classes[7][5][19] = int_stack + 358044;
 Libderiv->deriv2_classes[7][6][19] = int_stack + 358800;
 Libderiv->deriv2_classes[7][7][19] = int_stack + 359808;
 Libderiv->deriv2_classes[4][4][18] = int_stack + 361104;
 Libderiv->deriv2_classes[4][5][18] = int_stack + 361329;
 Libderiv->deriv2_classes[4][6][18] = int_stack + 361644;
 Libderiv->deriv2_classes[4][7][18] = int_stack + 362064;
 Libderiv->deriv2_classes[5][4][18] = int_stack + 362604;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 362919;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 363360;
 Libderiv->deriv2_classes[5][7][18] = int_stack + 363948;
 Libderiv->deriv2_classes[6][4][18] = int_stack + 364704;
 Libderiv->deriv2_classes[6][5][18] = int_stack + 365124;
 Libderiv->deriv2_classes[6][6][18] = int_stack + 365712;
 Libderiv->deriv2_classes[6][7][18] = int_stack + 366496;
 Libderiv->deriv_classes[7][4][1] = int_stack + 367504;
 Libderiv->deriv2_classes[7][4][18] = int_stack + 368044;
 Libderiv->deriv_classes[7][5][1] = int_stack + 368584;
 Libderiv->deriv2_classes[7][5][18] = int_stack + 369340;
 Libderiv->deriv_classes[7][6][1] = int_stack + 370096;
 Libderiv->deriv2_classes[7][6][18] = int_stack + 371104;
 Libderiv->deriv2_classes[7][7][18] = int_stack + 372112;
 Libderiv->deriv2_classes[4][4][14] = int_stack + 373408;
 Libderiv->deriv2_classes[4][5][14] = int_stack + 373633;
 Libderiv->deriv2_classes[4][6][14] = int_stack + 373948;
 Libderiv->deriv2_classes[4][7][14] = int_stack + 374368;
 Libderiv->deriv2_classes[5][4][14] = int_stack + 374908;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 375223;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 375664;
 Libderiv->deriv2_classes[5][7][14] = int_stack + 376252;
 Libderiv->deriv2_classes[6][4][14] = int_stack + 377008;
 Libderiv->deriv2_classes[6][5][14] = int_stack + 377428;
 Libderiv->deriv2_classes[6][6][14] = int_stack + 378016;
 Libderiv->deriv2_classes[6][7][14] = int_stack + 378800;
 Libderiv->deriv2_classes[7][4][14] = int_stack + 379808;
 Libderiv->deriv2_classes[7][5][14] = int_stack + 380348;
 Libderiv->deriv2_classes[7][6][14] = int_stack + 381104;
 Libderiv->deriv2_classes[7][7][14] = int_stack + 382112;
 Libderiv->deriv2_classes[4][4][13] = int_stack + 383408;
 Libderiv->deriv2_classes[4][5][13] = int_stack + 383633;
 Libderiv->deriv2_classes[4][6][13] = int_stack + 383948;
 Libderiv->deriv2_classes[4][7][13] = int_stack + 384368;
 Libderiv->deriv2_classes[5][4][13] = int_stack + 384908;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 385223;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 385664;
 Libderiv->deriv2_classes[5][7][13] = int_stack + 386252;
 Libderiv->deriv2_classes[6][4][13] = int_stack + 387008;
 Libderiv->deriv2_classes[6][5][13] = int_stack + 387428;
 Libderiv->deriv2_classes[6][6][13] = int_stack + 388016;
 Libderiv->deriv2_classes[6][7][13] = int_stack + 388800;
 Libderiv->deriv2_classes[7][4][13] = int_stack + 389808;
 Libderiv->deriv2_classes[7][5][13] = int_stack + 390348;
 Libderiv->deriv2_classes[7][6][13] = int_stack + 391104;
 Libderiv->deriv2_classes[7][7][13] = int_stack + 392112;
 Libderiv->deriv_classes[4][4][11] = int_stack + 393408;
 Libderiv->deriv_classes[4][5][11] = int_stack + 393633;
 Libderiv->deriv_classes[4][6][11] = int_stack + 393948;
 Libderiv->deriv_classes[4][7][11] = int_stack + 394368;
 Libderiv->deriv2_classes[4][4][11] = int_stack + 394908;
 Libderiv->deriv2_classes[4][5][11] = int_stack + 395133;
 Libderiv->deriv2_classes[4][6][11] = int_stack + 395448;
 Libderiv->deriv2_classes[4][7][11] = int_stack + 395868;
 Libderiv->deriv_classes[5][4][11] = int_stack + 396408;
 Libderiv->deriv_classes[5][5][11] = int_stack + 396723;
 Libderiv->deriv_classes[5][6][11] = int_stack + 397164;
 Libderiv->deriv_classes[5][7][11] = int_stack + 397752;
 Libderiv->deriv2_classes[5][4][11] = int_stack + 398508;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 398823;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 399264;
 Libderiv->deriv2_classes[5][7][11] = int_stack + 399852;
 Libderiv->deriv_classes[6][4][11] = int_stack + 400608;
 Libderiv->deriv_classes[6][5][11] = int_stack + 401028;
 Libderiv->deriv_classes[6][6][11] = int_stack + 401616;
 Libderiv->deriv_classes[6][7][11] = int_stack + 402400;
 Libderiv->deriv2_classes[6][4][11] = int_stack + 403408;
 Libderiv->deriv2_classes[6][5][11] = int_stack + 403828;
 Libderiv->deriv2_classes[6][6][11] = int_stack + 404416;
 Libderiv->deriv2_classes[6][7][11] = int_stack + 405200;
 Libderiv->deriv2_classes[7][4][11] = int_stack + 406208;
 Libderiv->deriv2_classes[7][5][11] = int_stack + 406748;
 Libderiv->deriv2_classes[7][6][11] = int_stack + 407504;
 Libderiv->deriv2_classes[7][7][11] = int_stack + 408512;
 Libderiv->deriv_classes[4][4][10] = int_stack + 409808;
 Libderiv->deriv_classes[4][5][10] = int_stack + 410033;
 Libderiv->deriv_classes[4][6][10] = int_stack + 410348;
 Libderiv->deriv_classes[4][7][10] = int_stack + 410768;
 Libderiv->deriv2_classes[4][4][10] = int_stack + 411308;
 Libderiv->deriv2_classes[4][5][10] = int_stack + 411533;
 Libderiv->deriv2_classes[4][6][10] = int_stack + 411848;
 Libderiv->deriv2_classes[4][7][10] = int_stack + 412268;
 Libderiv->deriv_classes[5][4][10] = int_stack + 412808;
 Libderiv->deriv_classes[5][5][10] = int_stack + 413123;
 Libderiv->deriv_classes[5][6][10] = int_stack + 413564;
 Libderiv->deriv_classes[5][7][10] = int_stack + 414152;
 Libderiv->deriv2_classes[5][4][10] = int_stack + 414908;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 415223;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 415664;
 Libderiv->deriv2_classes[5][7][10] = int_stack + 416252;
 Libderiv->deriv_classes[6][4][10] = int_stack + 417008;
 Libderiv->deriv_classes[6][5][10] = int_stack + 417428;
 Libderiv->deriv_classes[6][6][10] = int_stack + 418016;
 Libderiv->deriv_classes[6][7][10] = int_stack + 418800;
 Libderiv->deriv2_classes[6][4][10] = int_stack + 419808;
 Libderiv->deriv2_classes[6][5][10] = int_stack + 420228;
 Libderiv->deriv2_classes[6][6][10] = int_stack + 420816;
 Libderiv->deriv2_classes[6][7][10] = int_stack + 421600;
 Libderiv->deriv2_classes[7][4][10] = int_stack + 422608;
 Libderiv->deriv2_classes[7][5][10] = int_stack + 423148;
 Libderiv->deriv2_classes[7][6][10] = int_stack + 423904;
 Libderiv->deriv2_classes[7][7][10] = int_stack + 424912;
 Libderiv->deriv_classes[4][4][9] = int_stack + 426208;
 Libderiv->deriv_classes[4][5][9] = int_stack + 426433;
 Libderiv->deriv_classes[4][6][9] = int_stack + 426748;
 Libderiv->deriv_classes[4][7][9] = int_stack + 427168;
 Libderiv->deriv2_classes[4][4][9] = int_stack + 427708;
 Libderiv->deriv2_classes[4][5][9] = int_stack + 427933;
 Libderiv->deriv2_classes[4][6][9] = int_stack + 428248;
 Libderiv->deriv2_classes[4][7][9] = int_stack + 428668;
 Libderiv->deriv_classes[5][4][9] = int_stack + 429208;
 Libderiv->deriv_classes[5][5][9] = int_stack + 429523;
 Libderiv->deriv_classes[5][6][9] = int_stack + 429964;
 Libderiv->deriv_classes[5][7][9] = int_stack + 430552;
 Libderiv->deriv2_classes[5][4][9] = int_stack + 431308;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 431623;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 432064;
 Libderiv->deriv2_classes[5][7][9] = int_stack + 432652;
 Libderiv->deriv_classes[6][4][9] = int_stack + 433408;
 Libderiv->deriv_classes[6][5][9] = int_stack + 433828;
 Libderiv->deriv_classes[6][6][9] = int_stack + 434416;
 Libderiv->deriv_classes[6][7][9] = int_stack + 435200;
 Libderiv->deriv2_classes[6][4][9] = int_stack + 436208;
 Libderiv->deriv2_classes[6][5][9] = int_stack + 436628;
 Libderiv->deriv2_classes[6][6][9] = int_stack + 437216;
 Libderiv->deriv2_classes[6][7][9] = int_stack + 438000;
 Libderiv->deriv2_classes[7][4][9] = int_stack + 439008;
 Libderiv->deriv2_classes[7][5][9] = int_stack + 439548;
 Libderiv->deriv2_classes[7][6][9] = int_stack + 440304;
 Libderiv->deriv2_classes[7][7][9] = int_stack + 441312;
 Libderiv->deriv_classes[4][4][8] = int_stack + 442608;
 Libderiv->deriv_classes[4][5][8] = int_stack + 442833;
 Libderiv->deriv_classes[4][6][8] = int_stack + 443148;
 Libderiv->deriv_classes[4][7][8] = int_stack + 443568;
 Libderiv->deriv2_classes[4][4][8] = int_stack + 444108;
 Libderiv->deriv2_classes[4][5][8] = int_stack + 444333;
 Libderiv->deriv2_classes[4][6][8] = int_stack + 444648;
 Libderiv->deriv2_classes[4][7][8] = int_stack + 445068;
 Libderiv->deriv_classes[5][4][8] = int_stack + 445608;
 Libderiv->deriv_classes[5][5][8] = int_stack + 445923;
 Libderiv->deriv_classes[5][6][8] = int_stack + 446364;
 Libderiv->deriv_classes[5][7][8] = int_stack + 446952;
 Libderiv->deriv2_classes[5][4][8] = int_stack + 447708;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 448023;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 448464;
 Libderiv->deriv2_classes[5][7][8] = int_stack + 449052;
 Libderiv->deriv_classes[6][4][8] = int_stack + 449808;
 Libderiv->deriv_classes[6][5][8] = int_stack + 450228;
 Libderiv->deriv_classes[6][6][8] = int_stack + 450816;
 Libderiv->deriv_classes[6][7][8] = int_stack + 451600;
 Libderiv->deriv2_classes[6][4][8] = int_stack + 452608;
 Libderiv->deriv2_classes[6][5][8] = int_stack + 453028;
 Libderiv->deriv2_classes[6][6][8] = int_stack + 453616;
 Libderiv->deriv2_classes[6][7][8] = int_stack + 454400;
 Libderiv->deriv2_classes[7][4][8] = int_stack + 455408;
 Libderiv->deriv2_classes[7][5][8] = int_stack + 455948;
 Libderiv->deriv2_classes[7][6][8] = int_stack + 456704;
 Libderiv->deriv2_classes[7][7][8] = int_stack + 457712;
 Libderiv->deriv_classes[4][4][7] = int_stack + 459008;
 Libderiv->deriv_classes[4][5][7] = int_stack + 459233;
 Libderiv->deriv_classes[4][6][7] = int_stack + 459548;
 Libderiv->deriv_classes[4][7][7] = int_stack + 459968;
 Libderiv->deriv2_classes[4][4][7] = int_stack + 460508;
 Libderiv->deriv2_classes[4][5][7] = int_stack + 460733;
 Libderiv->deriv2_classes[4][6][7] = int_stack + 461048;
 Libderiv->deriv2_classes[4][7][7] = int_stack + 461468;
 Libderiv->deriv_classes[5][4][7] = int_stack + 462008;
 Libderiv->deriv_classes[5][5][7] = int_stack + 462323;
 Libderiv->deriv_classes[5][6][7] = int_stack + 462764;
 Libderiv->deriv_classes[5][7][7] = int_stack + 463352;
 Libderiv->deriv2_classes[5][4][7] = int_stack + 464108;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 464423;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 464864;
 Libderiv->deriv2_classes[5][7][7] = int_stack + 465452;
 Libderiv->deriv_classes[6][4][7] = int_stack + 466208;
 Libderiv->deriv_classes[6][5][7] = int_stack + 466628;
 Libderiv->deriv_classes[6][6][7] = int_stack + 467216;
 Libderiv->deriv_classes[6][7][7] = int_stack + 468000;
 Libderiv->deriv2_classes[6][4][7] = int_stack + 469008;
 Libderiv->deriv2_classes[6][5][7] = int_stack + 469428;
 Libderiv->deriv2_classes[6][6][7] = int_stack + 470016;
 Libderiv->deriv2_classes[6][7][7] = int_stack + 470800;
 Libderiv->deriv2_classes[7][4][7] = int_stack + 471808;
 Libderiv->deriv2_classes[7][5][7] = int_stack + 472348;
 Libderiv->deriv2_classes[7][6][7] = int_stack + 473104;
 Libderiv->deriv2_classes[7][7][7] = int_stack + 474112;
 Libderiv->deriv_classes[4][4][6] = int_stack + 475408;
 Libderiv->deriv_classes[4][5][6] = int_stack + 475633;
 Libderiv->deriv_classes[4][6][6] = int_stack + 475948;
 Libderiv->deriv_classes[4][7][6] = int_stack + 476368;
 Libderiv->deriv2_classes[4][4][6] = int_stack + 476908;
 Libderiv->deriv2_classes[4][5][6] = int_stack + 477133;
 Libderiv->deriv2_classes[4][6][6] = int_stack + 477448;
 Libderiv->deriv2_classes[4][7][6] = int_stack + 477868;
 Libderiv->deriv_classes[5][4][6] = int_stack + 478408;
 Libderiv->deriv_classes[5][5][6] = int_stack + 478723;
 Libderiv->deriv_classes[5][6][6] = int_stack + 479164;
 Libderiv->deriv_classes[5][7][6] = int_stack + 479752;
 Libderiv->deriv2_classes[5][4][6] = int_stack + 480508;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 480823;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 481264;
 Libderiv->deriv2_classes[5][7][6] = int_stack + 481852;
 Libderiv->dvrr_classes[6][4] = int_stack + 482608;
 Libderiv->deriv_classes[6][4][6] = int_stack + 483028;
 Libderiv->dvrr_classes[6][5] = int_stack + 483448;
 Libderiv->deriv_classes[6][5][6] = int_stack + 484036;
 Libderiv->dvrr_classes[6][6] = int_stack + 484624;
 Libderiv->deriv_classes[6][6][6] = int_stack + 485408;
 Libderiv->deriv_classes[6][7][6] = int_stack + 486192;
 Libderiv->deriv2_classes[6][4][6] = int_stack + 487200;
 Libderiv->deriv2_classes[6][5][6] = int_stack + 487620;
 Libderiv->deriv2_classes[6][6][6] = int_stack + 488208;
 Libderiv->deriv2_classes[6][7][6] = int_stack + 488992;
 Libderiv->deriv_classes[7][4][0] = int_stack + 490000;
 Libderiv->deriv2_classes[7][4][6] = int_stack + 490540;
 Libderiv->deriv_classes[7][5][0] = int_stack + 491080;
 Libderiv->deriv2_classes[7][5][6] = int_stack + 491836;
 Libderiv->deriv_classes[7][6][0] = int_stack + 492592;
 Libderiv->deriv2_classes[7][6][6] = int_stack + 493600;
 Libderiv->deriv2_classes[7][7][6] = int_stack + 494608;
 Libderiv->deriv_classes[4][4][2] = int_stack + 495904;
 Libderiv->deriv_classes[4][5][2] = int_stack + 496129;
 Libderiv->deriv_classes[4][6][2] = int_stack + 496444;
 Libderiv->deriv_classes[4][7][2] = int_stack + 496864;
 Libderiv->deriv2_classes[4][4][2] = int_stack + 497404;
 Libderiv->deriv2_classes[4][5][2] = int_stack + 497629;
 Libderiv->deriv2_classes[4][6][2] = int_stack + 497944;
 Libderiv->deriv2_classes[4][7][2] = int_stack + 498364;
 Libderiv->deriv_classes[5][4][2] = int_stack + 498904;
 Libderiv->deriv_classes[5][5][2] = int_stack + 499219;
 Libderiv->deriv_classes[5][6][2] = int_stack + 499660;
 Libderiv->deriv_classes[5][7][2] = int_stack + 500248;
 Libderiv->deriv2_classes[5][4][2] = int_stack + 501004;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 501319;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 501760;
 Libderiv->deriv2_classes[5][7][2] = int_stack + 502348;
 Libderiv->deriv_classes[6][4][2] = int_stack + 503104;
 Libderiv->deriv_classes[6][5][2] = int_stack + 503524;
 Libderiv->deriv_classes[6][6][2] = int_stack + 504112;
 Libderiv->deriv_classes[6][7][2] = int_stack + 504896;
 Libderiv->deriv2_classes[6][4][2] = int_stack + 505904;
 Libderiv->deriv2_classes[6][5][2] = int_stack + 506324;
 Libderiv->deriv2_classes[6][6][2] = int_stack + 506912;
 Libderiv->deriv2_classes[6][7][2] = int_stack + 507696;
 Libderiv->deriv2_classes[7][4][2] = int_stack + 508704;
 Libderiv->deriv2_classes[7][5][2] = int_stack + 509244;
 Libderiv->deriv2_classes[7][6][2] = int_stack + 510000;
 Libderiv->deriv2_classes[7][7][2] = int_stack + 511008;
 Libderiv->deriv_classes[4][4][1] = int_stack + 512304;
 Libderiv->deriv_classes[4][5][1] = int_stack + 512529;
 Libderiv->deriv_classes[4][6][1] = int_stack + 512844;
 Libderiv->deriv_classes[4][7][1] = int_stack + 513264;
 Libderiv->deriv2_classes[4][4][1] = int_stack + 513804;
 Libderiv->deriv2_classes[4][5][1] = int_stack + 514029;
 Libderiv->deriv2_classes[4][6][1] = int_stack + 514344;
 Libderiv->deriv2_classes[4][7][1] = int_stack + 514764;
 Libderiv->deriv_classes[5][4][1] = int_stack + 515304;
 Libderiv->deriv_classes[5][5][1] = int_stack + 515619;
 Libderiv->deriv_classes[5][6][1] = int_stack + 516060;
 Libderiv->deriv_classes[5][7][1] = int_stack + 516648;
 Libderiv->deriv2_classes[5][4][1] = int_stack + 517404;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 517719;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 518160;
 Libderiv->deriv2_classes[5][7][1] = int_stack + 518748;
 Libderiv->deriv_classes[6][4][1] = int_stack + 519504;
 Libderiv->deriv_classes[6][5][1] = int_stack + 519924;
 Libderiv->deriv_classes[6][6][1] = int_stack + 520512;
 Libderiv->deriv_classes[6][7][1] = int_stack + 521296;
 Libderiv->deriv2_classes[6][4][1] = int_stack + 522304;
 Libderiv->deriv2_classes[6][5][1] = int_stack + 522724;
 Libderiv->deriv2_classes[6][6][1] = int_stack + 523312;
 Libderiv->deriv2_classes[6][7][1] = int_stack + 524096;
 Libderiv->deriv2_classes[7][4][1] = int_stack + 525104;
 Libderiv->deriv2_classes[7][5][1] = int_stack + 525644;
 Libderiv->deriv2_classes[7][6][1] = int_stack + 526400;
 Libderiv->deriv2_classes[7][7][1] = int_stack + 527408;
 Libderiv->dvrr_classes[4][4] = int_stack + 528704;
 Libderiv->dvrr_classes[4][5] = int_stack + 528929;
 Libderiv->dvrr_classes[4][6] = int_stack + 529244;
 Libderiv->dvrr_classes[4][7] = int_stack + 529664;
 Libderiv->deriv_classes[4][4][0] = int_stack + 530204;
 Libderiv->deriv_classes[4][5][0] = int_stack + 530429;
 Libderiv->deriv_classes[4][6][0] = int_stack + 530744;
 Libderiv->deriv_classes[4][7][0] = int_stack + 531164;
 Libderiv->deriv2_classes[4][4][0] = int_stack + 531704;
 Libderiv->deriv2_classes[4][5][0] = int_stack + 531929;
 Libderiv->deriv2_classes[4][6][0] = int_stack + 532244;
 Libderiv->deriv2_classes[4][7][0] = int_stack + 532664;
 Libderiv->dvrr_classes[5][4] = int_stack + 533204;
 Libderiv->dvrr_classes[5][5] = int_stack + 533519;
 Libderiv->dvrr_classes[5][6] = int_stack + 533960;
 Libderiv->dvrr_classes[5][7] = int_stack + 534548;
 Libderiv->deriv_classes[5][4][0] = int_stack + 535304;
 Libderiv->deriv_classes[5][5][0] = int_stack + 535619;
 Libderiv->deriv_classes[5][6][0] = int_stack + 536060;
 Libderiv->deriv_classes[5][7][0] = int_stack + 536648;
 Libderiv->deriv2_classes[5][4][0] = int_stack + 537404;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 537719;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 538160;
 Libderiv->deriv2_classes[5][7][0] = int_stack + 538748;
 Libderiv->deriv_classes[6][4][0] = int_stack + 539504;
 Libderiv->deriv_classes[6][5][0] = int_stack + 539924;
 Libderiv->deriv_classes[6][6][0] = int_stack + 540512;
 Libderiv->deriv_classes[6][7][0] = int_stack + 541296;
 Libderiv->deriv2_classes[6][4][0] = int_stack + 542304;
 Libderiv->deriv2_classes[6][5][0] = int_stack + 542724;
 Libderiv->deriv2_classes[6][6][0] = int_stack + 543312;
 Libderiv->deriv2_classes[6][7][0] = int_stack + 544096;
 Libderiv->deriv2_classes[7][4][0] = int_stack + 545104;
 Libderiv->deriv2_classes[7][5][0] = int_stack + 545644;
 Libderiv->deriv2_classes[7][6][0] = int_stack + 546400;
 Libderiv->deriv2_classes[7][7][0] = int_stack + 547408;
 memset(int_stack,0,4389632);

 Libderiv->dvrr_stack = int_stack + 2140696;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_gfgf(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+548704,int_stack+528929,int_stack+528704,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+549379,int_stack+529244,int_stack+528929,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+550324,int_stack+549379,int_stack+548704,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+551674,int_stack+393633,int_stack+393408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528704,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+552349,int_stack+393948,int_stack+393633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528929,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+553294,int_stack+552349,int_stack+551674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+548704,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+554644,int_stack+394368,int_stack+393948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+529244,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+555904,int_stack+554644,int_stack+552349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+549379,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+557794,int_stack+555904,int_stack+553294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+550324,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+554644,int_stack+533519,int_stack+533204,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+555589,int_stack+533960,int_stack+533519,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+560044,int_stack+555589,int_stack+554644,21);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+561934,int_stack+396723,int_stack+396408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533204,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+562879,int_stack+397164,int_stack+396723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533519,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+564202,int_stack+562879,int_stack+561934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554644,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+566092,int_stack+397752,int_stack+397164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533960,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+567856,int_stack+566092,int_stack+562879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+555589,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+570502,int_stack+567856,int_stack+564202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+560044,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+573652,int_stack+570502,int_stack+557794,150);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+566092,int_stack+483448,int_stack+482608,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+567352,int_stack+484624,int_stack+483448,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+580402,int_stack+567352,int_stack+566092,28);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+569116,int_stack+401028,int_stack+400608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482608,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+582922,int_stack+401616,int_stack+401028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483448,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+584686,int_stack+582922,int_stack+569116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+566092,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+587206,int_stack+402400,int_stack+401616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484624,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+589558,int_stack+587206,int_stack+582922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+567352,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+593086,int_stack+589558,int_stack+584686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+580402,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+597286,int_stack+593086,int_stack+570502,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+606736,int_stack+597286,int_stack+573652,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+587206,int_stack+233220,int_stack+231600,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+588826,int_stack+6480,int_stack+233220,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+620236,int_stack+588826,int_stack+587206,36);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+591094,int_stack+171160,int_stack+170080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+231600,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+623476,int_stack+172672,int_stack+171160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233220,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+625744,int_stack+623476,int_stack+591094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+587206,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+628984,int_stack+0,int_stack+172672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6480,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+632008,int_stack+628984,int_stack+623476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588826,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+636544,int_stack+632008,int_stack+625744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+620236,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+641944,int_stack+636544,int_stack+593086,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+654544,int_stack+641944,int_stack+597286,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+628984,int_stack+410033,int_stack+409808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528704, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+629659,int_stack+410348,int_stack+410033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528929, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+630604,int_stack+629659,int_stack+628984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+548704, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+631954,int_stack+410768,int_stack+410348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+529244, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+633214,int_stack+631954,int_stack+629659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+549379, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+635104,int_stack+633214,int_stack+630604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+550324, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+631954,int_stack+413123,int_stack+412808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533204, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+632899,int_stack+413564,int_stack+413123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533519, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+637354,int_stack+632899,int_stack+631954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554644, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+639244,int_stack+414152,int_stack+413564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533960, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+641008,int_stack+639244,int_stack+632899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+555589, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+643654,int_stack+641008,int_stack+637354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+560044, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+646804,int_stack+643654,int_stack+635104,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+639244,int_stack+417428,int_stack+417008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482608, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+640504,int_stack+418016,int_stack+417428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483448, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+673444,int_stack+640504,int_stack+639244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+566092, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+675964,int_stack+418800,int_stack+418016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484624, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+678316,int_stack+675964,int_stack+640504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+567352, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+681844,int_stack+678316,int_stack+673444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+580402, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+686044,int_stack+681844,int_stack+643654,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+695494,int_stack+686044,int_stack+646804,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+675964,int_stack+183464,int_stack+182384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+231600, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+677584,int_stack+184976,int_stack+183464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233220, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+708994,int_stack+677584,int_stack+675964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+587206, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+712234,int_stack+1296,int_stack+184976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6480, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+715258,int_stack+712234,int_stack+677584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588826, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+719794,int_stack+715258,int_stack+708994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+620236, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+725194,int_stack+719794,int_stack+681844,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+737794,int_stack+725194,int_stack+686044,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+712234,int_stack+426433,int_stack+426208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528704, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+712909,int_stack+426748,int_stack+426433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528929, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+713854,int_stack+712909,int_stack+712234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+548704, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+715204,int_stack+427168,int_stack+426748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+529244, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+716464,int_stack+715204,int_stack+712909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+549379, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+718354,int_stack+716464,int_stack+713854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+550324, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+715204,int_stack+429523,int_stack+429208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533204, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716149,int_stack+429964,int_stack+429523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533519, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+720604,int_stack+716149,int_stack+715204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554644, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+722494,int_stack+430552,int_stack+429964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533960, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+724258,int_stack+722494,int_stack+716149, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+555589, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+726904,int_stack+724258,int_stack+720604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+560044, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+730054,int_stack+726904,int_stack+718354,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+722494,int_stack+433828,int_stack+433408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482608, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+723754,int_stack+434416,int_stack+433828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483448, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+0,int_stack+723754,int_stack+722494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+566092, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+756694,int_stack+435200,int_stack+434416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484624, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+759046,int_stack+756694,int_stack+723754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+567352, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+762574,int_stack+759046,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+580402, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+766774,int_stack+762574,int_stack+726904,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+776224,int_stack+766774,int_stack+730054,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+756694,int_stack+195768,int_stack+194688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+231600, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+758314,int_stack+197280,int_stack+195768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233220, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+789724,int_stack+758314,int_stack+756694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+587206, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+792964,int_stack+2592,int_stack+197280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6480, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+795988,int_stack+792964,int_stack+758314, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588826, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+800524,int_stack+795988,int_stack+789724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+620236, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+805924,int_stack+800524,int_stack+762574,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+818524,int_stack+805924,int_stack+766774,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+792964,int_stack+442833,int_stack+442608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+793639,int_stack+443148,int_stack+442833, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528929, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+794584,int_stack+793639,int_stack+792964, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+548704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+795934,int_stack+443568,int_stack+443148, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+529244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+797194,int_stack+795934,int_stack+793639, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+549379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+799084,int_stack+797194,int_stack+794584, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+550324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+795934,int_stack+445923,int_stack+445608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+796879,int_stack+446364,int_stack+445923, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+801334,int_stack+796879,int_stack+795934, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+803224,int_stack+446952,int_stack+446364, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+804988,int_stack+803224,int_stack+796879, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+555589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+807634,int_stack+804988,int_stack+801334, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+560044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+810784,int_stack+807634,int_stack+799084,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+803224,int_stack+450228,int_stack+449808, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+804484,int_stack+450816,int_stack+450228, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+837424,int_stack+804484,int_stack+803224, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+566092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+839944,int_stack+451600,int_stack+450816, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+842296,int_stack+839944,int_stack+804484, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+567352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+845824,int_stack+842296,int_stack+837424, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+580402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+850024,int_stack+845824,int_stack+807634,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+859474,int_stack+850024,int_stack+810784,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+839944,int_stack+208072,int_stack+206992, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+231600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+841564,int_stack+209584,int_stack+208072, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+872974,int_stack+841564,int_stack+839944, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+587206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+876214,int_stack+3888,int_stack+209584, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+879238,int_stack+876214,int_stack+841564, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+883774,int_stack+879238,int_stack+872974, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+620236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+889174,int_stack+883774,int_stack+845824,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+901774,int_stack+889174,int_stack+850024,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+876214,int_stack+459233,int_stack+459008, 0.0, zero_stack, 1.0, int_stack+528704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+876889,int_stack+459548,int_stack+459233, 0.0, zero_stack, 1.0, int_stack+528929, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+877834,int_stack+876889,int_stack+876214, 0.0, zero_stack, 1.0, int_stack+548704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+879184,int_stack+459968,int_stack+459548, 0.0, zero_stack, 1.0, int_stack+529244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+880444,int_stack+879184,int_stack+876889, 0.0, zero_stack, 1.0, int_stack+549379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+882334,int_stack+880444,int_stack+877834, 0.0, zero_stack, 1.0, int_stack+550324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+879184,int_stack+462323,int_stack+462008, 0.0, zero_stack, 1.0, int_stack+533204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+880129,int_stack+462764,int_stack+462323, 0.0, zero_stack, 1.0, int_stack+533519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+884584,int_stack+880129,int_stack+879184, 0.0, zero_stack, 1.0, int_stack+554644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+886474,int_stack+463352,int_stack+462764, 0.0, zero_stack, 1.0, int_stack+533960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+888238,int_stack+886474,int_stack+880129, 0.0, zero_stack, 1.0, int_stack+555589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+890884,int_stack+888238,int_stack+884584, 0.0, zero_stack, 1.0, int_stack+560044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+894034,int_stack+890884,int_stack+882334,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+886474,int_stack+466628,int_stack+466208, 0.0, zero_stack, 1.0, int_stack+482608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+887734,int_stack+467216,int_stack+466628, 0.0, zero_stack, 1.0, int_stack+483448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+2520,int_stack+887734,int_stack+886474, 0.0, zero_stack, 1.0, int_stack+566092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+920674,int_stack+468000,int_stack+467216, 0.0, zero_stack, 1.0, int_stack+484624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+923026,int_stack+920674,int_stack+887734, 0.0, zero_stack, 1.0, int_stack+567352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+926554,int_stack+923026,int_stack+2520, 0.0, zero_stack, 1.0, int_stack+580402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+930754,int_stack+926554,int_stack+890884,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+940204,int_stack+930754,int_stack+894034,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+920674,int_stack+220376,int_stack+219296, 0.0, zero_stack, 1.0, int_stack+231600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+922294,int_stack+221888,int_stack+220376, 0.0, zero_stack, 1.0, int_stack+233220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+953704,int_stack+922294,int_stack+920674, 0.0, zero_stack, 1.0, int_stack+587206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+956944,int_stack+5184,int_stack+221888, 0.0, zero_stack, 1.0, int_stack+6480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+959968,int_stack+956944,int_stack+922294, 0.0, zero_stack, 1.0, int_stack+588826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+964504,int_stack+959968,int_stack+953704, 0.0, zero_stack, 1.0, int_stack+620236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+969904,int_stack+964504,int_stack+926554,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+982504,int_stack+969904,int_stack+930754,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+956944,int_stack+475633,int_stack+475408, 1.0, int_stack+528704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+957619,int_stack+475948,int_stack+475633, 1.0, int_stack+528929, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+958564,int_stack+957619,int_stack+956944, 1.0, int_stack+548704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+959914,int_stack+476368,int_stack+475948, 1.0, int_stack+529244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+961174,int_stack+959914,int_stack+957619, 1.0, int_stack+549379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+963064,int_stack+961174,int_stack+958564, 1.0, int_stack+550324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+959914,int_stack+478723,int_stack+478408, 1.0, int_stack+533204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+960859,int_stack+479164,int_stack+478723, 1.0, int_stack+533519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+965314,int_stack+960859,int_stack+959914, 1.0, int_stack+554644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+967204,int_stack+479752,int_stack+479164, 1.0, int_stack+533960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+968968,int_stack+967204,int_stack+960859, 1.0, int_stack+555589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+971614,int_stack+968968,int_stack+965314, 1.0, int_stack+560044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+974764,int_stack+971614,int_stack+963064,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+967204,int_stack+484036,int_stack+483028, 1.0, int_stack+482608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+968464,int_stack+485408,int_stack+484036, 1.0, int_stack+483448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1001404,int_stack+968464,int_stack+967204, 1.0, int_stack+566092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1003924,int_stack+486192,int_stack+485408, 1.0, int_stack+484624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1006276,int_stack+1003924,int_stack+968464, 1.0, int_stack+567352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1009804,int_stack+1006276,int_stack+1001404, 1.0, int_stack+580402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1014004,int_stack+1009804,int_stack+971614,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1023454,int_stack+1014004,int_stack+974764,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1003924,int_stack+233976,int_stack+232140, 1.0, int_stack+231600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1005544,int_stack+235488,int_stack+233976, 1.0, int_stack+233220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1036954,int_stack+1005544,int_stack+1003924, 1.0, int_stack+587206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1040194,int_stack+7488,int_stack+235488, 1.0, int_stack+6480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1043218,int_stack+1040194,int_stack+1005544, 1.0, int_stack+588826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1047754,int_stack+1043218,int_stack+1036954, 1.0, int_stack+620236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1053154,int_stack+1047754,int_stack+1009804,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1065754,int_stack+1053154,int_stack+1014004,150);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+566092,int_stack+529664,int_stack+529244,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+620236,int_stack+566092,int_stack+549379,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1040194,int_stack+620236,int_stack+550324,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+620236,int_stack+534548,int_stack+533960,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1042444,int_stack+620236,int_stack+555589,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+554644,int_stack+1042444,int_stack+560044,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+1042444,int_stack+554644,int_stack+1040194,150);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1049194,int_stack+11376,int_stack+484624,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1051546,int_stack+1049194,int_stack+567352,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1055074,int_stack+1051546,int_stack+580402,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+1055074,int_stack+554644,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1094104,int_stack+1084654,int_stack+1042444,150);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+580402,int_stack+496129,int_stack+495904,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+581077,int_stack+496444,int_stack+496129,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1049194,int_stack+581077,int_stack+580402,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1050544,int_stack+496864,int_stack+496444,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+560044,int_stack+1050544,int_stack+581077,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1050544,int_stack+560044,int_stack+1049194,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+560044,int_stack+499219,int_stack+498904,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1052794,int_stack+499660,int_stack+499219,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1059274,int_stack+1052794,int_stack+560044,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1061164,int_stack+500248,int_stack+499660,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1062928,int_stack+1061164,int_stack+1052794,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+620236,int_stack+1062928,int_stack+1059274,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+1107604,int_stack+620236,int_stack+1050544, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1040194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1061164,int_stack+503524,int_stack+503104,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1062424,int_stack+504112,int_stack+503524,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+566092,int_stack+1062424,int_stack+1061164,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+587206,int_stack+504896,int_stack+504112,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+5040,int_stack+587206,int_stack+1062424,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1114354,int_stack+5040,int_stack+566092,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1118554,int_stack+1114354,int_stack+620236, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1128004,int_stack+1118554,int_stack+1107604, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1042444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+5040,int_stack+296280,int_stack+295200,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+587206,int_stack+297792,int_stack+296280,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1141504,int_stack+587206,int_stack+5040,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1144744,int_stack+8784,int_stack+297792,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1147768,int_stack+1144744,int_stack+587206,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1152304,int_stack+1147768,int_stack+1141504,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1157704,int_stack+1152304,int_stack+1114354, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1055074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1170304,int_stack+1157704,int_stack+1118554, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1144744,int_stack+512529,int_stack+512304,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+560989,int_stack+512844,int_stack+512529,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1145419,int_stack+560989,int_stack+1144744,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1146769,int_stack+513264,int_stack+512844,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1148029,int_stack+1146769,int_stack+560989,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1149919,int_stack+1148029,int_stack+1145419,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1146769,int_stack+515619,int_stack+515304,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1147714,int_stack+516060,int_stack+515619,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1152169,int_stack+1147714,int_stack+1146769,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1154059,int_stack+516648,int_stack+516060,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1155823,int_stack+1154059,int_stack+1147714,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1158469,int_stack+1155823,int_stack+1152169,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+1161619,int_stack+1158469,int_stack+1149919, 0.0, zero_stack, 1.0, int_stack+1040194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1154059,int_stack+519924,int_stack+519504,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1155319,int_stack+520512,int_stack+519924,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+6660,int_stack+1155319,int_stack+1154059,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+548704,int_stack+521296,int_stack+520512,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1189204,int_stack+548704,int_stack+1155319,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1192732,int_stack+1189204,int_stack+6660,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1196932,int_stack+1192732,int_stack+1158469, 0.0, zero_stack, 1.0, int_stack+554644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1206382,int_stack+1196932,int_stack+1161619, 0.0, zero_stack, 1.0, int_stack+1042444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+589474,int_stack+368584,int_stack+367504,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1189204,int_stack+370096,int_stack+368584,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1219882,int_stack+1189204,int_stack+589474,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1223122,int_stack+10080,int_stack+370096,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1226146,int_stack+1223122,int_stack+1189204,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1230682,int_stack+1226146,int_stack+1219882,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1236082,int_stack+1230682,int_stack+1192732, 0.0, zero_stack, 1.0, int_stack+1055074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1248682,int_stack+1236082,int_stack+1196932, 0.0, zero_stack, 1.0, int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1223122,int_stack+530429,int_stack+530204,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1223797,int_stack+530744,int_stack+530429,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1224742,int_stack+1223797,int_stack+1223122,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1191472,int_stack+531164,int_stack+530744,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1226092,int_stack+1191472,int_stack+1223797,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1227982,int_stack+1226092,int_stack+1224742,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1226092,int_stack+535619,int_stack+535304,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1230232,int_stack+536060,int_stack+535619,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1231555,int_stack+1230232,int_stack+1226092,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1233445,int_stack+536648,int_stack+536060,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1235209,int_stack+1233445,int_stack+1230232,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1237855,int_stack+1235209,int_stack+1231555,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+1241005,int_stack+1237855,int_stack+1227982, 1.0, int_stack+1040194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1191472,int_stack+539924,int_stack+539504,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1040194,int_stack+540512,int_stack+539924,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1233445,int_stack+1040194,int_stack+1191472,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+548704,int_stack+541296,int_stack+540512,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1267582,int_stack+548704,int_stack+1040194,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1271110,int_stack+1267582,int_stack+1233445,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1275310,int_stack+1271110,int_stack+1237855, 1.0, int_stack+554644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1284760,int_stack+1275310,int_stack+1241005, 1.0, int_stack+1042444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+554644,int_stack+491080,int_stack+490000,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1267582,int_stack+492592,int_stack+491080,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1041958,int_stack+1267582,int_stack+554644,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1045198,int_stack+12384,int_stack+492592,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1298260,int_stack+1045198,int_stack+1267582,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1302796,int_stack+1298260,int_stack+1041958,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1308196,int_stack+1302796,int_stack+1271110, 1.0, int_stack+1055074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1320796,int_stack+1308196,int_stack+1275310, 1.0, int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+13905,int_stack+13680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+393408,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+14220,int_stack+13905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+393633,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+551674,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+14640,int_stack+14220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+393948,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+552349,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+553294,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+15495,int_stack+15180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+396408,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+15936,int_stack+15495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+396723,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+561934,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088929,int_stack+16524,int_stack+15936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+397164,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1090693,int_stack+1088929,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+562879,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1298260,int_stack+1090693,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+564202,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+1301410,int_stack+1298260,int_stack+1086679,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+17700,int_stack+17280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+400608,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1084654,int_stack+18288,int_stack+17700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+401028,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1086418,int_stack+1084654,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+569116,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088938,int_stack+19072,int_stack+18288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+401616,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1308160,int_stack+1088938,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+582922,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1088938,int_stack+1308160,int_stack+1086418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+584686,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1308160,int_stack+1088938,int_stack+1298260,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1339696,int_stack+1308160,int_stack+1301410,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1298260,int_stack+20620,int_stack+20080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+170080,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1299880,int_stack+21376,int_stack+20620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+171160,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1302148,int_stack+1299880,int_stack+1298260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+591094,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1317610,int_stack+22384,int_stack+21376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+172672,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9180,int_stack+1317610,int_stack+1299880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+623476,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+13716,int_stack+9180,int_stack+1302148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+625744,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+13716,int_stack+1088938,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1365796,int_stack+1353196,int_stack+1308160,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1353196,int_stack+23905,int_stack+23680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393408, 1.0, int_stack+409808,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+24220,int_stack+23905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393633, 1.0, int_stack+410033,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353871,int_stack+1227037,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551674, 1.0, int_stack+628984,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+24640,int_stack+24220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393948, 1.0, int_stack+410348,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+552349, 1.0, int_stack+629659,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1355221,int_stack+1235965,int_stack+1353871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+553294, 1.0, int_stack+630604,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+25495,int_stack+25180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396408, 1.0, int_stack+412808,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+25936,int_stack+25495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396723, 1.0, int_stack+413123,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353196,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+561934, 1.0, int_stack+631954,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1357471,int_stack+26524,int_stack+25936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397164, 1.0, int_stack+413564,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1359235,int_stack+1357471,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+562879, 1.0, int_stack+632899,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1361881,int_stack+1359235,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+564202, 1.0, int_stack+637354,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+1361881,int_stack+1355221,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+27700,int_stack+27280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400608, 1.0, int_stack+417008,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1353196,int_stack+28288,int_stack+27700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401028, 1.0, int_stack+417428,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1354960,int_stack+1353196,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569116, 1.0, int_stack+639244,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1357480,int_stack+29072,int_stack+28288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401616, 1.0, int_stack+418016,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15930,int_stack+1357480,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+582922, 1.0, int_stack+640504,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1357480,int_stack+15930,int_stack+1354960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+584686, 1.0, int_stack+673444,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+1357480,int_stack+1361881,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+15930,int_stack+1084654,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+30620,int_stack+30080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170080, 1.0, int_stack+182384,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+31376,int_stack+30620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171160, 1.0, int_stack+183464,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353196,int_stack+10800,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+591094, 1.0, int_stack+675964,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1361680,int_stack+32384,int_stack+31376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172672, 1.0, int_stack+184976,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1298260,int_stack+1361680,int_stack+10800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+623476, 1.0, int_stack+677584,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+1298260,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+625744, 1.0, int_stack+708994,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1298260,int_stack+9180,int_stack+1357480,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1384696,int_stack+1298260,int_stack+1084654,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+33905,int_stack+33680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+409808, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+34220,int_stack+33905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+410033, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+628984, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+34640,int_stack+34220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+410348, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+629659, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+630604, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+35495,int_stack+35180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+412808, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+35936,int_stack+35495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+413123, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+631954, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088929,int_stack+36524,int_stack+35936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+413564, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1090693,int_stack+1088929,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+632899, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1298260,int_stack+1090693,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+637354, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+1298260,int_stack+1086679,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+37700,int_stack+37280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+417008, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1084654,int_stack+38288,int_stack+37700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+417428, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1086418,int_stack+1084654,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+639244, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088938,int_stack+39072,int_stack+38288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+418016, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1301410,int_stack+1088938,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+640504, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1088938,int_stack+1301410,int_stack+1086418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+673444, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1301410,int_stack+1088938,int_stack+1298260,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1403596,int_stack+1301410,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+40620,int_stack+40080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+182384, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+41376,int_stack+40620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+183464, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1310860,int_stack+10800,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+675964, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1298260,int_stack+42384,int_stack+41376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+184976, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1314100,int_stack+1298260,int_stack+10800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+677584, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+1314100,int_stack+1310860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+708994, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+9180,int_stack+1088938,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1417096,int_stack+1353196,int_stack+1301410,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1353196,int_stack+43905,int_stack+43680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393408, 0.0, zero_stack, 1.0, int_stack+426208,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+44220,int_stack+43905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393633, 0.0, zero_stack, 1.0, int_stack+426433,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353871,int_stack+1227037,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551674, 0.0, zero_stack, 1.0, int_stack+712234,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+44640,int_stack+44220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393948, 0.0, zero_stack, 1.0, int_stack+426748,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+552349, 0.0, zero_stack, 1.0, int_stack+712909,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1355221,int_stack+1235965,int_stack+1353871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+553294, 0.0, zero_stack, 1.0, int_stack+713854,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+45495,int_stack+45180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396408, 0.0, zero_stack, 1.0, int_stack+429208,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+45936,int_stack+45495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396723, 0.0, zero_stack, 1.0, int_stack+429523,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353196,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+561934, 0.0, zero_stack, 1.0, int_stack+715204,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1357471,int_stack+46524,int_stack+45936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397164, 0.0, zero_stack, 1.0, int_stack+429964,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1359235,int_stack+1357471,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+562879, 0.0, zero_stack, 1.0, int_stack+716149,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1361881,int_stack+1359235,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+564202, 0.0, zero_stack, 1.0, int_stack+720604,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+1361881,int_stack+1355221,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+47700,int_stack+47280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400608, 0.0, zero_stack, 1.0, int_stack+433408,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1353196,int_stack+48288,int_stack+47700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401028, 0.0, zero_stack, 1.0, int_stack+433828,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1354960,int_stack+1353196,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569116, 0.0, zero_stack, 1.0, int_stack+722494,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1357480,int_stack+49072,int_stack+48288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401616, 0.0, zero_stack, 1.0, int_stack+434416,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1298260,int_stack+1357480,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+582922, 0.0, zero_stack, 1.0, int_stack+723754,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1357480,int_stack+1298260,int_stack+1354960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+584686, 0.0, zero_stack, 1.0, int_stack+0,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+1357480,int_stack+1361881,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1298260,int_stack+1084654,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+50620,int_stack+50080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170080, 0.0, zero_stack, 1.0, int_stack+194688,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+51376,int_stack+50620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171160, 0.0, zero_stack, 1.0, int_stack+195768,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1311760,int_stack+10800,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+591094, 0.0, zero_stack, 1.0, int_stack+756694,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1315000,int_stack+52384,int_stack+51376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172672, 0.0, zero_stack, 1.0, int_stack+197280,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29430,int_stack+1315000,int_stack+10800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+623476, 0.0, zero_stack, 1.0, int_stack+758314,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1315000,int_stack+29430,int_stack+1311760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+625744, 0.0, zero_stack, 1.0, int_stack+789724,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+1315000,int_stack+1357480,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1435996,int_stack+29430,int_stack+1084654,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+53905,int_stack+53680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409808, 1.0, int_stack+426208, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+54220,int_stack+53905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410033, 1.0, int_stack+426433, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+628984, 1.0, int_stack+712234, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+54640,int_stack+54220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410348, 1.0, int_stack+426748, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+629659, 1.0, int_stack+712909, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+630604, 1.0, int_stack+713854, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+55495,int_stack+55180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412808, 1.0, int_stack+429208, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+55936,int_stack+55495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+413123, 1.0, int_stack+429523, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+631954, 1.0, int_stack+715204, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088929,int_stack+56524,int_stack+55936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+413564, 1.0, int_stack+429964, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1090693,int_stack+1088929,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+632899, 1.0, int_stack+716149, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+29430,int_stack+1090693,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+637354, 1.0, int_stack+720604, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+29430,int_stack+1086679,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+57700,int_stack+57280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+417008, 1.0, int_stack+433408, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1084654,int_stack+58288,int_stack+57700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+417428, 1.0, int_stack+433828, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1086418,int_stack+1084654,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+639244, 1.0, int_stack+722494, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088938,int_stack+59072,int_stack+58288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+418016, 1.0, int_stack+434416, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32580,int_stack+1088938,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+640504, 1.0, int_stack+723754, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1088938,int_stack+32580,int_stack+1086418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+673444, 1.0, int_stack+0, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+32580,int_stack+1088938,int_stack+29430,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+42030,int_stack+32580,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+60620,int_stack+60080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182384, 1.0, int_stack+194688, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+61376,int_stack+60620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183464, 1.0, int_stack+195768, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+55530,int_stack+10800,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+675964, 1.0, int_stack+756694, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29430,int_stack+62384,int_stack+61376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+184976, 1.0, int_stack+197280, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+58770,int_stack+29430,int_stack+10800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677584, 1.0, int_stack+758314, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+58770,int_stack+55530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+708994, 1.0, int_stack+789724, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+9180,int_stack+1088938,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1454896,int_stack+1353196,int_stack+32580,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1353196,int_stack+63905,int_stack+63680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+426208, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+64220,int_stack+63905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+426433, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353871,int_stack+1227037,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+712234, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+64640,int_stack+64220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+426748, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+712909, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1355221,int_stack+1235965,int_stack+1353871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+713854, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+65495,int_stack+65180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+429208, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+65936,int_stack+65495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+429523, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353196,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+715204, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1357471,int_stack+66524,int_stack+65936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+429964, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1359235,int_stack+1357471,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+716149, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1361881,int_stack+1359235,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+720604, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+1361881,int_stack+1355221,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+67700,int_stack+67280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+433408, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1353196,int_stack+68288,int_stack+67700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+433828, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1354960,int_stack+1353196,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+722494, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1357480,int_stack+69072,int_stack+68288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+434416, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+55530,int_stack+1357480,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+723754, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1357480,int_stack+55530,int_stack+1354960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+1357480,int_stack+1361881,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+55530,int_stack+1084654,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+70620,int_stack+70080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+194688, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+71376,int_stack+70620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+195768, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353196,int_stack+10800,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+756694, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1361680,int_stack+72384,int_stack+71376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+197280, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+69030,int_stack+1361680,int_stack+10800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+758314, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+69030,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+789724, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+9180,int_stack+1357480,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1473796,int_stack+29430,int_stack+1084654,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+73905,int_stack+73680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393408, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+442608,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+74220,int_stack+73905, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393633, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+442833,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551674, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+792964,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+74640,int_stack+74220, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393948, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443148,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+552349, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+793639,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+553294, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+794584,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+75495,int_stack+75180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396408, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+445608,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+75936,int_stack+75495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396723, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+445923,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+561934, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+795934,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088929,int_stack+76524,int_stack+75936, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397164, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+446364,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1090693,int_stack+1088929,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+562879, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+796879,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+29430,int_stack+1090693,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+564202, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+801334,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+29430,int_stack+1086679,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+77700,int_stack+77280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+449808,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1084654,int_stack+78288,int_stack+77700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401028, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450228,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1086418,int_stack+1084654,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569116, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+803224,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088938,int_stack+79072,int_stack+78288, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401616, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450816,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32580,int_stack+1088938,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+582922, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+804484,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1088938,int_stack+32580,int_stack+1086418, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+584686, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837424,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+32580,int_stack+1088938,int_stack+29430,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1492696,int_stack+32580,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+80620,int_stack+80080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+206992,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+81376,int_stack+80620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208072,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+10800,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+591094, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+839944,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29430,int_stack+82384,int_stack+81376, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+172672, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209584,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1353196,int_stack+29430,int_stack+10800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+623476, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+841564,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+1353196,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+625744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+872974,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+9180,int_stack+1088938,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1506196,int_stack+1353196,int_stack+32580,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1353196,int_stack+83905,int_stack+83680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409808, 0.0, zero_stack, 1.0, int_stack+442608, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+84220,int_stack+83905, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410033, 0.0, zero_stack, 1.0, int_stack+442833, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353871,int_stack+1227037,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+628984, 0.0, zero_stack, 1.0, int_stack+792964, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+84640,int_stack+84220, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410348, 0.0, zero_stack, 1.0, int_stack+443148, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+629659, 0.0, zero_stack, 1.0, int_stack+793639, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1355221,int_stack+1235965,int_stack+1353871, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+630604, 0.0, zero_stack, 1.0, int_stack+794584, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+85495,int_stack+85180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412808, 0.0, zero_stack, 1.0, int_stack+445608, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+85936,int_stack+85495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+413123, 0.0, zero_stack, 1.0, int_stack+445923, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353196,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+631954, 0.0, zero_stack, 1.0, int_stack+795934, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1357471,int_stack+86524,int_stack+85936, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+413564, 0.0, zero_stack, 1.0, int_stack+446364, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1359235,int_stack+1357471,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+632899, 0.0, zero_stack, 1.0, int_stack+796879, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1361881,int_stack+1359235,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+637354, 0.0, zero_stack, 1.0, int_stack+801334, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+1361881,int_stack+1355221,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+87700,int_stack+87280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+417008, 0.0, zero_stack, 1.0, int_stack+449808, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1353196,int_stack+88288,int_stack+87700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+417428, 0.0, zero_stack, 1.0, int_stack+450228, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1354960,int_stack+1353196,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+639244, 0.0, zero_stack, 1.0, int_stack+803224, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1357480,int_stack+89072,int_stack+88288, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+418016, 0.0, zero_stack, 1.0, int_stack+450816, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1084654,int_stack+1357480,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+640504, 0.0, zero_stack, 1.0, int_stack+804484, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1357480,int_stack+1084654,int_stack+1354960, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+673444, 0.0, zero_stack, 1.0, int_stack+837424, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+1357480,int_stack+1361881,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+69030,int_stack+1084654,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+90620,int_stack+90080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+182384, 0.0, zero_stack, 1.0, int_stack+206992, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+91376,int_stack+90620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+183464, 0.0, zero_stack, 1.0, int_stack+208072, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353196,int_stack+10800,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+675964, 0.0, zero_stack, 1.0, int_stack+839944, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1361680,int_stack+92384,int_stack+91376, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+184976, 0.0, zero_stack, 1.0, int_stack+209584, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29430,int_stack+1361680,int_stack+10800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677584, 0.0, zero_stack, 1.0, int_stack+841564, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+29430,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+708994, 0.0, zero_stack, 1.0, int_stack+872974, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+9180,int_stack+1357480,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1525096,int_stack+29430,int_stack+1084654,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+93905,int_stack+93680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426208, 1.0, int_stack+442608, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+94220,int_stack+93905, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426433, 1.0, int_stack+442833, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+712234, 1.0, int_stack+792964, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+94640,int_stack+94220, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426748, 1.0, int_stack+443148, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+712909, 1.0, int_stack+793639, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+713854, 1.0, int_stack+794584, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+95495,int_stack+95180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429208, 1.0, int_stack+445608, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+95936,int_stack+95495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429523, 1.0, int_stack+445923, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+715204, 1.0, int_stack+795934, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088929,int_stack+96524,int_stack+95936, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429964, 1.0, int_stack+446364, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1090693,int_stack+1088929,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+716149, 1.0, int_stack+796879, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+29430,int_stack+1090693,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+720604, 1.0, int_stack+801334, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+29430,int_stack+1086679,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+97700,int_stack+97280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433408, 1.0, int_stack+449808, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1084654,int_stack+98288,int_stack+97700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433828, 1.0, int_stack+450228, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1086418,int_stack+1084654,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+722494, 1.0, int_stack+803224, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088938,int_stack+99072,int_stack+98288, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+434416, 1.0, int_stack+450816, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32580,int_stack+1088938,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+723754, 1.0, int_stack+804484, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1088938,int_stack+32580,int_stack+1086418, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+837424, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+32580,int_stack+1088938,int_stack+29430,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+82530,int_stack+32580,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+100620,int_stack+100080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+194688, 1.0, int_stack+206992, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+101376,int_stack+100620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195768, 1.0, int_stack+208072, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+10800,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+756694, 1.0, int_stack+839944, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29430,int_stack+102384,int_stack+101376, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197280, 1.0, int_stack+209584, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1353196,int_stack+29430,int_stack+10800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+758314, 1.0, int_stack+841564, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+1353196,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+789724, 1.0, int_stack+872974, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+9180,int_stack+1088938,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1543996,int_stack+1353196,int_stack+32580,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1353196,int_stack+103905,int_stack+103680, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+442608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+104220,int_stack+103905, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+442833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353871,int_stack+1227037,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+792964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+104640,int_stack+104220, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+443148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+793639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1355221,int_stack+1235965,int_stack+1353871, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+794584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+105495,int_stack+105180, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+445608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+105936,int_stack+105495, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+445923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353196,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+795934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1357471,int_stack+106524,int_stack+105936, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+446364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1359235,int_stack+1357471,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+796879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1361881,int_stack+1359235,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+801334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+1361881,int_stack+1355221,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+107700,int_stack+107280, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+449808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1353196,int_stack+108288,int_stack+107700, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+450228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1354960,int_stack+1353196,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+803224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1357480,int_stack+109072,int_stack+108288, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+450816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1084654,int_stack+1357480,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+804484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1357480,int_stack+1084654,int_stack+1354960, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+837424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+1357480,int_stack+1361881,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+96030,int_stack+1084654,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+110620,int_stack+110080, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+206992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+111376,int_stack+110620, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+208072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353196,int_stack+10800,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+839944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1361680,int_stack+112384,int_stack+111376, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+209584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29430,int_stack+1361680,int_stack+10800, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+841564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+29430,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+872974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+9180,int_stack+1357480,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1562896,int_stack+29430,int_stack+1084654,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+113905,int_stack+113680, 0.0, zero_stack, 1.0, int_stack+393408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459008,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+114220,int_stack+113905, 0.0, zero_stack, 1.0, int_stack+393633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459233,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 0.0, zero_stack, 1.0, int_stack+551674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+876214,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+114640,int_stack+114220, 0.0, zero_stack, 1.0, int_stack+393948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459548,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 1.0, int_stack+552349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+876889,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329, 0.0, zero_stack, 1.0, int_stack+553294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877834,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+115495,int_stack+115180, 0.0, zero_stack, 1.0, int_stack+396408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462008,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+115936,int_stack+115495, 0.0, zero_stack, 1.0, int_stack+396723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462323,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 1.0, int_stack+561934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+879184,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088929,int_stack+116524,int_stack+115936, 0.0, zero_stack, 1.0, int_stack+397164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462764,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1090693,int_stack+1088929,int_stack+1235965, 0.0, zero_stack, 1.0, int_stack+562879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+880129,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+29430,int_stack+1090693,int_stack+1084654, 0.0, zero_stack, 1.0, int_stack+564202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+884584,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+29430,int_stack+1086679,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+117700,int_stack+117280, 0.0, zero_stack, 1.0, int_stack+400608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+466208,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1084654,int_stack+118288,int_stack+117700, 0.0, zero_stack, 1.0, int_stack+401028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+466628,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1086418,int_stack+1084654,int_stack+1269850, 0.0, zero_stack, 1.0, int_stack+569116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+886474,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088938,int_stack+119072,int_stack+118288, 0.0, zero_stack, 1.0, int_stack+401616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467216,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32580,int_stack+1088938,int_stack+1084654, 0.0, zero_stack, 1.0, int_stack+582922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+887734,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1088938,int_stack+32580,int_stack+1086418, 0.0, zero_stack, 1.0, int_stack+584686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+32580,int_stack+1088938,int_stack+29430,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1581796,int_stack+32580,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+120620,int_stack+120080, 0.0, zero_stack, 1.0, int_stack+170080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+219296,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+121376,int_stack+120620, 0.0, zero_stack, 1.0, int_stack+171160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+220376,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+10800,int_stack+9180, 0.0, zero_stack, 1.0, int_stack+591094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+920674,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29430,int_stack+122384,int_stack+121376, 0.0, zero_stack, 1.0, int_stack+172672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221888,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1353196,int_stack+29430,int_stack+10800, 0.0, zero_stack, 1.0, int_stack+623476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+922294,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+1353196,int_stack+1084654, 0.0, zero_stack, 1.0, int_stack+625744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+953704,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+9180,int_stack+1088938,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1595296,int_stack+1353196,int_stack+32580,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1353196,int_stack+123905,int_stack+123680, 0.0, zero_stack, 1.0, int_stack+409808, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459008, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+124220,int_stack+123905, 0.0, zero_stack, 1.0, int_stack+410033, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459233, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353871,int_stack+1227037,int_stack+1353196, 0.0, zero_stack, 1.0, int_stack+628984, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+876214, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+124640,int_stack+124220, 0.0, zero_stack, 1.0, int_stack+410348, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459548, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 1.0, int_stack+629659, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+876889, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1355221,int_stack+1235965,int_stack+1353871, 0.0, zero_stack, 1.0, int_stack+630604, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+877834, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+125495,int_stack+125180, 0.0, zero_stack, 1.0, int_stack+412808, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462008, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+125936,int_stack+125495, 0.0, zero_stack, 1.0, int_stack+413123, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462323, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353196,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 1.0, int_stack+631954, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+879184, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1357471,int_stack+126524,int_stack+125936, 0.0, zero_stack, 1.0, int_stack+413564, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462764, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1359235,int_stack+1357471,int_stack+1235965, 0.0, zero_stack, 1.0, int_stack+632899, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+880129, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1361881,int_stack+1359235,int_stack+1353196, 0.0, zero_stack, 1.0, int_stack+637354, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+884584, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+1361881,int_stack+1355221,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+127700,int_stack+127280, 0.0, zero_stack, 1.0, int_stack+417008, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+466208, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1353196,int_stack+128288,int_stack+127700, 0.0, zero_stack, 1.0, int_stack+417428, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+466628, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1354960,int_stack+1353196,int_stack+1269850, 0.0, zero_stack, 1.0, int_stack+639244, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+886474, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1357480,int_stack+129072,int_stack+128288, 0.0, zero_stack, 1.0, int_stack+418016, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467216, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1084654,int_stack+1357480,int_stack+1353196, 0.0, zero_stack, 1.0, int_stack+640504, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+887734, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1357480,int_stack+1084654,int_stack+1354960, 0.0, zero_stack, 1.0, int_stack+673444, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+1357480,int_stack+1361881,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+109530,int_stack+1084654,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+130620,int_stack+130080, 0.0, zero_stack, 1.0, int_stack+182384, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+219296, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+131376,int_stack+130620, 0.0, zero_stack, 1.0, int_stack+183464, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+220376, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353196,int_stack+10800,int_stack+9180, 0.0, zero_stack, 1.0, int_stack+675964, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+920674, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1361680,int_stack+132384,int_stack+131376, 0.0, zero_stack, 1.0, int_stack+184976, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221888, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29430,int_stack+1361680,int_stack+10800, 0.0, zero_stack, 1.0, int_stack+677584, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+922294, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+29430,int_stack+1353196, 0.0, zero_stack, 1.0, int_stack+708994, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+953704, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+9180,int_stack+1357480,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1614196,int_stack+29430,int_stack+1084654,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+133905,int_stack+133680, 0.0, zero_stack, 1.0, int_stack+426208, 0.0, zero_stack, 1.0, int_stack+459008, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+134220,int_stack+133905, 0.0, zero_stack, 1.0, int_stack+426433, 0.0, zero_stack, 1.0, int_stack+459233, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 0.0, zero_stack, 1.0, int_stack+712234, 0.0, zero_stack, 1.0, int_stack+876214, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+134640,int_stack+134220, 0.0, zero_stack, 1.0, int_stack+426748, 0.0, zero_stack, 1.0, int_stack+459548, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 1.0, int_stack+712909, 0.0, zero_stack, 1.0, int_stack+876889, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329, 0.0, zero_stack, 1.0, int_stack+713854, 0.0, zero_stack, 1.0, int_stack+877834, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+135495,int_stack+135180, 0.0, zero_stack, 1.0, int_stack+429208, 0.0, zero_stack, 1.0, int_stack+462008, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+135936,int_stack+135495, 0.0, zero_stack, 1.0, int_stack+429523, 0.0, zero_stack, 1.0, int_stack+462323, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 1.0, int_stack+715204, 0.0, zero_stack, 1.0, int_stack+879184, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088929,int_stack+136524,int_stack+135936, 0.0, zero_stack, 1.0, int_stack+429964, 0.0, zero_stack, 1.0, int_stack+462764, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1090693,int_stack+1088929,int_stack+1235965, 0.0, zero_stack, 1.0, int_stack+716149, 0.0, zero_stack, 1.0, int_stack+880129, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+29430,int_stack+1090693,int_stack+1084654, 0.0, zero_stack, 1.0, int_stack+720604, 0.0, zero_stack, 1.0, int_stack+884584, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+29430,int_stack+1086679,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+137700,int_stack+137280, 0.0, zero_stack, 1.0, int_stack+433408, 0.0, zero_stack, 1.0, int_stack+466208, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1084654,int_stack+138288,int_stack+137700, 0.0, zero_stack, 1.0, int_stack+433828, 0.0, zero_stack, 1.0, int_stack+466628, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1086418,int_stack+1084654,int_stack+1269850, 0.0, zero_stack, 1.0, int_stack+722494, 0.0, zero_stack, 1.0, int_stack+886474, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088938,int_stack+139072,int_stack+138288, 0.0, zero_stack, 1.0, int_stack+434416, 0.0, zero_stack, 1.0, int_stack+467216, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32580,int_stack+1088938,int_stack+1084654, 0.0, zero_stack, 1.0, int_stack+723754, 0.0, zero_stack, 1.0, int_stack+887734, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1088938,int_stack+32580,int_stack+1086418, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+32580,int_stack+1088938,int_stack+29430,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+123030,int_stack+32580,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+140620,int_stack+140080, 0.0, zero_stack, 1.0, int_stack+194688, 0.0, zero_stack, 1.0, int_stack+219296, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+141376,int_stack+140620, 0.0, zero_stack, 1.0, int_stack+195768, 0.0, zero_stack, 1.0, int_stack+220376, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+10800,int_stack+9180, 0.0, zero_stack, 1.0, int_stack+756694, 0.0, zero_stack, 1.0, int_stack+920674, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29430,int_stack+142384,int_stack+141376, 0.0, zero_stack, 1.0, int_stack+197280, 0.0, zero_stack, 1.0, int_stack+221888, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1353196,int_stack+29430,int_stack+10800, 0.0, zero_stack, 1.0, int_stack+758314, 0.0, zero_stack, 1.0, int_stack+922294, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+1353196,int_stack+1084654, 0.0, zero_stack, 1.0, int_stack+789724, 0.0, zero_stack, 1.0, int_stack+953704, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+9180,int_stack+1088938,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1633096,int_stack+1353196,int_stack+32580,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1353196,int_stack+143905,int_stack+143680, 0.0, zero_stack, 1.0, int_stack+442608, 1.0, int_stack+459008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+144220,int_stack+143905, 0.0, zero_stack, 1.0, int_stack+442833, 1.0, int_stack+459233, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353871,int_stack+1227037,int_stack+1353196, 0.0, zero_stack, 1.0, int_stack+792964, 1.0, int_stack+876214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+144640,int_stack+144220, 0.0, zero_stack, 1.0, int_stack+443148, 1.0, int_stack+459548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 1.0, int_stack+793639, 1.0, int_stack+876889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1355221,int_stack+1235965,int_stack+1353871, 0.0, zero_stack, 1.0, int_stack+794584, 1.0, int_stack+877834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+145495,int_stack+145180, 0.0, zero_stack, 1.0, int_stack+445608, 1.0, int_stack+462008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+145936,int_stack+145495, 0.0, zero_stack, 1.0, int_stack+445923, 1.0, int_stack+462323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353196,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 1.0, int_stack+795934, 1.0, int_stack+879184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1357471,int_stack+146524,int_stack+145936, 0.0, zero_stack, 1.0, int_stack+446364, 1.0, int_stack+462764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1359235,int_stack+1357471,int_stack+1235965, 0.0, zero_stack, 1.0, int_stack+796879, 1.0, int_stack+880129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1361881,int_stack+1359235,int_stack+1353196, 0.0, zero_stack, 1.0, int_stack+801334, 1.0, int_stack+884584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+1361881,int_stack+1355221,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+147700,int_stack+147280, 0.0, zero_stack, 1.0, int_stack+449808, 1.0, int_stack+466208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1353196,int_stack+148288,int_stack+147700, 0.0, zero_stack, 1.0, int_stack+450228, 1.0, int_stack+466628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1354960,int_stack+1353196,int_stack+1269850, 0.0, zero_stack, 1.0, int_stack+803224, 1.0, int_stack+886474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1357480,int_stack+149072,int_stack+148288, 0.0, zero_stack, 1.0, int_stack+450816, 1.0, int_stack+467216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1084654,int_stack+1357480,int_stack+1353196, 0.0, zero_stack, 1.0, int_stack+804484, 1.0, int_stack+887734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1357480,int_stack+1084654,int_stack+1354960, 0.0, zero_stack, 1.0, int_stack+837424, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+1357480,int_stack+1361881,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+136530,int_stack+1084654,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+150620,int_stack+150080, 0.0, zero_stack, 1.0, int_stack+206992, 1.0, int_stack+219296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+151376,int_stack+150620, 0.0, zero_stack, 1.0, int_stack+208072, 1.0, int_stack+220376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353196,int_stack+10800,int_stack+9180, 0.0, zero_stack, 1.0, int_stack+839944, 1.0, int_stack+920674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1361680,int_stack+152384,int_stack+151376, 0.0, zero_stack, 1.0, int_stack+209584, 1.0, int_stack+221888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29430,int_stack+1361680,int_stack+10800, 0.0, zero_stack, 1.0, int_stack+841564, 1.0, int_stack+922294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+29430,int_stack+1353196, 0.0, zero_stack, 1.0, int_stack+872974, 1.0, int_stack+953704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+9180,int_stack+1357480,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1651996,int_stack+29430,int_stack+1084654,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+153905,int_stack+153680, 0.0, zero_stack, 2.0, int_stack+459008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+154220,int_stack+153905, 0.0, zero_stack, 2.0, int_stack+459233, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 0.0, zero_stack, 2.0, int_stack+876214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+154640,int_stack+154220, 0.0, zero_stack, 2.0, int_stack+459548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 2.0, int_stack+876889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329, 0.0, zero_stack, 2.0, int_stack+877834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+155495,int_stack+155180, 0.0, zero_stack, 2.0, int_stack+462008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+155936,int_stack+155495, 0.0, zero_stack, 2.0, int_stack+462323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 2.0, int_stack+879184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088929,int_stack+156524,int_stack+155936, 0.0, zero_stack, 2.0, int_stack+462764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1090693,int_stack+1088929,int_stack+1235965, 0.0, zero_stack, 2.0, int_stack+880129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+29430,int_stack+1090693,int_stack+1084654, 0.0, zero_stack, 2.0, int_stack+884584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+29430,int_stack+1086679,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+157700,int_stack+157280, 0.0, zero_stack, 2.0, int_stack+466208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1084654,int_stack+158288,int_stack+157700, 0.0, zero_stack, 2.0, int_stack+466628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1086418,int_stack+1084654,int_stack+1269850, 0.0, zero_stack, 2.0, int_stack+886474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088938,int_stack+159072,int_stack+158288, 0.0, zero_stack, 2.0, int_stack+467216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32580,int_stack+1088938,int_stack+1084654, 0.0, zero_stack, 2.0, int_stack+887734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1088938,int_stack+32580,int_stack+1086418, 0.0, zero_stack, 2.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+32580,int_stack+1088938,int_stack+29430,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1670896,int_stack+32580,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+160620,int_stack+160080, 0.0, zero_stack, 2.0, int_stack+219296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+161376,int_stack+160620, 0.0, zero_stack, 2.0, int_stack+220376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+10800,int_stack+9180, 0.0, zero_stack, 2.0, int_stack+920674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29430,int_stack+162384,int_stack+161376, 0.0, zero_stack, 2.0, int_stack+221888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1353196,int_stack+29430,int_stack+10800, 0.0, zero_stack, 2.0, int_stack+922294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+1353196,int_stack+1084654, 0.0, zero_stack, 2.0, int_stack+953704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+9180,int_stack+1088938,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1684396,int_stack+1353196,int_stack+32580,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1353196,int_stack+163905,int_stack+163680, 1.0, int_stack+393408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475408,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+164220,int_stack+163905, 1.0, int_stack+393633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475633,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353871,int_stack+1227037,int_stack+1353196, 1.0, int_stack+551674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+956944,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+164640,int_stack+164220, 1.0, int_stack+393948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475948,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 1.0, int_stack+552349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+957619,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1355221,int_stack+1235965,int_stack+1353871, 1.0, int_stack+553294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+958564,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+165495,int_stack+165180, 1.0, int_stack+396408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478408,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+165936,int_stack+165495, 1.0, int_stack+396723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478723,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353196,int_stack+1235965,int_stack+1227037, 1.0, int_stack+561934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+959914,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1357471,int_stack+166524,int_stack+165936, 1.0, int_stack+397164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+479164,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1359235,int_stack+1357471,int_stack+1235965, 1.0, int_stack+562879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960859,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1361881,int_stack+1359235,int_stack+1353196, 1.0, int_stack+564202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+965314,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+1361881,int_stack+1355221,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+167700,int_stack+167280, 1.0, int_stack+400608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483028,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1353196,int_stack+168288,int_stack+167700, 1.0, int_stack+401028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484036,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1354960,int_stack+1353196,int_stack+1269850, 1.0, int_stack+569116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+967204,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1357480,int_stack+169072,int_stack+168288, 1.0, int_stack+401616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+485408,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+561934,int_stack+1357480,int_stack+1353196, 1.0, int_stack+582922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+968464,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1357480,int_stack+561934,int_stack+1354960, 1.0, int_stack+584686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1001404,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+1357480,int_stack+1361881,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+150030,int_stack+1084654,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+171916,int_stack+170620, 1.0, int_stack+170080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232140,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+173680,int_stack+171916, 1.0, int_stack+171160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233976,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+561934,int_stack+10800,int_stack+9180, 1.0, int_stack+591094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003924,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1353196,int_stack+174688,int_stack+173680, 1.0, int_stack+172672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235488,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29430,int_stack+1353196,int_stack+10800, 1.0, int_stack+623476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1005544,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+29430,int_stack+561934, 1.0, int_stack+625744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1036954,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+9180,int_stack+1357480,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1703296,int_stack+29430,int_stack+1084654,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+176209,int_stack+175984, 1.0, int_stack+409808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475408, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+176524,int_stack+176209, 1.0, int_stack+410033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475633, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 1.0, int_stack+628984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+956944, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+176944,int_stack+176524, 1.0, int_stack+410348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475948, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 1.0, int_stack+629659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+957619, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329, 1.0, int_stack+630604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+958564, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+177799,int_stack+177484, 1.0, int_stack+412808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478408, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+178240,int_stack+177799, 1.0, int_stack+413123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478723, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+568612,int_stack+1235965,int_stack+1227037, 1.0, int_stack+631954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+959914, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1084654,int_stack+178828,int_stack+178240, 1.0, int_stack+413564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+479164, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1088929,int_stack+1084654,int_stack+1235965, 1.0, int_stack+632899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960859, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+29430,int_stack+1088929,int_stack+568612, 1.0, int_stack+637354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+965314, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+29430,int_stack+1086679,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+180004,int_stack+179584, 1.0, int_stack+417008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483028, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+637354,int_stack+180592,int_stack+180004, 1.0, int_stack+417428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484036, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+637354,int_stack+1269850, 1.0, int_stack+639244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+967204, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1087174,int_stack+181376,int_stack+180592, 1.0, int_stack+418016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+485408, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1089526,int_stack+1087174,int_stack+637354, 1.0, int_stack+640504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+968464, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+637354,int_stack+1089526,int_stack+1084654, 1.0, int_stack+673444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1001404, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+637354,int_stack+29430,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+163530,int_stack+1084654,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+184220,int_stack+182924, 1.0, int_stack+182384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232140, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+185984,int_stack+184220, 1.0, int_stack+183464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233976, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+29430,int_stack+10800,int_stack+9180, 1.0, int_stack+675964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003924, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+32670,int_stack+186992,int_stack+185984, 1.0, int_stack+184976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235488, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35694,int_stack+32670,int_stack+10800, 1.0, int_stack+677584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1005544, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+35694,int_stack+29430, 1.0, int_stack+708994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1036954, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+9180,int_stack+637354,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1722196,int_stack+29430,int_stack+1084654,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+188513,int_stack+188288, 1.0, int_stack+426208, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475408, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+188828,int_stack+188513, 1.0, int_stack+426433, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475633, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 1.0, int_stack+712234, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+956944, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+189248,int_stack+188828, 1.0, int_stack+426748, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475948, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+568612,int_stack+1269850,int_stack+1227037, 1.0, int_stack+712909, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+957619, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+568612,int_stack+1085329, 1.0, int_stack+713854, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+958564, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+190103,int_stack+189788, 1.0, int_stack+429208, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478408, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+568612,int_stack+190544,int_stack+190103, 1.0, int_stack+429523, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478723, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1235965,int_stack+568612,int_stack+1227037, 1.0, int_stack+715204, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+959914, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1084654,int_stack+191132,int_stack+190544, 1.0, int_stack+429964, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+479164, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1088929,int_stack+1084654,int_stack+568612, 1.0, int_stack+716149, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960859, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+29430,int_stack+1088929,int_stack+1235965, 1.0, int_stack+720604, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+965314, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+29430,int_stack+1086679,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+192308,int_stack+191888, 1.0, int_stack+433408, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483028, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+720604,int_stack+192896,int_stack+192308, 1.0, int_stack+433828, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484036, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+720604,int_stack+1269850, 1.0, int_stack+722494, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+967204, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1087174,int_stack+193680,int_stack+192896, 1.0, int_stack+434416, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+485408, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1089526,int_stack+1087174,int_stack+720604, 1.0, int_stack+723754, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+968464, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+720604,int_stack+1089526,int_stack+1084654, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1001404, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+720604,int_stack+29430,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+177030,int_stack+1084654,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+196524,int_stack+195228, 1.0, int_stack+194688, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232140, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+198288,int_stack+196524, 1.0, int_stack+195768, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233976, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+29430,int_stack+10800,int_stack+9180, 1.0, int_stack+756694, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003924, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+32670,int_stack+199296,int_stack+198288, 1.0, int_stack+197280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235488, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35694,int_stack+32670,int_stack+10800, 1.0, int_stack+758314, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1005544, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+756694,int_stack+35694,int_stack+29430, 1.0, int_stack+789724, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1036954, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+756694,int_stack+720604,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1741096,int_stack+29430,int_stack+1084654,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+200817,int_stack+200592, 1.0, int_stack+442608, 0.0, zero_stack, 1.0, int_stack+475408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+201132,int_stack+200817, 1.0, int_stack+442833, 0.0, zero_stack, 1.0, int_stack+475633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 1.0, int_stack+792964, 0.0, zero_stack, 1.0, int_stack+956944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+201552,int_stack+201132, 1.0, int_stack+443148, 0.0, zero_stack, 1.0, int_stack+475948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 1.0, int_stack+793639, 0.0, zero_stack, 1.0, int_stack+957619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329, 1.0, int_stack+794584, 0.0, zero_stack, 1.0, int_stack+958564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+202407,int_stack+202092, 1.0, int_stack+445608, 0.0, zero_stack, 1.0, int_stack+478408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+202848,int_stack+202407, 1.0, int_stack+445923, 0.0, zero_stack, 1.0, int_stack+478723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+568612,int_stack+1235965,int_stack+1227037, 1.0, int_stack+795934, 0.0, zero_stack, 1.0, int_stack+959914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1084654,int_stack+203436,int_stack+202848, 1.0, int_stack+446364, 0.0, zero_stack, 1.0, int_stack+479164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1088929,int_stack+1084654,int_stack+1235965, 1.0, int_stack+796879, 0.0, zero_stack, 1.0, int_stack+960859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+29430,int_stack+1088929,int_stack+568612, 1.0, int_stack+801334, 0.0, zero_stack, 1.0, int_stack+965314, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+29430,int_stack+1086679,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+204612,int_stack+204192, 1.0, int_stack+449808, 0.0, zero_stack, 1.0, int_stack+483028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+801334,int_stack+205200,int_stack+204612, 1.0, int_stack+450228, 0.0, zero_stack, 1.0, int_stack+484036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+0,int_stack+801334,int_stack+1269850, 1.0, int_stack+803224, 0.0, zero_stack, 1.0, int_stack+967204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1084654,int_stack+205984,int_stack+205200, 1.0, int_stack+450816, 0.0, zero_stack, 1.0, int_stack+485408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1087006,int_stack+1084654,int_stack+801334, 1.0, int_stack+804484, 0.0, zero_stack, 1.0, int_stack+968464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+801334,int_stack+1087006,int_stack+0, 1.0, int_stack+837424, 0.0, zero_stack, 1.0, int_stack+1001404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+801334,int_stack+29430,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+190530,int_stack+1084654,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+208828,int_stack+207532, 1.0, int_stack+206992, 0.0, zero_stack, 1.0, int_stack+232140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+210592,int_stack+208828, 1.0, int_stack+208072, 0.0, zero_stack, 1.0, int_stack+233976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+29430,int_stack+10800,int_stack+9180, 1.0, int_stack+839944, 0.0, zero_stack, 1.0, int_stack+1003924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+32670,int_stack+211600,int_stack+210592, 1.0, int_stack+209584, 0.0, zero_stack, 1.0, int_stack+235488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35694,int_stack+32670,int_stack+10800, 1.0, int_stack+841564, 0.0, zero_stack, 1.0, int_stack+1005544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+35694,int_stack+29430, 1.0, int_stack+872974, 0.0, zero_stack, 1.0, int_stack+1036954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+9180,int_stack+801334,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1759996,int_stack+29430,int_stack+1084654,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+213121,int_stack+212896, 1.0, int_stack+459008, 1.0, int_stack+475408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+213436,int_stack+213121, 1.0, int_stack+459233, 1.0, int_stack+475633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 1.0, int_stack+876214, 1.0, int_stack+956944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+213856,int_stack+213436, 1.0, int_stack+459548, 1.0, int_stack+475948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+568612,int_stack+1269850,int_stack+1227037, 1.0, int_stack+876889, 1.0, int_stack+957619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+568612,int_stack+1085329, 1.0, int_stack+877834, 1.0, int_stack+958564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+214711,int_stack+214396, 1.0, int_stack+462008, 1.0, int_stack+478408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+568612,int_stack+215152,int_stack+214711, 1.0, int_stack+462323, 1.0, int_stack+478723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1235965,int_stack+568612,int_stack+1227037, 1.0, int_stack+879184, 1.0, int_stack+959914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1084654,int_stack+215740,int_stack+215152, 1.0, int_stack+462764, 1.0, int_stack+479164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1088929,int_stack+1084654,int_stack+568612, 1.0, int_stack+880129, 1.0, int_stack+960859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+29430,int_stack+1088929,int_stack+1235965, 1.0, int_stack+884584, 1.0, int_stack+965314, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+29430,int_stack+1086679,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+216916,int_stack+216496, 1.0, int_stack+466208, 1.0, int_stack+483028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+884584,int_stack+217504,int_stack+216916, 1.0, int_stack+466628, 1.0, int_stack+484036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+0,int_stack+884584,int_stack+1269850, 1.0, int_stack+886474, 1.0, int_stack+967204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1084654,int_stack+218288,int_stack+217504, 1.0, int_stack+467216, 1.0, int_stack+485408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1087006,int_stack+1084654,int_stack+884584, 1.0, int_stack+887734, 1.0, int_stack+968464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+884584,int_stack+1087006,int_stack+0, 1.0, int_stack+2520, 1.0, int_stack+1001404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+884584,int_stack+29430,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+204030,int_stack+1084654,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+221132,int_stack+219836, 1.0, int_stack+219296, 1.0, int_stack+232140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+222896,int_stack+221132, 1.0, int_stack+220376, 1.0, int_stack+233976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+29430,int_stack+10800,int_stack+9180, 1.0, int_stack+920674, 1.0, int_stack+1003924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+32670,int_stack+223904,int_stack+222896, 1.0, int_stack+221888, 1.0, int_stack+235488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35694,int_stack+32670,int_stack+10800, 1.0, int_stack+922294, 1.0, int_stack+1005544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+920674,int_stack+35694,int_stack+29430, 1.0, int_stack+953704, 1.0, int_stack+1036954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+920674,int_stack+884584,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1778896,int_stack+29430,int_stack+1084654,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+225425,int_stack+225200, 2.0, int_stack+475408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+225740,int_stack+225425, 2.0, int_stack+475633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 2.0, int_stack+956944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+226160,int_stack+225740, 2.0, int_stack+475948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 2.0, int_stack+957619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329, 2.0, int_stack+958564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+227015,int_stack+226700, 2.0, int_stack+478408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+227456,int_stack+227015, 2.0, int_stack+478723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+568612,int_stack+1235965,int_stack+1227037, 2.0, int_stack+959914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1084654,int_stack+228044,int_stack+227456, 2.0, int_stack+479164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1088929,int_stack+1084654,int_stack+1235965, 2.0, int_stack+960859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+29430,int_stack+1088929,int_stack+568612, 2.0, int_stack+965314, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+29430,int_stack+1086679,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+229220,int_stack+228800, 2.0, int_stack+483028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+965314,int_stack+229808,int_stack+229220, 2.0, int_stack+484036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+965314,int_stack+1269850, 2.0, int_stack+967204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1087174,int_stack+230592,int_stack+229808, 2.0, int_stack+485408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1089526,int_stack+1087174,int_stack+965314, 2.0, int_stack+968464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+965314,int_stack+1089526,int_stack+1084654, 2.0, int_stack+1001404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+965314,int_stack+29430,150);
 /*--- compute (gd|gf) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+217530,int_stack+1084654,int_stack+9180,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+234732,int_stack+232680, 2.0, int_stack+232140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+236496,int_stack+234732, 2.0, int_stack+233976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+29430,int_stack+10800,int_stack+9180, 2.0, int_stack+1003924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+32670,int_stack+237504,int_stack+236496, 2.0, int_stack+235488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35694,int_stack+32670,int_stack+10800, 2.0, int_stack+1005544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+35694,int_stack+29430, 2.0, int_stack+1036954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+9180,int_stack+965314,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1797796,int_stack+29430,int_stack+1084654,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+239025,int_stack+238800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+495904,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+239340,int_stack+239025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496129,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+580402,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+239760,int_stack+239340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496444,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+568612,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581077,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+568612,int_stack+1085329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1049194,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+240615,int_stack+240300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498904,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+568612,int_stack+241056,int_stack+240615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499219,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1235965,int_stack+568612,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+560044,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1084654,int_stack+241644,int_stack+241056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499660,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1088929,int_stack+1084654,int_stack+568612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1052794,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+29430,int_stack+1088929,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1059274,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+29430,int_stack+1086679, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+557794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+242820,int_stack+242400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+503104,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+243408,int_stack+242820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+503524,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+1235965,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1061164,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1087174,int_stack+244192,int_stack+243408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+504112,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1089526,int_stack+1087174,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1062424,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+32580,int_stack+1089526,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+566092,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+32580,int_stack+29430, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+570502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+231030,int_stack+1084654,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+573652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+245740,int_stack+245200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+295200,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+246496,int_stack+245740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+296280,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1036954,int_stack+10800,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29430,int_stack+247504,int_stack+246496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+297792,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+36780,int_stack+29430,int_stack+10800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+587206,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+36780,int_stack+1036954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1141504,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+9180,int_stack+32580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+593086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1816696,int_stack+1353196,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+597286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+249025,int_stack+248800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+495904, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+249340,int_stack+249025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496129, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+580402, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+249760,int_stack+249340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496444, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581077, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1049194, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+250615,int_stack+250300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498904, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+251056,int_stack+250615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499219, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+568612,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+560044, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1084654,int_stack+251644,int_stack+251056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499660, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1088929,int_stack+1084654,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1052794, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1353196,int_stack+1088929,int_stack+568612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1059274, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+1353196,int_stack+1086679, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+252820,int_stack+252400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+503104, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+568612,int_stack+253408,int_stack+252820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+503524, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+568612,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1061164, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1087174,int_stack+254192,int_stack+253408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+504112, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1089526,int_stack+1087174,int_stack+568612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1062424, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1356346,int_stack+1089526,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+566092, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+1356346,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+643654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1835596,int_stack+1084654,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+255740,int_stack+255200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+295200, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+256496,int_stack+255740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+296280, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1036954,int_stack+10800,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1353196,int_stack+257504,int_stack+256496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+297792, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1360546,int_stack+1353196,int_stack+10800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+587206, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+1360546,int_stack+1036954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1141504, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+9180,int_stack+1356346, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+681844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1849096,int_stack+29430,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+686044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+259025,int_stack+258800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+495904, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+259340,int_stack+259025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496129, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+580402, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+259760,int_stack+259340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496444, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+568612,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581077, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+568612,int_stack+1085329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1049194, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+260615,int_stack+260300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498904, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+568612,int_stack+261056,int_stack+260615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499219, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1235965,int_stack+568612,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+560044, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1084654,int_stack+261644,int_stack+261056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499660, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1088929,int_stack+1084654,int_stack+568612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1052794, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+29430,int_stack+1088929,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1059274, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+29430,int_stack+1086679, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+718354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+262820,int_stack+262400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+503104, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+263408,int_stack+262820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+503524, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+1235965,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1061164, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1087174,int_stack+264192,int_stack+263408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+504112, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1089526,int_stack+1087174,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1062424, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+32580,int_stack+1089526,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+566092, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+32580,int_stack+29430, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+726904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+244530,int_stack+1084654,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+730054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+265740,int_stack+265200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+295200, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+266496,int_stack+265740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+296280, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1036954,int_stack+10800,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29430,int_stack+267504,int_stack+266496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+297792, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+36780,int_stack+29430,int_stack+10800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+587206, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+36780,int_stack+1036954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1141504, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+9180,int_stack+32580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+762574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1867996,int_stack+1353196,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+766774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+269025,int_stack+268800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+495904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+269340,int_stack+269025, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+580402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+269760,int_stack+269340, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+581077, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1049194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+270615,int_stack+270300, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+271056,int_stack+270615, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+568612,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+560044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1084654,int_stack+271644,int_stack+271056, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1088929,int_stack+1084654,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1052794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1353196,int_stack+1088929,int_stack+568612, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1059274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+1353196,int_stack+1086679, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+799084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+272820,int_stack+272400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+503104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+568612,int_stack+273408,int_stack+272820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+503524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+568612,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1061164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1087174,int_stack+274192,int_stack+273408, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+504112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1089526,int_stack+1087174,int_stack+568612, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1062424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1356346,int_stack+1089526,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+566092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+1356346,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+807634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+258030,int_stack+1084654,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+810784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+275740,int_stack+275200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+295200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+276496,int_stack+275740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+296280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1036954,int_stack+10800,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1353196,int_stack+277504,int_stack+276496, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+297792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1360546,int_stack+1353196,int_stack+10800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+587206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+1360546,int_stack+1036954, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1141504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+9180,int_stack+1356346, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+845824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1886896,int_stack+29430,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+850024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+279025,int_stack+278800, 0.0, zero_stack, 1.0, int_stack+495904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+279340,int_stack+279025, 0.0, zero_stack, 1.0, int_stack+496129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 0.0, zero_stack, 1.0, int_stack+580402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+279760,int_stack+279340, 0.0, zero_stack, 1.0, int_stack+496444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+568612,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 1.0, int_stack+581077, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+568612,int_stack+1085329, 0.0, zero_stack, 1.0, int_stack+1049194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+280615,int_stack+280300, 0.0, zero_stack, 1.0, int_stack+498904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+568612,int_stack+281056,int_stack+280615, 0.0, zero_stack, 1.0, int_stack+499219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1235965,int_stack+568612,int_stack+1227037, 0.0, zero_stack, 1.0, int_stack+560044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1084654,int_stack+281644,int_stack+281056, 0.0, zero_stack, 1.0, int_stack+499660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1088929,int_stack+1084654,int_stack+568612, 0.0, zero_stack, 1.0, int_stack+1052794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+29430,int_stack+1088929,int_stack+1235965, 0.0, zero_stack, 1.0, int_stack+1059274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+29430,int_stack+1086679, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+882334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+282820,int_stack+282400, 0.0, zero_stack, 1.0, int_stack+503104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+283408,int_stack+282820, 0.0, zero_stack, 1.0, int_stack+503524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+1235965,int_stack+1269850, 0.0, zero_stack, 1.0, int_stack+1061164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1087174,int_stack+284192,int_stack+283408, 0.0, zero_stack, 1.0, int_stack+504112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1089526,int_stack+1087174,int_stack+1235965, 0.0, zero_stack, 1.0, int_stack+1062424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+32580,int_stack+1089526,int_stack+1084654, 0.0, zero_stack, 1.0, int_stack+566092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+32580,int_stack+29430, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+890884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+271530,int_stack+1084654,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+894034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+285740,int_stack+285200, 0.0, zero_stack, 1.0, int_stack+295200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+286496,int_stack+285740, 0.0, zero_stack, 1.0, int_stack+296280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1036954,int_stack+10800,int_stack+9180, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29430,int_stack+287504,int_stack+286496, 0.0, zero_stack, 1.0, int_stack+297792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+36780,int_stack+29430,int_stack+10800, 0.0, zero_stack, 1.0, int_stack+587206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+36780,int_stack+1036954, 0.0, zero_stack, 1.0, int_stack+1141504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+9180,int_stack+32580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+926554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1905796,int_stack+1353196,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+930754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+289025,int_stack+288800, 1.0, int_stack+495904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+289340,int_stack+289025, 1.0, int_stack+496129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 1.0, int_stack+580402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+289760,int_stack+289340, 1.0, int_stack+496444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 1.0, int_stack+581077, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+580402,int_stack+1235965,int_stack+1085329, 1.0, int_stack+1049194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+290615,int_stack+290300, 1.0, int_stack+498904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+291056,int_stack+290615, 1.0, int_stack+499219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+568612,int_stack+1235965,int_stack+1227037, 1.0, int_stack+560044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+582652,int_stack+291644,int_stack+291056, 1.0, int_stack+499660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+584416,int_stack+582652,int_stack+1235965, 1.0, int_stack+1052794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1052794,int_stack+584416,int_stack+568612, 1.0, int_stack+1059274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+1052794,int_stack+580402, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+963064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+292820,int_stack+292400, 1.0, int_stack+503104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+580402,int_stack+293408,int_stack+292820, 1.0, int_stack+503524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+582166,int_stack+580402,int_stack+1269850, 1.0, int_stack+1061164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+584686,int_stack+294192,int_stack+293408, 1.0, int_stack+504112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1055944,int_stack+584686,int_stack+580402, 1.0, int_stack+1062424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1059472,int_stack+1055944,int_stack+582166, 1.0, int_stack+566092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+1059472,int_stack+1052794, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+971614, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1924696,int_stack+1084654,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+974764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+297036,int_stack+295740, 1.0, int_stack+295200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+298800,int_stack+297036, 1.0, int_stack+296280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1036954,int_stack+10800,int_stack+9180, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1052794,int_stack+299808,int_stack+298800, 1.0, int_stack+297792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+580402,int_stack+1052794,int_stack+10800, 1.0, int_stack+587206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1052794,int_stack+580402,int_stack+1036954, 1.0, int_stack+1141504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+1052794,int_stack+1059472, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1009804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1938196,int_stack+1353196,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1014004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+301329,int_stack+301104,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+560044,int_stack+301644,int_stack+301329,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+560044,int_stack+1084654,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+302064,int_stack+301644,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+560044,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+560044,int_stack+302919,int_stack+302604,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+303360,int_stack+302919,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+1235965,int_stack+560044,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1088929,int_stack+303948,int_stack+303360,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1090693,int_stack+1088929,int_stack+1235965,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1353196,int_stack+1090693,int_stack+1084654,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+1353196,int_stack+1086679, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1050544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+305124,int_stack+304704,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1084654,int_stack+305712,int_stack+305124,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1086418,int_stack+1084654,int_stack+1269850,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1088938,int_stack+306496,int_stack+305712,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1356346,int_stack+1088938,int_stack+1084654,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1088938,int_stack+1356346,int_stack+1086418,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1356346,int_stack+1088938,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+620236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+285030,int_stack+1356346,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1107604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+308044,int_stack+307504,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+308800,int_stack+308044,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1141504,int_stack+10800,int_stack+9180,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1353196,int_stack+309808,int_stack+308800,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1052794,int_stack+1353196,int_stack+10800,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+1052794,int_stack+1141504,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+9180,int_stack+1088938, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1114354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1957096,int_stack+29430,int_stack+1356346, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1118554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+29430,int_stack+311329,int_stack+311104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512304,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+560044,int_stack+311644,int_stack+311329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512529,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+30105,int_stack+560044,int_stack+29430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1144744,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+312064,int_stack+311644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512844,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+560044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+560989,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+31455,int_stack+1235965,int_stack+30105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1145419,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+560044,int_stack+312919,int_stack+312604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+515304,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+313360,int_stack+312919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+515619,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+29430,int_stack+1235965,int_stack+560044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1146769,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+33705,int_stack+313948,int_stack+313360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+516060,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35469,int_stack+33705,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1147714,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38115,int_stack+35469,int_stack+29430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1152169,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+38115,int_stack+31455, 0.0, zero_stack, 1.0, int_stack+557794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+315124,int_stack+314704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519504,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29430,int_stack+315712,int_stack+315124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519924,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+31194,int_stack+29430,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1154059,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+33714,int_stack+316496,int_stack+315712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+520512,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1052794,int_stack+33714,int_stack+29430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1155319,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+33714,int_stack+1052794,int_stack+31194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6660,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+33714,int_stack+38115, 0.0, zero_stack, 1.0, int_stack+570502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+298530,int_stack+1084654,int_stack+9180, 0.0, zero_stack, 1.0, int_stack+573652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+318044,int_stack+317504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367504,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+318800,int_stack+318044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368584,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1141504,int_stack+10800,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589474,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1052794,int_stack+319808,int_stack+318800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370096,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1055818,int_stack+1052794,int_stack+10800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1189204,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1060354,int_stack+1055818,int_stack+1141504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1219882,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+1060354,int_stack+33714, 0.0, zero_stack, 1.0, int_stack+593086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1975996,int_stack+1353196,int_stack+1084654, 0.0, zero_stack, 1.0, int_stack+597286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+321329,int_stack+321104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512304, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+560044,int_stack+321644,int_stack+321329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512529, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+560044,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1144744, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+322064,int_stack+321644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512844, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+560044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+560989, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1145419, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+560044,int_stack+322919,int_stack+322604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+515304, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+323360,int_stack+322919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+515619, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+1235965,int_stack+560044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1146769, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088929,int_stack+323948,int_stack+323360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+516060, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1090693,int_stack+1088929,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1147714, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1353196,int_stack+1090693,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1152169, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+1353196,int_stack+1086679, 0.0, zero_stack, 1.0, int_stack+635104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+325124,int_stack+324704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519504, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1084654,int_stack+325712,int_stack+325124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519924, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1086418,int_stack+1084654,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1154059, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088938,int_stack+326496,int_stack+325712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+520512, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1356346,int_stack+1088938,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1155319, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1088938,int_stack+1356346,int_stack+1086418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6660, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1356346,int_stack+1088938,int_stack+1353196, 0.0, zero_stack, 1.0, int_stack+643654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+312030,int_stack+1356346,int_stack+9180, 0.0, zero_stack, 1.0, int_stack+646804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+328044,int_stack+327504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367504, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+328800,int_stack+328044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368584, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1141504,int_stack+10800,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589474, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1353196,int_stack+329808,int_stack+328800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370096, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1052794,int_stack+1353196,int_stack+10800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1189204, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+1052794,int_stack+1141504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1219882, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+9180,int_stack+1088938, 0.0, zero_stack, 1.0, int_stack+681844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1994896,int_stack+29430,int_stack+1356346, 0.0, zero_stack, 1.0, int_stack+686044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+29430,int_stack+331329,int_stack+331104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512304, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+560044,int_stack+331644,int_stack+331329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512529, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+30105,int_stack+560044,int_stack+29430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1144744, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+332064,int_stack+331644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512844, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+560044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+560989, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+31455,int_stack+1235965,int_stack+30105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1145419, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+560044,int_stack+332919,int_stack+332604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+515304, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+333360,int_stack+332919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+515619, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+29430,int_stack+1235965,int_stack+560044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1146769, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+33705,int_stack+333948,int_stack+333360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+516060, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35469,int_stack+33705,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1147714, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38115,int_stack+35469,int_stack+29430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1152169, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+38115,int_stack+31455, 0.0, zero_stack, 1.0, int_stack+718354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+335124,int_stack+334704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519504, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29430,int_stack+335712,int_stack+335124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519924, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+31194,int_stack+29430,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1154059, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+33714,int_stack+336496,int_stack+335712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+520512, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1052794,int_stack+33714,int_stack+29430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1155319, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+33714,int_stack+1052794,int_stack+31194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6660, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+33714,int_stack+38115, 0.0, zero_stack, 1.0, int_stack+726904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+2013796,int_stack+1084654,int_stack+9180, 0.0, zero_stack, 1.0, int_stack+730054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+338044,int_stack+337504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367504, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+338800,int_stack+338044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368584, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1141504,int_stack+10800,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589474, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1052794,int_stack+339808,int_stack+338800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370096, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1055818,int_stack+1052794,int_stack+10800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1189204, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1060354,int_stack+1055818,int_stack+1141504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1219882, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+1060354,int_stack+33714, 0.0, zero_stack, 1.0, int_stack+762574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2027296,int_stack+1353196,int_stack+1084654, 0.0, zero_stack, 1.0, int_stack+766774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+341329,int_stack+341104, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+560044,int_stack+341644,int_stack+341329, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+560044,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1144744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+342064,int_stack+341644, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+560044, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+560989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1145419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+560044,int_stack+342919,int_stack+342604, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+515304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+343360,int_stack+342919, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+515619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+1235965,int_stack+560044, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1146769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088929,int_stack+343948,int_stack+343360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+516060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1090693,int_stack+1088929,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1147714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1353196,int_stack+1090693,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1152169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+1353196,int_stack+1086679, 0.0, zero_stack, 1.0, int_stack+799084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+345124,int_stack+344704, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1084654,int_stack+345712,int_stack+345124, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1086418,int_stack+1084654,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1154059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088938,int_stack+346496,int_stack+345712, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+520512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1356346,int_stack+1088938,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1155319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1088938,int_stack+1356346,int_stack+1086418, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1356346,int_stack+1088938,int_stack+1353196, 0.0, zero_stack, 1.0, int_stack+807634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+325530,int_stack+1356346,int_stack+9180, 0.0, zero_stack, 1.0, int_stack+810784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+348044,int_stack+347504, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+348800,int_stack+348044, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1141504,int_stack+10800,int_stack+9180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1353196,int_stack+349808,int_stack+348800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1052794,int_stack+1353196,int_stack+10800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1189204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+9180,int_stack+1052794,int_stack+1141504, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1219882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+9180,int_stack+1088938, 0.0, zero_stack, 1.0, int_stack+845824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2046196,int_stack+29430,int_stack+1356346, 0.0, zero_stack, 1.0, int_stack+850024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+29430,int_stack+351329,int_stack+351104, 0.0, zero_stack, 1.0, int_stack+512304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+560044,int_stack+351644,int_stack+351329, 0.0, zero_stack, 1.0, int_stack+512529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+30105,int_stack+560044,int_stack+29430, 0.0, zero_stack, 1.0, int_stack+1144744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+352064,int_stack+351644, 0.0, zero_stack, 1.0, int_stack+512844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+560044, 0.0, zero_stack, 1.0, int_stack+560989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+31455,int_stack+1235965,int_stack+30105, 0.0, zero_stack, 1.0, int_stack+1145419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+560044,int_stack+352919,int_stack+352604, 0.0, zero_stack, 1.0, int_stack+515304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+353360,int_stack+352919, 0.0, zero_stack, 1.0, int_stack+515619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+29430,int_stack+1235965,int_stack+560044, 0.0, zero_stack, 1.0, int_stack+1146769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+33705,int_stack+353948,int_stack+353360, 0.0, zero_stack, 1.0, int_stack+516060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35469,int_stack+33705,int_stack+1235965, 0.0, zero_stack, 1.0, int_stack+1147714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38115,int_stack+35469,int_stack+29430, 0.0, zero_stack, 1.0, int_stack+1152169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+38115,int_stack+31455, 0.0, zero_stack, 1.0, int_stack+882334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+355124,int_stack+354704, 0.0, zero_stack, 1.0, int_stack+519504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29430,int_stack+355712,int_stack+355124, 0.0, zero_stack, 1.0, int_stack+519924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+31194,int_stack+29430,int_stack+1269850, 0.0, zero_stack, 1.0, int_stack+1154059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+33714,int_stack+356496,int_stack+355712, 0.0, zero_stack, 1.0, int_stack+520512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1052794,int_stack+33714,int_stack+29430, 0.0, zero_stack, 1.0, int_stack+1155319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+33714,int_stack+1052794,int_stack+31194, 0.0, zero_stack, 1.0, int_stack+6660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+33714,int_stack+38115, 0.0, zero_stack, 1.0, int_stack+890884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+339030,int_stack+1084654,int_stack+9180, 0.0, zero_stack, 1.0, int_stack+894034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9180,int_stack+358044,int_stack+357504, 0.0, zero_stack, 1.0, int_stack+367504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10800,int_stack+358800,int_stack+358044, 0.0, zero_stack, 1.0, int_stack+368584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1141504,int_stack+10800,int_stack+9180, 0.0, zero_stack, 1.0, int_stack+589474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1052794,int_stack+359808,int_stack+358800, 0.0, zero_stack, 1.0, int_stack+370096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1055818,int_stack+1052794,int_stack+10800, 0.0, zero_stack, 1.0, int_stack+1189204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1060354,int_stack+1055818,int_stack+1141504, 0.0, zero_stack, 1.0, int_stack+1219882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+1060354,int_stack+33714, 0.0, zero_stack, 1.0, int_stack+926554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2065096,int_stack+1353196,int_stack+1084654, 0.0, zero_stack, 1.0, int_stack+930754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+361329,int_stack+361104, 1.0, int_stack+512304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+560044,int_stack+361644,int_stack+361329, 1.0, int_stack+512529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+560044,int_stack+1084654, 1.0, int_stack+1144744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+362064,int_stack+361644, 1.0, int_stack+512844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+560044, 1.0, int_stack+560989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+560044,int_stack+1235965,int_stack+1085329, 1.0, int_stack+1145419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+362919,int_stack+362604, 1.0, int_stack+515304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+363360,int_stack+362919, 1.0, int_stack+515619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+562294,int_stack+1235965,int_stack+1227037, 1.0, int_stack+1146769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+564184,int_stack+363948,int_stack+363360, 1.0, int_stack+516060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+565948,int_stack+564184,int_stack+1235965, 1.0, int_stack+1147714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1084654,int_stack+565948,int_stack+562294, 1.0, int_stack+1152169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+9180,int_stack+1084654,int_stack+560044, 0.0, zero_stack, 1.0, int_stack+963064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+365124,int_stack+364704, 1.0, int_stack+519504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+560044,int_stack+365712,int_stack+365124, 1.0, int_stack+519924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+561808,int_stack+560044,int_stack+1269850, 1.0, int_stack+1154059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+564328,int_stack+366496,int_stack+365712, 1.0, int_stack+520512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+566680,int_stack+564328,int_stack+560044, 1.0, int_stack+1155319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1152169,int_stack+566680,int_stack+561808, 1.0, int_stack+6660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+560044,int_stack+1152169,int_stack+1084654, 0.0, zero_stack, 1.0, int_stack+971614, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+352530,int_stack+560044,int_stack+9180, 0.0, zero_stack, 1.0, int_stack+974764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+369340,int_stack+368044, 1.0, int_stack+367504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1086274,int_stack+371104,int_stack+369340, 1.0, int_stack+368584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1036954,int_stack+1086274,int_stack+1084654, 1.0, int_stack+589474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088542,int_stack+372112,int_stack+371104, 1.0, int_stack+370096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1353196,int_stack+1088542,int_stack+1086274, 1.0, int_stack+1189204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1084654,int_stack+1353196,int_stack+1036954, 1.0, int_stack+1219882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+1084654,int_stack+1152169, 0.0, zero_stack, 1.0, int_stack+1009804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2083996,int_stack+1353196,int_stack+560044, 0.0, zero_stack, 1.0, int_stack+1014004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+560044,int_stack+373633,int_stack+373408,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+373948,int_stack+373633,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+560719,int_stack+1227037,int_stack+560044,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+374368,int_stack+373948,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+562069,int_stack+1235965,int_stack+560719,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+375223,int_stack+374908,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+375664,int_stack+375223,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+560044,int_stack+1235965,int_stack+1227037,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+564319,int_stack+376252,int_stack+375664,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+566083,int_stack+564319,int_stack+1235965,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1353196,int_stack+566083,int_stack+560044,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+1356346,int_stack+1353196,int_stack+562069, 0.0, zero_stack, 1.0, int_stack+1050544, 1.0, int_stack+1149919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+377428,int_stack+377008,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+560044,int_stack+378016,int_stack+377428,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+561808,int_stack+560044,int_stack+1269850,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+564328,int_stack+378800,int_stack+378016,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+566680,int_stack+564328,int_stack+560044,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1152169,int_stack+566680,int_stack+561808,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+1152169,int_stack+1353196, 0.0, zero_stack, 1.0, int_stack+620236, 1.0, int_stack+1158469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+0,int_stack+1084654,int_stack+1356346, 0.0, zero_stack, 1.0, int_stack+1107604, 1.0, int_stack+1161619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1353196,int_stack+380348,int_stack+379808,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1189204,int_stack+381104,int_stack+380348,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1219882,int_stack+1189204,int_stack+1353196,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1353196,int_stack+382112,int_stack+381104,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1356220,int_stack+1353196,int_stack+1189204,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+560044,int_stack+1356220,int_stack+1219882,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+560044,int_stack+1152169, 0.0, zero_stack, 1.0, int_stack+1114354, 1.0, int_stack+1192732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2102896,int_stack+1353196,int_stack+1084654, 0.0, zero_stack, 1.0, int_stack+1118554, 1.0, int_stack+1196932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+383633,int_stack+383408,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+383948,int_stack+383633,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+384368,int_stack+383948,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+385223,int_stack+384908,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+385664,int_stack+385223,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+1235965,int_stack+1227037,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1088929,int_stack+386252,int_stack+385664,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1090693,int_stack+1088929,int_stack+1235965,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1353196,int_stack+1090693,int_stack+1084654,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+1356346,int_stack+1353196,int_stack+1086679, 0.0, zero_stack, 2.0, int_stack+1149919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+387428,int_stack+387008,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1084654,int_stack+388016,int_stack+387428,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1086418,int_stack+1084654,int_stack+1269850,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1088938,int_stack+388800,int_stack+388016,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1152169,int_stack+1088938,int_stack+1084654,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1088938,int_stack+1152169,int_stack+1086418,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+560044,int_stack+1088938,int_stack+1353196, 0.0, zero_stack, 2.0, int_stack+1158469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+366030,int_stack+560044,int_stack+1356346, 0.0, zero_stack, 2.0, int_stack+1161619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1353196,int_stack+390348,int_stack+389808,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1189204,int_stack+391104,int_stack+390348,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1219882,int_stack+1189204,int_stack+1353196,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1353196,int_stack+392112,int_stack+391104,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1356220,int_stack+1353196,int_stack+1189204,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1152169,int_stack+1356220,int_stack+1219882,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+1152169,int_stack+1088938, 0.0, zero_stack, 2.0, int_stack+1192732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2121796,int_stack+1353196,int_stack+560044, 0.0, zero_stack, 2.0, int_stack+1196932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+560044,int_stack+395133,int_stack+394908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530204,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+395448,int_stack+395133, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530429,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+560719,int_stack+1227037,int_stack+560044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1223122,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+395868,int_stack+395448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530744,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1223797,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+562069,int_stack+1235965,int_stack+560719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1224742,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+398823,int_stack+398508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535304,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+399264,int_stack+398823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535619,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+560044,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1226092,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+564319,int_stack+399852,int_stack+399264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+536060,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+566083,int_stack+564319,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1230232,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1353196,int_stack+566083,int_stack+560044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1231555,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+1356346,int_stack+1353196,int_stack+562069, 1.0, int_stack+557794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+403828,int_stack+403408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+539504,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+404416,int_stack+403828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+539924,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1363096,int_stack+1235965,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1191472,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1152169,int_stack+405200,int_stack+404416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+540512,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1154521,int_stack+1152169,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1040194,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1084654,int_stack+1154521,int_stack+1363096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1233445,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1052794,int_stack+1084654,int_stack+1353196, 1.0, int_stack+570502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+379530,int_stack+1052794,int_stack+1356346, 1.0, int_stack+573652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1353196,int_stack+406748,int_stack+406208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490000,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1189204,int_stack+407504,int_stack+406748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+491080,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1219882,int_stack+1189204,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554644,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1353196,int_stack+408512,int_stack+407504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492592,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1356220,int_stack+1353196,int_stack+1189204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1267582,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1152169,int_stack+1356220,int_stack+1219882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1041958,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+1152169,int_stack+1084654, 1.0, int_stack+593086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+556264,int_stack+1353196,int_stack+1052794, 1.0, int_stack+597286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1052794,int_stack+411533,int_stack+411308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530204, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+411848,int_stack+411533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530429, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1053469,int_stack+1227037,int_stack+1052794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1223122, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+412268,int_stack+411848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530744, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1223797, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1054819,int_stack+1235965,int_stack+1053469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1224742, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+415223,int_stack+414908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535304, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+415664,int_stack+415223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535619, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1052794,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1226092, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1057069,int_stack+416252,int_stack+415664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+536060, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1058833,int_stack+1057069,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1230232, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1061479,int_stack+1058833,int_stack+1052794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1231555, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+1353196,int_stack+1061479,int_stack+1054819, 1.0, int_stack+635104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+420228,int_stack+419808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+539504, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1052794,int_stack+420816,int_stack+420228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+539924, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1054558,int_stack+1052794,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1191472, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1057078,int_stack+421600,int_stack+420816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+540512, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1359946,int_stack+1057078,int_stack+1052794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1040194, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1057078,int_stack+1359946,int_stack+1054558, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1233445, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+1057078,int_stack+1061479, 1.0, int_stack+643654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+393030,int_stack+1084654,int_stack+1353196, 1.0, int_stack+646804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1353196,int_stack+423148,int_stack+422608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490000, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1189204,int_stack+423904,int_stack+423148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+491080, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1219882,int_stack+1189204,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554644, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1353196,int_stack+424912,int_stack+423904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492592, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1356220,int_stack+1353196,int_stack+1189204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1267582, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1152169,int_stack+1356220,int_stack+1219882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1041958, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+1152169,int_stack+1057078, 1.0, int_stack+681844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+406530,int_stack+1353196,int_stack+1084654, 1.0, int_stack+686044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+427933,int_stack+427708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530204, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+428248,int_stack+427933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530429, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1223122, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+428668,int_stack+428248, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530744, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1223797, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1224742, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+431623,int_stack+431308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535304, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+432064,int_stack+431623, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535619, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1226092, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088929,int_stack+432652,int_stack+432064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+536060, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1090693,int_stack+1088929,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1230232, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1353196,int_stack+1090693,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1231555, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+1356346,int_stack+1353196,int_stack+1086679, 1.0, int_stack+718354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+436628,int_stack+436208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+539504, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1084654,int_stack+437216,int_stack+436628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+539924, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1086418,int_stack+1084654,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1191472, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088938,int_stack+438000,int_stack+437216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+540512, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1152169,int_stack+1088938,int_stack+1084654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1040194, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1088938,int_stack+1152169,int_stack+1086418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1233445, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1052794,int_stack+1088938,int_stack+1353196, 1.0, int_stack+726904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+708994,int_stack+1052794,int_stack+1356346, 1.0, int_stack+730054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1353196,int_stack+439548,int_stack+439008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490000, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1189204,int_stack+440304,int_stack+439548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+491080, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1219882,int_stack+1189204,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554644, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1353196,int_stack+441312,int_stack+440304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492592, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1356220,int_stack+1353196,int_stack+1189204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1267582, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1152169,int_stack+1356220,int_stack+1219882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1041958, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+1152169,int_stack+1088938, 1.0, int_stack+762574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+673444,int_stack+1353196,int_stack+1052794, 1.0, int_stack+766774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1052794,int_stack+444333,int_stack+444108, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+444648,int_stack+444333, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1053469,int_stack+1227037,int_stack+1052794, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1223122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+445068,int_stack+444648, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1223797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1054819,int_stack+1235965,int_stack+1053469, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1224742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+448023,int_stack+447708, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+448464,int_stack+448023, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1052794,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1226092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1057069,int_stack+449052,int_stack+448464, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+536060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1058833,int_stack+1057069,int_stack+1235965, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1230232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+692344,int_stack+1058833,int_stack+1052794, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1231555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+1057069,int_stack+692344,int_stack+1054819, 1.0, int_stack+799084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+453028,int_stack+452608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+539504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1052794,int_stack+453616,int_stack+453028, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+539924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1353196,int_stack+1052794,int_stack+1269850, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1191472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1054558,int_stack+454400,int_stack+453616, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+540512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1355716,int_stack+1054558,int_stack+1052794, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1040194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1052794,int_stack+1355716,int_stack+1353196, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1233445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+1052794,int_stack+692344, 1.0, int_stack+807634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+756694,int_stack+1084654,int_stack+1057069, 1.0, int_stack+810784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+692344,int_stack+455948,int_stack+455408, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1189204,int_stack+456704,int_stack+455948, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+491080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1219882,int_stack+1189204,int_stack+692344, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+554644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+692344,int_stack+457712,int_stack+456704, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1353196,int_stack+692344,int_stack+1189204, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1267582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1357732,int_stack+1353196,int_stack+1219882, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1041958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+1357732,int_stack+1052794, 1.0, int_stack+845824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+789724,int_stack+29430,int_stack+1084654, 1.0, int_stack+850024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+460733,int_stack+460508, 0.0, zero_stack, 1.0, int_stack+530204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+461048,int_stack+460733, 0.0, zero_stack, 1.0, int_stack+530429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1085329,int_stack+1227037,int_stack+1084654, 0.0, zero_stack, 1.0, int_stack+1223122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+461468,int_stack+461048, 0.0, zero_stack, 1.0, int_stack+530744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 0.0, zero_stack, 1.0, int_stack+1223797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1086679,int_stack+1235965,int_stack+1085329, 0.0, zero_stack, 1.0, int_stack+1224742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+464423,int_stack+464108, 0.0, zero_stack, 1.0, int_stack+535304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+464864,int_stack+464423, 0.0, zero_stack, 1.0, int_stack+535619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1084654,int_stack+1235965,int_stack+1227037, 0.0, zero_stack, 1.0, int_stack+1226092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088929,int_stack+465452,int_stack+464864, 0.0, zero_stack, 1.0, int_stack+536060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1090693,int_stack+1088929,int_stack+1235965, 0.0, zero_stack, 1.0, int_stack+1230232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+692344,int_stack+1090693,int_stack+1084654, 0.0, zero_stack, 1.0, int_stack+1231555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+29430,int_stack+692344,int_stack+1086679, 1.0, int_stack+882334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+469428,int_stack+469008, 0.0, zero_stack, 1.0, int_stack+539504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1084654,int_stack+470016,int_stack+469428, 0.0, zero_stack, 1.0, int_stack+539924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1086418,int_stack+1084654,int_stack+1269850, 0.0, zero_stack, 1.0, int_stack+1191472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1088938,int_stack+470800,int_stack+470016, 0.0, zero_stack, 1.0, int_stack+540512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+36180,int_stack+1088938,int_stack+1084654, 0.0, zero_stack, 1.0, int_stack+1040194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1088938,int_stack+36180,int_stack+1086418, 0.0, zero_stack, 1.0, int_stack+1233445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1052794,int_stack+1088938,int_stack+692344, 1.0, int_stack+890884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+872974,int_stack+1052794,int_stack+29430, 1.0, int_stack+894034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+29430,int_stack+472348,int_stack+471808, 0.0, zero_stack, 1.0, int_stack+490000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1189204,int_stack+473104,int_stack+472348, 0.0, zero_stack, 1.0, int_stack+491080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1219882,int_stack+1189204,int_stack+29430, 0.0, zero_stack, 1.0, int_stack+554644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29430,int_stack+474112,int_stack+473104, 0.0, zero_stack, 1.0, int_stack+492592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32454,int_stack+29430,int_stack+1189204, 0.0, zero_stack, 1.0, int_stack+1267582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1353196,int_stack+32454,int_stack+1219882, 0.0, zero_stack, 1.0, int_stack+1041958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+1353196,int_stack+1088938, 1.0, int_stack+926554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+837424,int_stack+29430,int_stack+1052794, 1.0, int_stack+930754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1052794,int_stack+477133,int_stack+476908, 1.0, int_stack+530204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1227037,int_stack+477448,int_stack+477133, 1.0, int_stack+530429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1053469,int_stack+1227037,int_stack+1052794, 1.0, int_stack+1223122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269850,int_stack+477868,int_stack+477448, 1.0, int_stack+530744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1235965,int_stack+1269850,int_stack+1227037, 1.0, int_stack+1223797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1054819,int_stack+1235965,int_stack+1053469, 1.0, int_stack+1224742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1227037,int_stack+480823,int_stack+480508, 1.0, int_stack+535304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1235965,int_stack+481264,int_stack+480823, 1.0, int_stack+535619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1052794,int_stack+1235965,int_stack+1227037, 1.0, int_stack+1226092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1057069,int_stack+481852,int_stack+481264, 1.0, int_stack+536060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1058833,int_stack+1057069,int_stack+1235965, 1.0, int_stack+1230232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+692344,int_stack+1058833,int_stack+1052794, 1.0, int_stack+1231555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+1057069,int_stack+692344,int_stack+1054819, 1.0, int_stack+963064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1269850,int_stack+487620,int_stack+487200, 1.0, int_stack+539504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1052794,int_stack+488208,int_stack+487620, 1.0, int_stack+539924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1230232,int_stack+1052794,int_stack+1269850, 1.0, int_stack+1191472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1054558,int_stack+488992,int_stack+488208, 1.0, int_stack+540512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1189204,int_stack+1054558,int_stack+1052794, 1.0, int_stack+1040194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+533204,int_stack+1189204,int_stack+1230232, 1.0, int_stack+1233445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+533204,int_stack+692344, 1.0, int_stack+971614, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+920674,int_stack+1084654,int_stack+1057069, 1.0, int_stack+974764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+692344,int_stack+491836,int_stack+490540, 1.0, int_stack+490000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1230232,int_stack+493600,int_stack+491836, 1.0, int_stack+491080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1232500,int_stack+1230232,int_stack+692344, 1.0, int_stack+554644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+692344,int_stack+494608,int_stack+493600, 1.0, int_stack+492592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1052794,int_stack+692344,int_stack+1230232, 1.0, int_stack+1267582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1057330,int_stack+1052794,int_stack+1232500, 1.0, int_stack+1041958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+1057330,int_stack+533204, 1.0, int_stack+1009804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+953704,int_stack+29430,int_stack+1084654, 1.0, int_stack+1014004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+497629,int_stack+497404,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1085329,int_stack+497944,int_stack+497629,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1086274,int_stack+1085329,int_stack+1084654,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1087624,int_stack+498364,int_stack+497944,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1088884,int_stack+1087624,int_stack+1085329,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1090774,int_stack+1088884,int_stack+1086274,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+501319,int_stack+501004,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1085599,int_stack+501760,int_stack+501319,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1086922,int_stack+1085599,int_stack+1084654,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1088812,int_stack+502348,int_stack+501760,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+29430,int_stack+1088812,int_stack+1085599,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+692344,int_stack+29430,int_stack+1086922,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+29430,int_stack+692344,int_stack+1090774, 1.0, int_stack+1050544, 0.0, zero_stack, 1.0, int_stack+1227982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+36180,int_stack+506324,int_stack+505904,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+37440,int_stack+506912,int_stack+506324,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+39204,int_stack+37440,int_stack+36180,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1084654,int_stack+507696,int_stack+506912,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1267582,int_stack+1084654,int_stack+37440,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+533204,int_stack+1267582,int_stack+39204,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+533204,int_stack+692344, 1.0, int_stack+620236, 0.0, zero_stack, 1.0, int_stack+1237855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+620236,int_stack+1084654,int_stack+29430, 1.0, int_stack+1107604, 0.0, zero_stack, 1.0, int_stack+1241005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1107604,int_stack+509244,int_stack+508704,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1109224,int_stack+510000,int_stack+509244,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+29430,int_stack+1109224,int_stack+1107604,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+32670,int_stack+511008,int_stack+510000,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+35694,int_stack+32670,int_stack+1109224,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1107604,int_stack+35694,int_stack+29430,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+29430,int_stack+1107604,int_stack+533204, 1.0, int_stack+1114354, 0.0, zero_stack, 1.0, int_stack+1271110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+633736,int_stack+29430,int_stack+1084654, 1.0, int_stack+1118554, 0.0, zero_stack, 1.0, int_stack+1275310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+514029,int_stack+513804,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1085329,int_stack+514344,int_stack+514029,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1086274,int_stack+1085329,int_stack+1084654,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1087624,int_stack+514764,int_stack+514344,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1088884,int_stack+1087624,int_stack+1085329,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1090774,int_stack+1088884,int_stack+1086274,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+517719,int_stack+517404,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1085599,int_stack+518160,int_stack+517719,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1086922,int_stack+1085599,int_stack+1084654,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1088812,int_stack+518748,int_stack+518160,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+29430,int_stack+1088812,int_stack+1085599,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+692344,int_stack+29430,int_stack+1086922,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+29430,int_stack+692344,int_stack+1090774, 1.0, int_stack+1149919, 1.0, int_stack+1227982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+36180,int_stack+522724,int_stack+522304,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+37440,int_stack+523312,int_stack+522724,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+39204,int_stack+37440,int_stack+36180,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1084654,int_stack+524096,int_stack+523312,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1267582,int_stack+1084654,int_stack+37440,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+533204,int_stack+1267582,int_stack+39204,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1084654,int_stack+533204,int_stack+692344, 1.0, int_stack+1158469, 1.0, int_stack+1237855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1107604,int_stack+1084654,int_stack+29430, 1.0, int_stack+1161619, 1.0, int_stack+1241005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+29430,int_stack+525644,int_stack+525104,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+31050,int_stack+526400,int_stack+525644,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+33318,int_stack+31050,int_stack+29430,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+36558,int_stack+527408,int_stack+526400,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1121104,int_stack+36558,int_stack+31050,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+36558,int_stack+1121104,int_stack+33318,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1353196,int_stack+36558,int_stack+533204, 1.0, int_stack+1192732, 1.0, int_stack+1271110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1036954,int_stack+1353196,int_stack+1084654, 1.0, int_stack+1196932, 1.0, int_stack+1275310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+531929,int_stack+531704,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1085329,int_stack+532244,int_stack+531929,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1086274,int_stack+1085329,int_stack+1084654,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1087624,int_stack+532664,int_stack+532244,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1088884,int_stack+1087624,int_stack+1085329,15);
 /*--- compute (g0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1090774,int_stack+1088884,int_stack+1086274,15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1084654,int_stack+537719,int_stack+537404,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1085599,int_stack+538160,int_stack+537719,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1086922,int_stack+1085599,int_stack+1084654,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1088812,int_stack+538748,int_stack+538160,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1353196,int_stack+1088812,int_stack+1085599,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+692344,int_stack+1353196,int_stack+1086922,21);
 /*--- compute (gp|gf) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+1353196,int_stack+692344,int_stack+1090774, 2.0, int_stack+1227982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1359946,int_stack+542724,int_stack+542304,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1361206,int_stack+543312,int_stack+542724,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1362970,int_stack+1361206,int_stack+1359946,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1084654,int_stack+544096,int_stack+543312,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1267582,int_stack+1084654,int_stack+1361206,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1084654,int_stack+1267582,int_stack+1362970,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+29430,int_stack+1084654,int_stack+692344, 2.0, int_stack+1237855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gd|gf) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1189204,int_stack+29430,int_stack+1353196, 2.0, int_stack+1241005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1353196,int_stack+545644,int_stack+545104,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1354816,int_stack+546400,int_stack+545644,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1357084,int_stack+1354816,int_stack+1353196,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1360324,int_stack+547408,int_stack+546400,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1088854,int_stack+1360324,int_stack+1354816,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1360324,int_stack+1088854,int_stack+1357084,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1219882,int_stack+1360324,int_stack+1084654, 2.0, int_stack+1271110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1141504,int_stack+1219882,int_stack+29430, 2.0, int_stack+1275310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1219882,int_stack+654544,int_stack+606736,150);
     Libderiv->ABCD[11] = int_stack + 1219882;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+425430,int_stack+737794,int_stack+695494,150);
     Libderiv->ABCD[10] = int_stack + 425430;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+722494,int_stack+818524,int_stack+776224,150);
     Libderiv->ABCD[9] = int_stack + 722494;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+808624,int_stack+901774,int_stack+859474,150);
     Libderiv->ABCD[8] = int_stack + 808624;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+886474,int_stack+982504,int_stack+940204,150);
     Libderiv->ABCD[7] = int_stack + 886474;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+972604,int_stack+1065754,int_stack+1023454,150);
     Libderiv->ABCD[6] = int_stack + 972604;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1055854,int_stack+1170304,int_stack+1128004, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1094104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[2] = int_stack + 1055854;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1160404,int_stack+1248682,int_stack+1206382, 0.0, zero_stack, 1.0, int_stack+1094104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[1] = int_stack + 1160404;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1242382,int_stack+1320796,int_stack+1284760, 1.0, int_stack+1094104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[0] = int_stack + 1242382;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1078354,int_stack+1365796,int_stack+1339696,150);
     Libderiv->ABCD[155] = int_stack + 1078354;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+995104,int_stack+1384696,int_stack+15930,150);
     Libderiv->ABCD[143] = int_stack + 995104;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+13500,int_stack+1417096,int_stack+1403596,150);
     Libderiv->ABCD[142] = int_stack + 13500;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+447930,int_stack+1435996,int_stack+1298260,150);
     Libderiv->ABCD[131] = int_stack + 447930;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1298260,int_stack+1454896,int_stack+42030,150);
     Libderiv->ABCD[130] = int_stack + 1298260;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1320760,int_stack+1473796,int_stack+55530,150);
     Libderiv->ABCD[129] = int_stack + 1320760;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1343260,int_stack+1506196,int_stack+1492696,150);
     Libderiv->ABCD[119] = int_stack + 1343260;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1365760,int_stack+1525096,int_stack+69030,150);
     Libderiv->ABCD[118] = int_stack + 1365760;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1388260,int_stack+1543996,int_stack+82530,150);
     Libderiv->ABCD[117] = int_stack + 1388260;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1410760,int_stack+1562896,int_stack+96030,150);
     Libderiv->ABCD[116] = int_stack + 1410760;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1433260,int_stack+1595296,int_stack+1581796,150);
     Libderiv->ABCD[107] = int_stack + 1433260;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1455760,int_stack+1614196,int_stack+109530,150);
     Libderiv->ABCD[106] = int_stack + 1455760;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1478260,int_stack+1633096,int_stack+123030,150);
     Libderiv->ABCD[105] = int_stack + 1478260;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1500760,int_stack+1651996,int_stack+136530,150);
     Libderiv->ABCD[104] = int_stack + 1500760;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1523260,int_stack+1684396,int_stack+1670896,150);
     Libderiv->ABCD[103] = int_stack + 1523260;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1545760,int_stack+1703296,int_stack+150030,150);
     Libderiv->ABCD[95] = int_stack + 1545760;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1568260,int_stack+1722196,int_stack+163530,150);
     Libderiv->ABCD[94] = int_stack + 1568260;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1590760,int_stack+1741096,int_stack+177030,150);
     Libderiv->ABCD[93] = int_stack + 1590760;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1613260,int_stack+1759996,int_stack+190530,150);
     Libderiv->ABCD[92] = int_stack + 1613260;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1635760,int_stack+1778896,int_stack+204030,150);
     Libderiv->ABCD[91] = int_stack + 1635760;
 /*--- compute (gf|gf) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1658260,int_stack+1797796,int_stack+217530,150);
     Libderiv->ABCD[90] = int_stack + 1658260;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1680760,int_stack+1816696,int_stack+231030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+606736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[47] = int_stack + 1680760;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1703260,int_stack+1849096,int_stack+1835596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+695494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[46] = int_stack + 1703260;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1725760,int_stack+1867996,int_stack+244530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+776224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[45] = int_stack + 1725760;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1748260,int_stack+1886896,int_stack+258030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+859474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[44] = int_stack + 1748260;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1770760,int_stack+1905796,int_stack+271530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+940204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[43] = int_stack + 1770760;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1793260,int_stack+1938196,int_stack+1924696, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1023454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[42] = int_stack + 1793260;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1815760,int_stack+1957096,int_stack+285030, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1128004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[38] = int_stack + 1815760;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1838260,int_stack+1975996,int_stack+298530, 0.0, zero_stack, 1.0, int_stack+606736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[35] = int_stack + 1838260;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1860760,int_stack+1994896,int_stack+312030, 0.0, zero_stack, 1.0, int_stack+695494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[34] = int_stack + 1860760;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1883260,int_stack+2027296,int_stack+2013796, 0.0, zero_stack, 1.0, int_stack+776224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[33] = int_stack + 1883260;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1905760,int_stack+2046196,int_stack+325530, 0.0, zero_stack, 1.0, int_stack+859474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[32] = int_stack + 1905760;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1928260,int_stack+2065096,int_stack+339030, 0.0, zero_stack, 1.0, int_stack+940204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[31] = int_stack + 1928260;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1950760,int_stack+2083996,int_stack+352530, 0.0, zero_stack, 1.0, int_stack+1023454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[30] = int_stack + 1950760;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1973260,int_stack+2102896,int_stack+0, 0.0, zero_stack, 1.0, int_stack+1128004, 1.0, int_stack+1206382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[26] = int_stack + 1973260;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1995760,int_stack+2121796,int_stack+366030, 0.0, zero_stack, 2.0, int_stack+1206382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[25] = int_stack + 1995760;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+2018260,int_stack+556264,int_stack+379530, 1.0, int_stack+606736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[23] = int_stack + 2018260;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+2040760,int_stack+406530,int_stack+393030, 1.0, int_stack+695494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[22] = int_stack + 2040760;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+2063260,int_stack+673444,int_stack+708994, 1.0, int_stack+776224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[21] = int_stack + 2063260;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+2085760,int_stack+789724,int_stack+756694, 1.0, int_stack+859474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[20] = int_stack + 2085760;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+2108260,int_stack+837424,int_stack+872974, 1.0, int_stack+940204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[19] = int_stack + 2108260;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+652636,int_stack+953704,int_stack+920674, 1.0, int_stack+1023454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[18] = int_stack + 652636;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+675136,int_stack+633736,int_stack+620236, 1.0, int_stack+1128004, 0.0, zero_stack, 1.0, int_stack+1284760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[14] = int_stack + 675136;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+697636,int_stack+1036954,int_stack+1107604, 1.0, int_stack+1206382, 1.0, int_stack+1284760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[13] = int_stack + 697636;
 /*--- compute (gf|gf) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1100854,int_stack+1141504,int_stack+1189204, 2.0, int_stack+1284760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[12] = int_stack + 1100854;

}
