/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_gghh(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gg|hh) integrals */

void d12hrr_order_gghh(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[8][10][11] = int_stack + 0;
 Libderiv->deriv_classes[8][10][10] = int_stack + 2970;
 Libderiv->deriv_classes[8][10][9] = int_stack + 5940;
 Libderiv->deriv_classes[8][10][8] = int_stack + 8910;
 Libderiv->deriv_classes[8][10][7] = int_stack + 11880;
 Libderiv->dvrr_classes[8][9] = int_stack + 14850;
 Libderiv->deriv_classes[8][10][6] = int_stack + 17325;
 Libderiv->deriv_classes[8][10][2] = int_stack + 20295;
 Libderiv->deriv_classes[8][10][1] = int_stack + 23265;
 Libderiv->dvrr_classes[7][10] = int_stack + 26235;
 Libderiv->deriv_classes[8][10][0] = int_stack + 28611;
 Libderiv->deriv2_classes[4][5][143] = int_stack + 31581;
 Libderiv->deriv2_classes[4][6][143] = int_stack + 31896;
 Libderiv->deriv2_classes[4][7][143] = int_stack + 32316;
 Libderiv->deriv2_classes[4][8][143] = int_stack + 32856;
 Libderiv->deriv2_classes[4][9][143] = int_stack + 33531;
 Libderiv->deriv2_classes[4][10][143] = int_stack + 34356;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 35346;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 35787;
 Libderiv->deriv2_classes[5][7][143] = int_stack + 36375;
 Libderiv->deriv2_classes[5][8][143] = int_stack + 37131;
 Libderiv->deriv2_classes[5][9][143] = int_stack + 38076;
 Libderiv->deriv2_classes[5][10][143] = int_stack + 39231;
 Libderiv->deriv2_classes[6][5][143] = int_stack + 40617;
 Libderiv->deriv2_classes[6][6][143] = int_stack + 41205;
 Libderiv->deriv2_classes[6][7][143] = int_stack + 41989;
 Libderiv->deriv2_classes[6][8][143] = int_stack + 42997;
 Libderiv->deriv2_classes[6][9][143] = int_stack + 44257;
 Libderiv->deriv2_classes[6][10][143] = int_stack + 45797;
 Libderiv->deriv2_classes[7][5][143] = int_stack + 47645;
 Libderiv->deriv2_classes[7][6][143] = int_stack + 48401;
 Libderiv->deriv2_classes[7][7][143] = int_stack + 49409;
 Libderiv->deriv2_classes[7][8][143] = int_stack + 50705;
 Libderiv->deriv2_classes[7][9][143] = int_stack + 52325;
 Libderiv->deriv2_classes[7][10][143] = int_stack + 54305;
 Libderiv->deriv2_classes[8][5][143] = int_stack + 56681;
 Libderiv->deriv2_classes[8][6][143] = int_stack + 57626;
 Libderiv->deriv2_classes[8][7][143] = int_stack + 58886;
 Libderiv->deriv2_classes[8][8][143] = int_stack + 60506;
 Libderiv->deriv2_classes[8][9][143] = int_stack + 62531;
 Libderiv->deriv2_classes[8][10][143] = int_stack + 65006;
 Libderiv->deriv2_classes[4][5][131] = int_stack + 67976;
 Libderiv->deriv2_classes[4][6][131] = int_stack + 68291;
 Libderiv->deriv2_classes[4][7][131] = int_stack + 68711;
 Libderiv->deriv2_classes[4][8][131] = int_stack + 69251;
 Libderiv->deriv2_classes[4][9][131] = int_stack + 69926;
 Libderiv->deriv2_classes[4][10][131] = int_stack + 70751;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 71741;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 72182;
 Libderiv->deriv2_classes[5][7][131] = int_stack + 72770;
 Libderiv->deriv2_classes[5][8][131] = int_stack + 73526;
 Libderiv->deriv2_classes[5][9][131] = int_stack + 74471;
 Libderiv->deriv2_classes[5][10][131] = int_stack + 75626;
 Libderiv->deriv2_classes[6][5][131] = int_stack + 77012;
 Libderiv->deriv2_classes[6][6][131] = int_stack + 77600;
 Libderiv->deriv2_classes[6][7][131] = int_stack + 78384;
 Libderiv->deriv2_classes[6][8][131] = int_stack + 79392;
 Libderiv->deriv2_classes[6][9][131] = int_stack + 80652;
 Libderiv->deriv2_classes[6][10][131] = int_stack + 82192;
 Libderiv->deriv2_classes[7][5][131] = int_stack + 84040;
 Libderiv->deriv2_classes[7][6][131] = int_stack + 84796;
 Libderiv->deriv2_classes[7][7][131] = int_stack + 85804;
 Libderiv->deriv2_classes[7][8][131] = int_stack + 87100;
 Libderiv->deriv2_classes[7][9][131] = int_stack + 88720;
 Libderiv->deriv2_classes[7][10][131] = int_stack + 90700;
 Libderiv->deriv2_classes[8][5][131] = int_stack + 93076;
 Libderiv->deriv2_classes[8][6][131] = int_stack + 94021;
 Libderiv->deriv2_classes[8][7][131] = int_stack + 95281;
 Libderiv->deriv2_classes[8][8][131] = int_stack + 96901;
 Libderiv->deriv2_classes[8][9][131] = int_stack + 98926;
 Libderiv->deriv2_classes[8][10][131] = int_stack + 101401;
 Libderiv->deriv2_classes[4][5][130] = int_stack + 104371;
 Libderiv->deriv2_classes[4][6][130] = int_stack + 104686;
 Libderiv->deriv2_classes[4][7][130] = int_stack + 105106;
 Libderiv->deriv2_classes[4][8][130] = int_stack + 105646;
 Libderiv->deriv2_classes[4][9][130] = int_stack + 106321;
 Libderiv->deriv2_classes[4][10][130] = int_stack + 107146;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 108136;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 108577;
 Libderiv->deriv2_classes[5][7][130] = int_stack + 109165;
 Libderiv->deriv2_classes[5][8][130] = int_stack + 109921;
 Libderiv->deriv2_classes[5][9][130] = int_stack + 110866;
 Libderiv->deriv2_classes[5][10][130] = int_stack + 112021;
 Libderiv->deriv2_classes[6][5][130] = int_stack + 113407;
 Libderiv->deriv2_classes[6][6][130] = int_stack + 113995;
 Libderiv->deriv2_classes[6][7][130] = int_stack + 114779;
 Libderiv->deriv2_classes[6][8][130] = int_stack + 115787;
 Libderiv->deriv2_classes[6][9][130] = int_stack + 117047;
 Libderiv->deriv2_classes[6][10][130] = int_stack + 118587;
 Libderiv->deriv2_classes[7][5][130] = int_stack + 120435;
 Libderiv->deriv2_classes[7][6][130] = int_stack + 121191;
 Libderiv->deriv2_classes[7][7][130] = int_stack + 122199;
 Libderiv->deriv2_classes[7][8][130] = int_stack + 123495;
 Libderiv->deriv2_classes[7][9][130] = int_stack + 125115;
 Libderiv->deriv2_classes[7][10][130] = int_stack + 127095;
 Libderiv->deriv2_classes[8][5][130] = int_stack + 129471;
 Libderiv->deriv2_classes[8][6][130] = int_stack + 130416;
 Libderiv->deriv2_classes[8][7][130] = int_stack + 131676;
 Libderiv->deriv2_classes[8][8][130] = int_stack + 133296;
 Libderiv->deriv2_classes[8][9][130] = int_stack + 135321;
 Libderiv->deriv2_classes[8][10][130] = int_stack + 137796;
 Libderiv->deriv2_classes[4][5][119] = int_stack + 140766;
 Libderiv->deriv2_classes[4][6][119] = int_stack + 141081;
 Libderiv->deriv2_classes[4][7][119] = int_stack + 141501;
 Libderiv->deriv2_classes[4][8][119] = int_stack + 142041;
 Libderiv->deriv2_classes[4][9][119] = int_stack + 142716;
 Libderiv->deriv2_classes[4][10][119] = int_stack + 143541;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 144531;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 144972;
 Libderiv->deriv2_classes[5][7][119] = int_stack + 145560;
 Libderiv->deriv2_classes[5][8][119] = int_stack + 146316;
 Libderiv->deriv2_classes[5][9][119] = int_stack + 147261;
 Libderiv->deriv2_classes[5][10][119] = int_stack + 148416;
 Libderiv->deriv2_classes[6][5][119] = int_stack + 149802;
 Libderiv->deriv2_classes[6][6][119] = int_stack + 150390;
 Libderiv->deriv2_classes[6][7][119] = int_stack + 151174;
 Libderiv->deriv2_classes[6][8][119] = int_stack + 152182;
 Libderiv->deriv2_classes[6][9][119] = int_stack + 153442;
 Libderiv->deriv2_classes[6][10][119] = int_stack + 154982;
 Libderiv->deriv2_classes[7][5][119] = int_stack + 156830;
 Libderiv->deriv2_classes[7][6][119] = int_stack + 157586;
 Libderiv->deriv2_classes[7][7][119] = int_stack + 158594;
 Libderiv->deriv2_classes[7][8][119] = int_stack + 159890;
 Libderiv->deriv2_classes[7][9][119] = int_stack + 161510;
 Libderiv->deriv2_classes[7][10][119] = int_stack + 163490;
 Libderiv->deriv2_classes[8][5][119] = int_stack + 165866;
 Libderiv->deriv2_classes[8][6][119] = int_stack + 166811;
 Libderiv->deriv2_classes[8][7][119] = int_stack + 168071;
 Libderiv->deriv2_classes[8][8][119] = int_stack + 169691;
 Libderiv->deriv2_classes[8][9][119] = int_stack + 171716;
 Libderiv->deriv2_classes[8][10][119] = int_stack + 174191;
 Libderiv->deriv2_classes[4][5][118] = int_stack + 177161;
 Libderiv->deriv2_classes[4][6][118] = int_stack + 177476;
 Libderiv->deriv2_classes[4][7][118] = int_stack + 177896;
 Libderiv->deriv2_classes[4][8][118] = int_stack + 178436;
 Libderiv->deriv2_classes[4][9][118] = int_stack + 179111;
 Libderiv->deriv2_classes[4][10][118] = int_stack + 179936;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 180926;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 181367;
 Libderiv->deriv2_classes[5][7][118] = int_stack + 181955;
 Libderiv->deriv2_classes[5][8][118] = int_stack + 182711;
 Libderiv->deriv2_classes[5][9][118] = int_stack + 183656;
 Libderiv->deriv2_classes[5][10][118] = int_stack + 184811;
 Libderiv->deriv2_classes[6][5][118] = int_stack + 186197;
 Libderiv->deriv2_classes[6][6][118] = int_stack + 186785;
 Libderiv->deriv2_classes[6][7][118] = int_stack + 187569;
 Libderiv->deriv2_classes[6][8][118] = int_stack + 188577;
 Libderiv->deriv2_classes[6][9][118] = int_stack + 189837;
 Libderiv->deriv2_classes[6][10][118] = int_stack + 191377;
 Libderiv->deriv2_classes[7][5][118] = int_stack + 193225;
 Libderiv->deriv2_classes[7][6][118] = int_stack + 193981;
 Libderiv->deriv2_classes[7][7][118] = int_stack + 194989;
 Libderiv->deriv2_classes[7][8][118] = int_stack + 196285;
 Libderiv->deriv2_classes[7][9][118] = int_stack + 197905;
 Libderiv->deriv2_classes[7][10][118] = int_stack + 199885;
 Libderiv->deriv2_classes[8][5][118] = int_stack + 202261;
 Libderiv->deriv2_classes[8][6][118] = int_stack + 203206;
 Libderiv->deriv2_classes[8][7][118] = int_stack + 204466;
 Libderiv->deriv2_classes[8][8][118] = int_stack + 206086;
 Libderiv->deriv2_classes[8][9][118] = int_stack + 208111;
 Libderiv->deriv2_classes[8][10][118] = int_stack + 210586;
 Libderiv->deriv2_classes[4][5][117] = int_stack + 213556;
 Libderiv->deriv2_classes[4][6][117] = int_stack + 213871;
 Libderiv->deriv2_classes[4][7][117] = int_stack + 214291;
 Libderiv->deriv2_classes[4][8][117] = int_stack + 214831;
 Libderiv->deriv2_classes[4][9][117] = int_stack + 215506;
 Libderiv->deriv2_classes[4][10][117] = int_stack + 216331;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 217321;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 217762;
 Libderiv->deriv2_classes[5][7][117] = int_stack + 218350;
 Libderiv->deriv2_classes[5][8][117] = int_stack + 219106;
 Libderiv->deriv2_classes[5][9][117] = int_stack + 220051;
 Libderiv->deriv2_classes[5][10][117] = int_stack + 221206;
 Libderiv->deriv2_classes[6][5][117] = int_stack + 222592;
 Libderiv->deriv2_classes[6][6][117] = int_stack + 223180;
 Libderiv->deriv2_classes[6][7][117] = int_stack + 223964;
 Libderiv->deriv2_classes[6][8][117] = int_stack + 224972;
 Libderiv->deriv2_classes[6][9][117] = int_stack + 226232;
 Libderiv->deriv2_classes[6][10][117] = int_stack + 227772;
 Libderiv->deriv2_classes[7][5][117] = int_stack + 229620;
 Libderiv->deriv2_classes[7][6][117] = int_stack + 230376;
 Libderiv->deriv2_classes[7][7][117] = int_stack + 231384;
 Libderiv->deriv2_classes[7][8][117] = int_stack + 232680;
 Libderiv->deriv2_classes[7][9][117] = int_stack + 234300;
 Libderiv->deriv2_classes[7][10][117] = int_stack + 236280;
 Libderiv->deriv2_classes[8][5][117] = int_stack + 238656;
 Libderiv->deriv2_classes[8][6][117] = int_stack + 239601;
 Libderiv->deriv2_classes[8][7][117] = int_stack + 240861;
 Libderiv->deriv2_classes[8][8][117] = int_stack + 242481;
 Libderiv->deriv2_classes[8][9][117] = int_stack + 244506;
 Libderiv->deriv2_classes[8][10][117] = int_stack + 246981;
 Libderiv->deriv2_classes[4][5][107] = int_stack + 249951;
 Libderiv->deriv2_classes[4][6][107] = int_stack + 250266;
 Libderiv->deriv2_classes[4][7][107] = int_stack + 250686;
 Libderiv->deriv2_classes[4][8][107] = int_stack + 251226;
 Libderiv->deriv2_classes[4][9][107] = int_stack + 251901;
 Libderiv->deriv2_classes[4][10][107] = int_stack + 252726;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 253716;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 254157;
 Libderiv->deriv2_classes[5][7][107] = int_stack + 254745;
 Libderiv->deriv2_classes[5][8][107] = int_stack + 255501;
 Libderiv->deriv2_classes[5][9][107] = int_stack + 256446;
 Libderiv->deriv2_classes[5][10][107] = int_stack + 257601;
 Libderiv->deriv2_classes[6][5][107] = int_stack + 258987;
 Libderiv->deriv2_classes[6][6][107] = int_stack + 259575;
 Libderiv->deriv2_classes[6][7][107] = int_stack + 260359;
 Libderiv->deriv2_classes[6][8][107] = int_stack + 261367;
 Libderiv->deriv2_classes[6][9][107] = int_stack + 262627;
 Libderiv->deriv2_classes[6][10][107] = int_stack + 264167;
 Libderiv->deriv2_classes[7][5][107] = int_stack + 266015;
 Libderiv->deriv2_classes[7][6][107] = int_stack + 266771;
 Libderiv->deriv2_classes[7][7][107] = int_stack + 267779;
 Libderiv->deriv2_classes[7][8][107] = int_stack + 269075;
 Libderiv->deriv2_classes[7][9][107] = int_stack + 270695;
 Libderiv->deriv2_classes[7][10][107] = int_stack + 272675;
 Libderiv->deriv2_classes[8][5][107] = int_stack + 275051;
 Libderiv->deriv2_classes[8][6][107] = int_stack + 275996;
 Libderiv->deriv2_classes[8][7][107] = int_stack + 277256;
 Libderiv->deriv2_classes[8][8][107] = int_stack + 278876;
 Libderiv->deriv2_classes[8][9][107] = int_stack + 280901;
 Libderiv->deriv2_classes[8][10][107] = int_stack + 283376;
 Libderiv->deriv2_classes[4][5][106] = int_stack + 286346;
 Libderiv->deriv2_classes[4][6][106] = int_stack + 286661;
 Libderiv->deriv2_classes[4][7][106] = int_stack + 287081;
 Libderiv->deriv2_classes[4][8][106] = int_stack + 287621;
 Libderiv->deriv2_classes[4][9][106] = int_stack + 288296;
 Libderiv->deriv2_classes[4][10][106] = int_stack + 289121;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 290111;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 290552;
 Libderiv->deriv2_classes[5][7][106] = int_stack + 291140;
 Libderiv->deriv2_classes[5][8][106] = int_stack + 291896;
 Libderiv->deriv2_classes[5][9][106] = int_stack + 292841;
 Libderiv->deriv2_classes[5][10][106] = int_stack + 293996;
 Libderiv->deriv2_classes[6][5][106] = int_stack + 295382;
 Libderiv->deriv2_classes[6][6][106] = int_stack + 295970;
 Libderiv->deriv2_classes[6][7][106] = int_stack + 296754;
 Libderiv->deriv2_classes[6][8][106] = int_stack + 297762;
 Libderiv->deriv2_classes[6][9][106] = int_stack + 299022;
 Libderiv->deriv2_classes[6][10][106] = int_stack + 300562;
 Libderiv->deriv2_classes[7][5][106] = int_stack + 302410;
 Libderiv->deriv2_classes[7][6][106] = int_stack + 303166;
 Libderiv->deriv2_classes[7][7][106] = int_stack + 304174;
 Libderiv->deriv2_classes[7][8][106] = int_stack + 305470;
 Libderiv->deriv2_classes[7][9][106] = int_stack + 307090;
 Libderiv->deriv2_classes[7][10][106] = int_stack + 309070;
 Libderiv->deriv2_classes[8][5][106] = int_stack + 311446;
 Libderiv->deriv2_classes[8][6][106] = int_stack + 312391;
 Libderiv->deriv2_classes[8][7][106] = int_stack + 313651;
 Libderiv->deriv2_classes[8][8][106] = int_stack + 315271;
 Libderiv->deriv2_classes[8][9][106] = int_stack + 317296;
 Libderiv->deriv2_classes[8][10][106] = int_stack + 319771;
 Libderiv->deriv2_classes[4][5][105] = int_stack + 322741;
 Libderiv->deriv2_classes[4][6][105] = int_stack + 323056;
 Libderiv->deriv2_classes[4][7][105] = int_stack + 323476;
 Libderiv->deriv2_classes[4][8][105] = int_stack + 324016;
 Libderiv->deriv2_classes[4][9][105] = int_stack + 324691;
 Libderiv->deriv2_classes[4][10][105] = int_stack + 325516;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 326506;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 326947;
 Libderiv->deriv2_classes[5][7][105] = int_stack + 327535;
 Libderiv->deriv2_classes[5][8][105] = int_stack + 328291;
 Libderiv->deriv2_classes[5][9][105] = int_stack + 329236;
 Libderiv->deriv2_classes[5][10][105] = int_stack + 330391;
 Libderiv->deriv2_classes[6][5][105] = int_stack + 331777;
 Libderiv->deriv2_classes[6][6][105] = int_stack + 332365;
 Libderiv->deriv2_classes[6][7][105] = int_stack + 333149;
 Libderiv->deriv2_classes[6][8][105] = int_stack + 334157;
 Libderiv->deriv2_classes[6][9][105] = int_stack + 335417;
 Libderiv->deriv2_classes[6][10][105] = int_stack + 336957;
 Libderiv->deriv2_classes[7][5][105] = int_stack + 338805;
 Libderiv->deriv2_classes[7][6][105] = int_stack + 339561;
 Libderiv->deriv2_classes[7][7][105] = int_stack + 340569;
 Libderiv->deriv2_classes[7][8][105] = int_stack + 341865;
 Libderiv->deriv2_classes[7][9][105] = int_stack + 343485;
 Libderiv->deriv2_classes[7][10][105] = int_stack + 345465;
 Libderiv->deriv2_classes[8][5][105] = int_stack + 347841;
 Libderiv->deriv2_classes[8][6][105] = int_stack + 348786;
 Libderiv->deriv2_classes[8][7][105] = int_stack + 350046;
 Libderiv->deriv2_classes[8][8][105] = int_stack + 351666;
 Libderiv->deriv2_classes[8][9][105] = int_stack + 353691;
 Libderiv->deriv2_classes[8][10][105] = int_stack + 356166;
 Libderiv->deriv2_classes[4][5][104] = int_stack + 359136;
 Libderiv->deriv2_classes[4][6][104] = int_stack + 359451;
 Libderiv->deriv2_classes[4][7][104] = int_stack + 359871;
 Libderiv->deriv2_classes[4][8][104] = int_stack + 360411;
 Libderiv->deriv2_classes[4][9][104] = int_stack + 361086;
 Libderiv->deriv2_classes[4][10][104] = int_stack + 361911;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 362901;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 363342;
 Libderiv->deriv2_classes[5][7][104] = int_stack + 363930;
 Libderiv->deriv2_classes[5][8][104] = int_stack + 364686;
 Libderiv->deriv2_classes[5][9][104] = int_stack + 365631;
 Libderiv->deriv2_classes[5][10][104] = int_stack + 366786;
 Libderiv->deriv2_classes[6][5][104] = int_stack + 368172;
 Libderiv->deriv2_classes[6][6][104] = int_stack + 368760;
 Libderiv->deriv2_classes[6][7][104] = int_stack + 369544;
 Libderiv->deriv2_classes[6][8][104] = int_stack + 370552;
 Libderiv->deriv2_classes[6][9][104] = int_stack + 371812;
 Libderiv->deriv2_classes[6][10][104] = int_stack + 373352;
 Libderiv->deriv2_classes[7][5][104] = int_stack + 375200;
 Libderiv->deriv2_classes[7][6][104] = int_stack + 375956;
 Libderiv->deriv2_classes[7][7][104] = int_stack + 376964;
 Libderiv->deriv2_classes[7][8][104] = int_stack + 378260;
 Libderiv->deriv2_classes[7][9][104] = int_stack + 379880;
 Libderiv->deriv2_classes[7][10][104] = int_stack + 381860;
 Libderiv->deriv2_classes[8][5][104] = int_stack + 384236;
 Libderiv->deriv2_classes[8][6][104] = int_stack + 385181;
 Libderiv->deriv2_classes[8][7][104] = int_stack + 386441;
 Libderiv->deriv2_classes[8][8][104] = int_stack + 388061;
 Libderiv->deriv2_classes[8][9][104] = int_stack + 390086;
 Libderiv->deriv2_classes[8][10][104] = int_stack + 392561;
 Libderiv->deriv2_classes[4][5][95] = int_stack + 395531;
 Libderiv->deriv2_classes[4][6][95] = int_stack + 395846;
 Libderiv->deriv2_classes[4][7][95] = int_stack + 396266;
 Libderiv->deriv2_classes[4][8][95] = int_stack + 396806;
 Libderiv->deriv2_classes[4][9][95] = int_stack + 397481;
 Libderiv->deriv2_classes[4][10][95] = int_stack + 398306;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 399296;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 399737;
 Libderiv->deriv2_classes[5][7][95] = int_stack + 400325;
 Libderiv->deriv2_classes[5][8][95] = int_stack + 401081;
 Libderiv->deriv2_classes[5][9][95] = int_stack + 402026;
 Libderiv->deriv2_classes[5][10][95] = int_stack + 403181;
 Libderiv->deriv2_classes[6][5][95] = int_stack + 404567;
 Libderiv->deriv2_classes[6][6][95] = int_stack + 405155;
 Libderiv->deriv2_classes[6][7][95] = int_stack + 405939;
 Libderiv->deriv2_classes[6][8][95] = int_stack + 406947;
 Libderiv->deriv2_classes[6][9][95] = int_stack + 408207;
 Libderiv->deriv2_classes[6][10][95] = int_stack + 409747;
 Libderiv->deriv2_classes[7][5][95] = int_stack + 411595;
 Libderiv->deriv2_classes[7][6][95] = int_stack + 412351;
 Libderiv->deriv2_classes[7][7][95] = int_stack + 413359;
 Libderiv->deriv2_classes[7][8][95] = int_stack + 414655;
 Libderiv->deriv2_classes[7][9][95] = int_stack + 416275;
 Libderiv->deriv2_classes[7][10][95] = int_stack + 418255;
 Libderiv->deriv2_classes[8][5][95] = int_stack + 420631;
 Libderiv->deriv2_classes[8][6][95] = int_stack + 421576;
 Libderiv->deriv2_classes[8][7][95] = int_stack + 422836;
 Libderiv->deriv2_classes[8][8][95] = int_stack + 424456;
 Libderiv->deriv2_classes[8][9][95] = int_stack + 426481;
 Libderiv->deriv2_classes[8][10][95] = int_stack + 428956;
 Libderiv->deriv2_classes[4][5][94] = int_stack + 431926;
 Libderiv->deriv2_classes[4][6][94] = int_stack + 432241;
 Libderiv->deriv2_classes[4][7][94] = int_stack + 432661;
 Libderiv->deriv2_classes[4][8][94] = int_stack + 433201;
 Libderiv->deriv2_classes[4][9][94] = int_stack + 433876;
 Libderiv->deriv2_classes[4][10][94] = int_stack + 434701;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 435691;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 436132;
 Libderiv->deriv2_classes[5][7][94] = int_stack + 436720;
 Libderiv->deriv2_classes[5][8][94] = int_stack + 437476;
 Libderiv->deriv2_classes[5][9][94] = int_stack + 438421;
 Libderiv->deriv2_classes[5][10][94] = int_stack + 439576;
 Libderiv->deriv2_classes[6][5][94] = int_stack + 440962;
 Libderiv->deriv2_classes[6][6][94] = int_stack + 441550;
 Libderiv->deriv2_classes[6][7][94] = int_stack + 442334;
 Libderiv->deriv2_classes[6][8][94] = int_stack + 443342;
 Libderiv->deriv2_classes[6][9][94] = int_stack + 444602;
 Libderiv->deriv2_classes[6][10][94] = int_stack + 446142;
 Libderiv->deriv2_classes[7][5][94] = int_stack + 447990;
 Libderiv->deriv2_classes[7][6][94] = int_stack + 448746;
 Libderiv->deriv2_classes[7][7][94] = int_stack + 449754;
 Libderiv->deriv2_classes[7][8][94] = int_stack + 451050;
 Libderiv->deriv2_classes[7][9][94] = int_stack + 452670;
 Libderiv->deriv2_classes[7][10][94] = int_stack + 454650;
 Libderiv->deriv2_classes[8][5][94] = int_stack + 457026;
 Libderiv->deriv2_classes[8][6][94] = int_stack + 457971;
 Libderiv->deriv2_classes[8][7][94] = int_stack + 459231;
 Libderiv->deriv2_classes[8][8][94] = int_stack + 460851;
 Libderiv->deriv2_classes[8][9][94] = int_stack + 462876;
 Libderiv->deriv2_classes[8][10][94] = int_stack + 465351;
 Libderiv->deriv2_classes[4][5][93] = int_stack + 468321;
 Libderiv->deriv2_classes[4][6][93] = int_stack + 468636;
 Libderiv->deriv2_classes[4][7][93] = int_stack + 469056;
 Libderiv->deriv2_classes[4][8][93] = int_stack + 469596;
 Libderiv->deriv2_classes[4][9][93] = int_stack + 470271;
 Libderiv->deriv2_classes[4][10][93] = int_stack + 471096;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 472086;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 472527;
 Libderiv->deriv2_classes[5][7][93] = int_stack + 473115;
 Libderiv->deriv2_classes[5][8][93] = int_stack + 473871;
 Libderiv->deriv2_classes[5][9][93] = int_stack + 474816;
 Libderiv->deriv2_classes[5][10][93] = int_stack + 475971;
 Libderiv->deriv2_classes[6][5][93] = int_stack + 477357;
 Libderiv->deriv2_classes[6][6][93] = int_stack + 477945;
 Libderiv->deriv2_classes[6][7][93] = int_stack + 478729;
 Libderiv->deriv2_classes[6][8][93] = int_stack + 479737;
 Libderiv->deriv2_classes[6][9][93] = int_stack + 480997;
 Libderiv->deriv2_classes[6][10][93] = int_stack + 482537;
 Libderiv->deriv2_classes[7][5][93] = int_stack + 484385;
 Libderiv->deriv2_classes[7][6][93] = int_stack + 485141;
 Libderiv->deriv2_classes[7][7][93] = int_stack + 486149;
 Libderiv->deriv2_classes[7][8][93] = int_stack + 487445;
 Libderiv->deriv2_classes[7][9][93] = int_stack + 489065;
 Libderiv->deriv2_classes[7][10][93] = int_stack + 491045;
 Libderiv->deriv2_classes[8][5][93] = int_stack + 493421;
 Libderiv->deriv2_classes[8][6][93] = int_stack + 494366;
 Libderiv->deriv2_classes[8][7][93] = int_stack + 495626;
 Libderiv->deriv2_classes[8][8][93] = int_stack + 497246;
 Libderiv->deriv2_classes[8][9][93] = int_stack + 499271;
 Libderiv->deriv2_classes[8][10][93] = int_stack + 501746;
 Libderiv->deriv2_classes[4][5][92] = int_stack + 504716;
 Libderiv->deriv2_classes[4][6][92] = int_stack + 505031;
 Libderiv->deriv2_classes[4][7][92] = int_stack + 505451;
 Libderiv->deriv2_classes[4][8][92] = int_stack + 505991;
 Libderiv->deriv2_classes[4][9][92] = int_stack + 506666;
 Libderiv->deriv2_classes[4][10][92] = int_stack + 507491;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 508481;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 508922;
 Libderiv->deriv2_classes[5][7][92] = int_stack + 509510;
 Libderiv->deriv2_classes[5][8][92] = int_stack + 510266;
 Libderiv->deriv2_classes[5][9][92] = int_stack + 511211;
 Libderiv->deriv2_classes[5][10][92] = int_stack + 512366;
 Libderiv->deriv2_classes[6][5][92] = int_stack + 513752;
 Libderiv->deriv2_classes[6][6][92] = int_stack + 514340;
 Libderiv->deriv2_classes[6][7][92] = int_stack + 515124;
 Libderiv->deriv2_classes[6][8][92] = int_stack + 516132;
 Libderiv->deriv2_classes[6][9][92] = int_stack + 517392;
 Libderiv->deriv2_classes[6][10][92] = int_stack + 518932;
 Libderiv->deriv2_classes[7][5][92] = int_stack + 520780;
 Libderiv->deriv2_classes[7][6][92] = int_stack + 521536;
 Libderiv->deriv2_classes[7][7][92] = int_stack + 522544;
 Libderiv->deriv2_classes[7][8][92] = int_stack + 523840;
 Libderiv->deriv2_classes[7][9][92] = int_stack + 525460;
 Libderiv->deriv2_classes[7][10][92] = int_stack + 527440;
 Libderiv->deriv2_classes[8][5][92] = int_stack + 529816;
 Libderiv->deriv2_classes[8][6][92] = int_stack + 530761;
 Libderiv->deriv2_classes[8][7][92] = int_stack + 532021;
 Libderiv->deriv2_classes[8][8][92] = int_stack + 533641;
 Libderiv->deriv2_classes[8][9][92] = int_stack + 535666;
 Libderiv->deriv2_classes[8][10][92] = int_stack + 538141;
 Libderiv->deriv2_classes[4][5][91] = int_stack + 541111;
 Libderiv->deriv2_classes[4][6][91] = int_stack + 541426;
 Libderiv->deriv2_classes[4][7][91] = int_stack + 541846;
 Libderiv->deriv2_classes[4][8][91] = int_stack + 542386;
 Libderiv->deriv2_classes[4][9][91] = int_stack + 543061;
 Libderiv->deriv2_classes[4][10][91] = int_stack + 543886;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 544876;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 545317;
 Libderiv->deriv2_classes[5][7][91] = int_stack + 545905;
 Libderiv->deriv2_classes[5][8][91] = int_stack + 546661;
 Libderiv->deriv2_classes[5][9][91] = int_stack + 547606;
 Libderiv->deriv2_classes[5][10][91] = int_stack + 548761;
 Libderiv->deriv2_classes[6][5][91] = int_stack + 550147;
 Libderiv->deriv2_classes[6][6][91] = int_stack + 550735;
 Libderiv->deriv2_classes[6][7][91] = int_stack + 551519;
 Libderiv->deriv2_classes[6][8][91] = int_stack + 552527;
 Libderiv->deriv2_classes[6][9][91] = int_stack + 553787;
 Libderiv->deriv2_classes[6][10][91] = int_stack + 555327;
 Libderiv->deriv2_classes[7][5][91] = int_stack + 557175;
 Libderiv->deriv2_classes[7][6][91] = int_stack + 557931;
 Libderiv->deriv2_classes[7][7][91] = int_stack + 558939;
 Libderiv->deriv2_classes[7][8][91] = int_stack + 560235;
 Libderiv->deriv2_classes[7][9][91] = int_stack + 561855;
 Libderiv->deriv2_classes[7][10][91] = int_stack + 563835;
 Libderiv->deriv2_classes[8][5][91] = int_stack + 566211;
 Libderiv->deriv2_classes[8][6][91] = int_stack + 567156;
 Libderiv->deriv2_classes[8][7][91] = int_stack + 568416;
 Libderiv->deriv2_classes[8][8][91] = int_stack + 570036;
 Libderiv->deriv2_classes[8][9][91] = int_stack + 572061;
 Libderiv->deriv2_classes[8][10][91] = int_stack + 574536;
 Libderiv->deriv2_classes[4][5][83] = int_stack + 577506;
 Libderiv->deriv2_classes[4][6][83] = int_stack + 577821;
 Libderiv->deriv2_classes[4][7][83] = int_stack + 578241;
 Libderiv->deriv2_classes[4][8][83] = int_stack + 578781;
 Libderiv->deriv2_classes[4][9][83] = int_stack + 579456;
 Libderiv->deriv2_classes[4][10][83] = int_stack + 580281;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 581271;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 581712;
 Libderiv->deriv2_classes[5][7][83] = int_stack + 582300;
 Libderiv->deriv2_classes[5][8][83] = int_stack + 583056;
 Libderiv->deriv2_classes[5][9][83] = int_stack + 584001;
 Libderiv->deriv2_classes[5][10][83] = int_stack + 585156;
 Libderiv->deriv2_classes[6][5][83] = int_stack + 586542;
 Libderiv->deriv2_classes[6][6][83] = int_stack + 587130;
 Libderiv->deriv2_classes[6][7][83] = int_stack + 587914;
 Libderiv->deriv2_classes[6][8][83] = int_stack + 588922;
 Libderiv->deriv2_classes[6][9][83] = int_stack + 590182;
 Libderiv->deriv2_classes[6][10][83] = int_stack + 591722;
 Libderiv->deriv2_classes[7][5][83] = int_stack + 593570;
 Libderiv->deriv2_classes[7][6][83] = int_stack + 594326;
 Libderiv->deriv2_classes[7][7][83] = int_stack + 595334;
 Libderiv->deriv2_classes[7][8][83] = int_stack + 596630;
 Libderiv->deriv2_classes[7][9][83] = int_stack + 598250;
 Libderiv->deriv2_classes[7][10][83] = int_stack + 600230;
 Libderiv->deriv_classes[8][5][11] = int_stack + 602606;
 Libderiv->deriv2_classes[8][5][83] = int_stack + 603551;
 Libderiv->deriv_classes[8][6][11] = int_stack + 604496;
 Libderiv->deriv2_classes[8][6][83] = int_stack + 605756;
 Libderiv->deriv_classes[8][7][11] = int_stack + 607016;
 Libderiv->deriv2_classes[8][7][83] = int_stack + 608636;
 Libderiv->deriv_classes[8][8][11] = int_stack + 610256;
 Libderiv->deriv2_classes[8][8][83] = int_stack + 612281;
 Libderiv->deriv_classes[8][9][11] = int_stack + 614306;
 Libderiv->deriv2_classes[8][9][83] = int_stack + 616781;
 Libderiv->deriv2_classes[8][10][83] = int_stack + 619256;
 Libderiv->deriv2_classes[4][5][82] = int_stack + 622226;
 Libderiv->deriv2_classes[4][6][82] = int_stack + 622541;
 Libderiv->deriv2_classes[4][7][82] = int_stack + 622961;
 Libderiv->deriv2_classes[4][8][82] = int_stack + 623501;
 Libderiv->deriv2_classes[4][9][82] = int_stack + 624176;
 Libderiv->deriv2_classes[4][10][82] = int_stack + 625001;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 625991;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 626432;
 Libderiv->deriv2_classes[5][7][82] = int_stack + 627020;
 Libderiv->deriv2_classes[5][8][82] = int_stack + 627776;
 Libderiv->deriv2_classes[5][9][82] = int_stack + 628721;
 Libderiv->deriv2_classes[5][10][82] = int_stack + 629876;
 Libderiv->deriv2_classes[6][5][82] = int_stack + 631262;
 Libderiv->deriv2_classes[6][6][82] = int_stack + 631850;
 Libderiv->deriv2_classes[6][7][82] = int_stack + 632634;
 Libderiv->deriv2_classes[6][8][82] = int_stack + 633642;
 Libderiv->deriv2_classes[6][9][82] = int_stack + 634902;
 Libderiv->deriv2_classes[6][10][82] = int_stack + 636442;
 Libderiv->deriv2_classes[7][5][82] = int_stack + 638290;
 Libderiv->deriv2_classes[7][6][82] = int_stack + 639046;
 Libderiv->deriv2_classes[7][7][82] = int_stack + 640054;
 Libderiv->deriv2_classes[7][8][82] = int_stack + 641350;
 Libderiv->deriv2_classes[7][9][82] = int_stack + 642970;
 Libderiv->deriv2_classes[7][10][82] = int_stack + 644950;
 Libderiv->deriv_classes[8][5][10] = int_stack + 647326;
 Libderiv->deriv2_classes[8][5][82] = int_stack + 648271;
 Libderiv->deriv_classes[8][6][10] = int_stack + 649216;
 Libderiv->deriv2_classes[8][6][82] = int_stack + 650476;
 Libderiv->deriv_classes[8][7][10] = int_stack + 651736;
 Libderiv->deriv2_classes[8][7][82] = int_stack + 653356;
 Libderiv->deriv_classes[8][8][10] = int_stack + 654976;
 Libderiv->deriv2_classes[8][8][82] = int_stack + 657001;
 Libderiv->deriv_classes[8][9][10] = int_stack + 659026;
 Libderiv->deriv2_classes[8][9][82] = int_stack + 661501;
 Libderiv->deriv2_classes[8][10][82] = int_stack + 663976;
 Libderiv->deriv2_classes[4][5][81] = int_stack + 666946;
 Libderiv->deriv2_classes[4][6][81] = int_stack + 667261;
 Libderiv->deriv2_classes[4][7][81] = int_stack + 667681;
 Libderiv->deriv2_classes[4][8][81] = int_stack + 668221;
 Libderiv->deriv2_classes[4][9][81] = int_stack + 668896;
 Libderiv->deriv2_classes[4][10][81] = int_stack + 669721;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 670711;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 671152;
 Libderiv->deriv2_classes[5][7][81] = int_stack + 671740;
 Libderiv->deriv2_classes[5][8][81] = int_stack + 672496;
 Libderiv->deriv2_classes[5][9][81] = int_stack + 673441;
 Libderiv->deriv2_classes[5][10][81] = int_stack + 674596;
 Libderiv->deriv2_classes[6][5][81] = int_stack + 675982;
 Libderiv->deriv2_classes[6][6][81] = int_stack + 676570;
 Libderiv->deriv2_classes[6][7][81] = int_stack + 677354;
 Libderiv->deriv2_classes[6][8][81] = int_stack + 678362;
 Libderiv->deriv2_classes[6][9][81] = int_stack + 679622;
 Libderiv->deriv2_classes[6][10][81] = int_stack + 681162;
 Libderiv->deriv2_classes[7][5][81] = int_stack + 683010;
 Libderiv->deriv2_classes[7][6][81] = int_stack + 683766;
 Libderiv->deriv2_classes[7][7][81] = int_stack + 684774;
 Libderiv->deriv2_classes[7][8][81] = int_stack + 686070;
 Libderiv->deriv2_classes[7][9][81] = int_stack + 687690;
 Libderiv->deriv2_classes[7][10][81] = int_stack + 689670;
 Libderiv->deriv_classes[8][5][9] = int_stack + 692046;
 Libderiv->deriv2_classes[8][5][81] = int_stack + 692991;
 Libderiv->deriv_classes[8][6][9] = int_stack + 693936;
 Libderiv->deriv2_classes[8][6][81] = int_stack + 695196;
 Libderiv->deriv_classes[8][7][9] = int_stack + 696456;
 Libderiv->deriv2_classes[8][7][81] = int_stack + 698076;
 Libderiv->deriv_classes[8][8][9] = int_stack + 699696;
 Libderiv->deriv2_classes[8][8][81] = int_stack + 701721;
 Libderiv->deriv_classes[8][9][9] = int_stack + 703746;
 Libderiv->deriv2_classes[8][9][81] = int_stack + 706221;
 Libderiv->deriv2_classes[8][10][81] = int_stack + 708696;
 Libderiv->deriv2_classes[4][5][80] = int_stack + 711666;
 Libderiv->deriv2_classes[4][6][80] = int_stack + 711981;
 Libderiv->deriv2_classes[4][7][80] = int_stack + 712401;
 Libderiv->deriv2_classes[4][8][80] = int_stack + 712941;
 Libderiv->deriv2_classes[4][9][80] = int_stack + 713616;
 Libderiv->deriv2_classes[4][10][80] = int_stack + 714441;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 715431;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 715872;
 Libderiv->deriv2_classes[5][7][80] = int_stack + 716460;
 Libderiv->deriv2_classes[5][8][80] = int_stack + 717216;
 Libderiv->deriv2_classes[5][9][80] = int_stack + 718161;
 Libderiv->deriv2_classes[5][10][80] = int_stack + 719316;
 Libderiv->deriv2_classes[6][5][80] = int_stack + 720702;
 Libderiv->deriv2_classes[6][6][80] = int_stack + 721290;
 Libderiv->deriv2_classes[6][7][80] = int_stack + 722074;
 Libderiv->deriv2_classes[6][8][80] = int_stack + 723082;
 Libderiv->deriv2_classes[6][9][80] = int_stack + 724342;
 Libderiv->deriv2_classes[6][10][80] = int_stack + 725882;
 Libderiv->deriv2_classes[7][5][80] = int_stack + 727730;
 Libderiv->deriv2_classes[7][6][80] = int_stack + 728486;
 Libderiv->deriv2_classes[7][7][80] = int_stack + 729494;
 Libderiv->deriv2_classes[7][8][80] = int_stack + 730790;
 Libderiv->deriv2_classes[7][9][80] = int_stack + 732410;
 Libderiv->deriv2_classes[7][10][80] = int_stack + 734390;
 Libderiv->deriv_classes[8][5][8] = int_stack + 736766;
 Libderiv->deriv2_classes[8][5][80] = int_stack + 737711;
 Libderiv->deriv_classes[8][6][8] = int_stack + 738656;
 Libderiv->deriv2_classes[8][6][80] = int_stack + 739916;
 Libderiv->deriv_classes[8][7][8] = int_stack + 741176;
 Libderiv->deriv2_classes[8][7][80] = int_stack + 742796;
 Libderiv->deriv_classes[8][8][8] = int_stack + 744416;
 Libderiv->deriv2_classes[8][8][80] = int_stack + 746441;
 Libderiv->deriv_classes[8][9][8] = int_stack + 748466;
 Libderiv->deriv2_classes[8][9][80] = int_stack + 750941;
 Libderiv->deriv2_classes[8][10][80] = int_stack + 753416;
 Libderiv->deriv2_classes[4][5][79] = int_stack + 756386;
 Libderiv->deriv2_classes[4][6][79] = int_stack + 756701;
 Libderiv->deriv2_classes[4][7][79] = int_stack + 757121;
 Libderiv->deriv2_classes[4][8][79] = int_stack + 757661;
 Libderiv->deriv2_classes[4][9][79] = int_stack + 758336;
 Libderiv->deriv2_classes[4][10][79] = int_stack + 759161;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 760151;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 760592;
 Libderiv->deriv2_classes[5][7][79] = int_stack + 761180;
 Libderiv->deriv2_classes[5][8][79] = int_stack + 761936;
 Libderiv->deriv2_classes[5][9][79] = int_stack + 762881;
 Libderiv->deriv2_classes[5][10][79] = int_stack + 764036;
 Libderiv->deriv2_classes[6][5][79] = int_stack + 765422;
 Libderiv->deriv2_classes[6][6][79] = int_stack + 766010;
 Libderiv->deriv2_classes[6][7][79] = int_stack + 766794;
 Libderiv->deriv2_classes[6][8][79] = int_stack + 767802;
 Libderiv->deriv2_classes[6][9][79] = int_stack + 769062;
 Libderiv->deriv2_classes[6][10][79] = int_stack + 770602;
 Libderiv->deriv2_classes[7][5][79] = int_stack + 772450;
 Libderiv->deriv2_classes[7][6][79] = int_stack + 773206;
 Libderiv->deriv2_classes[7][7][79] = int_stack + 774214;
 Libderiv->deriv2_classes[7][8][79] = int_stack + 775510;
 Libderiv->deriv2_classes[7][9][79] = int_stack + 777130;
 Libderiv->deriv2_classes[7][10][79] = int_stack + 779110;
 Libderiv->deriv_classes[8][5][7] = int_stack + 781486;
 Libderiv->deriv2_classes[8][5][79] = int_stack + 782431;
 Libderiv->deriv_classes[8][6][7] = int_stack + 783376;
 Libderiv->deriv2_classes[8][6][79] = int_stack + 784636;
 Libderiv->deriv_classes[8][7][7] = int_stack + 785896;
 Libderiv->deriv2_classes[8][7][79] = int_stack + 787516;
 Libderiv->deriv_classes[8][8][7] = int_stack + 789136;
 Libderiv->deriv2_classes[8][8][79] = int_stack + 791161;
 Libderiv->deriv_classes[8][9][7] = int_stack + 793186;
 Libderiv->deriv2_classes[8][9][79] = int_stack + 795661;
 Libderiv->deriv2_classes[8][10][79] = int_stack + 798136;
 Libderiv->deriv2_classes[4][5][78] = int_stack + 801106;
 Libderiv->deriv2_classes[4][6][78] = int_stack + 801421;
 Libderiv->deriv2_classes[4][7][78] = int_stack + 801841;
 Libderiv->deriv2_classes[4][8][78] = int_stack + 802381;
 Libderiv->deriv2_classes[4][9][78] = int_stack + 803056;
 Libderiv->deriv2_classes[4][10][78] = int_stack + 803881;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 804871;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 805312;
 Libderiv->deriv2_classes[5][7][78] = int_stack + 805900;
 Libderiv->deriv2_classes[5][8][78] = int_stack + 806656;
 Libderiv->deriv2_classes[5][9][78] = int_stack + 807601;
 Libderiv->deriv2_classes[5][10][78] = int_stack + 808756;
 Libderiv->deriv2_classes[6][5][78] = int_stack + 810142;
 Libderiv->deriv2_classes[6][6][78] = int_stack + 810730;
 Libderiv->deriv2_classes[6][7][78] = int_stack + 811514;
 Libderiv->deriv2_classes[6][8][78] = int_stack + 812522;
 Libderiv->deriv2_classes[6][9][78] = int_stack + 813782;
 Libderiv->deriv2_classes[6][10][78] = int_stack + 815322;
 Libderiv->deriv2_classes[7][5][78] = int_stack + 817170;
 Libderiv->deriv2_classes[7][6][78] = int_stack + 817926;
 Libderiv->deriv2_classes[7][7][78] = int_stack + 818934;
 Libderiv->deriv2_classes[7][8][78] = int_stack + 820230;
 Libderiv->deriv2_classes[7][9][78] = int_stack + 821850;
 Libderiv->deriv2_classes[7][10][78] = int_stack + 823830;
 Libderiv->dvrr_classes[8][5] = int_stack + 826206;
 Libderiv->deriv_classes[8][5][6] = int_stack + 827151;
 Libderiv->deriv2_classes[8][5][78] = int_stack + 828096;
 Libderiv->dvrr_classes[8][6] = int_stack + 829041;
 Libderiv->deriv_classes[8][6][6] = int_stack + 830301;
 Libderiv->deriv2_classes[8][6][78] = int_stack + 831561;
 Libderiv->dvrr_classes[8][7] = int_stack + 832821;
 Libderiv->deriv_classes[8][7][6] = int_stack + 834441;
 Libderiv->deriv2_classes[8][7][78] = int_stack + 836061;
 Libderiv->dvrr_classes[8][8] = int_stack + 837681;
 Libderiv->deriv_classes[8][8][6] = int_stack + 839706;
 Libderiv->deriv2_classes[8][8][78] = int_stack + 841731;
 Libderiv->deriv_classes[8][9][6] = int_stack + 843756;
 Libderiv->deriv2_classes[8][9][78] = int_stack + 846231;
 Libderiv->deriv2_classes[8][10][78] = int_stack + 848706;
 Libderiv->deriv2_classes[4][5][35] = int_stack + 851676;
 Libderiv->deriv2_classes[4][6][35] = int_stack + 851991;
 Libderiv->deriv2_classes[4][7][35] = int_stack + 852411;
 Libderiv->deriv2_classes[4][8][35] = int_stack + 852951;
 Libderiv->deriv2_classes[4][9][35] = int_stack + 853626;
 Libderiv->deriv2_classes[4][10][35] = int_stack + 854451;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 855441;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 855882;
 Libderiv->deriv2_classes[5][7][35] = int_stack + 856470;
 Libderiv->deriv2_classes[5][8][35] = int_stack + 857226;
 Libderiv->deriv2_classes[5][9][35] = int_stack + 858171;
 Libderiv->deriv2_classes[5][10][35] = int_stack + 859326;
 Libderiv->deriv2_classes[6][5][35] = int_stack + 860712;
 Libderiv->deriv2_classes[6][6][35] = int_stack + 861300;
 Libderiv->deriv2_classes[6][7][35] = int_stack + 862084;
 Libderiv->deriv2_classes[6][8][35] = int_stack + 863092;
 Libderiv->deriv2_classes[6][9][35] = int_stack + 864352;
 Libderiv->deriv2_classes[6][10][35] = int_stack + 865892;
 Libderiv->deriv2_classes[7][5][35] = int_stack + 867740;
 Libderiv->deriv2_classes[7][6][35] = int_stack + 868496;
 Libderiv->deriv2_classes[7][7][35] = int_stack + 869504;
 Libderiv->deriv2_classes[7][8][35] = int_stack + 870800;
 Libderiv->deriv2_classes[7][9][35] = int_stack + 872420;
 Libderiv->deriv2_classes[7][10][35] = int_stack + 874400;
 Libderiv->deriv2_classes[8][5][35] = int_stack + 876776;
 Libderiv->deriv2_classes[8][6][35] = int_stack + 877721;
 Libderiv->deriv2_classes[8][7][35] = int_stack + 878981;
 Libderiv->deriv2_classes[8][8][35] = int_stack + 880601;
 Libderiv->deriv2_classes[8][9][35] = int_stack + 882626;
 Libderiv->deriv2_classes[8][10][35] = int_stack + 885101;
 Libderiv->deriv2_classes[4][5][34] = int_stack + 888071;
 Libderiv->deriv2_classes[4][6][34] = int_stack + 888386;
 Libderiv->deriv2_classes[4][7][34] = int_stack + 888806;
 Libderiv->deriv2_classes[4][8][34] = int_stack + 889346;
 Libderiv->deriv2_classes[4][9][34] = int_stack + 890021;
 Libderiv->deriv2_classes[4][10][34] = int_stack + 890846;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 891836;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 892277;
 Libderiv->deriv2_classes[5][7][34] = int_stack + 892865;
 Libderiv->deriv2_classes[5][8][34] = int_stack + 893621;
 Libderiv->deriv2_classes[5][9][34] = int_stack + 894566;
 Libderiv->deriv2_classes[5][10][34] = int_stack + 895721;
 Libderiv->deriv2_classes[6][5][34] = int_stack + 897107;
 Libderiv->deriv2_classes[6][6][34] = int_stack + 897695;
 Libderiv->deriv2_classes[6][7][34] = int_stack + 898479;
 Libderiv->deriv2_classes[6][8][34] = int_stack + 899487;
 Libderiv->deriv2_classes[6][9][34] = int_stack + 900747;
 Libderiv->deriv2_classes[6][10][34] = int_stack + 902287;
 Libderiv->deriv2_classes[7][5][34] = int_stack + 904135;
 Libderiv->deriv2_classes[7][6][34] = int_stack + 904891;
 Libderiv->deriv2_classes[7][7][34] = int_stack + 905899;
 Libderiv->deriv2_classes[7][8][34] = int_stack + 907195;
 Libderiv->deriv2_classes[7][9][34] = int_stack + 908815;
 Libderiv->deriv2_classes[7][10][34] = int_stack + 910795;
 Libderiv->deriv2_classes[8][5][34] = int_stack + 913171;
 Libderiv->deriv2_classes[8][6][34] = int_stack + 914116;
 Libderiv->deriv2_classes[8][7][34] = int_stack + 915376;
 Libderiv->deriv2_classes[8][8][34] = int_stack + 916996;
 Libderiv->deriv2_classes[8][9][34] = int_stack + 919021;
 Libderiv->deriv2_classes[8][10][34] = int_stack + 921496;
 Libderiv->deriv2_classes[4][5][33] = int_stack + 924466;
 Libderiv->deriv2_classes[4][6][33] = int_stack + 924781;
 Libderiv->deriv2_classes[4][7][33] = int_stack + 925201;
 Libderiv->deriv2_classes[4][8][33] = int_stack + 925741;
 Libderiv->deriv2_classes[4][9][33] = int_stack + 926416;
 Libderiv->deriv2_classes[4][10][33] = int_stack + 927241;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 928231;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 928672;
 Libderiv->deriv2_classes[5][7][33] = int_stack + 929260;
 Libderiv->deriv2_classes[5][8][33] = int_stack + 930016;
 Libderiv->deriv2_classes[5][9][33] = int_stack + 930961;
 Libderiv->deriv2_classes[5][10][33] = int_stack + 932116;
 Libderiv->deriv2_classes[6][5][33] = int_stack + 933502;
 Libderiv->deriv2_classes[6][6][33] = int_stack + 934090;
 Libderiv->deriv2_classes[6][7][33] = int_stack + 934874;
 Libderiv->deriv2_classes[6][8][33] = int_stack + 935882;
 Libderiv->deriv2_classes[6][9][33] = int_stack + 937142;
 Libderiv->deriv2_classes[6][10][33] = int_stack + 938682;
 Libderiv->deriv2_classes[7][5][33] = int_stack + 940530;
 Libderiv->deriv2_classes[7][6][33] = int_stack + 941286;
 Libderiv->deriv2_classes[7][7][33] = int_stack + 942294;
 Libderiv->deriv2_classes[7][8][33] = int_stack + 943590;
 Libderiv->deriv2_classes[7][9][33] = int_stack + 945210;
 Libderiv->deriv2_classes[7][10][33] = int_stack + 947190;
 Libderiv->deriv2_classes[8][5][33] = int_stack + 949566;
 Libderiv->deriv2_classes[8][6][33] = int_stack + 950511;
 Libderiv->deriv2_classes[8][7][33] = int_stack + 951771;
 Libderiv->deriv2_classes[8][8][33] = int_stack + 953391;
 Libderiv->deriv2_classes[8][9][33] = int_stack + 955416;
 Libderiv->deriv2_classes[8][10][33] = int_stack + 957891;
 Libderiv->deriv2_classes[4][5][32] = int_stack + 960861;
 Libderiv->deriv2_classes[4][6][32] = int_stack + 961176;
 Libderiv->deriv2_classes[4][7][32] = int_stack + 961596;
 Libderiv->deriv2_classes[4][8][32] = int_stack + 962136;
 Libderiv->deriv2_classes[4][9][32] = int_stack + 962811;
 Libderiv->deriv2_classes[4][10][32] = int_stack + 963636;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 964626;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 965067;
 Libderiv->deriv2_classes[5][7][32] = int_stack + 965655;
 Libderiv->deriv2_classes[5][8][32] = int_stack + 966411;
 Libderiv->deriv2_classes[5][9][32] = int_stack + 967356;
 Libderiv->deriv2_classes[5][10][32] = int_stack + 968511;
 Libderiv->deriv2_classes[6][5][32] = int_stack + 969897;
 Libderiv->deriv2_classes[6][6][32] = int_stack + 970485;
 Libderiv->deriv2_classes[6][7][32] = int_stack + 971269;
 Libderiv->deriv2_classes[6][8][32] = int_stack + 972277;
 Libderiv->deriv2_classes[6][9][32] = int_stack + 973537;
 Libderiv->deriv2_classes[6][10][32] = int_stack + 975077;
 Libderiv->deriv2_classes[7][5][32] = int_stack + 976925;
 Libderiv->deriv2_classes[7][6][32] = int_stack + 977681;
 Libderiv->deriv2_classes[7][7][32] = int_stack + 978689;
 Libderiv->deriv2_classes[7][8][32] = int_stack + 979985;
 Libderiv->deriv2_classes[7][9][32] = int_stack + 981605;
 Libderiv->deriv2_classes[7][10][32] = int_stack + 983585;
 Libderiv->deriv2_classes[8][5][32] = int_stack + 985961;
 Libderiv->deriv2_classes[8][6][32] = int_stack + 986906;
 Libderiv->deriv2_classes[8][7][32] = int_stack + 988166;
 Libderiv->deriv2_classes[8][8][32] = int_stack + 989786;
 Libderiv->deriv2_classes[8][9][32] = int_stack + 991811;
 Libderiv->deriv2_classes[8][10][32] = int_stack + 994286;
 Libderiv->deriv2_classes[4][5][31] = int_stack + 997256;
 Libderiv->deriv2_classes[4][6][31] = int_stack + 997571;
 Libderiv->deriv2_classes[4][7][31] = int_stack + 997991;
 Libderiv->deriv2_classes[4][8][31] = int_stack + 998531;
 Libderiv->deriv2_classes[4][9][31] = int_stack + 999206;
 Libderiv->deriv2_classes[4][10][31] = int_stack + 1000031;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 1001021;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 1001462;
 Libderiv->deriv2_classes[5][7][31] = int_stack + 1002050;
 Libderiv->deriv2_classes[5][8][31] = int_stack + 1002806;
 Libderiv->deriv2_classes[5][9][31] = int_stack + 1003751;
 Libderiv->deriv2_classes[5][10][31] = int_stack + 1004906;
 Libderiv->deriv2_classes[6][5][31] = int_stack + 1006292;
 Libderiv->deriv2_classes[6][6][31] = int_stack + 1006880;
 Libderiv->deriv2_classes[6][7][31] = int_stack + 1007664;
 Libderiv->deriv2_classes[6][8][31] = int_stack + 1008672;
 Libderiv->deriv2_classes[6][9][31] = int_stack + 1009932;
 Libderiv->deriv2_classes[6][10][31] = int_stack + 1011472;
 Libderiv->deriv2_classes[7][5][31] = int_stack + 1013320;
 Libderiv->deriv2_classes[7][6][31] = int_stack + 1014076;
 Libderiv->deriv2_classes[7][7][31] = int_stack + 1015084;
 Libderiv->deriv2_classes[7][8][31] = int_stack + 1016380;
 Libderiv->deriv2_classes[7][9][31] = int_stack + 1018000;
 Libderiv->deriv2_classes[7][10][31] = int_stack + 1019980;
 Libderiv->deriv2_classes[8][5][31] = int_stack + 1022356;
 Libderiv->deriv2_classes[8][6][31] = int_stack + 1023301;
 Libderiv->deriv2_classes[8][7][31] = int_stack + 1024561;
 Libderiv->deriv2_classes[8][8][31] = int_stack + 1026181;
 Libderiv->deriv2_classes[8][9][31] = int_stack + 1028206;
 Libderiv->deriv2_classes[8][10][31] = int_stack + 1030681;
 Libderiv->deriv2_classes[4][5][30] = int_stack + 1033651;
 Libderiv->deriv2_classes[4][6][30] = int_stack + 1033966;
 Libderiv->deriv2_classes[4][7][30] = int_stack + 1034386;
 Libderiv->deriv2_classes[4][8][30] = int_stack + 1034926;
 Libderiv->deriv2_classes[4][9][30] = int_stack + 1035601;
 Libderiv->deriv2_classes[4][10][30] = int_stack + 1036426;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 1037416;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 1037857;
 Libderiv->deriv2_classes[5][7][30] = int_stack + 1038445;
 Libderiv->deriv2_classes[5][8][30] = int_stack + 1039201;
 Libderiv->deriv2_classes[5][9][30] = int_stack + 1040146;
 Libderiv->deriv2_classes[5][10][30] = int_stack + 1041301;
 Libderiv->deriv2_classes[6][5][30] = int_stack + 1042687;
 Libderiv->deriv2_classes[6][6][30] = int_stack + 1043275;
 Libderiv->deriv2_classes[6][7][30] = int_stack + 1044059;
 Libderiv->deriv2_classes[6][8][30] = int_stack + 1045067;
 Libderiv->deriv2_classes[6][9][30] = int_stack + 1046327;
 Libderiv->deriv2_classes[6][10][30] = int_stack + 1047867;
 Libderiv->deriv2_classes[7][5][30] = int_stack + 1049715;
 Libderiv->deriv2_classes[7][6][30] = int_stack + 1050471;
 Libderiv->deriv2_classes[7][7][30] = int_stack + 1051479;
 Libderiv->deriv2_classes[7][8][30] = int_stack + 1052775;
 Libderiv->deriv2_classes[7][9][30] = int_stack + 1054395;
 Libderiv->deriv2_classes[7][10][30] = int_stack + 1056375;
 Libderiv->deriv_classes[8][5][2] = int_stack + 1058751;
 Libderiv->deriv2_classes[8][5][30] = int_stack + 1059696;
 Libderiv->deriv_classes[8][6][2] = int_stack + 1060641;
 Libderiv->deriv2_classes[8][6][30] = int_stack + 1061901;
 Libderiv->deriv_classes[8][7][2] = int_stack + 1063161;
 Libderiv->deriv2_classes[8][7][30] = int_stack + 1064781;
 Libderiv->deriv_classes[8][8][2] = int_stack + 1066401;
 Libderiv->deriv2_classes[8][8][30] = int_stack + 1068426;
 Libderiv->deriv_classes[8][9][2] = int_stack + 1070451;
 Libderiv->deriv2_classes[8][9][30] = int_stack + 1072926;
 Libderiv->deriv2_classes[8][10][30] = int_stack + 1075401;
 Libderiv->deriv2_classes[4][5][26] = int_stack + 1078371;
 Libderiv->deriv2_classes[4][6][26] = int_stack + 1078686;
 Libderiv->deriv2_classes[4][7][26] = int_stack + 1079106;
 Libderiv->deriv2_classes[4][8][26] = int_stack + 1079646;
 Libderiv->deriv2_classes[4][9][26] = int_stack + 1080321;
 Libderiv->deriv2_classes[4][10][26] = int_stack + 1081146;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 1082136;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 1082577;
 Libderiv->deriv2_classes[5][7][26] = int_stack + 1083165;
 Libderiv->deriv2_classes[5][8][26] = int_stack + 1083921;
 Libderiv->deriv2_classes[5][9][26] = int_stack + 1084866;
 Libderiv->deriv2_classes[5][10][26] = int_stack + 1086021;
 Libderiv->deriv2_classes[6][5][26] = int_stack + 1087407;
 Libderiv->deriv2_classes[6][6][26] = int_stack + 1087995;
 Libderiv->deriv2_classes[6][7][26] = int_stack + 1088779;
 Libderiv->deriv2_classes[6][8][26] = int_stack + 1089787;
 Libderiv->deriv2_classes[6][9][26] = int_stack + 1091047;
 Libderiv->deriv2_classes[6][10][26] = int_stack + 1092587;
 Libderiv->deriv2_classes[7][5][26] = int_stack + 1094435;
 Libderiv->deriv2_classes[7][6][26] = int_stack + 1095191;
 Libderiv->deriv2_classes[7][7][26] = int_stack + 1096199;
 Libderiv->deriv2_classes[7][8][26] = int_stack + 1097495;
 Libderiv->deriv2_classes[7][9][26] = int_stack + 1099115;
 Libderiv->deriv2_classes[7][10][26] = int_stack + 1101095;
 Libderiv->deriv2_classes[8][5][26] = int_stack + 1103471;
 Libderiv->deriv2_classes[8][6][26] = int_stack + 1104416;
 Libderiv->deriv2_classes[8][7][26] = int_stack + 1105676;
 Libderiv->deriv2_classes[8][8][26] = int_stack + 1107296;
 Libderiv->deriv2_classes[8][9][26] = int_stack + 1109321;
 Libderiv->deriv2_classes[8][10][26] = int_stack + 1111796;
 Libderiv->deriv2_classes[4][5][23] = int_stack + 1114766;
 Libderiv->deriv2_classes[4][6][23] = int_stack + 1115081;
 Libderiv->deriv2_classes[4][7][23] = int_stack + 1115501;
 Libderiv->deriv2_classes[4][8][23] = int_stack + 1116041;
 Libderiv->deriv2_classes[4][9][23] = int_stack + 1116716;
 Libderiv->deriv2_classes[4][10][23] = int_stack + 1117541;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 1118531;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 1118972;
 Libderiv->deriv2_classes[5][7][23] = int_stack + 1119560;
 Libderiv->deriv2_classes[5][8][23] = int_stack + 1120316;
 Libderiv->deriv2_classes[5][9][23] = int_stack + 1121261;
 Libderiv->deriv2_classes[5][10][23] = int_stack + 1122416;
 Libderiv->deriv2_classes[6][5][23] = int_stack + 1123802;
 Libderiv->deriv2_classes[6][6][23] = int_stack + 1124390;
 Libderiv->deriv2_classes[6][7][23] = int_stack + 1125174;
 Libderiv->deriv2_classes[6][8][23] = int_stack + 1126182;
 Libderiv->deriv2_classes[6][9][23] = int_stack + 1127442;
 Libderiv->deriv2_classes[6][10][23] = int_stack + 1128982;
 Libderiv->deriv2_classes[7][5][23] = int_stack + 1130830;
 Libderiv->deriv2_classes[7][6][23] = int_stack + 1131586;
 Libderiv->deriv2_classes[7][7][23] = int_stack + 1132594;
 Libderiv->deriv2_classes[7][8][23] = int_stack + 1133890;
 Libderiv->deriv2_classes[7][9][23] = int_stack + 1135510;
 Libderiv->deriv2_classes[7][10][23] = int_stack + 1137490;
 Libderiv->deriv2_classes[8][5][23] = int_stack + 1139866;
 Libderiv->deriv2_classes[8][6][23] = int_stack + 1140811;
 Libderiv->deriv2_classes[8][7][23] = int_stack + 1142071;
 Libderiv->deriv2_classes[8][8][23] = int_stack + 1143691;
 Libderiv->deriv2_classes[8][9][23] = int_stack + 1145716;
 Libderiv->deriv2_classes[8][10][23] = int_stack + 1148191;
 Libderiv->deriv2_classes[4][5][22] = int_stack + 1151161;
 Libderiv->deriv2_classes[4][6][22] = int_stack + 1151476;
 Libderiv->deriv2_classes[4][7][22] = int_stack + 1151896;
 Libderiv->deriv2_classes[4][8][22] = int_stack + 1152436;
 Libderiv->deriv2_classes[4][9][22] = int_stack + 1153111;
 Libderiv->deriv2_classes[4][10][22] = int_stack + 1153936;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 1154926;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 1155367;
 Libderiv->deriv2_classes[5][7][22] = int_stack + 1155955;
 Libderiv->deriv2_classes[5][8][22] = int_stack + 1156711;
 Libderiv->deriv2_classes[5][9][22] = int_stack + 1157656;
 Libderiv->deriv2_classes[5][10][22] = int_stack + 1158811;
 Libderiv->deriv2_classes[6][5][22] = int_stack + 1160197;
 Libderiv->deriv2_classes[6][6][22] = int_stack + 1160785;
 Libderiv->deriv2_classes[6][7][22] = int_stack + 1161569;
 Libderiv->deriv2_classes[6][8][22] = int_stack + 1162577;
 Libderiv->deriv2_classes[6][9][22] = int_stack + 1163837;
 Libderiv->deriv2_classes[6][10][22] = int_stack + 1165377;
 Libderiv->deriv2_classes[7][5][22] = int_stack + 1167225;
 Libderiv->deriv2_classes[7][6][22] = int_stack + 1167981;
 Libderiv->deriv2_classes[7][7][22] = int_stack + 1168989;
 Libderiv->deriv2_classes[7][8][22] = int_stack + 1170285;
 Libderiv->deriv2_classes[7][9][22] = int_stack + 1171905;
 Libderiv->deriv2_classes[7][10][22] = int_stack + 1173885;
 Libderiv->deriv2_classes[8][5][22] = int_stack + 1176261;
 Libderiv->deriv2_classes[8][6][22] = int_stack + 1177206;
 Libderiv->deriv2_classes[8][7][22] = int_stack + 1178466;
 Libderiv->deriv2_classes[8][8][22] = int_stack + 1180086;
 Libderiv->deriv2_classes[8][9][22] = int_stack + 1182111;
 Libderiv->deriv2_classes[8][10][22] = int_stack + 1184586;
 Libderiv->deriv2_classes[4][5][21] = int_stack + 1187556;
 Libderiv->deriv2_classes[4][6][21] = int_stack + 1187871;
 Libderiv->deriv2_classes[4][7][21] = int_stack + 1188291;
 Libderiv->deriv2_classes[4][8][21] = int_stack + 1188831;
 Libderiv->deriv2_classes[4][9][21] = int_stack + 1189506;
 Libderiv->deriv2_classes[4][10][21] = int_stack + 1190331;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 1191321;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 1191762;
 Libderiv->deriv2_classes[5][7][21] = int_stack + 1192350;
 Libderiv->deriv2_classes[5][8][21] = int_stack + 1193106;
 Libderiv->deriv2_classes[5][9][21] = int_stack + 1194051;
 Libderiv->deriv2_classes[5][10][21] = int_stack + 1195206;
 Libderiv->deriv2_classes[6][5][21] = int_stack + 1196592;
 Libderiv->deriv2_classes[6][6][21] = int_stack + 1197180;
 Libderiv->deriv2_classes[6][7][21] = int_stack + 1197964;
 Libderiv->deriv2_classes[6][8][21] = int_stack + 1198972;
 Libderiv->deriv2_classes[6][9][21] = int_stack + 1200232;
 Libderiv->deriv2_classes[6][10][21] = int_stack + 1201772;
 Libderiv->deriv2_classes[7][5][21] = int_stack + 1203620;
 Libderiv->deriv2_classes[7][6][21] = int_stack + 1204376;
 Libderiv->deriv2_classes[7][7][21] = int_stack + 1205384;
 Libderiv->deriv2_classes[7][8][21] = int_stack + 1206680;
 Libderiv->deriv2_classes[7][9][21] = int_stack + 1208300;
 Libderiv->deriv2_classes[7][10][21] = int_stack + 1210280;
 Libderiv->deriv2_classes[8][5][21] = int_stack + 1212656;
 Libderiv->deriv2_classes[8][6][21] = int_stack + 1213601;
 Libderiv->deriv2_classes[8][7][21] = int_stack + 1214861;
 Libderiv->deriv2_classes[8][8][21] = int_stack + 1216481;
 Libderiv->deriv2_classes[8][9][21] = int_stack + 1218506;
 Libderiv->deriv2_classes[8][10][21] = int_stack + 1220981;
 Libderiv->deriv2_classes[4][5][20] = int_stack + 1223951;
 Libderiv->deriv2_classes[4][6][20] = int_stack + 1224266;
 Libderiv->deriv2_classes[4][7][20] = int_stack + 1224686;
 Libderiv->deriv2_classes[4][8][20] = int_stack + 1225226;
 Libderiv->deriv2_classes[4][9][20] = int_stack + 1225901;
 Libderiv->deriv2_classes[4][10][20] = int_stack + 1226726;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 1227716;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 1228157;
 Libderiv->deriv2_classes[5][7][20] = int_stack + 1228745;
 Libderiv->deriv2_classes[5][8][20] = int_stack + 1229501;
 Libderiv->deriv2_classes[5][9][20] = int_stack + 1230446;
 Libderiv->deriv2_classes[5][10][20] = int_stack + 1231601;
 Libderiv->deriv2_classes[6][5][20] = int_stack + 1232987;
 Libderiv->deriv2_classes[6][6][20] = int_stack + 1233575;
 Libderiv->deriv2_classes[6][7][20] = int_stack + 1234359;
 Libderiv->deriv2_classes[6][8][20] = int_stack + 1235367;
 Libderiv->deriv2_classes[6][9][20] = int_stack + 1236627;
 Libderiv->deriv2_classes[6][10][20] = int_stack + 1238167;
 Libderiv->deriv2_classes[7][5][20] = int_stack + 1240015;
 Libderiv->deriv2_classes[7][6][20] = int_stack + 1240771;
 Libderiv->deriv2_classes[7][7][20] = int_stack + 1241779;
 Libderiv->deriv2_classes[7][8][20] = int_stack + 1243075;
 Libderiv->deriv2_classes[7][9][20] = int_stack + 1244695;
 Libderiv->deriv2_classes[7][10][20] = int_stack + 1246675;
 Libderiv->deriv2_classes[8][5][20] = int_stack + 1249051;
 Libderiv->deriv2_classes[8][6][20] = int_stack + 1249996;
 Libderiv->deriv2_classes[8][7][20] = int_stack + 1251256;
 Libderiv->deriv2_classes[8][8][20] = int_stack + 1252876;
 Libderiv->deriv2_classes[8][9][20] = int_stack + 1254901;
 Libderiv->deriv2_classes[8][10][20] = int_stack + 1257376;
 Libderiv->deriv2_classes[4][5][19] = int_stack + 1260346;
 Libderiv->deriv2_classes[4][6][19] = int_stack + 1260661;
 Libderiv->deriv2_classes[4][7][19] = int_stack + 1261081;
 Libderiv->deriv2_classes[4][8][19] = int_stack + 1261621;
 Libderiv->deriv2_classes[4][9][19] = int_stack + 1262296;
 Libderiv->deriv2_classes[4][10][19] = int_stack + 1263121;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 1264111;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 1264552;
 Libderiv->deriv2_classes[5][7][19] = int_stack + 1265140;
 Libderiv->deriv2_classes[5][8][19] = int_stack + 1265896;
 Libderiv->deriv2_classes[5][9][19] = int_stack + 1266841;
 Libderiv->deriv2_classes[5][10][19] = int_stack + 1267996;
 Libderiv->deriv2_classes[6][5][19] = int_stack + 1269382;
 Libderiv->deriv2_classes[6][6][19] = int_stack + 1269970;
 Libderiv->deriv2_classes[6][7][19] = int_stack + 1270754;
 Libderiv->deriv2_classes[6][8][19] = int_stack + 1271762;
 Libderiv->deriv2_classes[6][9][19] = int_stack + 1273022;
 Libderiv->deriv2_classes[6][10][19] = int_stack + 1274562;
 Libderiv->deriv2_classes[7][5][19] = int_stack + 1276410;
 Libderiv->deriv2_classes[7][6][19] = int_stack + 1277166;
 Libderiv->deriv2_classes[7][7][19] = int_stack + 1278174;
 Libderiv->deriv2_classes[7][8][19] = int_stack + 1279470;
 Libderiv->deriv2_classes[7][9][19] = int_stack + 1281090;
 Libderiv->deriv2_classes[7][10][19] = int_stack + 1283070;
 Libderiv->deriv2_classes[8][5][19] = int_stack + 1285446;
 Libderiv->deriv2_classes[8][6][19] = int_stack + 1286391;
 Libderiv->deriv2_classes[8][7][19] = int_stack + 1287651;
 Libderiv->deriv2_classes[8][8][19] = int_stack + 1289271;
 Libderiv->deriv2_classes[8][9][19] = int_stack + 1291296;
 Libderiv->deriv2_classes[8][10][19] = int_stack + 1293771;
 Libderiv->deriv2_classes[4][5][18] = int_stack + 1296741;
 Libderiv->deriv2_classes[4][6][18] = int_stack + 1297056;
 Libderiv->deriv2_classes[4][7][18] = int_stack + 1297476;
 Libderiv->deriv2_classes[4][8][18] = int_stack + 1298016;
 Libderiv->deriv2_classes[4][9][18] = int_stack + 1298691;
 Libderiv->deriv2_classes[4][10][18] = int_stack + 1299516;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 1300506;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 1300947;
 Libderiv->deriv2_classes[5][7][18] = int_stack + 1301535;
 Libderiv->deriv2_classes[5][8][18] = int_stack + 1302291;
 Libderiv->deriv2_classes[5][9][18] = int_stack + 1303236;
 Libderiv->deriv2_classes[5][10][18] = int_stack + 1304391;
 Libderiv->deriv2_classes[6][5][18] = int_stack + 1305777;
 Libderiv->deriv2_classes[6][6][18] = int_stack + 1306365;
 Libderiv->deriv2_classes[6][7][18] = int_stack + 1307149;
 Libderiv->deriv2_classes[6][8][18] = int_stack + 1308157;
 Libderiv->deriv2_classes[6][9][18] = int_stack + 1309417;
 Libderiv->deriv2_classes[6][10][18] = int_stack + 1310957;
 Libderiv->deriv2_classes[7][5][18] = int_stack + 1312805;
 Libderiv->deriv2_classes[7][6][18] = int_stack + 1313561;
 Libderiv->deriv2_classes[7][7][18] = int_stack + 1314569;
 Libderiv->deriv2_classes[7][8][18] = int_stack + 1315865;
 Libderiv->deriv2_classes[7][9][18] = int_stack + 1317485;
 Libderiv->deriv2_classes[7][10][18] = int_stack + 1319465;
 Libderiv->deriv_classes[8][5][1] = int_stack + 1321841;
 Libderiv->deriv2_classes[8][5][18] = int_stack + 1322786;
 Libderiv->deriv_classes[8][6][1] = int_stack + 1323731;
 Libderiv->deriv2_classes[8][6][18] = int_stack + 1324991;
 Libderiv->deriv_classes[8][7][1] = int_stack + 1326251;
 Libderiv->deriv2_classes[8][7][18] = int_stack + 1327871;
 Libderiv->deriv_classes[8][8][1] = int_stack + 1329491;
 Libderiv->deriv2_classes[8][8][18] = int_stack + 1331516;
 Libderiv->deriv_classes[8][9][1] = int_stack + 1333541;
 Libderiv->deriv2_classes[8][9][18] = int_stack + 1336016;
 Libderiv->deriv2_classes[8][10][18] = int_stack + 1338491;
 Libderiv->deriv2_classes[4][5][14] = int_stack + 1341461;
 Libderiv->deriv2_classes[4][6][14] = int_stack + 1341776;
 Libderiv->deriv2_classes[4][7][14] = int_stack + 1342196;
 Libderiv->deriv2_classes[4][8][14] = int_stack + 1342736;
 Libderiv->deriv2_classes[4][9][14] = int_stack + 1343411;
 Libderiv->deriv2_classes[4][10][14] = int_stack + 1344236;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 1345226;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 1345667;
 Libderiv->deriv2_classes[5][7][14] = int_stack + 1346255;
 Libderiv->deriv2_classes[5][8][14] = int_stack + 1347011;
 Libderiv->deriv2_classes[5][9][14] = int_stack + 1347956;
 Libderiv->deriv2_classes[5][10][14] = int_stack + 1349111;
 Libderiv->deriv2_classes[6][5][14] = int_stack + 1350497;
 Libderiv->deriv2_classes[6][6][14] = int_stack + 1351085;
 Libderiv->deriv2_classes[6][7][14] = int_stack + 1351869;
 Libderiv->deriv2_classes[6][8][14] = int_stack + 1352877;
 Libderiv->deriv2_classes[6][9][14] = int_stack + 1354137;
 Libderiv->deriv2_classes[6][10][14] = int_stack + 1355677;
 Libderiv->deriv2_classes[7][5][14] = int_stack + 1357525;
 Libderiv->deriv2_classes[7][6][14] = int_stack + 1358281;
 Libderiv->deriv2_classes[7][7][14] = int_stack + 1359289;
 Libderiv->deriv2_classes[7][8][14] = int_stack + 1360585;
 Libderiv->deriv2_classes[7][9][14] = int_stack + 1362205;
 Libderiv->deriv2_classes[7][10][14] = int_stack + 1364185;
 Libderiv->deriv2_classes[8][5][14] = int_stack + 1366561;
 Libderiv->deriv2_classes[8][6][14] = int_stack + 1367506;
 Libderiv->deriv2_classes[8][7][14] = int_stack + 1368766;
 Libderiv->deriv2_classes[8][8][14] = int_stack + 1370386;
 Libderiv->deriv2_classes[8][9][14] = int_stack + 1372411;
 Libderiv->deriv2_classes[8][10][14] = int_stack + 1374886;
 Libderiv->deriv2_classes[4][5][13] = int_stack + 1377856;
 Libderiv->deriv2_classes[4][6][13] = int_stack + 1378171;
 Libderiv->deriv2_classes[4][7][13] = int_stack + 1378591;
 Libderiv->deriv2_classes[4][8][13] = int_stack + 1379131;
 Libderiv->deriv2_classes[4][9][13] = int_stack + 1379806;
 Libderiv->deriv2_classes[4][10][13] = int_stack + 1380631;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 1381621;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 1382062;
 Libderiv->deriv2_classes[5][7][13] = int_stack + 1382650;
 Libderiv->deriv2_classes[5][8][13] = int_stack + 1383406;
 Libderiv->deriv2_classes[5][9][13] = int_stack + 1384351;
 Libderiv->deriv2_classes[5][10][13] = int_stack + 1385506;
 Libderiv->deriv2_classes[6][5][13] = int_stack + 1386892;
 Libderiv->deriv2_classes[6][6][13] = int_stack + 1387480;
 Libderiv->deriv2_classes[6][7][13] = int_stack + 1388264;
 Libderiv->deriv2_classes[6][8][13] = int_stack + 1389272;
 Libderiv->deriv2_classes[6][9][13] = int_stack + 1390532;
 Libderiv->deriv2_classes[6][10][13] = int_stack + 1392072;
 Libderiv->deriv2_classes[7][5][13] = int_stack + 1393920;
 Libderiv->deriv2_classes[7][6][13] = int_stack + 1394676;
 Libderiv->deriv2_classes[7][7][13] = int_stack + 1395684;
 Libderiv->deriv2_classes[7][8][13] = int_stack + 1396980;
 Libderiv->deriv2_classes[7][9][13] = int_stack + 1398600;
 Libderiv->deriv2_classes[7][10][13] = int_stack + 1400580;
 Libderiv->deriv2_classes[8][5][13] = int_stack + 1402956;
 Libderiv->deriv2_classes[8][6][13] = int_stack + 1403901;
 Libderiv->deriv2_classes[8][7][13] = int_stack + 1405161;
 Libderiv->deriv2_classes[8][8][13] = int_stack + 1406781;
 Libderiv->deriv2_classes[8][9][13] = int_stack + 1408806;
 Libderiv->deriv2_classes[8][10][13] = int_stack + 1411281;
 Libderiv->deriv_classes[4][5][11] = int_stack + 1414251;
 Libderiv->deriv_classes[4][6][11] = int_stack + 1414566;
 Libderiv->deriv_classes[4][7][11] = int_stack + 1414986;
 Libderiv->deriv_classes[4][8][11] = int_stack + 1415526;
 Libderiv->deriv_classes[4][9][11] = int_stack + 1416201;
 Libderiv->deriv_classes[4][10][11] = int_stack + 1417026;
 Libderiv->deriv2_classes[4][5][11] = int_stack + 1418016;
 Libderiv->deriv2_classes[4][6][11] = int_stack + 1418331;
 Libderiv->deriv2_classes[4][7][11] = int_stack + 1418751;
 Libderiv->deriv2_classes[4][8][11] = int_stack + 1419291;
 Libderiv->deriv2_classes[4][9][11] = int_stack + 1419966;
 Libderiv->deriv2_classes[4][10][11] = int_stack + 1420791;
 Libderiv->deriv_classes[5][5][11] = int_stack + 1421781;
 Libderiv->deriv_classes[5][6][11] = int_stack + 1422222;
 Libderiv->deriv_classes[5][7][11] = int_stack + 1422810;
 Libderiv->deriv_classes[5][8][11] = int_stack + 1423566;
 Libderiv->deriv_classes[5][9][11] = int_stack + 1424511;
 Libderiv->deriv_classes[5][10][11] = int_stack + 1425666;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 1427052;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 1427493;
 Libderiv->deriv2_classes[5][7][11] = int_stack + 1428081;
 Libderiv->deriv2_classes[5][8][11] = int_stack + 1428837;
 Libderiv->deriv2_classes[5][9][11] = int_stack + 1429782;
 Libderiv->deriv2_classes[5][10][11] = int_stack + 1430937;
 Libderiv->deriv_classes[6][5][11] = int_stack + 1432323;
 Libderiv->deriv_classes[6][6][11] = int_stack + 1432911;
 Libderiv->deriv_classes[6][7][11] = int_stack + 1433695;
 Libderiv->deriv_classes[6][8][11] = int_stack + 1434703;
 Libderiv->deriv_classes[6][9][11] = int_stack + 1435963;
 Libderiv->deriv_classes[6][10][11] = int_stack + 1437503;
 Libderiv->deriv2_classes[6][5][11] = int_stack + 1439351;
 Libderiv->deriv2_classes[6][6][11] = int_stack + 1439939;
 Libderiv->deriv2_classes[6][7][11] = int_stack + 1440723;
 Libderiv->deriv2_classes[6][8][11] = int_stack + 1441731;
 Libderiv->deriv2_classes[6][9][11] = int_stack + 1442991;
 Libderiv->deriv2_classes[6][10][11] = int_stack + 1444531;
 Libderiv->deriv_classes[7][5][11] = int_stack + 1446379;
 Libderiv->deriv_classes[7][6][11] = int_stack + 1447135;
 Libderiv->deriv_classes[7][7][11] = int_stack + 1448143;
 Libderiv->deriv_classes[7][8][11] = int_stack + 1449439;
 Libderiv->deriv_classes[7][9][11] = int_stack + 1451059;
 Libderiv->deriv_classes[7][10][11] = int_stack + 1453039;
 Libderiv->deriv2_classes[7][5][11] = int_stack + 1455415;
 Libderiv->deriv2_classes[7][6][11] = int_stack + 1456171;
 Libderiv->deriv2_classes[7][7][11] = int_stack + 1457179;
 Libderiv->deriv2_classes[7][8][11] = int_stack + 1458475;
 Libderiv->deriv2_classes[7][9][11] = int_stack + 1460095;
 Libderiv->deriv2_classes[7][10][11] = int_stack + 1462075;
 Libderiv->deriv2_classes[8][5][11] = int_stack + 1464451;
 Libderiv->deriv2_classes[8][6][11] = int_stack + 1465396;
 Libderiv->deriv2_classes[8][7][11] = int_stack + 1466656;
 Libderiv->deriv2_classes[8][8][11] = int_stack + 1468276;
 Libderiv->deriv2_classes[8][9][11] = int_stack + 1470301;
 Libderiv->deriv2_classes[8][10][11] = int_stack + 1472776;
 Libderiv->deriv_classes[4][5][10] = int_stack + 1475746;
 Libderiv->deriv_classes[4][6][10] = int_stack + 1476061;
 Libderiv->deriv_classes[4][7][10] = int_stack + 1476481;
 Libderiv->deriv_classes[4][8][10] = int_stack + 1477021;
 Libderiv->deriv_classes[4][9][10] = int_stack + 1477696;
 Libderiv->deriv_classes[4][10][10] = int_stack + 1478521;
 Libderiv->deriv2_classes[4][5][10] = int_stack + 1479511;
 Libderiv->deriv2_classes[4][6][10] = int_stack + 1479826;
 Libderiv->deriv2_classes[4][7][10] = int_stack + 1480246;
 Libderiv->deriv2_classes[4][8][10] = int_stack + 1480786;
 Libderiv->deriv2_classes[4][9][10] = int_stack + 1481461;
 Libderiv->deriv2_classes[4][10][10] = int_stack + 1482286;
 Libderiv->deriv_classes[5][5][10] = int_stack + 1483276;
 Libderiv->deriv_classes[5][6][10] = int_stack + 1483717;
 Libderiv->deriv_classes[5][7][10] = int_stack + 1484305;
 Libderiv->deriv_classes[5][8][10] = int_stack + 1485061;
 Libderiv->deriv_classes[5][9][10] = int_stack + 1486006;
 Libderiv->deriv_classes[5][10][10] = int_stack + 1487161;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 1488547;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 1488988;
 Libderiv->deriv2_classes[5][7][10] = int_stack + 1489576;
 Libderiv->deriv2_classes[5][8][10] = int_stack + 1490332;
 Libderiv->deriv2_classes[5][9][10] = int_stack + 1491277;
 Libderiv->deriv2_classes[5][10][10] = int_stack + 1492432;
 Libderiv->deriv_classes[6][5][10] = int_stack + 1493818;
 Libderiv->deriv_classes[6][6][10] = int_stack + 1494406;
 Libderiv->deriv_classes[6][7][10] = int_stack + 1495190;
 Libderiv->deriv_classes[6][8][10] = int_stack + 1496198;
 Libderiv->deriv_classes[6][9][10] = int_stack + 1497458;
 Libderiv->deriv_classes[6][10][10] = int_stack + 1498998;
 Libderiv->deriv2_classes[6][5][10] = int_stack + 1500846;
 Libderiv->deriv2_classes[6][6][10] = int_stack + 1501434;
 Libderiv->deriv2_classes[6][7][10] = int_stack + 1502218;
 Libderiv->deriv2_classes[6][8][10] = int_stack + 1503226;
 Libderiv->deriv2_classes[6][9][10] = int_stack + 1504486;
 Libderiv->deriv2_classes[6][10][10] = int_stack + 1506026;
 Libderiv->deriv_classes[7][5][10] = int_stack + 1507874;
 Libderiv->deriv_classes[7][6][10] = int_stack + 1508630;
 Libderiv->deriv_classes[7][7][10] = int_stack + 1509638;
 Libderiv->deriv_classes[7][8][10] = int_stack + 1510934;
 Libderiv->deriv_classes[7][9][10] = int_stack + 1512554;
 Libderiv->deriv_classes[7][10][10] = int_stack + 1514534;
 Libderiv->deriv2_classes[7][5][10] = int_stack + 1516910;
 Libderiv->deriv2_classes[7][6][10] = int_stack + 1517666;
 Libderiv->deriv2_classes[7][7][10] = int_stack + 1518674;
 Libderiv->deriv2_classes[7][8][10] = int_stack + 1519970;
 Libderiv->deriv2_classes[7][9][10] = int_stack + 1521590;
 Libderiv->deriv2_classes[7][10][10] = int_stack + 1523570;
 Libderiv->deriv2_classes[8][5][10] = int_stack + 1525946;
 Libderiv->deriv2_classes[8][6][10] = int_stack + 1526891;
 Libderiv->deriv2_classes[8][7][10] = int_stack + 1528151;
 Libderiv->deriv2_classes[8][8][10] = int_stack + 1529771;
 Libderiv->deriv2_classes[8][9][10] = int_stack + 1531796;
 Libderiv->deriv2_classes[8][10][10] = int_stack + 1534271;
 Libderiv->deriv_classes[4][5][9] = int_stack + 1537241;
 Libderiv->deriv_classes[4][6][9] = int_stack + 1537556;
 Libderiv->deriv_classes[4][7][9] = int_stack + 1537976;
 Libderiv->deriv_classes[4][8][9] = int_stack + 1538516;
 Libderiv->deriv_classes[4][9][9] = int_stack + 1539191;
 Libderiv->deriv_classes[4][10][9] = int_stack + 1540016;
 Libderiv->deriv2_classes[4][5][9] = int_stack + 1541006;
 Libderiv->deriv2_classes[4][6][9] = int_stack + 1541321;
 Libderiv->deriv2_classes[4][7][9] = int_stack + 1541741;
 Libderiv->deriv2_classes[4][8][9] = int_stack + 1542281;
 Libderiv->deriv2_classes[4][9][9] = int_stack + 1542956;
 Libderiv->deriv2_classes[4][10][9] = int_stack + 1543781;
 Libderiv->deriv_classes[5][5][9] = int_stack + 1544771;
 Libderiv->deriv_classes[5][6][9] = int_stack + 1545212;
 Libderiv->deriv_classes[5][7][9] = int_stack + 1545800;
 Libderiv->deriv_classes[5][8][9] = int_stack + 1546556;
 Libderiv->deriv_classes[5][9][9] = int_stack + 1547501;
 Libderiv->deriv_classes[5][10][9] = int_stack + 1548656;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 1550042;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 1550483;
 Libderiv->deriv2_classes[5][7][9] = int_stack + 1551071;
 Libderiv->deriv2_classes[5][8][9] = int_stack + 1551827;
 Libderiv->deriv2_classes[5][9][9] = int_stack + 1552772;
 Libderiv->deriv2_classes[5][10][9] = int_stack + 1553927;
 Libderiv->deriv_classes[6][5][9] = int_stack + 1555313;
 Libderiv->deriv_classes[6][6][9] = int_stack + 1555901;
 Libderiv->deriv_classes[6][7][9] = int_stack + 1556685;
 Libderiv->deriv_classes[6][8][9] = int_stack + 1557693;
 Libderiv->deriv_classes[6][9][9] = int_stack + 1558953;
 Libderiv->deriv_classes[6][10][9] = int_stack + 1560493;
 Libderiv->deriv2_classes[6][5][9] = int_stack + 1562341;
 Libderiv->deriv2_classes[6][6][9] = int_stack + 1562929;
 Libderiv->deriv2_classes[6][7][9] = int_stack + 1563713;
 Libderiv->deriv2_classes[6][8][9] = int_stack + 1564721;
 Libderiv->deriv2_classes[6][9][9] = int_stack + 1565981;
 Libderiv->deriv2_classes[6][10][9] = int_stack + 1567521;
 Libderiv->deriv_classes[7][5][9] = int_stack + 1569369;
 Libderiv->deriv_classes[7][6][9] = int_stack + 1570125;
 Libderiv->deriv_classes[7][7][9] = int_stack + 1571133;
 Libderiv->deriv_classes[7][8][9] = int_stack + 1572429;
 Libderiv->deriv_classes[7][9][9] = int_stack + 1574049;
 Libderiv->deriv_classes[7][10][9] = int_stack + 1576029;
 Libderiv->deriv2_classes[7][5][9] = int_stack + 1578405;
 Libderiv->deriv2_classes[7][6][9] = int_stack + 1579161;
 Libderiv->deriv2_classes[7][7][9] = int_stack + 1580169;
 Libderiv->deriv2_classes[7][8][9] = int_stack + 1581465;
 Libderiv->deriv2_classes[7][9][9] = int_stack + 1583085;
 Libderiv->deriv2_classes[7][10][9] = int_stack + 1585065;
 Libderiv->deriv2_classes[8][5][9] = int_stack + 1587441;
 Libderiv->deriv2_classes[8][6][9] = int_stack + 1588386;
 Libderiv->deriv2_classes[8][7][9] = int_stack + 1589646;
 Libderiv->deriv2_classes[8][8][9] = int_stack + 1591266;
 Libderiv->deriv2_classes[8][9][9] = int_stack + 1593291;
 Libderiv->deriv2_classes[8][10][9] = int_stack + 1595766;
 Libderiv->deriv_classes[4][5][8] = int_stack + 1598736;
 Libderiv->deriv_classes[4][6][8] = int_stack + 1599051;
 Libderiv->deriv_classes[4][7][8] = int_stack + 1599471;
 Libderiv->deriv_classes[4][8][8] = int_stack + 1600011;
 Libderiv->deriv_classes[4][9][8] = int_stack + 1600686;
 Libderiv->deriv_classes[4][10][8] = int_stack + 1601511;
 Libderiv->deriv2_classes[4][5][8] = int_stack + 1602501;
 Libderiv->deriv2_classes[4][6][8] = int_stack + 1602816;
 Libderiv->deriv2_classes[4][7][8] = int_stack + 1603236;
 Libderiv->deriv2_classes[4][8][8] = int_stack + 1603776;
 Libderiv->deriv2_classes[4][9][8] = int_stack + 1604451;
 Libderiv->deriv2_classes[4][10][8] = int_stack + 1605276;
 Libderiv->deriv_classes[5][5][8] = int_stack + 1606266;
 Libderiv->deriv_classes[5][6][8] = int_stack + 1606707;
 Libderiv->deriv_classes[5][7][8] = int_stack + 1607295;
 Libderiv->deriv_classes[5][8][8] = int_stack + 1608051;
 Libderiv->deriv_classes[5][9][8] = int_stack + 1608996;
 Libderiv->deriv_classes[5][10][8] = int_stack + 1610151;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 1611537;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 1611978;
 Libderiv->deriv2_classes[5][7][8] = int_stack + 1612566;
 Libderiv->deriv2_classes[5][8][8] = int_stack + 1613322;
 Libderiv->deriv2_classes[5][9][8] = int_stack + 1614267;
 Libderiv->deriv2_classes[5][10][8] = int_stack + 1615422;
 Libderiv->deriv_classes[6][5][8] = int_stack + 1616808;
 Libderiv->deriv_classes[6][6][8] = int_stack + 1617396;
 Libderiv->deriv_classes[6][7][8] = int_stack + 1618180;
 Libderiv->deriv_classes[6][8][8] = int_stack + 1619188;
 Libderiv->deriv_classes[6][9][8] = int_stack + 1620448;
 Libderiv->deriv_classes[6][10][8] = int_stack + 1621988;
 Libderiv->deriv2_classes[6][5][8] = int_stack + 1623836;
 Libderiv->deriv2_classes[6][6][8] = int_stack + 1624424;
 Libderiv->deriv2_classes[6][7][8] = int_stack + 1625208;
 Libderiv->deriv2_classes[6][8][8] = int_stack + 1626216;
 Libderiv->deriv2_classes[6][9][8] = int_stack + 1627476;
 Libderiv->deriv2_classes[6][10][8] = int_stack + 1629016;
 Libderiv->deriv_classes[7][5][8] = int_stack + 1630864;
 Libderiv->deriv_classes[7][6][8] = int_stack + 1631620;
 Libderiv->deriv_classes[7][7][8] = int_stack + 1632628;
 Libderiv->deriv_classes[7][8][8] = int_stack + 1633924;
 Libderiv->deriv_classes[7][9][8] = int_stack + 1635544;
 Libderiv->deriv_classes[7][10][8] = int_stack + 1637524;
 Libderiv->deriv2_classes[7][5][8] = int_stack + 1639900;
 Libderiv->deriv2_classes[7][6][8] = int_stack + 1640656;
 Libderiv->deriv2_classes[7][7][8] = int_stack + 1641664;
 Libderiv->deriv2_classes[7][8][8] = int_stack + 1642960;
 Libderiv->deriv2_classes[7][9][8] = int_stack + 1644580;
 Libderiv->deriv2_classes[7][10][8] = int_stack + 1646560;
 Libderiv->deriv2_classes[8][5][8] = int_stack + 1648936;
 Libderiv->deriv2_classes[8][6][8] = int_stack + 1649881;
 Libderiv->deriv2_classes[8][7][8] = int_stack + 1651141;
 Libderiv->deriv2_classes[8][8][8] = int_stack + 1652761;
 Libderiv->deriv2_classes[8][9][8] = int_stack + 1654786;
 Libderiv->deriv2_classes[8][10][8] = int_stack + 1657261;
 Libderiv->deriv_classes[4][5][7] = int_stack + 1660231;
 Libderiv->deriv_classes[4][6][7] = int_stack + 1660546;
 Libderiv->deriv_classes[4][7][7] = int_stack + 1660966;
 Libderiv->deriv_classes[4][8][7] = int_stack + 1661506;
 Libderiv->deriv_classes[4][9][7] = int_stack + 1662181;
 Libderiv->deriv_classes[4][10][7] = int_stack + 1663006;
 Libderiv->deriv2_classes[4][5][7] = int_stack + 1663996;
 Libderiv->deriv2_classes[4][6][7] = int_stack + 1664311;
 Libderiv->deriv2_classes[4][7][7] = int_stack + 1664731;
 Libderiv->deriv2_classes[4][8][7] = int_stack + 1665271;
 Libderiv->deriv2_classes[4][9][7] = int_stack + 1665946;
 Libderiv->deriv2_classes[4][10][7] = int_stack + 1666771;
 Libderiv->deriv_classes[5][5][7] = int_stack + 1667761;
 Libderiv->deriv_classes[5][6][7] = int_stack + 1668202;
 Libderiv->deriv_classes[5][7][7] = int_stack + 1668790;
 Libderiv->deriv_classes[5][8][7] = int_stack + 1669546;
 Libderiv->deriv_classes[5][9][7] = int_stack + 1670491;
 Libderiv->deriv_classes[5][10][7] = int_stack + 1671646;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 1673032;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 1673473;
 Libderiv->deriv2_classes[5][7][7] = int_stack + 1674061;
 Libderiv->deriv2_classes[5][8][7] = int_stack + 1674817;
 Libderiv->deriv2_classes[5][9][7] = int_stack + 1675762;
 Libderiv->deriv2_classes[5][10][7] = int_stack + 1676917;
 Libderiv->deriv_classes[6][5][7] = int_stack + 1678303;
 Libderiv->deriv_classes[6][6][7] = int_stack + 1678891;
 Libderiv->deriv_classes[6][7][7] = int_stack + 1679675;
 Libderiv->deriv_classes[6][8][7] = int_stack + 1680683;
 Libderiv->deriv_classes[6][9][7] = int_stack + 1681943;
 Libderiv->deriv_classes[6][10][7] = int_stack + 1683483;
 Libderiv->deriv2_classes[6][5][7] = int_stack + 1685331;
 Libderiv->deriv2_classes[6][6][7] = int_stack + 1685919;
 Libderiv->deriv2_classes[6][7][7] = int_stack + 1686703;
 Libderiv->deriv2_classes[6][8][7] = int_stack + 1687711;
 Libderiv->deriv2_classes[6][9][7] = int_stack + 1688971;
 Libderiv->deriv2_classes[6][10][7] = int_stack + 1690511;
 Libderiv->deriv_classes[7][5][7] = int_stack + 1692359;
 Libderiv->deriv_classes[7][6][7] = int_stack + 1693115;
 Libderiv->deriv_classes[7][7][7] = int_stack + 1694123;
 Libderiv->deriv_classes[7][8][7] = int_stack + 1695419;
 Libderiv->deriv_classes[7][9][7] = int_stack + 1697039;
 Libderiv->deriv_classes[7][10][7] = int_stack + 1699019;
 Libderiv->deriv2_classes[7][5][7] = int_stack + 1701395;
 Libderiv->deriv2_classes[7][6][7] = int_stack + 1702151;
 Libderiv->deriv2_classes[7][7][7] = int_stack + 1703159;
 Libderiv->deriv2_classes[7][8][7] = int_stack + 1704455;
 Libderiv->deriv2_classes[7][9][7] = int_stack + 1706075;
 Libderiv->deriv2_classes[7][10][7] = int_stack + 1708055;
 Libderiv->deriv2_classes[8][5][7] = int_stack + 1710431;
 Libderiv->deriv2_classes[8][6][7] = int_stack + 1711376;
 Libderiv->deriv2_classes[8][7][7] = int_stack + 1712636;
 Libderiv->deriv2_classes[8][8][7] = int_stack + 1714256;
 Libderiv->deriv2_classes[8][9][7] = int_stack + 1716281;
 Libderiv->deriv2_classes[8][10][7] = int_stack + 1718756;
 Libderiv->deriv_classes[4][5][6] = int_stack + 1721726;
 Libderiv->deriv_classes[4][6][6] = int_stack + 1722041;
 Libderiv->deriv_classes[4][7][6] = int_stack + 1722461;
 Libderiv->deriv_classes[4][8][6] = int_stack + 1723001;
 Libderiv->deriv_classes[4][9][6] = int_stack + 1723676;
 Libderiv->deriv_classes[4][10][6] = int_stack + 1724501;
 Libderiv->deriv2_classes[4][5][6] = int_stack + 1725491;
 Libderiv->deriv2_classes[4][6][6] = int_stack + 1725806;
 Libderiv->deriv2_classes[4][7][6] = int_stack + 1726226;
 Libderiv->deriv2_classes[4][8][6] = int_stack + 1726766;
 Libderiv->deriv2_classes[4][9][6] = int_stack + 1727441;
 Libderiv->deriv2_classes[4][10][6] = int_stack + 1728266;
 Libderiv->deriv_classes[5][5][6] = int_stack + 1729256;
 Libderiv->deriv_classes[5][6][6] = int_stack + 1729697;
 Libderiv->deriv_classes[5][7][6] = int_stack + 1730285;
 Libderiv->deriv_classes[5][8][6] = int_stack + 1731041;
 Libderiv->deriv_classes[5][9][6] = int_stack + 1731986;
 Libderiv->deriv_classes[5][10][6] = int_stack + 1733141;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 1734527;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 1734968;
 Libderiv->deriv2_classes[5][7][6] = int_stack + 1735556;
 Libderiv->deriv2_classes[5][8][6] = int_stack + 1736312;
 Libderiv->deriv2_classes[5][9][6] = int_stack + 1737257;
 Libderiv->deriv2_classes[5][10][6] = int_stack + 1738412;
 Libderiv->deriv_classes[6][5][6] = int_stack + 1739798;
 Libderiv->deriv_classes[6][6][6] = int_stack + 1740386;
 Libderiv->deriv_classes[6][7][6] = int_stack + 1741170;
 Libderiv->deriv_classes[6][8][6] = int_stack + 1742178;
 Libderiv->deriv_classes[6][9][6] = int_stack + 1743438;
 Libderiv->deriv_classes[6][10][6] = int_stack + 1744978;
 Libderiv->deriv2_classes[6][5][6] = int_stack + 1746826;
 Libderiv->deriv2_classes[6][6][6] = int_stack + 1747414;
 Libderiv->deriv2_classes[6][7][6] = int_stack + 1748198;
 Libderiv->deriv2_classes[6][8][6] = int_stack + 1749206;
 Libderiv->deriv2_classes[6][9][6] = int_stack + 1750466;
 Libderiv->deriv2_classes[6][10][6] = int_stack + 1752006;
 Libderiv->dvrr_classes[7][5] = int_stack + 1753854;
 Libderiv->deriv_classes[7][5][6] = int_stack + 1754610;
 Libderiv->dvrr_classes[7][6] = int_stack + 1755366;
 Libderiv->deriv_classes[7][6][6] = int_stack + 1756374;
 Libderiv->dvrr_classes[7][7] = int_stack + 1757382;
 Libderiv->deriv_classes[7][7][6] = int_stack + 1758678;
 Libderiv->dvrr_classes[7][8] = int_stack + 1759974;
 Libderiv->deriv_classes[7][8][6] = int_stack + 1761594;
 Libderiv->dvrr_classes[7][9] = int_stack + 1763214;
 Libderiv->deriv_classes[7][9][6] = int_stack + 1765194;
 Libderiv->deriv_classes[7][10][6] = int_stack + 1767174;
 Libderiv->deriv2_classes[7][5][6] = int_stack + 1769550;
 Libderiv->deriv2_classes[7][6][6] = int_stack + 1770306;
 Libderiv->deriv2_classes[7][7][6] = int_stack + 1771314;
 Libderiv->deriv2_classes[7][8][6] = int_stack + 1772610;
 Libderiv->deriv2_classes[7][9][6] = int_stack + 1774230;
 Libderiv->deriv2_classes[7][10][6] = int_stack + 1776210;
 Libderiv->deriv_classes[8][5][0] = int_stack + 1778586;
 Libderiv->deriv2_classes[8][5][6] = int_stack + 1779531;
 Libderiv->deriv_classes[8][6][0] = int_stack + 1780476;
 Libderiv->deriv2_classes[8][6][6] = int_stack + 1781736;
 Libderiv->deriv_classes[8][7][0] = int_stack + 1782996;
 Libderiv->deriv2_classes[8][7][6] = int_stack + 1784616;
 Libderiv->deriv_classes[8][8][0] = int_stack + 1786236;
 Libderiv->deriv2_classes[8][8][6] = int_stack + 1788261;
 Libderiv->deriv_classes[8][9][0] = int_stack + 1790286;
 Libderiv->deriv2_classes[8][9][6] = int_stack + 1792761;
 Libderiv->deriv2_classes[8][10][6] = int_stack + 1795236;
 Libderiv->deriv_classes[4][5][2] = int_stack + 1798206;
 Libderiv->deriv_classes[4][6][2] = int_stack + 1798521;
 Libderiv->deriv_classes[4][7][2] = int_stack + 1798941;
 Libderiv->deriv_classes[4][8][2] = int_stack + 1799481;
 Libderiv->deriv_classes[4][9][2] = int_stack + 1800156;
 Libderiv->deriv_classes[4][10][2] = int_stack + 1800981;
 Libderiv->deriv2_classes[4][5][2] = int_stack + 1801971;
 Libderiv->deriv2_classes[4][6][2] = int_stack + 1802286;
 Libderiv->deriv2_classes[4][7][2] = int_stack + 1802706;
 Libderiv->deriv2_classes[4][8][2] = int_stack + 1803246;
 Libderiv->deriv2_classes[4][9][2] = int_stack + 1803921;
 Libderiv->deriv2_classes[4][10][2] = int_stack + 1804746;
 Libderiv->deriv_classes[5][5][2] = int_stack + 1805736;
 Libderiv->deriv_classes[5][6][2] = int_stack + 1806177;
 Libderiv->deriv_classes[5][7][2] = int_stack + 1806765;
 Libderiv->deriv_classes[5][8][2] = int_stack + 1807521;
 Libderiv->deriv_classes[5][9][2] = int_stack + 1808466;
 Libderiv->deriv_classes[5][10][2] = int_stack + 1809621;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 1811007;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 1811448;
 Libderiv->deriv2_classes[5][7][2] = int_stack + 1812036;
 Libderiv->deriv2_classes[5][8][2] = int_stack + 1812792;
 Libderiv->deriv2_classes[5][9][2] = int_stack + 1813737;
 Libderiv->deriv2_classes[5][10][2] = int_stack + 1814892;
 Libderiv->deriv_classes[6][5][2] = int_stack + 1816278;
 Libderiv->deriv_classes[6][6][2] = int_stack + 1816866;
 Libderiv->deriv_classes[6][7][2] = int_stack + 1817650;
 Libderiv->deriv_classes[6][8][2] = int_stack + 1818658;
 Libderiv->deriv_classes[6][9][2] = int_stack + 1819918;
 Libderiv->deriv_classes[6][10][2] = int_stack + 1821458;
 Libderiv->deriv2_classes[6][5][2] = int_stack + 1823306;
 Libderiv->deriv2_classes[6][6][2] = int_stack + 1823894;
 Libderiv->deriv2_classes[6][7][2] = int_stack + 1824678;
 Libderiv->deriv2_classes[6][8][2] = int_stack + 1825686;
 Libderiv->deriv2_classes[6][9][2] = int_stack + 1826946;
 Libderiv->deriv2_classes[6][10][2] = int_stack + 1828486;
 Libderiv->deriv_classes[7][5][2] = int_stack + 1830334;
 Libderiv->deriv_classes[7][6][2] = int_stack + 1831090;
 Libderiv->deriv_classes[7][7][2] = int_stack + 1832098;
 Libderiv->deriv_classes[7][8][2] = int_stack + 1833394;
 Libderiv->deriv_classes[7][9][2] = int_stack + 1835014;
 Libderiv->deriv_classes[7][10][2] = int_stack + 1836994;
 Libderiv->deriv2_classes[7][5][2] = int_stack + 1839370;
 Libderiv->deriv2_classes[7][6][2] = int_stack + 1840126;
 Libderiv->deriv2_classes[7][7][2] = int_stack + 1841134;
 Libderiv->deriv2_classes[7][8][2] = int_stack + 1842430;
 Libderiv->deriv2_classes[7][9][2] = int_stack + 1844050;
 Libderiv->deriv2_classes[7][10][2] = int_stack + 1846030;
 Libderiv->deriv2_classes[8][5][2] = int_stack + 1848406;
 Libderiv->deriv2_classes[8][6][2] = int_stack + 1849351;
 Libderiv->deriv2_classes[8][7][2] = int_stack + 1850611;
 Libderiv->deriv2_classes[8][8][2] = int_stack + 1852231;
 Libderiv->deriv2_classes[8][9][2] = int_stack + 1854256;
 Libderiv->deriv2_classes[8][10][2] = int_stack + 1856731;
 Libderiv->deriv_classes[4][5][1] = int_stack + 1859701;
 Libderiv->deriv_classes[4][6][1] = int_stack + 1860016;
 Libderiv->deriv_classes[4][7][1] = int_stack + 1860436;
 Libderiv->deriv_classes[4][8][1] = int_stack + 1860976;
 Libderiv->deriv_classes[4][9][1] = int_stack + 1861651;
 Libderiv->deriv_classes[4][10][1] = int_stack + 1862476;
 Libderiv->deriv2_classes[4][5][1] = int_stack + 1863466;
 Libderiv->deriv2_classes[4][6][1] = int_stack + 1863781;
 Libderiv->deriv2_classes[4][7][1] = int_stack + 1864201;
 Libderiv->deriv2_classes[4][8][1] = int_stack + 1864741;
 Libderiv->deriv2_classes[4][9][1] = int_stack + 1865416;
 Libderiv->deriv2_classes[4][10][1] = int_stack + 1866241;
 Libderiv->deriv_classes[5][5][1] = int_stack + 1867231;
 Libderiv->deriv_classes[5][6][1] = int_stack + 1867672;
 Libderiv->deriv_classes[5][7][1] = int_stack + 1868260;
 Libderiv->deriv_classes[5][8][1] = int_stack + 1869016;
 Libderiv->deriv_classes[5][9][1] = int_stack + 1869961;
 Libderiv->deriv_classes[5][10][1] = int_stack + 1871116;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 1872502;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 1872943;
 Libderiv->deriv2_classes[5][7][1] = int_stack + 1873531;
 Libderiv->deriv2_classes[5][8][1] = int_stack + 1874287;
 Libderiv->deriv2_classes[5][9][1] = int_stack + 1875232;
 Libderiv->deriv2_classes[5][10][1] = int_stack + 1876387;
 Libderiv->deriv_classes[6][5][1] = int_stack + 1877773;
 Libderiv->deriv_classes[6][6][1] = int_stack + 1878361;
 Libderiv->deriv_classes[6][7][1] = int_stack + 1879145;
 Libderiv->deriv_classes[6][8][1] = int_stack + 1880153;
 Libderiv->deriv_classes[6][9][1] = int_stack + 1881413;
 Libderiv->deriv_classes[6][10][1] = int_stack + 1882953;
 Libderiv->deriv2_classes[6][5][1] = int_stack + 1884801;
 Libderiv->deriv2_classes[6][6][1] = int_stack + 1885389;
 Libderiv->deriv2_classes[6][7][1] = int_stack + 1886173;
 Libderiv->deriv2_classes[6][8][1] = int_stack + 1887181;
 Libderiv->deriv2_classes[6][9][1] = int_stack + 1888441;
 Libderiv->deriv2_classes[6][10][1] = int_stack + 1889981;
 Libderiv->deriv_classes[7][5][1] = int_stack + 1891829;
 Libderiv->deriv_classes[7][6][1] = int_stack + 1892585;
 Libderiv->deriv_classes[7][7][1] = int_stack + 1893593;
 Libderiv->deriv_classes[7][8][1] = int_stack + 1894889;
 Libderiv->deriv_classes[7][9][1] = int_stack + 1896509;
 Libderiv->deriv_classes[7][10][1] = int_stack + 1898489;
 Libderiv->deriv2_classes[7][5][1] = int_stack + 1900865;
 Libderiv->deriv2_classes[7][6][1] = int_stack + 1901621;
 Libderiv->deriv2_classes[7][7][1] = int_stack + 1902629;
 Libderiv->deriv2_classes[7][8][1] = int_stack + 1903925;
 Libderiv->deriv2_classes[7][9][1] = int_stack + 1905545;
 Libderiv->deriv2_classes[7][10][1] = int_stack + 1907525;
 Libderiv->deriv2_classes[8][5][1] = int_stack + 1909901;
 Libderiv->deriv2_classes[8][6][1] = int_stack + 1910846;
 Libderiv->deriv2_classes[8][7][1] = int_stack + 1912106;
 Libderiv->deriv2_classes[8][8][1] = int_stack + 1913726;
 Libderiv->deriv2_classes[8][9][1] = int_stack + 1915751;
 Libderiv->deriv2_classes[8][10][1] = int_stack + 1918226;
 Libderiv->dvrr_classes[4][5] = int_stack + 1921196;
 Libderiv->dvrr_classes[4][6] = int_stack + 1921511;
 Libderiv->dvrr_classes[4][7] = int_stack + 1921931;
 Libderiv->dvrr_classes[4][8] = int_stack + 1922471;
 Libderiv->dvrr_classes[4][9] = int_stack + 1923146;
 Libderiv->dvrr_classes[4][10] = int_stack + 1923971;
 Libderiv->deriv_classes[4][5][0] = int_stack + 1924961;
 Libderiv->deriv_classes[4][6][0] = int_stack + 1925276;
 Libderiv->deriv_classes[4][7][0] = int_stack + 1925696;
 Libderiv->deriv_classes[4][8][0] = int_stack + 1926236;
 Libderiv->deriv_classes[4][9][0] = int_stack + 1926911;
 Libderiv->deriv_classes[4][10][0] = int_stack + 1927736;
 Libderiv->deriv2_classes[4][5][0] = int_stack + 1928726;
 Libderiv->deriv2_classes[4][6][0] = int_stack + 1929041;
 Libderiv->deriv2_classes[4][7][0] = int_stack + 1929461;
 Libderiv->deriv2_classes[4][8][0] = int_stack + 1930001;
 Libderiv->deriv2_classes[4][9][0] = int_stack + 1930676;
 Libderiv->deriv2_classes[4][10][0] = int_stack + 1931501;
 Libderiv->dvrr_classes[5][5] = int_stack + 1932491;
 Libderiv->dvrr_classes[5][6] = int_stack + 1932932;
 Libderiv->dvrr_classes[5][7] = int_stack + 1933520;
 Libderiv->dvrr_classes[5][8] = int_stack + 1934276;
 Libderiv->dvrr_classes[5][9] = int_stack + 1935221;
 Libderiv->dvrr_classes[5][10] = int_stack + 1936376;
 Libderiv->deriv_classes[5][5][0] = int_stack + 1937762;
 Libderiv->deriv_classes[5][6][0] = int_stack + 1938203;
 Libderiv->deriv_classes[5][7][0] = int_stack + 1938791;
 Libderiv->deriv_classes[5][8][0] = int_stack + 1939547;
 Libderiv->deriv_classes[5][9][0] = int_stack + 1940492;
 Libderiv->deriv_classes[5][10][0] = int_stack + 1941647;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 1943033;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 1943474;
 Libderiv->deriv2_classes[5][7][0] = int_stack + 1944062;
 Libderiv->deriv2_classes[5][8][0] = int_stack + 1944818;
 Libderiv->deriv2_classes[5][9][0] = int_stack + 1945763;
 Libderiv->deriv2_classes[5][10][0] = int_stack + 1946918;
 Libderiv->dvrr_classes[6][5] = int_stack + 1948304;
 Libderiv->dvrr_classes[6][6] = int_stack + 1948892;
 Libderiv->dvrr_classes[6][7] = int_stack + 1949676;
 Libderiv->dvrr_classes[6][8] = int_stack + 1950684;
 Libderiv->dvrr_classes[6][9] = int_stack + 1951944;
 Libderiv->dvrr_classes[6][10] = int_stack + 1953484;
 Libderiv->deriv_classes[6][5][0] = int_stack + 1955332;
 Libderiv->deriv_classes[6][6][0] = int_stack + 1955920;
 Libderiv->deriv_classes[6][7][0] = int_stack + 1956704;
 Libderiv->deriv_classes[6][8][0] = int_stack + 1957712;
 Libderiv->deriv_classes[6][9][0] = int_stack + 1958972;
 Libderiv->deriv_classes[6][10][0] = int_stack + 1960512;
 Libderiv->deriv2_classes[6][5][0] = int_stack + 1962360;
 Libderiv->deriv2_classes[6][6][0] = int_stack + 1962948;
 Libderiv->deriv2_classes[6][7][0] = int_stack + 1963732;
 Libderiv->deriv2_classes[6][8][0] = int_stack + 1964740;
 Libderiv->deriv2_classes[6][9][0] = int_stack + 1966000;
 Libderiv->deriv2_classes[6][10][0] = int_stack + 1967540;
 Libderiv->deriv_classes[7][5][0] = int_stack + 1969388;
 Libderiv->deriv_classes[7][6][0] = int_stack + 1970144;
 Libderiv->deriv_classes[7][7][0] = int_stack + 1971152;
 Libderiv->deriv_classes[7][8][0] = int_stack + 1972448;
 Libderiv->deriv_classes[7][9][0] = int_stack + 1974068;
 Libderiv->deriv_classes[7][10][0] = int_stack + 1976048;
 Libderiv->deriv2_classes[7][5][0] = int_stack + 1978424;
 Libderiv->deriv2_classes[7][6][0] = int_stack + 1979180;
 Libderiv->deriv2_classes[7][7][0] = int_stack + 1980188;
 Libderiv->deriv2_classes[7][8][0] = int_stack + 1981484;
 Libderiv->deriv2_classes[7][9][0] = int_stack + 1983104;
 Libderiv->deriv2_classes[7][10][0] = int_stack + 1985084;
 Libderiv->deriv2_classes[8][5][0] = int_stack + 1987460;
 Libderiv->deriv2_classes[8][6][0] = int_stack + 1988405;
 Libderiv->deriv2_classes[8][7][0] = int_stack + 1989665;
 Libderiv->deriv2_classes[8][8][0] = int_stack + 1991285;
 Libderiv->deriv2_classes[8][9][0] = int_stack + 1993310;
 Libderiv->deriv2_classes[8][10][0] = int_stack + 1995785;
 memset(int_stack,0,15990040);

 Libderiv->dvrr_stack = int_stack + 12070771;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_gghh(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1998755,int_stack+1921511,int_stack+1921196,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1999700,int_stack+1921931,int_stack+1921511,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2000960,int_stack+1999700,int_stack+1998755,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2002850,int_stack+1922471,int_stack+1921931,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2004470,int_stack+2002850,int_stack+1999700,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2006990,int_stack+2004470,int_stack+2000960,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2010140,int_stack+1923146,int_stack+1922471,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2012165,int_stack+2010140,int_stack+2002850,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2015405,int_stack+2012165,int_stack+2004470,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2019605,int_stack+2015405,int_stack+2006990,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2024330,int_stack+1414566,int_stack+1414251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1921196,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2025275,int_stack+1414986,int_stack+1414566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1921511,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2026535,int_stack+2025275,int_stack+2024330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1998755,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2028425,int_stack+1415526,int_stack+1414986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1921931,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2030045,int_stack+2028425,int_stack+2025275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1999700,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2032565,int_stack+2030045,int_stack+2026535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2000960,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2035715,int_stack+1416201,int_stack+1415526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1922471,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2037740,int_stack+2035715,int_stack+2028425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2002850,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2040980,int_stack+2037740,int_stack+2030045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2004470,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2045180,int_stack+2040980,int_stack+2032565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2006990,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2049905,int_stack+1417026,int_stack+1416201, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1923146,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2052380,int_stack+2049905,int_stack+2035715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2010140,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2056430,int_stack+2052380,int_stack+2037740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2012165,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2049905,int_stack+2056430,int_stack+2040980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2015405,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2056205,int_stack+2049905,int_stack+2045180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2019605,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2049905,int_stack+1932932,int_stack+1932491,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2051228,int_stack+1933520,int_stack+1932932,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2052992,int_stack+2051228,int_stack+2049905,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2062820,int_stack+1934276,int_stack+1933520,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2065088,int_stack+2062820,int_stack+2051228,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2068616,int_stack+2065088,int_stack+2052992,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2073026,int_stack+1935221,int_stack+1934276,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2075861,int_stack+2073026,int_stack+2062820,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2080397,int_stack+2075861,int_stack+2065088,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2086277,int_stack+2080397,int_stack+2068616,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2092892,int_stack+1422222,int_stack+1421781, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1932491,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2094215,int_stack+1422810,int_stack+1422222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1932932,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2095979,int_stack+2094215,int_stack+2092892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2049905,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2098625,int_stack+1423566,int_stack+1422810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1933520,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2100893,int_stack+2098625,int_stack+2094215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2051228,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2104421,int_stack+2100893,int_stack+2095979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2052992,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2108831,int_stack+1424511,int_stack+1423566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1934276,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2111666,int_stack+2108831,int_stack+2098625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2062820,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2116202,int_stack+2111666,int_stack+2100893, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2065088,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2122082,int_stack+2116202,int_stack+2104421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2068616,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2128697,int_stack+1425666,int_stack+1424511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1935221,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2132162,int_stack+2128697,int_stack+2108831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2073026,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2137832,int_stack+2132162,int_stack+2111666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2075861,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2128697,int_stack+2137832,int_stack+2116202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2080397,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2137517,int_stack+2128697,int_stack+2122082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2086277,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+2146778,int_stack+2137517,int_stack+2056205,441);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2128697,int_stack+1948892,int_stack+1948304,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2130461,int_stack+1949676,int_stack+1948892,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2132813,int_stack+2130461,int_stack+2128697,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2166623,int_stack+1950684,int_stack+1949676,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2169647,int_stack+2166623,int_stack+2130461,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2174351,int_stack+2169647,int_stack+2132813,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2180231,int_stack+1951944,int_stack+1950684,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2184011,int_stack+2180231,int_stack+2166623,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2190059,int_stack+2184011,int_stack+2169647,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2197899,int_stack+2190059,int_stack+2174351,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2206719,int_stack+1432911,int_stack+1432323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1948304,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2208483,int_stack+1433695,int_stack+1432911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1948892,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2210835,int_stack+2208483,int_stack+2206719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2128697,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2214363,int_stack+1434703,int_stack+1433695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1949676,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2217387,int_stack+2214363,int_stack+2208483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2130461,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2222091,int_stack+2217387,int_stack+2210835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2132813,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2227971,int_stack+1435963,int_stack+1434703, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1950684,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2231751,int_stack+2227971,int_stack+2214363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2166623,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2237799,int_stack+2231751,int_stack+2217387, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2169647,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2245639,int_stack+2237799,int_stack+2222091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2174351,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2254459,int_stack+1437503,int_stack+1435963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1951944,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2259079,int_stack+2254459,int_stack+2227971, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2180231,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2266639,int_stack+2259079,int_stack+2231751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2184011,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2254459,int_stack+2266639,int_stack+2237799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2190059,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2266219,int_stack+2254459,int_stack+2245639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2197899,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2278567,int_stack+2266219,int_stack+2137517,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+2306350,int_stack+2278567,int_stack+2146778,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2254459,int_stack+1755366,int_stack+1753854,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2256727,int_stack+1757382,int_stack+1755366,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2259751,int_stack+2256727,int_stack+2254459,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2346040,int_stack+1759974,int_stack+1757382,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2349928,int_stack+2346040,int_stack+2256727,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2355976,int_stack+2349928,int_stack+2259751,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2363536,int_stack+1763214,int_stack+1759974,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2368396,int_stack+2363536,int_stack+2346040,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2376172,int_stack+2368396,int_stack+2349928,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2386252,int_stack+2376172,int_stack+2355976,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2397592,int_stack+1447135,int_stack+1446379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1753854,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2399860,int_stack+1448143,int_stack+1447135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1755366,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2402884,int_stack+2399860,int_stack+2397592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2254459,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2407420,int_stack+1449439,int_stack+1448143, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1757382,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2411308,int_stack+2407420,int_stack+2399860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2256727,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2417356,int_stack+2411308,int_stack+2402884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2259751,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2424916,int_stack+1451059,int_stack+1449439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1759974,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2429776,int_stack+2424916,int_stack+2407420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2346040,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2437552,int_stack+2429776,int_stack+2411308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2349928,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2447632,int_stack+2437552,int_stack+2417356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2355976,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2458972,int_stack+1453039,int_stack+1451059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1763214,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2464912,int_stack+2458972,int_stack+2424916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2363536,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2474632,int_stack+2464912,int_stack+2429776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2368396,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2458972,int_stack+2474632,int_stack+2437552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2376172,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2474092,int_stack+2458972,int_stack+2447632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2386252,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2489968,int_stack+2474092,int_stack+2266219,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2527012,int_stack+2489968,int_stack+2278567,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+2582578,int_stack+2527012,int_stack+2306350,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2458972,int_stack+829041,int_stack+826206,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2461807,int_stack+832821,int_stack+829041,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2465587,int_stack+2461807,int_stack+2458972,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2648728,int_stack+837681,int_stack+832821,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2653588,int_stack+2648728,int_stack+2461807,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2661148,int_stack+2653588,int_stack+2465587,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2670598,int_stack+14850,int_stack+837681,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2676673,int_stack+2670598,int_stack+2648728,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2686393,int_stack+2676673,int_stack+2653588,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2698993,int_stack+2686393,int_stack+2661148,45);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2471257,int_stack+604496,int_stack+602606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+826206,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2713168,int_stack+607016,int_stack+604496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829041,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2716948,int_stack+2713168,int_stack+2471257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2458972,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2722618,int_stack+610256,int_stack+607016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+832821,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2727478,int_stack+2722618,int_stack+2713168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2461807,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2735038,int_stack+2727478,int_stack+2716948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2465587,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2744488,int_stack+614306,int_stack+610256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837681,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2750563,int_stack+2744488,int_stack+2722618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2648728,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2760283,int_stack+2750563,int_stack+2727478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2653588,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2772883,int_stack+2760283,int_stack+2735038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2661148,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2787058,int_stack+0,int_stack+614306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14850,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2794483,int_stack+2787058,int_stack+2744488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2670598,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2806633,int_stack+2794483,int_stack+2750563, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2676673,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2787058,int_stack+2806633,int_stack+2760283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2686393,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2805958,int_stack+2787058,int_stack+2772883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2698993,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2825803,int_stack+2805958,int_stack+2474092,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2873431,int_stack+2825803,int_stack+2489968,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2947519,int_stack+2873431,int_stack+2527012,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2787058,int_stack+1476061,int_stack+1475746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1921196, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2788003,int_stack+1476481,int_stack+1476061, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1921511, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2789263,int_stack+2788003,int_stack+2787058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1998755, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2791153,int_stack+1477021,int_stack+1476481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1921931, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2792773,int_stack+2791153,int_stack+2788003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1999700, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2795293,int_stack+2792773,int_stack+2789263, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2000960, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2798443,int_stack+1477696,int_stack+1477021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1922471, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2800468,int_stack+2798443,int_stack+2791153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2002850, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2803708,int_stack+2800468,int_stack+2792773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2004470, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2807908,int_stack+2803708,int_stack+2795293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2006990, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2812633,int_stack+1478521,int_stack+1477696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1923146, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2815108,int_stack+2812633,int_stack+2798443, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2010140, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2819158,int_stack+2815108,int_stack+2800468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2012165, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2812633,int_stack+2819158,int_stack+2803708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2015405, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2818933,int_stack+2812633,int_stack+2807908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2019605, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2812633,int_stack+1483717,int_stack+1483276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1932491, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2813956,int_stack+1484305,int_stack+1483717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1932932, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2815720,int_stack+2813956,int_stack+2812633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2049905, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2825548,int_stack+1485061,int_stack+1484305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1933520, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2827816,int_stack+2825548,int_stack+2813956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2051228, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2831344,int_stack+2827816,int_stack+2815720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2052992, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2835754,int_stack+1486006,int_stack+1485061, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1934276, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2838589,int_stack+2835754,int_stack+2825548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2062820, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2843125,int_stack+2838589,int_stack+2827816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2065088, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2849005,int_stack+2843125,int_stack+2831344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2068616, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2855620,int_stack+1487161,int_stack+1486006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1935221, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2859085,int_stack+2855620,int_stack+2835754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2073026, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2864755,int_stack+2859085,int_stack+2838589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2075861, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2855620,int_stack+2864755,int_stack+2843125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2080397, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2864440,int_stack+2855620,int_stack+2849005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2086277, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+2873701,int_stack+2864440,int_stack+2818933,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2855620,int_stack+1494406,int_stack+1493818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1948304, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2857384,int_stack+1495190,int_stack+1494406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1948892, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2859736,int_stack+2857384,int_stack+2855620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2128697, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2893546,int_stack+1496198,int_stack+1495190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1949676, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2896570,int_stack+2893546,int_stack+2857384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2130461, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2901274,int_stack+2896570,int_stack+2859736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2132813, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2907154,int_stack+1497458,int_stack+1496198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1950684, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2910934,int_stack+2907154,int_stack+2893546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2166623, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2916982,int_stack+2910934,int_stack+2896570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2169647, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2924822,int_stack+2916982,int_stack+2901274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2174351, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2933642,int_stack+1498998,int_stack+1497458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1951944, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2938262,int_stack+2933642,int_stack+2907154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2180231, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3040129,int_stack+2938262,int_stack+2910934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2184011, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2933642,int_stack+3040129,int_stack+2916982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2190059, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3040129,int_stack+2933642,int_stack+2924822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2197899, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3052477,int_stack+3040129,int_stack+2864440,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+3080260,int_stack+3052477,int_stack+2873701,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2933642,int_stack+1508630,int_stack+1507874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1753854, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2935910,int_stack+1509638,int_stack+1508630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1755366, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2938934,int_stack+2935910,int_stack+2933642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2254459, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2943470,int_stack+1510934,int_stack+1509638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1757382, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3119950,int_stack+2943470,int_stack+2935910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2256727, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3125998,int_stack+3119950,int_stack+2938934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2259751, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3133558,int_stack+1512554,int_stack+1510934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1759974, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3138418,int_stack+3133558,int_stack+2943470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2346040, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3146194,int_stack+3138418,int_stack+3119950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2349928, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3156274,int_stack+3146194,int_stack+3125998, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2355976, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3167614,int_stack+1514534,int_stack+1512554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1763214, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3173554,int_stack+3167614,int_stack+3133558, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2363536, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3183274,int_stack+3173554,int_stack+3138418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2368396, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3167614,int_stack+3183274,int_stack+3146194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2376172, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3182734,int_stack+3167614,int_stack+3156274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2386252, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3198610,int_stack+3182734,int_stack+3040129,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3235654,int_stack+3198610,int_stack+3052477,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+3291220,int_stack+3235654,int_stack+3080260,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3167614,int_stack+649216,int_stack+647326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+826206, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3170449,int_stack+651736,int_stack+649216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829041, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3174229,int_stack+3170449,int_stack+3167614, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2458972, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3357370,int_stack+654976,int_stack+651736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+832821, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3362230,int_stack+3357370,int_stack+3170449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2461807, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3369790,int_stack+3362230,int_stack+3174229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2465587, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3379240,int_stack+659026,int_stack+654976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837681, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3385315,int_stack+3379240,int_stack+3357370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2648728, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3395035,int_stack+3385315,int_stack+3362230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2653588, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3407635,int_stack+3395035,int_stack+3369790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2661148, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3421810,int_stack+2970,int_stack+659026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14850, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3429235,int_stack+3421810,int_stack+3379240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2670598, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3441385,int_stack+3429235,int_stack+3385315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2676673, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3421810,int_stack+3441385,int_stack+3395035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2686393, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3440710,int_stack+3421810,int_stack+3407635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2698993, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3460555,int_stack+3440710,int_stack+3182734,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3508183,int_stack+3460555,int_stack+3198610,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3582271,int_stack+3508183,int_stack+3235654,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3421810,int_stack+1537556,int_stack+1537241, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1921196, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3422755,int_stack+1537976,int_stack+1537556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1921511, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3424015,int_stack+3422755,int_stack+3421810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1998755, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3425905,int_stack+1538516,int_stack+1537976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1921931, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3427525,int_stack+3425905,int_stack+3422755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1999700, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3430045,int_stack+3427525,int_stack+3424015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2000960, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3433195,int_stack+1539191,int_stack+1538516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1922471, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3435220,int_stack+3433195,int_stack+3425905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2002850, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3438460,int_stack+3435220,int_stack+3427525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2004470, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3442660,int_stack+3438460,int_stack+3430045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2006990, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3447385,int_stack+1540016,int_stack+1539191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1923146, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3449860,int_stack+3447385,int_stack+3433195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2010140, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3453910,int_stack+3449860,int_stack+3435220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2012165, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3447385,int_stack+3453910,int_stack+3438460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2015405, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3453685,int_stack+3447385,int_stack+3442660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2019605, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3447385,int_stack+1545212,int_stack+1544771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1932491, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3448708,int_stack+1545800,int_stack+1545212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1932932, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3450472,int_stack+3448708,int_stack+3447385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2049905, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3460300,int_stack+1546556,int_stack+1545800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1933520, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3462568,int_stack+3460300,int_stack+3448708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2051228, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3466096,int_stack+3462568,int_stack+3450472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2052992, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3179899,int_stack+1547501,int_stack+1546556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1934276, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3470506,int_stack+3179899,int_stack+3460300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2062820, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3475042,int_stack+3470506,int_stack+3462568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2065088, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3480922,int_stack+3475042,int_stack+3466096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2068616, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3487537,int_stack+1548656,int_stack+1547501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1935221, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3491002,int_stack+3487537,int_stack+3179899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2073026, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3496672,int_stack+3491002,int_stack+3470506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2075861, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3487537,int_stack+3496672,int_stack+3475042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2080397, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3496357,int_stack+3487537,int_stack+3480922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2086277, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+3505618,int_stack+3496357,int_stack+3453685,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3487537,int_stack+1555901,int_stack+1555313, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1948304, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3489301,int_stack+1556685,int_stack+1555901, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1948892, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3491653,int_stack+3489301,int_stack+3487537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2128697, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3525463,int_stack+1557693,int_stack+1556685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1949676, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3528487,int_stack+3525463,int_stack+3489301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2130461, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3533191,int_stack+3528487,int_stack+3491653, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2132813, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3539071,int_stack+1558953,int_stack+1557693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1950684, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3542851,int_stack+3539071,int_stack+3525463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2166623, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3548899,int_stack+3542851,int_stack+3528487, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2169647, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3556739,int_stack+3548899,int_stack+3533191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2174351, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3565559,int_stack+1560493,int_stack+1558953, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1951944, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3570179,int_stack+3565559,int_stack+3539071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2180231, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3674881,int_stack+3570179,int_stack+3542851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2184011, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3565559,int_stack+3674881,int_stack+3548899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2190059, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3674881,int_stack+3565559,int_stack+3556739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2197899, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3687229,int_stack+3674881,int_stack+3496357,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+3715012,int_stack+3687229,int_stack+3505618,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3565559,int_stack+1570125,int_stack+1569369, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1753854, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3567827,int_stack+1571133,int_stack+1570125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1755366, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3570851,int_stack+3567827,int_stack+3565559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2254459, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3575387,int_stack+1572429,int_stack+1571133, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1757382, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3754702,int_stack+3575387,int_stack+3567827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2256727, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3760750,int_stack+3754702,int_stack+3570851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2259751, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+1574049,int_stack+1572429, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1759974, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3768310,int_stack+0,int_stack+3575387, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2346040, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3776086,int_stack+3768310,int_stack+3754702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2349928, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3786166,int_stack+3776086,int_stack+3760750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2355976, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3797506,int_stack+1576029,int_stack+1574049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1763214, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3803446,int_stack+3797506,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2363536, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3813166,int_stack+3803446,int_stack+3768310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2368396, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3797506,int_stack+3813166,int_stack+3776086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2376172, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3812626,int_stack+3797506,int_stack+3786166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2386252, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3828502,int_stack+3812626,int_stack+3674881,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3865546,int_stack+3828502,int_stack+3687229,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+3921112,int_stack+3865546,int_stack+3715012,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3797506,int_stack+693936,int_stack+692046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+826206, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3800341,int_stack+696456,int_stack+693936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829041, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3804121,int_stack+3800341,int_stack+3797506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2458972, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3987262,int_stack+699696,int_stack+696456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+832821, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3992122,int_stack+3987262,int_stack+3800341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2461807, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3999682,int_stack+3992122,int_stack+3804121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2465587, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4009132,int_stack+703746,int_stack+699696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837681, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4015207,int_stack+4009132,int_stack+3987262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2648728, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4024927,int_stack+4015207,int_stack+3992122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2653588, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4037527,int_stack+4024927,int_stack+3999682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2661148, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4051702,int_stack+5940,int_stack+703746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14850, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4059127,int_stack+4051702,int_stack+4009132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2670598, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4071277,int_stack+4059127,int_stack+4015207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2676673, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4051702,int_stack+4071277,int_stack+4024927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2686393, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4070602,int_stack+4051702,int_stack+4037527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2698993, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+4090447,int_stack+4070602,int_stack+3812626,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4138075,int_stack+4090447,int_stack+3828502,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4212163,int_stack+4138075,int_stack+3865546,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4051702,int_stack+1599051,int_stack+1598736, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1921196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4052647,int_stack+1599471,int_stack+1599051, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1921511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4053907,int_stack+4052647,int_stack+4051702, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1998755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4055797,int_stack+1600011,int_stack+1599471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1921931, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4057417,int_stack+4055797,int_stack+4052647, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1999700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4059937,int_stack+4057417,int_stack+4053907, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2000960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4063087,int_stack+1600686,int_stack+1600011, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1922471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4065112,int_stack+4063087,int_stack+4055797, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2002850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4068352,int_stack+4065112,int_stack+4057417, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2004470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4072552,int_stack+4068352,int_stack+4059937, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2006990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4077277,int_stack+1601511,int_stack+1600686, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1923146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4860,int_stack+4077277,int_stack+4063087, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2010140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4077277,int_stack+4860,int_stack+4065112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2012165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4082677,int_stack+4077277,int_stack+4068352, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2015405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4088977,int_stack+4082677,int_stack+4072552, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2019605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4077277,int_stack+1606707,int_stack+1606266, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1932491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4078600,int_stack+1607295,int_stack+1606707, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1932932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4080364,int_stack+4078600,int_stack+4077277, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2049905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4083010,int_stack+1608051,int_stack+1607295, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1933520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4085278,int_stack+4083010,int_stack+4078600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2051228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4095592,int_stack+4085278,int_stack+4080364, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2052992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3809791,int_stack+1608996,int_stack+1608051, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1934276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4100002,int_stack+3809791,int_stack+4083010, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2062820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4104538,int_stack+4100002,int_stack+4085278, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2065088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4110418,int_stack+4104538,int_stack+4095592, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2068616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4860,int_stack+1610151,int_stack+1608996, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1935221, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4117033,int_stack+4860,int_stack+3809791, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2073026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4122703,int_stack+4117033,int_stack+4100002, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2075861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4130263,int_stack+4122703,int_stack+4104538, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2080397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4117033,int_stack+4130263,int_stack+4110418, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2086277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+4126294,int_stack+4117033,int_stack+4088977,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4146139,int_stack+1617396,int_stack+1616808, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1948304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4147903,int_stack+1618180,int_stack+1617396, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1948892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4150255,int_stack+4147903,int_stack+4146139, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2128697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4153783,int_stack+1619188,int_stack+1618180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1949676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4156807,int_stack+4153783,int_stack+4147903, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2130461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4161511,int_stack+4156807,int_stack+4150255, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2132813, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4167391,int_stack+1620448,int_stack+1619188, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1950684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4171171,int_stack+4167391,int_stack+4153783, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2166623, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4177219,int_stack+4171171,int_stack+4156807, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2169647, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4185059,int_stack+4177219,int_stack+4161511, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2174351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4193879,int_stack+1621988,int_stack+1620448, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1951944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4198499,int_stack+4193879,int_stack+4167391, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2180231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4304773,int_stack+4198499,int_stack+4171171, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2184011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4193879,int_stack+4304773,int_stack+4177219, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2190059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4304773,int_stack+4193879,int_stack+4185059, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2197899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+4317121,int_stack+4304773,int_stack+4117033,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+4344904,int_stack+4317121,int_stack+4126294,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4193879,int_stack+1631620,int_stack+1630864, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1753854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4196147,int_stack+1632628,int_stack+1631620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1755366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4199171,int_stack+4196147,int_stack+4193879, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2254459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4203707,int_stack+1633924,int_stack+1632628, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1757382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4384594,int_stack+4203707,int_stack+4196147, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2256727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4390642,int_stack+4384594,int_stack+4199171, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2259751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4398202,int_stack+1635544,int_stack+1633924, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1759974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4403062,int_stack+4398202,int_stack+4203707, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2346040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4410838,int_stack+4403062,int_stack+4384594, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2349928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4420918,int_stack+4410838,int_stack+4390642, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2355976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4432258,int_stack+1637524,int_stack+1635544, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1763214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4438198,int_stack+4432258,int_stack+4398202, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2363536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4447918,int_stack+4438198,int_stack+4403062, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2368396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4432258,int_stack+4447918,int_stack+4410838, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2376172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4447378,int_stack+4432258,int_stack+4420918, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2386252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+4463254,int_stack+4447378,int_stack+4304773,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+4500298,int_stack+4463254,int_stack+4317121,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+4555864,int_stack+4500298,int_stack+4344904,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4432258,int_stack+738656,int_stack+736766, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+826206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4435093,int_stack+741176,int_stack+738656, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4438873,int_stack+4435093,int_stack+4432258, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2458972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4622014,int_stack+744416,int_stack+741176, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+832821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4626874,int_stack+4622014,int_stack+4435093, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2461807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4634434,int_stack+4626874,int_stack+4438873, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2465587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4643884,int_stack+748466,int_stack+744416, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4649959,int_stack+4643884,int_stack+4622014, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2648728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4659679,int_stack+4649959,int_stack+4626874, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2653588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4672279,int_stack+4659679,int_stack+4634434, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2661148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4686454,int_stack+8910,int_stack+748466, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4693879,int_stack+4686454,int_stack+4643884, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2670598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4706029,int_stack+4693879,int_stack+4649959, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2676673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4686454,int_stack+4706029,int_stack+4659679, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2686393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4705354,int_stack+4686454,int_stack+4672279, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2698993, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+4725199,int_stack+4705354,int_stack+4447378,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4772827,int_stack+4725199,int_stack+4463254,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4846915,int_stack+4772827,int_stack+4500298,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4686454,int_stack+1660546,int_stack+1660231, 0.0, zero_stack, 1.0, int_stack+1921196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4687399,int_stack+1660966,int_stack+1660546, 0.0, zero_stack, 1.0, int_stack+1921511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4688659,int_stack+4687399,int_stack+4686454, 0.0, zero_stack, 1.0, int_stack+1998755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4690549,int_stack+1661506,int_stack+1660966, 0.0, zero_stack, 1.0, int_stack+1921931, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4692169,int_stack+4690549,int_stack+4687399, 0.0, zero_stack, 1.0, int_stack+1999700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4694689,int_stack+4692169,int_stack+4688659, 0.0, zero_stack, 1.0, int_stack+2000960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4697839,int_stack+1662181,int_stack+1661506, 0.0, zero_stack, 1.0, int_stack+1922471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4699864,int_stack+4697839,int_stack+4690549, 0.0, zero_stack, 1.0, int_stack+2002850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4703104,int_stack+4699864,int_stack+4692169, 0.0, zero_stack, 1.0, int_stack+2004470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4707304,int_stack+4703104,int_stack+4694689, 0.0, zero_stack, 1.0, int_stack+2006990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4712029,int_stack+1663006,int_stack+1662181, 0.0, zero_stack, 1.0, int_stack+1923146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4714504,int_stack+4712029,int_stack+4697839, 0.0, zero_stack, 1.0, int_stack+2010140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4718554,int_stack+4714504,int_stack+4699864, 0.0, zero_stack, 1.0, int_stack+2012165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4712029,int_stack+4718554,int_stack+4703104, 0.0, zero_stack, 1.0, int_stack+2015405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4718329,int_stack+4712029,int_stack+4707304, 0.0, zero_stack, 1.0, int_stack+2019605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4712029,int_stack+1668202,int_stack+1667761, 0.0, zero_stack, 1.0, int_stack+1932491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4713352,int_stack+1668790,int_stack+1668202, 0.0, zero_stack, 1.0, int_stack+1932932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4715116,int_stack+4713352,int_stack+4712029, 0.0, zero_stack, 1.0, int_stack+2049905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4724944,int_stack+1669546,int_stack+1668790, 0.0, zero_stack, 1.0, int_stack+1933520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4727212,int_stack+4724944,int_stack+4713352, 0.0, zero_stack, 1.0, int_stack+2051228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4730740,int_stack+4727212,int_stack+4715116, 0.0, zero_stack, 1.0, int_stack+2052992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4444543,int_stack+1670491,int_stack+1669546, 0.0, zero_stack, 1.0, int_stack+1934276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4735150,int_stack+4444543,int_stack+4724944, 0.0, zero_stack, 1.0, int_stack+2062820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4739686,int_stack+4735150,int_stack+4727212, 0.0, zero_stack, 1.0, int_stack+2065088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4745566,int_stack+4739686,int_stack+4730740, 0.0, zero_stack, 1.0, int_stack+2068616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4752181,int_stack+1671646,int_stack+1670491, 0.0, zero_stack, 1.0, int_stack+1935221, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4755646,int_stack+4752181,int_stack+4444543, 0.0, zero_stack, 1.0, int_stack+2073026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4761316,int_stack+4755646,int_stack+4735150, 0.0, zero_stack, 1.0, int_stack+2075861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4752181,int_stack+4761316,int_stack+4739686, 0.0, zero_stack, 1.0, int_stack+2080397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4761001,int_stack+4752181,int_stack+4745566, 0.0, zero_stack, 1.0, int_stack+2086277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+4770262,int_stack+4761001,int_stack+4718329,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4752181,int_stack+1678891,int_stack+1678303, 0.0, zero_stack, 1.0, int_stack+1948304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4753945,int_stack+1679675,int_stack+1678891, 0.0, zero_stack, 1.0, int_stack+1948892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4756297,int_stack+4753945,int_stack+4752181, 0.0, zero_stack, 1.0, int_stack+2128697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4790107,int_stack+1680683,int_stack+1679675, 0.0, zero_stack, 1.0, int_stack+1949676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4793131,int_stack+4790107,int_stack+4753945, 0.0, zero_stack, 1.0, int_stack+2130461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4797835,int_stack+4793131,int_stack+4756297, 0.0, zero_stack, 1.0, int_stack+2132813, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4803715,int_stack+1681943,int_stack+1680683, 0.0, zero_stack, 1.0, int_stack+1950684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4807495,int_stack+4803715,int_stack+4790107, 0.0, zero_stack, 1.0, int_stack+2166623, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4813543,int_stack+4807495,int_stack+4793131, 0.0, zero_stack, 1.0, int_stack+2169647, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4821383,int_stack+4813543,int_stack+4797835, 0.0, zero_stack, 1.0, int_stack+2174351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4830203,int_stack+1683483,int_stack+1681943, 0.0, zero_stack, 1.0, int_stack+1951944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4834823,int_stack+4830203,int_stack+4803715, 0.0, zero_stack, 1.0, int_stack+2180231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4939525,int_stack+4834823,int_stack+4807495, 0.0, zero_stack, 1.0, int_stack+2184011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4830203,int_stack+4939525,int_stack+4813543, 0.0, zero_stack, 1.0, int_stack+2190059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4939525,int_stack+4830203,int_stack+4821383, 0.0, zero_stack, 1.0, int_stack+2197899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+4951873,int_stack+4939525,int_stack+4761001,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+4979656,int_stack+4951873,int_stack+4770262,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4830203,int_stack+1693115,int_stack+1692359, 0.0, zero_stack, 1.0, int_stack+1753854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4832471,int_stack+1694123,int_stack+1693115, 0.0, zero_stack, 1.0, int_stack+1755366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4835495,int_stack+4832471,int_stack+4830203, 0.0, zero_stack, 1.0, int_stack+2254459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4840031,int_stack+1695419,int_stack+1694123, 0.0, zero_stack, 1.0, int_stack+1757382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4860,int_stack+4840031,int_stack+4832471, 0.0, zero_stack, 1.0, int_stack+2256727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5019346,int_stack+4860,int_stack+4835495, 0.0, zero_stack, 1.0, int_stack+2259751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5026906,int_stack+1697039,int_stack+1695419, 0.0, zero_stack, 1.0, int_stack+1759974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5031766,int_stack+5026906,int_stack+4840031, 0.0, zero_stack, 1.0, int_stack+2346040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5039542,int_stack+5031766,int_stack+4860, 0.0, zero_stack, 1.0, int_stack+2349928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5049622,int_stack+5039542,int_stack+5019346, 0.0, zero_stack, 1.0, int_stack+2355976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5060962,int_stack+1699019,int_stack+1697039, 0.0, zero_stack, 1.0, int_stack+1763214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5066902,int_stack+5060962,int_stack+5026906, 0.0, zero_stack, 1.0, int_stack+2363536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5076622,int_stack+5066902,int_stack+5031766, 0.0, zero_stack, 1.0, int_stack+2368396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5060962,int_stack+5076622,int_stack+5039542, 0.0, zero_stack, 1.0, int_stack+2376172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5076082,int_stack+5060962,int_stack+5049622, 0.0, zero_stack, 1.0, int_stack+2386252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+5091958,int_stack+5076082,int_stack+4939525,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+5129002,int_stack+5091958,int_stack+4951873,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+5184568,int_stack+5129002,int_stack+4979656,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5060962,int_stack+783376,int_stack+781486, 0.0, zero_stack, 1.0, int_stack+826206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5063797,int_stack+785896,int_stack+783376, 0.0, zero_stack, 1.0, int_stack+829041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5067577,int_stack+5063797,int_stack+5060962, 0.0, zero_stack, 1.0, int_stack+2458972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5250718,int_stack+789136,int_stack+785896, 0.0, zero_stack, 1.0, int_stack+832821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5255578,int_stack+5250718,int_stack+5063797, 0.0, zero_stack, 1.0, int_stack+2461807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5263138,int_stack+5255578,int_stack+5067577, 0.0, zero_stack, 1.0, int_stack+2465587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5272588,int_stack+793186,int_stack+789136, 0.0, zero_stack, 1.0, int_stack+837681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5278663,int_stack+5272588,int_stack+5250718, 0.0, zero_stack, 1.0, int_stack+2648728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5288383,int_stack+5278663,int_stack+5255578, 0.0, zero_stack, 1.0, int_stack+2653588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5300983,int_stack+5288383,int_stack+5263138, 0.0, zero_stack, 1.0, int_stack+2661148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5315158,int_stack+11880,int_stack+793186, 0.0, zero_stack, 1.0, int_stack+14850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5322583,int_stack+5315158,int_stack+5272588, 0.0, zero_stack, 1.0, int_stack+2670598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5334733,int_stack+5322583,int_stack+5278663, 0.0, zero_stack, 1.0, int_stack+2676673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5315158,int_stack+5334733,int_stack+5288383, 0.0, zero_stack, 1.0, int_stack+2686393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5334058,int_stack+5315158,int_stack+5300983, 0.0, zero_stack, 1.0, int_stack+2698993, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+5353903,int_stack+5334058,int_stack+5076082,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+5401531,int_stack+5353903,int_stack+5091958,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+5475619,int_stack+5401531,int_stack+5129002,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5315158,int_stack+1722041,int_stack+1721726, 1.0, int_stack+1921196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5316103,int_stack+1722461,int_stack+1722041, 1.0, int_stack+1921511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5317363,int_stack+5316103,int_stack+5315158, 1.0, int_stack+1998755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5319253,int_stack+1723001,int_stack+1722461, 1.0, int_stack+1921931, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5320873,int_stack+5319253,int_stack+5316103, 1.0, int_stack+1999700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5323393,int_stack+5320873,int_stack+5317363, 1.0, int_stack+2000960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1998755,int_stack+1723676,int_stack+1723001, 1.0, int_stack+1922471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5326543,int_stack+1998755,int_stack+5319253, 1.0, int_stack+2002850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5329783,int_stack+5326543,int_stack+5320873, 1.0, int_stack+2004470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2000780,int_stack+5329783,int_stack+5323393, 1.0, int_stack+2006990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2005505,int_stack+1724501,int_stack+1723676, 1.0, int_stack+1923146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5333983,int_stack+2005505,int_stack+1998755, 1.0, int_stack+2010140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5338033,int_stack+5333983,int_stack+5326543, 1.0, int_stack+2012165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5343433,int_stack+5338033,int_stack+5329783, 1.0, int_stack+2015405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5333983,int_stack+5343433,int_stack+2000780, 1.0, int_stack+2019605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5340598,int_stack+1729697,int_stack+1729256, 1.0, int_stack+1932491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5341921,int_stack+1730285,int_stack+1729697, 1.0, int_stack+1932932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5343685,int_stack+5341921,int_stack+5340598, 1.0, int_stack+2049905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5346331,int_stack+1731041,int_stack+1730285, 1.0, int_stack+1933520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5348599,int_stack+5346331,int_stack+5341921, 1.0, int_stack+2051228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5352127,int_stack+5348599,int_stack+5343685, 1.0, int_stack+2052992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5073247,int_stack+1731986,int_stack+1731041, 1.0, int_stack+1934276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2049905,int_stack+5073247,int_stack+5346331, 1.0, int_stack+2062820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5356537,int_stack+2049905,int_stack+5348599, 1.0, int_stack+2065088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5362417,int_stack+5356537,int_stack+5352127, 1.0, int_stack+2068616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2062820,int_stack+1733141,int_stack+1731986, 1.0, int_stack+1935221, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2066285,int_stack+2062820,int_stack+5073247, 1.0, int_stack+2073026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5369032,int_stack+2066285,int_stack+2049905, 1.0, int_stack+2075861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2062820,int_stack+5369032,int_stack+5356537, 1.0, int_stack+2080397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5369032,int_stack+2062820,int_stack+5362417, 1.0, int_stack+2086277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+5378293,int_stack+5369032,int_stack+5333983,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2054441,int_stack+1740386,int_stack+1739798, 1.0, int_stack+1948304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2062820,int_stack+1741170,int_stack+1740386, 1.0, int_stack+1948892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2065172,int_stack+2062820,int_stack+2054441, 1.0, int_stack+2128697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2068700,int_stack+1742178,int_stack+1741170, 1.0, int_stack+1949676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5398138,int_stack+2068700,int_stack+2062820, 1.0, int_stack+2130461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5402842,int_stack+5398138,int_stack+2065172, 1.0, int_stack+2132813, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2128697,int_stack+1743438,int_stack+1742178, 1.0, int_stack+1950684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5408722,int_stack+2128697,int_stack+2068700, 1.0, int_stack+2166623, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5414770,int_stack+5408722,int_stack+5398138, 1.0, int_stack+2169647, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5422610,int_stack+5414770,int_stack+5402842, 1.0, int_stack+2174351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2166623,int_stack+1744978,int_stack+1743438, 1.0, int_stack+1951944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2171243,int_stack+2166623,int_stack+2128697, 1.0, int_stack+2180231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5431430,int_stack+2171243,int_stack+5408722, 1.0, int_stack+2184011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2166623,int_stack+5431430,int_stack+5414770, 1.0, int_stack+2190059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5431430,int_stack+2166623,int_stack+5422610, 1.0, int_stack+2197899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+5443778,int_stack+5431430,int_stack+5369032,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+5568229,int_stack+5443778,int_stack+5378293,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2166623,int_stack+1756374,int_stack+1754610, 1.0, int_stack+1753854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2168891,int_stack+1758678,int_stack+1756374, 1.0, int_stack+1755366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2171915,int_stack+2168891,int_stack+2166623, 1.0, int_stack+2254459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5471561,int_stack+1761594,int_stack+1758678, 1.0, int_stack+1757382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5607919,int_stack+5471561,int_stack+2168891, 1.0, int_stack+2256727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5613967,int_stack+5607919,int_stack+2171915, 1.0, int_stack+2259751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2254459,int_stack+1765194,int_stack+1761594, 1.0, int_stack+1759974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5621527,int_stack+2254459,int_stack+5471561, 1.0, int_stack+2346040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5629303,int_stack+5621527,int_stack+5607919, 1.0, int_stack+2349928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5639383,int_stack+5629303,int_stack+5613967, 1.0, int_stack+2355976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2346040,int_stack+1767174,int_stack+1765194, 1.0, int_stack+1763214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2351980,int_stack+2346040,int_stack+2254459, 1.0, int_stack+2363536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5650723,int_stack+2351980,int_stack+5621527, 1.0, int_stack+2368396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2346040,int_stack+5650723,int_stack+5629303, 1.0, int_stack+2376172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5650723,int_stack+2346040,int_stack+5639383, 1.0, int_stack+2386252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+5666599,int_stack+5650723,int_stack+5431430,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+5703643,int_stack+5666599,int_stack+5443778,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+5759209,int_stack+5703643,int_stack+5568229,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2346040,int_stack+830301,int_stack+827151, 1.0, int_stack+826206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2176451,int_stack+834441,int_stack+830301, 1.0, int_stack+829041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2348875,int_stack+2176451,int_stack+2346040, 1.0, int_stack+2458972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2354545,int_stack+839706,int_stack+834441, 1.0, int_stack+832821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5825359,int_stack+2354545,int_stack+2176451, 1.0, int_stack+2461807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5832919,int_stack+5825359,int_stack+2348875, 1.0, int_stack+2465587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2458972,int_stack+843756,int_stack+839706, 1.0, int_stack+837681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5842369,int_stack+2458972,int_stack+2354545, 1.0, int_stack+2648728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5852089,int_stack+5842369,int_stack+5825359, 1.0, int_stack+2653588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5864689,int_stack+5852089,int_stack+5832919, 1.0, int_stack+2661148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2648728,int_stack+17325,int_stack+843756, 1.0, int_stack+14850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2656153,int_stack+2648728,int_stack+2458972, 1.0, int_stack+2670598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5878864,int_stack+2656153,int_stack+5842369, 1.0, int_stack+2676673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2648728,int_stack+5878864,int_stack+5852089, 1.0, int_stack+2686393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2667628,int_stack+2648728,int_stack+5864689, 1.0, int_stack+2698993, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+5878864,int_stack+2667628,int_stack+5650723,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+5926492,int_stack+5878864,int_stack+5666599,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+6000580,int_stack+5926492,int_stack+5703643,441);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+5878864,int_stack+1923971,int_stack+1923146,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+5881339,int_stack+5878864,int_stack+2010140,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+5885389,int_stack+5881339,int_stack+2012165,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5878864,int_stack+5885389,int_stack+2015405,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+5885164,int_stack+5878864,int_stack+2019605,15);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+5878864,int_stack+1936376,int_stack+1935221,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+5891779,int_stack+5878864,int_stack+2073026,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+5897449,int_stack+5891779,int_stack+2075861,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5905009,int_stack+5897449,int_stack+2080397,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+5891779,int_stack+5905009,int_stack+2086277,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+5901040,int_stack+5891779,int_stack+5885164,441);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+5920885,int_stack+1953484,int_stack+1951944,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+5925505,int_stack+5920885,int_stack+2180231,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+5933065,int_stack+5925505,int_stack+2184011,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5920885,int_stack+5933065,int_stack+2190059,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+2180231,int_stack+5920885,int_stack+2197899,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+5920885,int_stack+2180231,int_stack+5891779,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+5948668,int_stack+5920885,int_stack+5901040,441);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+5988358,int_stack+26235,int_stack+1763214,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2192579,int_stack+5988358,int_stack+2363536,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2648728,int_stack+2192579,int_stack+2368396,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2661688,int_stack+2648728,int_stack+2376172,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+2676808,int_stack+2661688,int_stack+2386252,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2359405,int_stack+2676808,int_stack+2180231,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+6093190,int_stack+2359405,int_stack+5920885,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+6148756,int_stack+6093190,int_stack+5948668,441);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+826206,int_stack+1798521,int_stack+1798206,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+829041,int_stack+1798941,int_stack+1798521,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2648728,int_stack+829041,int_stack+826206,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+832821,int_stack+1799481,int_stack+1798941,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2650618,int_stack+832821,int_stack+829041,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2653138,int_stack+2650618,int_stack+2648728,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+837681,int_stack+1800156,int_stack+1799481,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2656288,int_stack+837681,int_stack+832821,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2659528,int_stack+2656288,int_stack+2650618,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2663728,int_stack+2659528,int_stack+2653138,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2668453,int_stack+1800981,int_stack+1800156,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2670928,int_stack+2668453,int_stack+837681,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2192579,int_stack+2670928,int_stack+2656288,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+5878864,int_stack+2192579,int_stack+2659528,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+2192579,int_stack+5878864,int_stack+2663728,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5878864,int_stack+1806177,int_stack+1805736,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5880187,int_stack+1806765,int_stack+1806177,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+5881951,int_stack+5880187,int_stack+5878864,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2199194,int_stack+1807521,int_stack+1806765,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2201462,int_stack+2199194,int_stack+5880187,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2668453,int_stack+2201462,int_stack+5881951,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2672863,int_stack+1808466,int_stack+1807521,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5988358,int_stack+2672863,int_stack+2199194,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5992894,int_stack+5988358,int_stack+2201462,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2692684,int_stack+5992894,int_stack+2668453,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2699299,int_stack+1809621,int_stack+1808466,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2702764,int_stack+2699299,int_stack+2672863,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2071724,int_stack+2702764,int_stack+5988358,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2699299,int_stack+2071724,int_stack+5992894,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+2071724,int_stack+2699299,int_stack+2692684,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+6214906,int_stack+2071724,int_stack+2192579, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5885164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2699299,int_stack+1816866,int_stack+1816278,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2701063,int_stack+1817650,int_stack+1816866,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2703415,int_stack+2701063,int_stack+2699299,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2706943,int_stack+1818658,int_stack+1817650,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2080985,int_stack+2706943,int_stack+2701063,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2085689,int_stack+2080985,int_stack+2703415,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2465047,int_stack+1819918,int_stack+1818658,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2259319,int_stack+2465047,int_stack+2706943,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2005505,int_stack+2259319,int_stack+2080985,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2013345,int_stack+2005505,int_stack+2085689,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2132477,int_stack+1821458,int_stack+1819918,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+10908,int_stack+2132477,int_stack+2465047,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6234751,int_stack+10908,int_stack+2259319,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6244831,int_stack+6234751,int_stack+2005505,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6256591,int_stack+6244831,int_stack+2013345,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+6268939,int_stack+6256591,int_stack+2071724, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5891779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+6296722,int_stack+6268939,int_stack+6214906, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5901040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6234751,int_stack+1831090,int_stack+1830334,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6237019,int_stack+1832098,int_stack+1831090,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6240043,int_stack+6237019,int_stack+6234751,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6244579,int_stack+1833394,int_stack+1832098,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6248467,int_stack+6244579,int_stack+6237019,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+10908,int_stack+6248467,int_stack+6240043,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2132477,int_stack+1835014,int_stack+1833394,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6336412,int_stack+2132477,int_stack+6244579,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6344188,int_stack+6336412,int_stack+6248467,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6354268,int_stack+6344188,int_stack+10908,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1948304,int_stack+1836994,int_stack+1835014,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6365608,int_stack+1948304,int_stack+2132477,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6375328,int_stack+6365608,int_stack+6336412,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6388288,int_stack+6375328,int_stack+6344188,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6365608,int_stack+6388288,int_stack+6354268,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+6381484,int_stack+6365608,int_stack+6256591, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2180231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+6418528,int_stack+6381484,int_stack+6268939, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5920885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+6474094,int_stack+6418528,int_stack+6296722, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5948668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1948304,int_stack+1060641,int_stack+1058751,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1951139,int_stack+1063161,int_stack+1060641,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6540244,int_stack+1951139,int_stack+1948304,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1932491,int_stack+1066401,int_stack+1063161,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6545914,int_stack+1932491,int_stack+1951139,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6553474,int_stack+6545914,int_stack+6540244,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6562924,int_stack+1070451,int_stack+1066401,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6568999,int_stack+6562924,int_stack+1932491,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6578719,int_stack+6568999,int_stack+6545914,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6591319,int_stack+6578719,int_stack+6553474,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6605494,int_stack+20295,int_stack+1070451,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6612919,int_stack+6605494,int_stack+6562924,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6625069,int_stack+6612919,int_stack+6568999,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6605494,int_stack+6625069,int_stack+6578719,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6624394,int_stack+6605494,int_stack+6591319,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+6644239,int_stack+6624394,int_stack+6365608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2676808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+6691867,int_stack+6644239,int_stack+6381484, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2359405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+6765955,int_stack+6691867,int_stack+6418528, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6605494,int_stack+1860016,int_stack+1859701,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6606439,int_stack+1860436,int_stack+1860016,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6607699,int_stack+6606439,int_stack+6605494,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1759974,int_stack+1860976,int_stack+1860436,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6609589,int_stack+1759974,int_stack+6606439,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6612109,int_stack+6609589,int_stack+6607699,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6615259,int_stack+1861651,int_stack+1860976,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6617284,int_stack+6615259,int_stack+1759974,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6620524,int_stack+6617284,int_stack+6609589,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6624724,int_stack+6620524,int_stack+6612109,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6629449,int_stack+1862476,int_stack+1861651,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6631924,int_stack+6629449,int_stack+6615259,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6635974,int_stack+6631924,int_stack+6617284,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6629449,int_stack+6635974,int_stack+6620524,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6635749,int_stack+6629449,int_stack+6624724,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2091569,int_stack+1867672,int_stack+1867231,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6629449,int_stack+1868260,int_stack+1867672,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6631213,int_stack+6629449,int_stack+2091569,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6642364,int_stack+1869016,int_stack+1868260,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6644632,int_stack+6642364,int_stack+6629449,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6648160,int_stack+6644632,int_stack+6631213,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6652570,int_stack+1869961,int_stack+1869016,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6655405,int_stack+6652570,int_stack+6642364,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6659941,int_stack+6655405,int_stack+6644632,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6665821,int_stack+6659941,int_stack+6648160,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6672436,int_stack+1871116,int_stack+1869961,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6675901,int_stack+6672436,int_stack+6652570,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6681571,int_stack+6675901,int_stack+6655405,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6672436,int_stack+6681571,int_stack+6659941,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6681256,int_stack+6672436,int_stack+6665821,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+6690517,int_stack+6681256,int_stack+6635749, 0.0, zero_stack, 1.0, int_stack+5885164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6672436,int_stack+1878361,int_stack+1877773,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6674200,int_stack+1879145,int_stack+1878361,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6676552,int_stack+6674200,int_stack+6672436,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6710362,int_stack+1880153,int_stack+1879145,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6713386,int_stack+6710362,int_stack+6674200,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6718090,int_stack+6713386,int_stack+6676552,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6723970,int_stack+1881413,int_stack+1880153,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6727750,int_stack+6723970,int_stack+6710362,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6733798,int_stack+6727750,int_stack+6713386,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6741638,int_stack+6733798,int_stack+6718090,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6750458,int_stack+1882953,int_stack+1881413,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6755078,int_stack+6750458,int_stack+6723970,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6858565,int_stack+6755078,int_stack+6727750,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6750458,int_stack+6858565,int_stack+6733798,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6858565,int_stack+6750458,int_stack+6741638,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+6870913,int_stack+6858565,int_stack+6681256, 0.0, zero_stack, 1.0, int_stack+5891779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+6898696,int_stack+6870913,int_stack+6690517, 0.0, zero_stack, 1.0, int_stack+5901040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6750458,int_stack+1892585,int_stack+1891829,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6752726,int_stack+1893593,int_stack+1892585,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6755750,int_stack+6752726,int_stack+6750458,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6760286,int_stack+1894889,int_stack+1893593,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6938386,int_stack+6760286,int_stack+6752726,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6944434,int_stack+6938386,int_stack+6755750,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6951994,int_stack+1896509,int_stack+1894889,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6956854,int_stack+6951994,int_stack+6760286,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6964630,int_stack+6956854,int_stack+6938386,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6974710,int_stack+6964630,int_stack+6944434,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6986050,int_stack+1898489,int_stack+1896509,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6991990,int_stack+6986050,int_stack+6951994,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+7001710,int_stack+6991990,int_stack+6956854,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6986050,int_stack+7001710,int_stack+6964630,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+7001170,int_stack+6986050,int_stack+6974710,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+7017046,int_stack+7001170,int_stack+6858565, 0.0, zero_stack, 1.0, int_stack+2180231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+7054090,int_stack+7017046,int_stack+6870913, 0.0, zero_stack, 1.0, int_stack+5920885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+7109656,int_stack+7054090,int_stack+6898696, 0.0, zero_stack, 1.0, int_stack+5948668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6986050,int_stack+1323731,int_stack+1321841,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6988885,int_stack+1326251,int_stack+1323731,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6992665,int_stack+6988885,int_stack+6986050,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7175806,int_stack+1329491,int_stack+1326251,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7180666,int_stack+7175806,int_stack+6988885,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7188226,int_stack+7180666,int_stack+6992665,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7197676,int_stack+1333541,int_stack+1329491,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7203751,int_stack+7197676,int_stack+7175806,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7213471,int_stack+7203751,int_stack+7180666,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7226071,int_stack+7213471,int_stack+7188226,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+7240246,int_stack+23265,int_stack+1333541,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+7247671,int_stack+7240246,int_stack+7197676,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+7259821,int_stack+7247671,int_stack+7203751,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+7240246,int_stack+7259821,int_stack+7213471,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+7259146,int_stack+7240246,int_stack+7226071,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+7278991,int_stack+7259146,int_stack+7001170, 0.0, zero_stack, 1.0, int_stack+2676808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+7326619,int_stack+7278991,int_stack+7017046, 0.0, zero_stack, 1.0, int_stack+2359405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+7400707,int_stack+7326619,int_stack+7054090, 0.0, zero_stack, 1.0, int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7240246,int_stack+1925276,int_stack+1924961,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7241191,int_stack+1925696,int_stack+1925276,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6633859,int_stack+7241191,int_stack+7240246,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7242451,int_stack+1926236,int_stack+1925696,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7244071,int_stack+7242451,int_stack+7241191,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7246591,int_stack+7244071,int_stack+6633859,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7249741,int_stack+1926911,int_stack+1926236,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7251766,int_stack+7249741,int_stack+7242451,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7255006,int_stack+7251766,int_stack+7244071,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7259206,int_stack+7255006,int_stack+7246591,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+7263931,int_stack+1927736,int_stack+1926911,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+7266406,int_stack+7263931,int_stack+7249741,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+7270456,int_stack+7266406,int_stack+7251766,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+7263931,int_stack+7270456,int_stack+7255006,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+7270231,int_stack+7263931,int_stack+7259206,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7263931,int_stack+1938203,int_stack+1937762,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7265254,int_stack+1938791,int_stack+1938203,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7267018,int_stack+7265254,int_stack+7263931,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7276846,int_stack+1939547,int_stack+1938791,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7279114,int_stack+7276846,int_stack+7265254,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7282642,int_stack+7279114,int_stack+7267018,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6998335,int_stack+1940492,int_stack+1939547,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7287052,int_stack+6998335,int_stack+7276846,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7291588,int_stack+7287052,int_stack+7279114,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7297468,int_stack+7291588,int_stack+7282642,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+7304083,int_stack+1941647,int_stack+1940492,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+7307548,int_stack+7304083,int_stack+6998335,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+7313218,int_stack+7307548,int_stack+7287052,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+7304083,int_stack+7313218,int_stack+7291588,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+7312903,int_stack+7304083,int_stack+7297468,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+7322164,int_stack+7312903,int_stack+7270231, 1.0, int_stack+5885164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7304083,int_stack+1955920,int_stack+1955332,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7305847,int_stack+1956704,int_stack+1955920,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7308199,int_stack+7305847,int_stack+7304083,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7342009,int_stack+1957712,int_stack+1956704,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7345033,int_stack+7342009,int_stack+7305847,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+7349737,int_stack+7345033,int_stack+7308199,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7355617,int_stack+1958972,int_stack+1957712,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7359397,int_stack+7355617,int_stack+7342009,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+7365445,int_stack+7359397,int_stack+7345033,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7373285,int_stack+7365445,int_stack+7349737,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+7382105,int_stack+1960512,int_stack+1958972,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+7386725,int_stack+7382105,int_stack+7355617,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+18468,int_stack+7386725,int_stack+7359397,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+7382105,int_stack+18468,int_stack+7365445,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+7493317,int_stack+7382105,int_stack+7373285,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+7505665,int_stack+7493317,int_stack+7312903, 1.0, int_stack+5891779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+7533448,int_stack+7505665,int_stack+7322164, 1.0, int_stack+5901040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7382105,int_stack+1970144,int_stack+1969388,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7384373,int_stack+1971152,int_stack+1970144,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7387397,int_stack+7384373,int_stack+7382105,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7391933,int_stack+1972448,int_stack+1971152,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+18468,int_stack+7391933,int_stack+7384373,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5884597,int_stack+18468,int_stack+7387397,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7395821,int_stack+1974068,int_stack+1972448,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5892157,int_stack+7395821,int_stack+7391933,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5899933,int_stack+5892157,int_stack+18468,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7573138,int_stack+5899933,int_stack+5884597,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+5910013,int_stack+1976048,int_stack+1974068,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+7584478,int_stack+5910013,int_stack+7395821,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+7594198,int_stack+7584478,int_stack+5892157,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+7607158,int_stack+7594198,int_stack+5899933,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+7584478,int_stack+7607158,int_stack+7573138,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+7600354,int_stack+7584478,int_stack+7493317, 1.0, int_stack+2180231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+7637398,int_stack+7600354,int_stack+7505665, 1.0, int_stack+5920885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+7692964,int_stack+7637398,int_stack+7533448, 1.0, int_stack+5948668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2180231,int_stack+1780476,int_stack+1778586,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2183066,int_stack+1782996,int_stack+1780476,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2186846,int_stack+2183066,int_stack+2180231,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+5910013,int_stack+1786236,int_stack+1782996,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5914873,int_stack+5910013,int_stack+2183066,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+5922433,int_stack+5914873,int_stack+2186846,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+5931883,int_stack+1790286,int_stack+1786236,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+5937958,int_stack+5931883,int_stack+5910013,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5947678,int_stack+5937958,int_stack+5914873,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+5960278,int_stack+5947678,int_stack+5922433,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+5974453,int_stack+28611,int_stack+1790286,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+7759114,int_stack+5974453,int_stack+5931883,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+7771264,int_stack+7759114,int_stack+5937958,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+7787464,int_stack+7771264,int_stack+5947678,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+7759114,int_stack+7787464,int_stack+5960278,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+7778959,int_stack+7759114,int_stack+7584478, 1.0, int_stack+2676808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+7826587,int_stack+7778959,int_stack+7600354, 1.0, int_stack+2359405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+7900675,int_stack+7826587,int_stack+7637398, 1.0, int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+31896,int_stack+31581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1414251,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094135,int_stack+32316,int_stack+31896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1414566,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6095395,int_stack+6094135,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2024330,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6097285,int_stack+32856,int_stack+32316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1414986,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6098905,int_stack+6097285,int_stack+6094135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2025275,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6101425,int_stack+6098905,int_stack+6095395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2026535,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+33531,int_stack+32856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1415526,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6104575,int_stack+6093190,int_stack+6097285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2028425,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6107815,int_stack+6104575,int_stack+6098905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2030045,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6095215,int_stack+6107815,int_stack+6101425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2032565,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6099940,int_stack+34356,int_stack+33531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1416201,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6112015,int_stack+6099940,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2035715,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6116065,int_stack+6112015,int_stack+6104575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2037740,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6099940,int_stack+6116065,int_stack+6107815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2040980,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6106240,int_stack+6099940,int_stack+6095215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2045180,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+35787,int_stack+35346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1421781,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094513,int_stack+36375,int_stack+35787, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1422222,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6096277,int_stack+6094513,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2092892,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6098923,int_stack+37131,int_stack+36375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1422810,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6101191,int_stack+6098923,int_stack+6094513, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2094215,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6112855,int_stack+6101191,int_stack+6096277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2095979,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+38076,int_stack+37131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1423566,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6117265,int_stack+6093190,int_stack+6098923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2098625,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6121801,int_stack+6117265,int_stack+6101191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2100893,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096025,int_stack+6121801,int_stack+6112855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2104421,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6112855,int_stack+39231,int_stack+38076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1424511,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6127681,int_stack+6112855,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2108831,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6133351,int_stack+6127681,int_stack+6117265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2111666,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6112855,int_stack+6133351,int_stack+6121801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2116202,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6121675,int_stack+6112855,int_stack+6096025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2122082,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+2359405,int_stack+6121675,int_stack+6106240,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+41205,int_stack+40617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1432323,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094954,int_stack+41989,int_stack+41205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1432911,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6097306,int_stack+6094954,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2206719,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6100834,int_stack+42997,int_stack+41989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1433695,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6103858,int_stack+6100834,int_stack+6094954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2208483,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6108562,int_stack+6103858,int_stack+6097306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2210835,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+44257,int_stack+42997, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1434703,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6114442,int_stack+6093190,int_stack+6100834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2214363,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6130936,int_stack+6114442,int_stack+6103858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2217387,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096970,int_stack+6130936,int_stack+6108562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2222091,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6105790,int_stack+45797,int_stack+44257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1435963,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6138776,int_stack+6105790,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2227971,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2379250,int_stack+6138776,int_stack+6114442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2231751,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6105790,int_stack+2379250,int_stack+6130936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2237799,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6130936,int_stack+6105790,int_stack+6096970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2245639,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+6093190,int_stack+6130936,int_stack+6121675,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+7759114,int_stack+6093190,int_stack+2359405,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2359405,int_stack+48401,int_stack+47645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1446379,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2361673,int_stack+49409,int_stack+48401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1447135,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2364697,int_stack+2361673,int_stack+2359405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2397592,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2369233,int_stack+50705,int_stack+49409, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1448143,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2373121,int_stack+2369233,int_stack+2361673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2399860,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2379169,int_stack+2373121,int_stack+2364697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2402884,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2359405,int_stack+52325,int_stack+50705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1449439,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2386729,int_stack+2359405,int_stack+2369233, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2407420,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7798804,int_stack+2386729,int_stack+2373121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2411308,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2364265,int_stack+7798804,int_stack+2379169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2417356,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2375605,int_stack+54305,int_stack+52325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1451059,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6120973,int_stack+2375605,int_stack+2359405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2424916,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+7808884,int_stack+6120973,int_stack+2386729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2429776,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2375605,int_stack+7808884,int_stack+7798804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2437552,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+7798804,int_stack+2375605,int_stack+2364265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2447632,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+7814680,int_stack+7798804,int_stack+6130936,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+7814680,int_stack+6093190,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+8048851,int_stack+7993285,int_stack+7759114,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7759114,int_stack+57626,int_stack+56681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+602606,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7761949,int_stack+58886,int_stack+57626, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+604496,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7765729,int_stack+7761949,int_stack+7759114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2471257,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7771399,int_stack+60506,int_stack+58886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+607016,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7776259,int_stack+7771399,int_stack+7761949, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2713168,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7783819,int_stack+7776259,int_stack+7765729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2716948,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7759114,int_stack+62531,int_stack+60506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+610256,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6093190,int_stack+7759114,int_stack+7771399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2722618,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6102910,int_stack+6093190,int_stack+7776259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2727478,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7765189,int_stack+6102910,int_stack+7783819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2735038,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+7779364,int_stack+65006,int_stack+62531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+614306,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6115510,int_stack+7779364,int_stack+7759114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2744488,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+7779364,int_stack+6115510,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2750563,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6115510,int_stack+7779364,int_stack+6102910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2760283,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6093190,int_stack+6115510,int_stack+7765189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2772883,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+7851724,int_stack+6093190,int_stack+7798804,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+8115001,int_stack+7851724,int_stack+7814680,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+7759114,int_stack+8115001,int_stack+7993285,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+68291,int_stack+67976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1414251, 1.0, int_stack+1475746,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+68711,int_stack+68291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1414566, 1.0, int_stack+1476061,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2024330, 1.0, int_stack+2787058,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+69251,int_stack+68711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1414986, 1.0, int_stack+1476481,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2025275, 1.0, int_stack+2788003,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2026535, 1.0, int_stack+2789263,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+69926,int_stack+69251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1415526, 1.0, int_stack+1477021,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2028425, 1.0, int_stack+2791153,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2030045, 1.0, int_stack+2792773,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2032565, 1.0, int_stack+2795293,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+70751,int_stack+69926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1416201, 1.0, int_stack+1477696,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2035715, 1.0, int_stack+2798443,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2037740, 1.0, int_stack+2800468,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2040980, 1.0, int_stack+2803708,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2045180, 1.0, int_stack+2807908,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+72182,int_stack+71741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1421781, 1.0, int_stack+1483276,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+72770,int_stack+72182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1422222, 1.0, int_stack+1483717,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2092892, 1.0, int_stack+2812633,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+73526,int_stack+72770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1422810, 1.0, int_stack+1484305,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2094215, 1.0, int_stack+2813956,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8012950,int_stack+8001286,int_stack+7996372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2095979, 1.0, int_stack+2815720,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+74471,int_stack+73526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1423566, 1.0, int_stack+1485061,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8017360,int_stack+7993285,int_stack+7999018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2098625, 1.0, int_stack+2825548,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8021896,int_stack+8017360,int_stack+8001286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100893, 1.0, int_stack+2827816,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8021896,int_stack+8012950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2104421, 1.0, int_stack+2831344,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8012950,int_stack+75626,int_stack+74471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1424511, 1.0, int_stack+1486006,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8027776,int_stack+8012950,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2108831, 1.0, int_stack+2835754,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8033446,int_stack+8027776,int_stack+8017360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2111666, 1.0, int_stack+2838589,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8012950,int_stack+8033446,int_stack+8021896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2116202, 1.0, int_stack+2843125,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8021770,int_stack+8012950,int_stack+7996120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2122082, 1.0, int_stack+2849005,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+8115001,int_stack+8021770,int_stack+8006335,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+77600,int_stack+77012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1432323, 1.0, int_stack+1493818,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7995049,int_stack+78384,int_stack+77600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1432911, 1.0, int_stack+1494406,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7997401,int_stack+7995049,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2206719, 1.0, int_stack+2855620,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8000929,int_stack+79392,int_stack+78384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1433695, 1.0, int_stack+1495190,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8003953,int_stack+8000929,int_stack+7995049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2208483, 1.0, int_stack+2857384,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8008657,int_stack+8003953,int_stack+7997401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2210835, 1.0, int_stack+2859736,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+80652,int_stack+79392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1434703, 1.0, int_stack+1496198,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8014537,int_stack+7993285,int_stack+8000929, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2214363, 1.0, int_stack+2893546,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8031031,int_stack+8014537,int_stack+8003953, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2217387, 1.0, int_stack+2896570,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7997065,int_stack+8031031,int_stack+8008657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2222091, 1.0, int_stack+2901274,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8005885,int_stack+82192,int_stack+80652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1435963, 1.0, int_stack+1497458,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8038871,int_stack+8005885,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2227971, 1.0, int_stack+2907154,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8134846,int_stack+8038871,int_stack+8014537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2231751, 1.0, int_stack+2910934,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8005885,int_stack+8134846,int_stack+8031031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2237799, 1.0, int_stack+2916982,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8031031,int_stack+8005885,int_stack+7997065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2245639, 1.0, int_stack+2924822,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+8134846,int_stack+8031031,int_stack+8021770,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+6093190,int_stack+8134846,int_stack+8115001,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8115001,int_stack+84796,int_stack+84040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1446379, 1.0, int_stack+1507874,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8117269,int_stack+85804,int_stack+84796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1447135, 1.0, int_stack+1508630,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8120293,int_stack+8117269,int_stack+8115001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2397592, 1.0, int_stack+2933642,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8124829,int_stack+87100,int_stack+85804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1448143, 1.0, int_stack+1509638,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8128717,int_stack+8124829,int_stack+8117269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2399860, 1.0, int_stack+2935910,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8162629,int_stack+8128717,int_stack+8120293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2402884, 1.0, int_stack+2938934,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8115001,int_stack+88720,int_stack+87100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1449439, 1.0, int_stack+1510934,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8170189,int_stack+8115001,int_stack+8124829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2407420, 1.0, int_stack+2943470,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8177965,int_stack+8170189,int_stack+8128717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2411308, 1.0, int_stack+3119950,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8119861,int_stack+8177965,int_stack+8162629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2417356, 1.0, int_stack+3125998,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8162629,int_stack+90700,int_stack+88720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1451059, 1.0, int_stack+1512554,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7993285,int_stack+8162629,int_stack+8115001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2424916, 1.0, int_stack+3133558,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8003005,int_stack+7993285,int_stack+8170189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2429776, 1.0, int_stack+3138418,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8162629,int_stack+8003005,int_stack+8177965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2437552, 1.0, int_stack+3146194,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6132880,int_stack+8162629,int_stack+8119861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2447632, 1.0, int_stack+3156274,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+7993285,int_stack+6132880,int_stack+8031031,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+24516,int_stack+7993285,int_stack+8134846,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+8115001,int_stack+24516,int_stack+6093190,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+94021,int_stack+93076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+602606, 1.0, int_stack+647326,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6096025,int_stack+95281,int_stack+94021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+604496, 1.0, int_stack+649216,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6099805,int_stack+6096025,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2471257, 1.0, int_stack+3167614,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6105475,int_stack+96901,int_stack+95281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+607016, 1.0, int_stack+651736,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6110335,int_stack+6105475,int_stack+6096025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2713168, 1.0, int_stack+3170449,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6117895,int_stack+6110335,int_stack+6099805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2716948, 1.0, int_stack+3174229,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+98926,int_stack+96901, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+610256, 1.0, int_stack+654976,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8030329,int_stack+6093190,int_stack+6105475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2722618, 1.0, int_stack+3357370,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7851724,int_stack+8030329,int_stack+6110335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2727478, 1.0, int_stack+3362230,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6099265,int_stack+7851724,int_stack+6117895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2735038, 1.0, int_stack+3369790,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6113440,int_stack+101401,int_stack+98926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614306, 1.0, int_stack+659026,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7864324,int_stack+6113440,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2744488, 1.0, int_stack+3379240,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6113440,int_stack+7864324,int_stack+8030329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2750563, 1.0, int_stack+3385315,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+7864324,int_stack+6113440,int_stack+7851724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2760283, 1.0, int_stack+3395035,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2359405,int_stack+7864324,int_stack+6099265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2772883, 1.0, int_stack+3407635,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+7851724,int_stack+2359405,int_stack+6132880,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+8181151,int_stack+7851724,int_stack+7993285,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+8255239,int_stack+8181151,int_stack+24516,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+24516,int_stack+104686,int_stack+104371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1475746, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+25461,int_stack+105106,int_stack+104686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1476061, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+26721,int_stack+25461,int_stack+24516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2787058, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28611,int_stack+105646,int_stack+105106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1476481, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+30231,int_stack+28611,int_stack+25461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2788003, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+32751,int_stack+30231,int_stack+26721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2789263, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+24516,int_stack+106321,int_stack+105646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1477021, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+35901,int_stack+24516,int_stack+28611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2791153, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+39141,int_stack+35901,int_stack+30231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2792773, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+26541,int_stack+39141,int_stack+32751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2795293, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+31266,int_stack+107146,int_stack+106321, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1477696, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+43341,int_stack+31266,int_stack+24516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2798443, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+47391,int_stack+43341,int_stack+35901, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2800468, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+31266,int_stack+47391,int_stack+39141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2803708, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+37566,int_stack+31266,int_stack+26541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2807908, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+24516,int_stack+108577,int_stack+108136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1483276, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+25839,int_stack+109165,int_stack+108577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1483717, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+27603,int_stack+25839,int_stack+24516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2812633, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+30249,int_stack+109921,int_stack+109165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1484305, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+32517,int_stack+30249,int_stack+25839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2813956, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+44181,int_stack+32517,int_stack+27603, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2815720, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+24516,int_stack+110866,int_stack+109921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1485061, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+48591,int_stack+24516,int_stack+30249, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2825548, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+53127,int_stack+48591,int_stack+32517, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2827816, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+27351,int_stack+53127,int_stack+44181, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2831344, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+44181,int_stack+112021,int_stack+110866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1486006, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+59007,int_stack+44181,int_stack+24516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2835754, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+64677,int_stack+59007,int_stack+48591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2838589, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+44181,int_stack+64677,int_stack+53127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2843125, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+53001,int_stack+44181,int_stack+27351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2849005, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+62262,int_stack+53001,int_stack+37566,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+24516,int_stack+113995,int_stack+113407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1493818, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+26280,int_stack+114779,int_stack+113995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1494406, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+28632,int_stack+26280,int_stack+24516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2855620, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+32160,int_stack+115787,int_stack+114779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1495190, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+35184,int_stack+32160,int_stack+26280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2857384, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+39888,int_stack+35184,int_stack+28632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2859736, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+24516,int_stack+117047,int_stack+115787, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1496198, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+45768,int_stack+24516,int_stack+32160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2893546, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+82107,int_stack+45768,int_stack+35184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2896570, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+28296,int_stack+82107,int_stack+39888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2901274, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+37116,int_stack+118587,int_stack+117047, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1497458, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+89947,int_stack+37116,int_stack+24516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2907154, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+97507,int_stack+89947,int_stack+45768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2910934, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+37116,int_stack+97507,int_stack+82107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2916982, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+82107,int_stack+37116,int_stack+28296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2924822, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+24516,int_stack+82107,int_stack+53001,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+8181151,int_stack+24516,int_stack+62262,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+94455,int_stack+121191,int_stack+120435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1507874, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+96723,int_stack+122199,int_stack+121191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1508630, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+99747,int_stack+96723,int_stack+94455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2933642, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+104283,int_stack+123495,int_stack+122199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1509638, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+108171,int_stack+104283,int_stack+96723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2935910, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+114219,int_stack+108171,int_stack+99747, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2938934, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+94455,int_stack+125115,int_stack+123495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1510934, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+52299,int_stack+94455,int_stack+104283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2943470, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+60075,int_stack+52299,int_stack+108171, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3119950, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+99315,int_stack+60075,int_stack+114219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3125998, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+110655,int_stack+127095,int_stack+125115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1512554, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+116595,int_stack+110655,int_stack+94455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3133558, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8220841,int_stack+116595,int_stack+52299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3138418, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+110655,int_stack+8220841,int_stack+60075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3146194, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8220841,int_stack+110655,int_stack+99315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3156274, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+7993285,int_stack+8220841,int_stack+82107,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+6093190,int_stack+7993285,int_stack+24516,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+24516,int_stack+6093190,int_stack+8181151,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8181151,int_stack+130416,int_stack+129471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+647326, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8183986,int_stack+131676,int_stack+130416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+649216, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8187766,int_stack+8183986,int_stack+8181151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3167614, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8193436,int_stack+133296,int_stack+131676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+651736, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8198296,int_stack+8193436,int_stack+8183986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3170449, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8205856,int_stack+8198296,int_stack+8187766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3174229, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8181151,int_stack+135321,int_stack+133296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+654976, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+90666,int_stack+8181151,int_stack+8193436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3357370, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+100386,int_stack+90666,int_stack+8198296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3362230, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8187226,int_stack+100386,int_stack+8205856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3369790, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8201401,int_stack+137796,int_stack+135321, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+659026, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+112986,int_stack+8201401,int_stack+8181151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3379240, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8201401,int_stack+112986,int_stack+90666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3385315, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+112986,int_stack+8201401,int_stack+100386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3395035, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+90666,int_stack+112986,int_stack+8187226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3407635, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+7851724,int_stack+90666,int_stack+8220841,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+8181151,int_stack+7851724,int_stack+7993285,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+8347849,int_stack+8181151,int_stack+6093190,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+141081,int_stack+140766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1414251, 0.0, zero_stack, 1.0, int_stack+1537241,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094135,int_stack+141501,int_stack+141081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1414566, 0.0, zero_stack, 1.0, int_stack+1537556,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6095395,int_stack+6094135,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2024330, 0.0, zero_stack, 1.0, int_stack+3421810,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6097285,int_stack+142041,int_stack+141501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1414986, 0.0, zero_stack, 1.0, int_stack+1537976,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6098905,int_stack+6097285,int_stack+6094135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2025275, 0.0, zero_stack, 1.0, int_stack+3422755,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6101425,int_stack+6098905,int_stack+6095395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2026535, 0.0, zero_stack, 1.0, int_stack+3424015,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+142716,int_stack+142041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1415526, 0.0, zero_stack, 1.0, int_stack+1538516,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6104575,int_stack+6093190,int_stack+6097285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2028425, 0.0, zero_stack, 1.0, int_stack+3425905,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6107815,int_stack+6104575,int_stack+6098905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2030045, 0.0, zero_stack, 1.0, int_stack+3427525,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6095215,int_stack+6107815,int_stack+6101425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2032565, 0.0, zero_stack, 1.0, int_stack+3430045,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6099940,int_stack+143541,int_stack+142716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1416201, 0.0, zero_stack, 1.0, int_stack+1539191,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6112015,int_stack+6099940,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2035715, 0.0, zero_stack, 1.0, int_stack+3433195,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6116065,int_stack+6112015,int_stack+6104575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2037740, 0.0, zero_stack, 1.0, int_stack+3435220,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6099940,int_stack+6116065,int_stack+6107815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2040980, 0.0, zero_stack, 1.0, int_stack+3438460,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6106240,int_stack+6099940,int_stack+6095215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2045180, 0.0, zero_stack, 1.0, int_stack+3442660,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+144972,int_stack+144531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1421781, 0.0, zero_stack, 1.0, int_stack+1544771,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094513,int_stack+145560,int_stack+144972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1422222, 0.0, zero_stack, 1.0, int_stack+1545212,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6096277,int_stack+6094513,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2092892, 0.0, zero_stack, 1.0, int_stack+3447385,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6098923,int_stack+146316,int_stack+145560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1422810, 0.0, zero_stack, 1.0, int_stack+1545800,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6101191,int_stack+6098923,int_stack+6094513, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2094215, 0.0, zero_stack, 1.0, int_stack+3448708,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6112855,int_stack+6101191,int_stack+6096277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2095979, 0.0, zero_stack, 1.0, int_stack+3450472,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+147261,int_stack+146316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1423566, 0.0, zero_stack, 1.0, int_stack+1546556,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6117265,int_stack+6093190,int_stack+6098923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2098625, 0.0, zero_stack, 1.0, int_stack+3460300,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6121801,int_stack+6117265,int_stack+6101191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100893, 0.0, zero_stack, 1.0, int_stack+3462568,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096025,int_stack+6121801,int_stack+6112855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2104421, 0.0, zero_stack, 1.0, int_stack+3466096,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6112855,int_stack+148416,int_stack+147261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1424511, 0.0, zero_stack, 1.0, int_stack+1547501,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6127681,int_stack+6112855,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2108831, 0.0, zero_stack, 1.0, int_stack+3179899,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6133351,int_stack+6127681,int_stack+6117265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2111666, 0.0, zero_stack, 1.0, int_stack+3470506,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6112855,int_stack+6133351,int_stack+6121801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2116202, 0.0, zero_stack, 1.0, int_stack+3475042,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6121675,int_stack+6112855,int_stack+6096025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2122082, 0.0, zero_stack, 1.0, int_stack+3480922,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+8181151,int_stack+6121675,int_stack+6106240,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+150390,int_stack+149802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1432323, 0.0, zero_stack, 1.0, int_stack+1555313,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094954,int_stack+151174,int_stack+150390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1432911, 0.0, zero_stack, 1.0, int_stack+1555901,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6097306,int_stack+6094954,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2206719, 0.0, zero_stack, 1.0, int_stack+3487537,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6100834,int_stack+152182,int_stack+151174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1433695, 0.0, zero_stack, 1.0, int_stack+1556685,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6103858,int_stack+6100834,int_stack+6094954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2208483, 0.0, zero_stack, 1.0, int_stack+3489301,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6108562,int_stack+6103858,int_stack+6097306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2210835, 0.0, zero_stack, 1.0, int_stack+3491653,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+153442,int_stack+152182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1434703, 0.0, zero_stack, 1.0, int_stack+1557693,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6114442,int_stack+6093190,int_stack+6100834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2214363, 0.0, zero_stack, 1.0, int_stack+3525463,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6130936,int_stack+6114442,int_stack+6103858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2217387, 0.0, zero_stack, 1.0, int_stack+3528487,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096970,int_stack+6130936,int_stack+6108562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2222091, 0.0, zero_stack, 1.0, int_stack+3533191,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6105790,int_stack+154982,int_stack+153442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1435963, 0.0, zero_stack, 1.0, int_stack+1558953,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6138776,int_stack+6105790,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2227971, 0.0, zero_stack, 1.0, int_stack+3539071,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8200996,int_stack+6138776,int_stack+6114442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2231751, 0.0, zero_stack, 1.0, int_stack+3542851,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6105790,int_stack+8200996,int_stack+6130936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2237799, 0.0, zero_stack, 1.0, int_stack+3548899,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6130936,int_stack+6105790,int_stack+6096970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2245639, 0.0, zero_stack, 1.0, int_stack+3556739,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+8200996,int_stack+6130936,int_stack+6121675,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+7993285,int_stack+8200996,int_stack+8181151,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8181151,int_stack+157586,int_stack+156830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1446379, 0.0, zero_stack, 1.0, int_stack+1569369,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8183419,int_stack+158594,int_stack+157586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1447135, 0.0, zero_stack, 1.0, int_stack+1570125,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8186443,int_stack+8183419,int_stack+8181151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2397592, 0.0, zero_stack, 1.0, int_stack+3565559,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8190979,int_stack+159890,int_stack+158594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1448143, 0.0, zero_stack, 1.0, int_stack+1571133,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8194867,int_stack+8190979,int_stack+8183419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2399860, 0.0, zero_stack, 1.0, int_stack+3567827,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8228779,int_stack+8194867,int_stack+8186443, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2402884, 0.0, zero_stack, 1.0, int_stack+3570851,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8181151,int_stack+161510,int_stack+159890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1449439, 0.0, zero_stack, 1.0, int_stack+1572429,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8236339,int_stack+8181151,int_stack+8190979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2407420, 0.0, zero_stack, 1.0, int_stack+3575387,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8244115,int_stack+8236339,int_stack+8194867, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2411308, 0.0, zero_stack, 1.0, int_stack+3754702,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8186011,int_stack+8244115,int_stack+8228779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2417356, 0.0, zero_stack, 1.0, int_stack+3760750,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8228779,int_stack+163490,int_stack+161510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1451059, 0.0, zero_stack, 1.0, int_stack+1574049,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6093190,int_stack+8228779,int_stack+8181151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2424916, 0.0, zero_stack, 1.0, int_stack+0,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6102910,int_stack+6093190,int_stack+8236339, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2429776, 0.0, zero_stack, 1.0, int_stack+3768310,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8228779,int_stack+6102910,int_stack+8244115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2437552, 0.0, zero_stack, 1.0, int_stack+3776086,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8032975,int_stack+8228779,int_stack+8186011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2447632, 0.0, zero_stack, 1.0, int_stack+3786166,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+6093190,int_stack+8032975,int_stack+6130936,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+90666,int_stack+6093190,int_stack+8200996,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+8181151,int_stack+90666,int_stack+7993285,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+166811,int_stack+165866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+602606, 0.0, zero_stack, 1.0, int_stack+692046,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7996120,int_stack+168071,int_stack+166811, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+604496, 0.0, zero_stack, 1.0, int_stack+693936,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7999900,int_stack+7996120,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2471257, 0.0, zero_stack, 1.0, int_stack+3797506,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8005570,int_stack+169691,int_stack+168071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+607016, 0.0, zero_stack, 1.0, int_stack+696456,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8010430,int_stack+8005570,int_stack+7996120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2713168, 0.0, zero_stack, 1.0, int_stack+3800341,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8017990,int_stack+8010430,int_stack+7999900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2716948, 0.0, zero_stack, 1.0, int_stack+3804121,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+171716,int_stack+169691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+610256, 0.0, zero_stack, 1.0, int_stack+699696,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6130234,int_stack+7993285,int_stack+8005570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2722618, 0.0, zero_stack, 1.0, int_stack+3987262,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7851724,int_stack+6130234,int_stack+8010430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2727478, 0.0, zero_stack, 1.0, int_stack+3992122,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7999360,int_stack+7851724,int_stack+8017990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2735038, 0.0, zero_stack, 1.0, int_stack+3999682,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8013535,int_stack+174191,int_stack+171716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614306, 0.0, zero_stack, 1.0, int_stack+703746,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7864324,int_stack+8013535,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2744488, 0.0, zero_stack, 1.0, int_stack+4009132,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8013535,int_stack+7864324,int_stack+6130234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2750563, 0.0, zero_stack, 1.0, int_stack+4015207,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+7864324,int_stack+8013535,int_stack+7851724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2760283, 0.0, zero_stack, 1.0, int_stack+4024927,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+146232,int_stack+7864324,int_stack+7999360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2772883, 0.0, zero_stack, 1.0, int_stack+4037527,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+7851724,int_stack+146232,int_stack+8032975,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+8440459,int_stack+7851724,int_stack+6093190,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+8514547,int_stack+8440459,int_stack+90666,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90666,int_stack+177476,int_stack+177161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1475746, 1.0, int_stack+1537241, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+91611,int_stack+177896,int_stack+177476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1476061, 1.0, int_stack+1537556, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+92871,int_stack+91611,int_stack+90666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2787058, 1.0, int_stack+3421810, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+94761,int_stack+178436,int_stack+177896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1476481, 1.0, int_stack+1537976, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+96381,int_stack+94761,int_stack+91611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2788003, 1.0, int_stack+3422755, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+98901,int_stack+96381,int_stack+92871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2789263, 1.0, int_stack+3424015, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+90666,int_stack+179111,int_stack+178436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1477021, 1.0, int_stack+1538516, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+102051,int_stack+90666,int_stack+94761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2791153, 1.0, int_stack+3425905, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+105291,int_stack+102051,int_stack+96381, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2792773, 1.0, int_stack+3427525, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+92691,int_stack+105291,int_stack+98901, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2795293, 1.0, int_stack+3430045, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+97416,int_stack+179936,int_stack+179111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1477696, 1.0, int_stack+1539191, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+109491,int_stack+97416,int_stack+90666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2798443, 1.0, int_stack+3433195, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+113541,int_stack+109491,int_stack+102051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2800468, 1.0, int_stack+3435220, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+97416,int_stack+113541,int_stack+105291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2803708, 1.0, int_stack+3438460, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+103716,int_stack+97416,int_stack+92691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2807908, 1.0, int_stack+3442660, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90666,int_stack+181367,int_stack+180926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1483276, 1.0, int_stack+1544771, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+91989,int_stack+181955,int_stack+181367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1483717, 1.0, int_stack+1545212, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+93753,int_stack+91989,int_stack+90666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2812633, 1.0, int_stack+3447385, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+96399,int_stack+182711,int_stack+181955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1484305, 1.0, int_stack+1545800, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98667,int_stack+96399,int_stack+91989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2813956, 1.0, int_stack+3448708, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+110331,int_stack+98667,int_stack+93753, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2815720, 1.0, int_stack+3450472, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+90666,int_stack+183656,int_stack+182711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1485061, 1.0, int_stack+1546556, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+114741,int_stack+90666,int_stack+96399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2825548, 1.0, int_stack+3460300, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+119277,int_stack+114741,int_stack+98667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2827816, 1.0, int_stack+3462568, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+93501,int_stack+119277,int_stack+110331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2831344, 1.0, int_stack+3466096, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+110331,int_stack+184811,int_stack+183656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1486006, 1.0, int_stack+1547501, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+125157,int_stack+110331,int_stack+90666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2835754, 1.0, int_stack+3179899, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+130827,int_stack+125157,int_stack+114741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2838589, 1.0, int_stack+3470506, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+110331,int_stack+130827,int_stack+119277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2843125, 1.0, int_stack+3475042, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+119151,int_stack+110331,int_stack+93501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2849005, 1.0, int_stack+3480922, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+128412,int_stack+119151,int_stack+103716,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90666,int_stack+186785,int_stack+186197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1493818, 1.0, int_stack+1555313, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+92430,int_stack+187569,int_stack+186785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1494406, 1.0, int_stack+1555901, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+94782,int_stack+92430,int_stack+90666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2855620, 1.0, int_stack+3487537, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+98310,int_stack+188577,int_stack+187569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1495190, 1.0, int_stack+1556685, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+101334,int_stack+98310,int_stack+92430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2857384, 1.0, int_stack+3489301, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+106038,int_stack+101334,int_stack+94782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2859736, 1.0, int_stack+3491653, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+90666,int_stack+189837,int_stack+188577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1496198, 1.0, int_stack+1557693, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+111918,int_stack+90666,int_stack+98310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2893546, 1.0, int_stack+3525463, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+148257,int_stack+111918,int_stack+101334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2896570, 1.0, int_stack+3528487, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+94446,int_stack+148257,int_stack+106038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2901274, 1.0, int_stack+3533191, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+103266,int_stack+191377,int_stack+189837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1497458, 1.0, int_stack+1558953, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+156097,int_stack+103266,int_stack+90666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2907154, 1.0, int_stack+3539071, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+163657,int_stack+156097,int_stack+111918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2910934, 1.0, int_stack+3542851, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+103266,int_stack+163657,int_stack+148257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2916982, 1.0, int_stack+3548899, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+148257,int_stack+103266,int_stack+94446, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2924822, 1.0, int_stack+3556739, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+160605,int_stack+148257,int_stack+119151,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+8440459,int_stack+160605,int_stack+128412,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+188388,int_stack+193981,int_stack+193225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1507874, 1.0, int_stack+1569369, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+190656,int_stack+194989,int_stack+193981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1508630, 1.0, int_stack+1570125, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+90666,int_stack+190656,int_stack+188388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2933642, 1.0, int_stack+3565559, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+95202,int_stack+196285,int_stack+194989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1509638, 1.0, int_stack+1571133, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+99090,int_stack+95202,int_stack+190656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2935910, 1.0, int_stack+3567827, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+188388,int_stack+99090,int_stack+90666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2938934, 1.0, int_stack+3570851, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+105138,int_stack+197905,int_stack+196285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1510934, 1.0, int_stack+1572429, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+109998,int_stack+105138,int_stack+95202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2943470, 1.0, int_stack+3575387, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+117774,int_stack+109998,int_stack+99090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3119950, 1.0, int_stack+3754702, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+90666,int_stack+117774,int_stack+188388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3125998, 1.0, int_stack+3760750, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+188388,int_stack+199885,int_stack+197905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1512554, 1.0, int_stack+1574049, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+127854,int_stack+188388,int_stack+105138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3133558, 1.0, int_stack+0, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+188388,int_stack+127854,int_stack+109998, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3138418, 1.0, int_stack+3768310, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+127854,int_stack+188388,int_stack+117774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3146194, 1.0, int_stack+3776086, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+102006,int_stack+127854,int_stack+90666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3156274, 1.0, int_stack+3786166, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+6093190,int_stack+102006,int_stack+148257,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+6093190,int_stack+160605,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+117882,int_stack+7993285,int_stack+8440459,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8440459,int_stack+203206,int_stack+202261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+647326, 1.0, int_stack+692046, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8443294,int_stack+204466,int_stack+203206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649216, 1.0, int_stack+693936, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8447074,int_stack+8443294,int_stack+8440459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3167614, 1.0, int_stack+3797506, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8452744,int_stack+206086,int_stack+204466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+651736, 1.0, int_stack+696456, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8457604,int_stack+8452744,int_stack+8443294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3170449, 1.0, int_stack+3800341, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8465164,int_stack+8457604,int_stack+8447074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3174229, 1.0, int_stack+3804121, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8440459,int_stack+208111,int_stack+206086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654976, 1.0, int_stack+699696, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8474614,int_stack+8440459,int_stack+8452744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3357370, 1.0, int_stack+3987262, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8484334,int_stack+8474614,int_stack+8457604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3362230, 1.0, int_stack+3992122, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8446534,int_stack+8484334,int_stack+8465164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3369790, 1.0, int_stack+3999682, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8460709,int_stack+210586,int_stack+208111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+659026, 1.0, int_stack+703746, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8496934,int_stack+8460709,int_stack+8440459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3379240, 1.0, int_stack+4009132, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+184032,int_stack+8496934,int_stack+8474614, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3385315, 1.0, int_stack+4015207, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8460709,int_stack+184032,int_stack+8484334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3395035, 1.0, int_stack+4024927, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+184032,int_stack+8460709,int_stack+8446534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3407635, 1.0, int_stack+4037527, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+8440459,int_stack+184032,int_stack+102006,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+8607157,int_stack+8440459,int_stack+6093190,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+8681245,int_stack+8607157,int_stack+7993285,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+213871,int_stack+213556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1537241, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+214291,int_stack+213871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1537556, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3421810, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+214831,int_stack+214291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1537976, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3422755, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3424015, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+215506,int_stack+214831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1538516, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3425905, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3427525, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3430045, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+216331,int_stack+215506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1539191, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3433195, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3435220, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3438460, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3442660, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+217762,int_stack+217321, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1544771, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+218350,int_stack+217762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1545212, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3447385, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+219106,int_stack+218350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1545800, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3448708, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8012950,int_stack+8001286,int_stack+7996372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3450472, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+220051,int_stack+219106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1546556, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8017360,int_stack+7993285,int_stack+7999018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3460300, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8021896,int_stack+8017360,int_stack+8001286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3462568, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8021896,int_stack+8012950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3466096, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8012950,int_stack+221206,int_stack+220051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1547501, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8027776,int_stack+8012950,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3179899, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8033446,int_stack+8027776,int_stack+8017360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3470506, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8012950,int_stack+8033446,int_stack+8021896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3475042, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8021770,int_stack+8012950,int_stack+7996120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3480922, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+8607157,int_stack+8021770,int_stack+8006335,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+223180,int_stack+222592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1555313, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7995049,int_stack+223964,int_stack+223180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1555901, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7997401,int_stack+7995049,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3487537, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8000929,int_stack+224972,int_stack+223964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1556685, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8003953,int_stack+8000929,int_stack+7995049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3489301, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8008657,int_stack+8003953,int_stack+7997401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3491653, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+226232,int_stack+224972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1557693, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8014537,int_stack+7993285,int_stack+8000929, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3525463, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8031031,int_stack+8014537,int_stack+8003953, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3528487, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7997065,int_stack+8031031,int_stack+8008657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3533191, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8005885,int_stack+227772,int_stack+226232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1558953, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8038871,int_stack+8005885,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3539071, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8627002,int_stack+8038871,int_stack+8014537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3542851, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8005885,int_stack+8627002,int_stack+8031031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3548899, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8031031,int_stack+8005885,int_stack+7997065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3556739, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+8627002,int_stack+8031031,int_stack+8021770,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+6093190,int_stack+8627002,int_stack+8607157,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8607157,int_stack+230376,int_stack+229620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1569369, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8609425,int_stack+231384,int_stack+230376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1570125, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8612449,int_stack+8609425,int_stack+8607157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3565559, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8616985,int_stack+232680,int_stack+231384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1571133, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8620873,int_stack+8616985,int_stack+8609425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3567827, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8654785,int_stack+8620873,int_stack+8612449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3570851, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8607157,int_stack+234300,int_stack+232680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1572429, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8662345,int_stack+8607157,int_stack+8616985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3575387, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8670121,int_stack+8662345,int_stack+8620873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3754702, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8612017,int_stack+8670121,int_stack+8654785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3760750, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8654785,int_stack+236280,int_stack+234300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1574049, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7993285,int_stack+8654785,int_stack+8607157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8003005,int_stack+7993285,int_stack+8662345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3768310, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8654785,int_stack+8003005,int_stack+8670121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3776086, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6132880,int_stack+8654785,int_stack+8612017, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3786166, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+7993285,int_stack+6132880,int_stack+8031031,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+8440459,int_stack+7993285,int_stack+8627002,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+8607157,int_stack+8440459,int_stack+6093190,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+239601,int_stack+238656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+692046, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6096025,int_stack+240861,int_stack+239601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+693936, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6099805,int_stack+6096025,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3797506, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6105475,int_stack+242481,int_stack+240861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+696456, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6110335,int_stack+6105475,int_stack+6096025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3800341, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6117895,int_stack+6110335,int_stack+6099805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3804121, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+244506,int_stack+242481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+699696, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8030329,int_stack+6093190,int_stack+6105475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3987262, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8496025,int_stack+8030329,int_stack+6110335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3992122, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6099265,int_stack+8496025,int_stack+6117895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3999682, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6113440,int_stack+246981,int_stack+244506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+703746, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+184032,int_stack+6113440,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4009132, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6113440,int_stack+184032,int_stack+8030329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4015207, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+184032,int_stack+6113440,int_stack+8496025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4024927, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+202932,int_stack+184032,int_stack+6099265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4037527, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+7851724,int_stack+202932,int_stack+6132880,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+8773855,int_stack+7851724,int_stack+7993285,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+8847943,int_stack+8773855,int_stack+8440459,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8440459,int_stack+250266,int_stack+249951, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1414251, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1598736,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8441404,int_stack+250686,int_stack+250266, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1414566, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1599051,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8442664,int_stack+8441404,int_stack+8440459, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2024330, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4051702,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8444554,int_stack+251226,int_stack+250686, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1414986, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1599471,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8446174,int_stack+8444554,int_stack+8441404, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2025275, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4052647,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8448694,int_stack+8446174,int_stack+8442664, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2026535, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4053907,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8440459,int_stack+251901,int_stack+251226, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1415526, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1600011,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8451844,int_stack+8440459,int_stack+8444554, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2028425, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4055797,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8455084,int_stack+8451844,int_stack+8446174, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2030045, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4057417,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8442484,int_stack+8455084,int_stack+8448694, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2032565, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4059937,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8447209,int_stack+252726,int_stack+251901, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1416201, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1600686,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8459284,int_stack+8447209,int_stack+8440459, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2035715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4063087,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8463334,int_stack+8459284,int_stack+8451844, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2037740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4065112,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8447209,int_stack+8463334,int_stack+8455084, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2040980, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4068352,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8453509,int_stack+8447209,int_stack+8442484, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2045180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4072552,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8440459,int_stack+254157,int_stack+253716, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1421781, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1606266,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8441782,int_stack+254745,int_stack+254157, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1422222, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1606707,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8443546,int_stack+8441782,int_stack+8440459, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2092892, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4077277,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8446192,int_stack+255501,int_stack+254745, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1422810, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1607295,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8448460,int_stack+8446192,int_stack+8441782, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2094215, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4078600,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8460124,int_stack+8448460,int_stack+8443546, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2095979, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4080364,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8440459,int_stack+256446,int_stack+255501, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1423566, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1608051,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8464534,int_stack+8440459,int_stack+8446192, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2098625, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4083010,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8469070,int_stack+8464534,int_stack+8448460, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100893, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4085278,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8443294,int_stack+8469070,int_stack+8460124, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2104421, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4095592,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8460124,int_stack+257601,int_stack+256446, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1424511, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1608996,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8474950,int_stack+8460124,int_stack+8440459, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2108831, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3809791,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8480620,int_stack+8474950,int_stack+8464534, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2111666, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4100002,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8460124,int_stack+8480620,int_stack+8469070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2116202, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4104538,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8468944,int_stack+8460124,int_stack+8443294, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2122082, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4110418,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+8478205,int_stack+8468944,int_stack+8453509,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8440459,int_stack+259575,int_stack+258987, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1432323, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1616808,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8442223,int_stack+260359,int_stack+259575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1432911, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1617396,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8444575,int_stack+8442223,int_stack+8440459, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2206719, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4146139,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8448103,int_stack+261367,int_stack+260359, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1433695, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1618180,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8451127,int_stack+8448103,int_stack+8442223, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2208483, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4147903,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8455831,int_stack+8451127,int_stack+8444575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2210835, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4150255,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8440459,int_stack+262627,int_stack+261367, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1434703, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1619188,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8461711,int_stack+8440459,int_stack+8448103, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2214363, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4153783,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8498050,int_stack+8461711,int_stack+8451127, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2217387, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4156807,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8444239,int_stack+8498050,int_stack+8455831, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2222091, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4161511,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8453059,int_stack+264167,int_stack+262627, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1435963, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1620448,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8505890,int_stack+8453059,int_stack+8440459, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2227971, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4167391,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8773855,int_stack+8505890,int_stack+8461711, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2231751, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4171171,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8453059,int_stack+8773855,int_stack+8498050, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2237799, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4177219,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8498050,int_stack+8453059,int_stack+8444239, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2245639, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4185059,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+8773855,int_stack+8498050,int_stack+8468944,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+8801638,int_stack+8773855,int_stack+8478205,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8510398,int_stack+266771,int_stack+266015, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1446379, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1630864,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8841328,int_stack+267779,int_stack+266771, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1447135, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1631620,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8440459,int_stack+8841328,int_stack+8510398, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2397592, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4193879,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8510398,int_stack+269075,int_stack+267779, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1448143, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1632628,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8444995,int_stack+8510398,int_stack+8841328, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2399860, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4196147,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8451043,int_stack+8444995,int_stack+8440459, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2402884, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4199171,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8841328,int_stack+270695,int_stack+269075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1449439, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1633924,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8458603,int_stack+8841328,int_stack+8510398, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2407420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4203707,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8466379,int_stack+8458603,int_stack+8444995, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2411308, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4384594,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8476459,int_stack+8466379,int_stack+8451043, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2417356, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4390642,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8440459,int_stack+272675,int_stack+270695, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1451059, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1635544,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8446399,int_stack+8440459,int_stack+8841328, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2424916, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4398202,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+7993285,int_stack+8446399,int_stack+8458603, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2429776, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4403062,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8440459,int_stack+7993285,int_stack+8466379, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2437552, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4410838,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+7993285,int_stack+8440459,int_stack+8476459, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2447632, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4420918,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+8440459,int_stack+7993285,int_stack+8498050,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+6093190,int_stack+8440459,int_stack+8773855,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+184032,int_stack+6093190,int_stack+8801638,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8773855,int_stack+275996,int_stack+275051, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+602606, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+736766,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8776690,int_stack+277256,int_stack+275996, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+604496, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+738656,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8780470,int_stack+8776690,int_stack+8773855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2471257, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4432258,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8786140,int_stack+278876,int_stack+277256, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+607016, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+741176,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8791000,int_stack+8786140,int_stack+8776690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2713168, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4435093,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8798560,int_stack+8791000,int_stack+8780470, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2716948, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4438873,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8773855,int_stack+280901,int_stack+278876, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+610256, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+744416,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8808010,int_stack+8773855,int_stack+8786140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2722618, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4622014,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8817730,int_stack+8808010,int_stack+8791000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2727478, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4626874,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8779930,int_stack+8817730,int_stack+8798560, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2735038, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4634434,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8794105,int_stack+283376,int_stack+280901, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614306, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+748466,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8830330,int_stack+8794105,int_stack+8773855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2744488, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4643884,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8477503,int_stack+8830330,int_stack+8808010, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2750563, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4649959,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8794105,int_stack+8477503,int_stack+8817730, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2760283, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4659679,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8477503,int_stack+8794105,int_stack+8779930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2772883, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4672279,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+8773855,int_stack+8477503,int_stack+7993285,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+8940553,int_stack+8773855,int_stack+8440459,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+9014641,int_stack+8940553,int_stack+6093190,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+286661,int_stack+286346, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1475746, 0.0, zero_stack, 1.0, int_stack+1598736, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094135,int_stack+287081,int_stack+286661, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1476061, 0.0, zero_stack, 1.0, int_stack+1599051, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6095395,int_stack+6094135,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2787058, 0.0, zero_stack, 1.0, int_stack+4051702, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6097285,int_stack+287621,int_stack+287081, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1476481, 0.0, zero_stack, 1.0, int_stack+1599471, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6098905,int_stack+6097285,int_stack+6094135, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2788003, 0.0, zero_stack, 1.0, int_stack+4052647, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6101425,int_stack+6098905,int_stack+6095395, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2789263, 0.0, zero_stack, 1.0, int_stack+4053907, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+288296,int_stack+287621, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1477021, 0.0, zero_stack, 1.0, int_stack+1600011, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6104575,int_stack+6093190,int_stack+6097285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2791153, 0.0, zero_stack, 1.0, int_stack+4055797, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6107815,int_stack+6104575,int_stack+6098905, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2792773, 0.0, zero_stack, 1.0, int_stack+4057417, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6095215,int_stack+6107815,int_stack+6101425, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2795293, 0.0, zero_stack, 1.0, int_stack+4059937, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6099940,int_stack+289121,int_stack+288296, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1477696, 0.0, zero_stack, 1.0, int_stack+1600686, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6112015,int_stack+6099940,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2798443, 0.0, zero_stack, 1.0, int_stack+4063087, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6116065,int_stack+6112015,int_stack+6104575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2800468, 0.0, zero_stack, 1.0, int_stack+4065112, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6099940,int_stack+6116065,int_stack+6107815, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2803708, 0.0, zero_stack, 1.0, int_stack+4068352, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6106240,int_stack+6099940,int_stack+6095215, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2807908, 0.0, zero_stack, 1.0, int_stack+4072552, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+290552,int_stack+290111, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1483276, 0.0, zero_stack, 1.0, int_stack+1606266, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094513,int_stack+291140,int_stack+290552, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1483717, 0.0, zero_stack, 1.0, int_stack+1606707, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6096277,int_stack+6094513,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2812633, 0.0, zero_stack, 1.0, int_stack+4077277, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6098923,int_stack+291896,int_stack+291140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1484305, 0.0, zero_stack, 1.0, int_stack+1607295, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6101191,int_stack+6098923,int_stack+6094513, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2813956, 0.0, zero_stack, 1.0, int_stack+4078600, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6112855,int_stack+6101191,int_stack+6096277, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2815720, 0.0, zero_stack, 1.0, int_stack+4080364, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+292841,int_stack+291896, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1485061, 0.0, zero_stack, 1.0, int_stack+1608051, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6117265,int_stack+6093190,int_stack+6098923, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2825548, 0.0, zero_stack, 1.0, int_stack+4083010, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6121801,int_stack+6117265,int_stack+6101191, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2827816, 0.0, zero_stack, 1.0, int_stack+4085278, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096025,int_stack+6121801,int_stack+6112855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2831344, 0.0, zero_stack, 1.0, int_stack+4095592, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6112855,int_stack+293996,int_stack+292841, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1486006, 0.0, zero_stack, 1.0, int_stack+1608996, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6127681,int_stack+6112855,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2835754, 0.0, zero_stack, 1.0, int_stack+3809791, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6133351,int_stack+6127681,int_stack+6117265, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2838589, 0.0, zero_stack, 1.0, int_stack+4100002, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6112855,int_stack+6133351,int_stack+6121801, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2843125, 0.0, zero_stack, 1.0, int_stack+4104538, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6121675,int_stack+6112855,int_stack+6096025, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2849005, 0.0, zero_stack, 1.0, int_stack+4110418, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+8940553,int_stack+6121675,int_stack+6106240,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+295970,int_stack+295382, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1493818, 0.0, zero_stack, 1.0, int_stack+1616808, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094954,int_stack+296754,int_stack+295970, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1494406, 0.0, zero_stack, 1.0, int_stack+1617396, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6097306,int_stack+6094954,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2855620, 0.0, zero_stack, 1.0, int_stack+4146139, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6100834,int_stack+297762,int_stack+296754, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1495190, 0.0, zero_stack, 1.0, int_stack+1618180, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6103858,int_stack+6100834,int_stack+6094954, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2857384, 0.0, zero_stack, 1.0, int_stack+4147903, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6108562,int_stack+6103858,int_stack+6097306, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2859736, 0.0, zero_stack, 1.0, int_stack+4150255, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+299022,int_stack+297762, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1496198, 0.0, zero_stack, 1.0, int_stack+1619188, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6114442,int_stack+6093190,int_stack+6100834, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2893546, 0.0, zero_stack, 1.0, int_stack+4153783, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6130936,int_stack+6114442,int_stack+6103858, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2896570, 0.0, zero_stack, 1.0, int_stack+4156807, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096970,int_stack+6130936,int_stack+6108562, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2901274, 0.0, zero_stack, 1.0, int_stack+4161511, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6105790,int_stack+300562,int_stack+299022, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1497458, 0.0, zero_stack, 1.0, int_stack+1620448, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6138776,int_stack+6105790,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2907154, 0.0, zero_stack, 1.0, int_stack+4167391, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8960398,int_stack+6138776,int_stack+6114442, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2910934, 0.0, zero_stack, 1.0, int_stack+4171171, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6105790,int_stack+8960398,int_stack+6130936, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2916982, 0.0, zero_stack, 1.0, int_stack+4177219, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6130936,int_stack+6105790,int_stack+6096970, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2924822, 0.0, zero_stack, 1.0, int_stack+4185059, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+8960398,int_stack+6130936,int_stack+6121675,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+8440459,int_stack+8960398,int_stack+8940553,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8940553,int_stack+303166,int_stack+302410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1507874, 0.0, zero_stack, 1.0, int_stack+1630864, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8942821,int_stack+304174,int_stack+303166, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1508630, 0.0, zero_stack, 1.0, int_stack+1631620, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8945845,int_stack+8942821,int_stack+8940553, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2933642, 0.0, zero_stack, 1.0, int_stack+4193879, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8950381,int_stack+305470,int_stack+304174, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1509638, 0.0, zero_stack, 1.0, int_stack+1632628, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8954269,int_stack+8950381,int_stack+8942821, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2935910, 0.0, zero_stack, 1.0, int_stack+4196147, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8988181,int_stack+8954269,int_stack+8945845, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2938934, 0.0, zero_stack, 1.0, int_stack+4199171, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8940553,int_stack+307090,int_stack+305470, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1510934, 0.0, zero_stack, 1.0, int_stack+1633924, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8995741,int_stack+8940553,int_stack+8950381, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2943470, 0.0, zero_stack, 1.0, int_stack+4203707, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+9003517,int_stack+8995741,int_stack+8954269, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3119950, 0.0, zero_stack, 1.0, int_stack+4384594, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8945413,int_stack+9003517,int_stack+8988181, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3125998, 0.0, zero_stack, 1.0, int_stack+4390642, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8988181,int_stack+309070,int_stack+307090, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1512554, 0.0, zero_stack, 1.0, int_stack+1635544, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6093190,int_stack+8988181,int_stack+8940553, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3133558, 0.0, zero_stack, 1.0, int_stack+4398202, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6102910,int_stack+6093190,int_stack+8995741, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3138418, 0.0, zero_stack, 1.0, int_stack+4403062, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8988181,int_stack+6102910,int_stack+9003517, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3146194, 0.0, zero_stack, 1.0, int_stack+4410838, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6093190,int_stack+8988181,int_stack+8945413, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3156274, 0.0, zero_stack, 1.0, int_stack+4420918, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+8773855,int_stack+6093190,int_stack+6130936,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+8773855,int_stack+8960398,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+8940553,int_stack+7993285,int_stack+8440459,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8440459,int_stack+312391,int_stack+311446, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+647326, 0.0, zero_stack, 1.0, int_stack+736766, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8443294,int_stack+313651,int_stack+312391, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+649216, 0.0, zero_stack, 1.0, int_stack+738656, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8447074,int_stack+8443294,int_stack+8440459, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3167614, 0.0, zero_stack, 1.0, int_stack+4432258, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8452744,int_stack+315271,int_stack+313651, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+651736, 0.0, zero_stack, 1.0, int_stack+741176, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8457604,int_stack+8452744,int_stack+8443294, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3170449, 0.0, zero_stack, 1.0, int_stack+4435093, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8465164,int_stack+8457604,int_stack+8447074, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3174229, 0.0, zero_stack, 1.0, int_stack+4438873, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8440459,int_stack+317296,int_stack+315271, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654976, 0.0, zero_stack, 1.0, int_stack+744416, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8474614,int_stack+8440459,int_stack+8452744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3357370, 0.0, zero_stack, 1.0, int_stack+4622014, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8484334,int_stack+8474614,int_stack+8457604, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3362230, 0.0, zero_stack, 1.0, int_stack+4626874, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8446534,int_stack+8484334,int_stack+8465164, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3369790, 0.0, zero_stack, 1.0, int_stack+4634434, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8460709,int_stack+319771,int_stack+317296, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+659026, 0.0, zero_stack, 1.0, int_stack+748466, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8496934,int_stack+8460709,int_stack+8440459, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3379240, 0.0, zero_stack, 1.0, int_stack+4643884, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6109066,int_stack+8496934,int_stack+8474614, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3385315, 0.0, zero_stack, 1.0, int_stack+4649959, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8460709,int_stack+6109066,int_stack+8484334, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3395035, 0.0, zero_stack, 1.0, int_stack+4659679, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6109066,int_stack+8460709,int_stack+8446534, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3407635, 0.0, zero_stack, 1.0, int_stack+4672279, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+8440459,int_stack+6109066,int_stack+6093190,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+9107251,int_stack+8440459,int_stack+8773855,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+9181339,int_stack+9107251,int_stack+7993285,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+323056,int_stack+322741, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1537241, 1.0, int_stack+1598736, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+323476,int_stack+323056, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1537556, 1.0, int_stack+1599051, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3421810, 1.0, int_stack+4051702, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+324016,int_stack+323476, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1537976, 1.0, int_stack+1599471, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3422755, 1.0, int_stack+4052647, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3424015, 1.0, int_stack+4053907, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+324691,int_stack+324016, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1538516, 1.0, int_stack+1600011, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3425905, 1.0, int_stack+4055797, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3427525, 1.0, int_stack+4057417, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3430045, 1.0, int_stack+4059937, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+325516,int_stack+324691, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1539191, 1.0, int_stack+1600686, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3433195, 1.0, int_stack+4063087, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3435220, 1.0, int_stack+4065112, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3438460, 1.0, int_stack+4068352, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3442660, 1.0, int_stack+4072552, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+326947,int_stack+326506, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1544771, 1.0, int_stack+1606266, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+327535,int_stack+326947, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1545212, 1.0, int_stack+1606707, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3447385, 1.0, int_stack+4077277, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+328291,int_stack+327535, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1545800, 1.0, int_stack+1607295, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3448708, 1.0, int_stack+4078600, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8012950,int_stack+8001286,int_stack+7996372, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3450472, 1.0, int_stack+4080364, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+329236,int_stack+328291, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1546556, 1.0, int_stack+1608051, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8017360,int_stack+7993285,int_stack+7999018, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3460300, 1.0, int_stack+4083010, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8021896,int_stack+8017360,int_stack+8001286, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3462568, 1.0, int_stack+4085278, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8021896,int_stack+8012950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3466096, 1.0, int_stack+4095592, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8012950,int_stack+330391,int_stack+329236, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1547501, 1.0, int_stack+1608996, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8027776,int_stack+8012950,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3179899, 1.0, int_stack+3809791, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8033446,int_stack+8027776,int_stack+8017360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3470506, 1.0, int_stack+4100002, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8012950,int_stack+8033446,int_stack+8021896, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3475042, 1.0, int_stack+4104538, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8021770,int_stack+8012950,int_stack+7996120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3480922, 1.0, int_stack+4110418, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9107251,int_stack+8021770,int_stack+8006335,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+332365,int_stack+331777, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1555313, 1.0, int_stack+1616808, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7995049,int_stack+333149,int_stack+332365, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1555901, 1.0, int_stack+1617396, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7997401,int_stack+7995049,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3487537, 1.0, int_stack+4146139, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8000929,int_stack+334157,int_stack+333149, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1556685, 1.0, int_stack+1618180, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8003953,int_stack+8000929,int_stack+7995049, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3489301, 1.0, int_stack+4147903, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8008657,int_stack+8003953,int_stack+7997401, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3491653, 1.0, int_stack+4150255, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+335417,int_stack+334157, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1557693, 1.0, int_stack+1619188, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8014537,int_stack+7993285,int_stack+8000929, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3525463, 1.0, int_stack+4153783, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8031031,int_stack+8014537,int_stack+8003953, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3528487, 1.0, int_stack+4156807, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7997065,int_stack+8031031,int_stack+8008657, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3533191, 1.0, int_stack+4161511, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8005885,int_stack+336957,int_stack+335417, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1558953, 1.0, int_stack+1620448, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8038871,int_stack+8005885,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3539071, 1.0, int_stack+4167391, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+9127096,int_stack+8038871,int_stack+8014537, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3542851, 1.0, int_stack+4171171, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8005885,int_stack+9127096,int_stack+8031031, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3548899, 1.0, int_stack+4177219, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8031031,int_stack+8005885,int_stack+7997065, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3556739, 1.0, int_stack+4185059, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+9127096,int_stack+8031031,int_stack+8021770,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+8773855,int_stack+9127096,int_stack+9107251,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9107251,int_stack+339561,int_stack+338805, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1569369, 1.0, int_stack+1630864, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+9109519,int_stack+340569,int_stack+339561, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1570125, 1.0, int_stack+1631620, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9112543,int_stack+9109519,int_stack+9107251, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3565559, 1.0, int_stack+4193879, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+9117079,int_stack+341865,int_stack+340569, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1571133, 1.0, int_stack+1632628, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+9120967,int_stack+9117079,int_stack+9109519, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3567827, 1.0, int_stack+4196147, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+9154879,int_stack+9120967,int_stack+9112543, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3570851, 1.0, int_stack+4199171, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9107251,int_stack+343485,int_stack+341865, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1572429, 1.0, int_stack+1633924, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+9162439,int_stack+9107251,int_stack+9117079, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3575387, 1.0, int_stack+4203707, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+9170215,int_stack+9162439,int_stack+9120967, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3754702, 1.0, int_stack+4384594, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+9112111,int_stack+9170215,int_stack+9154879, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3760750, 1.0, int_stack+4390642, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+9154879,int_stack+345465,int_stack+343485, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1574049, 1.0, int_stack+1635544, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7993285,int_stack+9154879,int_stack+9107251, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+4398202, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8003005,int_stack+7993285,int_stack+9162439, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3768310, 1.0, int_stack+4403062, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+9154879,int_stack+8003005,int_stack+9170215, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3776086, 1.0, int_stack+4410838, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+7993285,int_stack+9154879,int_stack+9112111, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3786166, 1.0, int_stack+4420918, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+8440459,int_stack+7993285,int_stack+8031031,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+6093190,int_stack+8440459,int_stack+9127096,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+9107251,int_stack+6093190,int_stack+8773855,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8773855,int_stack+348786,int_stack+347841, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+692046, 1.0, int_stack+736766, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8776690,int_stack+350046,int_stack+348786, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+693936, 1.0, int_stack+738656, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8780470,int_stack+8776690,int_stack+8773855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3797506, 1.0, int_stack+4432258, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8786140,int_stack+351666,int_stack+350046, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+696456, 1.0, int_stack+741176, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8791000,int_stack+8786140,int_stack+8776690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3800341, 1.0, int_stack+4435093, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8798560,int_stack+8791000,int_stack+8780470, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3804121, 1.0, int_stack+4438873, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8773855,int_stack+353691,int_stack+351666, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+699696, 1.0, int_stack+744416, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8808010,int_stack+8773855,int_stack+8786140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3987262, 1.0, int_stack+4622014, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8817730,int_stack+8808010,int_stack+8791000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3992122, 1.0, int_stack+4626874, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8779930,int_stack+8817730,int_stack+8798560, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3999682, 1.0, int_stack+4634434, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8794105,int_stack+356166,int_stack+353691, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+703746, 1.0, int_stack+748466, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8830330,int_stack+8794105,int_stack+8773855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4009132, 1.0, int_stack+4643884, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8009161,int_stack+8830330,int_stack+8808010, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4015207, 1.0, int_stack+4649959, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8794105,int_stack+8009161,int_stack+8817730, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4024927, 1.0, int_stack+4659679, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8009161,int_stack+8794105,int_stack+8779930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4037527, 1.0, int_stack+4672279, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+8773855,int_stack+8009161,int_stack+7993285,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+250182,int_stack+8773855,int_stack+8440459,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+9273949,int_stack+250182,int_stack+6093190,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+359451,int_stack+359136, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1598736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094135,int_stack+359871,int_stack+359451, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1599051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6095395,int_stack+6094135,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4051702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6097285,int_stack+360411,int_stack+359871, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1599471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6098905,int_stack+6097285,int_stack+6094135, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4052647, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6101425,int_stack+6098905,int_stack+6095395, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4053907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+361086,int_stack+360411, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1600011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6104575,int_stack+6093190,int_stack+6097285, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4055797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6107815,int_stack+6104575,int_stack+6098905, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4057417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6095215,int_stack+6107815,int_stack+6101425, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4059937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6099940,int_stack+361911,int_stack+361086, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1600686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6112015,int_stack+6099940,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4063087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6116065,int_stack+6112015,int_stack+6104575, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4065112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6099940,int_stack+6116065,int_stack+6107815, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4068352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6106240,int_stack+6099940,int_stack+6095215, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4072552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+363342,int_stack+362901, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1606266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094513,int_stack+363930,int_stack+363342, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1606707, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6096277,int_stack+6094513,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4077277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6098923,int_stack+364686,int_stack+363930, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1607295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6101191,int_stack+6098923,int_stack+6094513, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4078600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6112855,int_stack+6101191,int_stack+6096277, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4080364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+365631,int_stack+364686, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1608051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6117265,int_stack+6093190,int_stack+6098923, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4083010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6121801,int_stack+6117265,int_stack+6101191, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4085278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096025,int_stack+6121801,int_stack+6112855, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4095592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6112855,int_stack+366786,int_stack+365631, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1608996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6127681,int_stack+6112855,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3809791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6133351,int_stack+6127681,int_stack+6117265, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4100002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6112855,int_stack+6133351,int_stack+6121801, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4104538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6121675,int_stack+6112855,int_stack+6096025, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4110418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+250182,int_stack+6121675,int_stack+6106240,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+368760,int_stack+368172, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1616808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094954,int_stack+369544,int_stack+368760, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1617396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6097306,int_stack+6094954,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4146139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6100834,int_stack+370552,int_stack+369544, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1618180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6103858,int_stack+6100834,int_stack+6094954, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4147903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6108562,int_stack+6103858,int_stack+6097306, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4150255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+371812,int_stack+370552, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1619188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6114442,int_stack+6093190,int_stack+6100834, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4153783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6130936,int_stack+6114442,int_stack+6103858, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4156807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096970,int_stack+6130936,int_stack+6108562, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4161511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6105790,int_stack+373352,int_stack+371812, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1620448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6138776,int_stack+6105790,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4167391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+270027,int_stack+6138776,int_stack+6114442, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4171171, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6105790,int_stack+270027,int_stack+6130936, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4177219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6130936,int_stack+6105790,int_stack+6096970, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4185059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+270027,int_stack+6130936,int_stack+6121675,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+297810,int_stack+270027,int_stack+250182,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+250182,int_stack+375956,int_stack+375200, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1630864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+252450,int_stack+376964,int_stack+375956, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1631620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+255474,int_stack+252450,int_stack+250182, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4193879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+260010,int_stack+378260,int_stack+376964, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1632628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+263898,int_stack+260010,int_stack+252450, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4196147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+337500,int_stack+263898,int_stack+255474, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4199171, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+250182,int_stack+379880,int_stack+378260, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1633924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+345060,int_stack+250182,int_stack+260010, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4203707, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+352836,int_stack+345060,int_stack+263898, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4384594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+255042,int_stack+352836,int_stack+337500, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4390642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+337500,int_stack+381860,int_stack+379880, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1635544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+362916,int_stack+337500,int_stack+250182, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4398202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6093190,int_stack+362916,int_stack+345060, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4403062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+362916,int_stack+6093190,int_stack+352836, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4410838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6093190,int_stack+362916,int_stack+255042, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4420918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+337500,int_stack+6093190,int_stack+6130936,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+337500,int_stack+270027,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+8440459,int_stack+7993285,int_stack+297810,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6109066,int_stack+385181,int_stack+384236, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+736766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6111901,int_stack+386441,int_stack+385181, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+738656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6115681,int_stack+6111901,int_stack+6109066, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4432258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6121351,int_stack+388061,int_stack+386441, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+741176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6126211,int_stack+6121351,int_stack+6111901, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4435093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6133771,int_stack+6126211,int_stack+6115681, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4438873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6109066,int_stack+390086,int_stack+388061, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+744416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+250182,int_stack+6109066,int_stack+6121351, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4622014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+259902,int_stack+250182,int_stack+6126211, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4626874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6115141,int_stack+259902,int_stack+6133771, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4634434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6129316,int_stack+392561,int_stack+390086, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+748466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+272502,int_stack+6129316,int_stack+6109066, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4643884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6129316,int_stack+272502,int_stack+250182, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4649959, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+272502,int_stack+6129316,int_stack+259902, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4659679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+250182,int_stack+272502,int_stack+6115141, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4672279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+270027,int_stack+250182,int_stack+6093190,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+8773855,int_stack+270027,int_stack+337500,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+250182,int_stack+8773855,int_stack+7993285,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+395846,int_stack+395531, 0.0, zero_stack, 1.0, int_stack+1414251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1660231,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+396266,int_stack+395846, 0.0, zero_stack, 1.0, int_stack+1414566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1660546,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+2024330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4686454,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+396806,int_stack+396266, 0.0, zero_stack, 1.0, int_stack+1414986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1660966,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230, 0.0, zero_stack, 1.0, int_stack+2025275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4687399,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490, 0.0, zero_stack, 1.0, int_stack+2026535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4688659,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+397481,int_stack+396806, 0.0, zero_stack, 1.0, int_stack+1415526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1661506,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380, 0.0, zero_stack, 1.0, int_stack+2028425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4690549,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000, 0.0, zero_stack, 1.0, int_stack+2030045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4692169,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520, 0.0, zero_stack, 1.0, int_stack+2032565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4694689,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+398306,int_stack+397481, 0.0, zero_stack, 1.0, int_stack+1416201, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1662181,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+2035715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4697839,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670, 0.0, zero_stack, 1.0, int_stack+2037740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4699864,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910, 0.0, zero_stack, 1.0, int_stack+2040980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4703104,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310, 0.0, zero_stack, 1.0, int_stack+2045180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4707304,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+399737,int_stack+399296, 0.0, zero_stack, 1.0, int_stack+1421781, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1667761,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+400325,int_stack+399737, 0.0, zero_stack, 1.0, int_stack+1422222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1668202,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+2092892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4712029,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+401081,int_stack+400325, 0.0, zero_stack, 1.0, int_stack+1422810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1668790,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 0.0, zero_stack, 1.0, int_stack+2094215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4713352,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8012950,int_stack+8001286,int_stack+7996372, 0.0, zero_stack, 1.0, int_stack+2095979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4715116,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+402026,int_stack+401081, 0.0, zero_stack, 1.0, int_stack+1423566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1669546,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8017360,int_stack+7993285,int_stack+7999018, 0.0, zero_stack, 1.0, int_stack+2098625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4724944,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8021896,int_stack+8017360,int_stack+8001286, 0.0, zero_stack, 1.0, int_stack+2100893, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4727212,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8021896,int_stack+8012950, 0.0, zero_stack, 1.0, int_stack+2104421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4730740,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8012950,int_stack+403181,int_stack+402026, 0.0, zero_stack, 1.0, int_stack+1424511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1670491,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8027776,int_stack+8012950,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+2108831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4444543,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8033446,int_stack+8027776,int_stack+8017360, 0.0, zero_stack, 1.0, int_stack+2111666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4735150,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8012950,int_stack+8033446,int_stack+8021896, 0.0, zero_stack, 1.0, int_stack+2116202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4739686,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8021770,int_stack+8012950,int_stack+7996120, 0.0, zero_stack, 1.0, int_stack+2122082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4745566,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+8773855,int_stack+8021770,int_stack+8006335,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+405155,int_stack+404567, 0.0, zero_stack, 1.0, int_stack+1432323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1678303,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7995049,int_stack+405939,int_stack+405155, 0.0, zero_stack, 1.0, int_stack+1432911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1678891,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7997401,int_stack+7995049,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+2206719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4752181,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8000929,int_stack+406947,int_stack+405939, 0.0, zero_stack, 1.0, int_stack+1433695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1679675,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8003953,int_stack+8000929,int_stack+7995049, 0.0, zero_stack, 1.0, int_stack+2208483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4753945,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8008657,int_stack+8003953,int_stack+7997401, 0.0, zero_stack, 1.0, int_stack+2210835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4756297,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+408207,int_stack+406947, 0.0, zero_stack, 1.0, int_stack+1434703, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1680683,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8014537,int_stack+7993285,int_stack+8000929, 0.0, zero_stack, 1.0, int_stack+2214363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4790107,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8031031,int_stack+8014537,int_stack+8003953, 0.0, zero_stack, 1.0, int_stack+2217387, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4793131,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7997065,int_stack+8031031,int_stack+8008657, 0.0, zero_stack, 1.0, int_stack+2222091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4797835,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8005885,int_stack+409747,int_stack+408207, 0.0, zero_stack, 1.0, int_stack+1435963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1681943,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8038871,int_stack+8005885,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+2227971, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4803715,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8793700,int_stack+8038871,int_stack+8014537, 0.0, zero_stack, 1.0, int_stack+2231751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4807495,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8005885,int_stack+8793700,int_stack+8031031, 0.0, zero_stack, 1.0, int_stack+2237799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4813543,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8031031,int_stack+8005885,int_stack+7997065, 0.0, zero_stack, 1.0, int_stack+2245639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4821383,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+8793700,int_stack+8031031,int_stack+8021770,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+6093190,int_stack+8793700,int_stack+8773855,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8773855,int_stack+412351,int_stack+411595, 0.0, zero_stack, 1.0, int_stack+1446379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1692359,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8776123,int_stack+413359,int_stack+412351, 0.0, zero_stack, 1.0, int_stack+1447135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1693115,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8779147,int_stack+8776123,int_stack+8773855, 0.0, zero_stack, 1.0, int_stack+2397592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4830203,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8783683,int_stack+414655,int_stack+413359, 0.0, zero_stack, 1.0, int_stack+1448143, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1694123,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8787571,int_stack+8783683,int_stack+8776123, 0.0, zero_stack, 1.0, int_stack+2399860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4832471,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8821483,int_stack+8787571,int_stack+8779147, 0.0, zero_stack, 1.0, int_stack+2402884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4835495,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8773855,int_stack+416275,int_stack+414655, 0.0, zero_stack, 1.0, int_stack+1449439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1695419,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8829043,int_stack+8773855,int_stack+8783683, 0.0, zero_stack, 1.0, int_stack+2407420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4840031,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8836819,int_stack+8829043,int_stack+8787571, 0.0, zero_stack, 1.0, int_stack+2411308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4860,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8778715,int_stack+8836819,int_stack+8821483, 0.0, zero_stack, 1.0, int_stack+2417356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5019346,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8821483,int_stack+418255,int_stack+416275, 0.0, zero_stack, 1.0, int_stack+1451059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1697039,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7993285,int_stack+8821483,int_stack+8773855, 0.0, zero_stack, 1.0, int_stack+2424916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5026906,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8003005,int_stack+7993285,int_stack+8829043, 0.0, zero_stack, 1.0, int_stack+2429776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5031766,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8821483,int_stack+8003005,int_stack+8836819, 0.0, zero_stack, 1.0, int_stack+2437552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5039542,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6132880,int_stack+8821483,int_stack+8778715, 0.0, zero_stack, 1.0, int_stack+2447632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5049622,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+7993285,int_stack+6132880,int_stack+8031031,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+342792,int_stack+7993285,int_stack+8793700,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+8773855,int_stack+342792,int_stack+6093190,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+421576,int_stack+420631, 0.0, zero_stack, 1.0, int_stack+602606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+781486,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6096025,int_stack+422836,int_stack+421576, 0.0, zero_stack, 1.0, int_stack+604496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+783376,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6099805,int_stack+6096025,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+2471257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5060962,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6105475,int_stack+424456,int_stack+422836, 0.0, zero_stack, 1.0, int_stack+607016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+785896,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6110335,int_stack+6105475,int_stack+6096025, 0.0, zero_stack, 1.0, int_stack+2713168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5063797,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6117895,int_stack+6110335,int_stack+6099805, 0.0, zero_stack, 1.0, int_stack+2716948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5067577,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+426481,int_stack+424456, 0.0, zero_stack, 1.0, int_stack+610256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+789136,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8030329,int_stack+6093190,int_stack+6105475, 0.0, zero_stack, 1.0, int_stack+2722618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5250718,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+398358,int_stack+8030329,int_stack+6110335, 0.0, zero_stack, 1.0, int_stack+2727478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5255578,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6099265,int_stack+398358,int_stack+6117895, 0.0, zero_stack, 1.0, int_stack+2735038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5263138,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6113440,int_stack+428956,int_stack+426481, 0.0, zero_stack, 1.0, int_stack+614306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+793186,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+410958,int_stack+6113440,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+2744488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5272588,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6113440,int_stack+410958,int_stack+8030329, 0.0, zero_stack, 1.0, int_stack+2750563, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5278663,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+410958,int_stack+6113440,int_stack+398358, 0.0, zero_stack, 1.0, int_stack+2760283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5288383,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+7851724,int_stack+410958,int_stack+6099265, 0.0, zero_stack, 1.0, int_stack+2772883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5300983,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+9366559,int_stack+7851724,int_stack+6132880,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+9414187,int_stack+9366559,int_stack+7993285,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+9488275,int_stack+9414187,int_stack+342792,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+342792,int_stack+432241,int_stack+431926, 0.0, zero_stack, 1.0, int_stack+1475746, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1660231, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+343737,int_stack+432661,int_stack+432241, 0.0, zero_stack, 1.0, int_stack+1476061, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1660546, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+344997,int_stack+343737,int_stack+342792, 0.0, zero_stack, 1.0, int_stack+2787058, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4686454, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+346887,int_stack+433201,int_stack+432661, 0.0, zero_stack, 1.0, int_stack+1476481, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1660966, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+348507,int_stack+346887,int_stack+343737, 0.0, zero_stack, 1.0, int_stack+2788003, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4687399, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+351027,int_stack+348507,int_stack+344997, 0.0, zero_stack, 1.0, int_stack+2789263, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4688659, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+342792,int_stack+433876,int_stack+433201, 0.0, zero_stack, 1.0, int_stack+1477021, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1661506, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+354177,int_stack+342792,int_stack+346887, 0.0, zero_stack, 1.0, int_stack+2791153, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4690549, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+357417,int_stack+354177,int_stack+348507, 0.0, zero_stack, 1.0, int_stack+2792773, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4692169, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+344817,int_stack+357417,int_stack+351027, 0.0, zero_stack, 1.0, int_stack+2795293, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4694689, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+349542,int_stack+434701,int_stack+433876, 0.0, zero_stack, 1.0, int_stack+1477696, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1662181, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+361617,int_stack+349542,int_stack+342792, 0.0, zero_stack, 1.0, int_stack+2798443, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4697839, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+365667,int_stack+361617,int_stack+354177, 0.0, zero_stack, 1.0, int_stack+2800468, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4699864, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+349542,int_stack+365667,int_stack+357417, 0.0, zero_stack, 1.0, int_stack+2803708, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4703104, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+355842,int_stack+349542,int_stack+344817, 0.0, zero_stack, 1.0, int_stack+2807908, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4707304, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+342792,int_stack+436132,int_stack+435691, 0.0, zero_stack, 1.0, int_stack+1483276, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1667761, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+344115,int_stack+436720,int_stack+436132, 0.0, zero_stack, 1.0, int_stack+1483717, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1668202, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+345879,int_stack+344115,int_stack+342792, 0.0, zero_stack, 1.0, int_stack+2812633, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4712029, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+348525,int_stack+437476,int_stack+436720, 0.0, zero_stack, 1.0, int_stack+1484305, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1668790, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+350793,int_stack+348525,int_stack+344115, 0.0, zero_stack, 1.0, int_stack+2813956, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4713352, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+362457,int_stack+350793,int_stack+345879, 0.0, zero_stack, 1.0, int_stack+2815720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4715116, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+342792,int_stack+438421,int_stack+437476, 0.0, zero_stack, 1.0, int_stack+1485061, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1669546, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+366867,int_stack+342792,int_stack+348525, 0.0, zero_stack, 1.0, int_stack+2825548, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4724944, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+371403,int_stack+366867,int_stack+350793, 0.0, zero_stack, 1.0, int_stack+2827816, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4727212, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+345627,int_stack+371403,int_stack+362457, 0.0, zero_stack, 1.0, int_stack+2831344, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4730740, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+362457,int_stack+439576,int_stack+438421, 0.0, zero_stack, 1.0, int_stack+1486006, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1670491, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+377283,int_stack+362457,int_stack+342792, 0.0, zero_stack, 1.0, int_stack+2835754, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4444543, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+382953,int_stack+377283,int_stack+366867, 0.0, zero_stack, 1.0, int_stack+2838589, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4735150, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+362457,int_stack+382953,int_stack+371403, 0.0, zero_stack, 1.0, int_stack+2843125, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4739686, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+371277,int_stack+362457,int_stack+345627, 0.0, zero_stack, 1.0, int_stack+2849005, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4745566, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+380538,int_stack+371277,int_stack+355842,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+342792,int_stack+441550,int_stack+440962, 0.0, zero_stack, 1.0, int_stack+1493818, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1678303, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+344556,int_stack+442334,int_stack+441550, 0.0, zero_stack, 1.0, int_stack+1494406, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1678891, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+346908,int_stack+344556,int_stack+342792, 0.0, zero_stack, 1.0, int_stack+2855620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4752181, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+350436,int_stack+443342,int_stack+442334, 0.0, zero_stack, 1.0, int_stack+1495190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1679675, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+353460,int_stack+350436,int_stack+344556, 0.0, zero_stack, 1.0, int_stack+2857384, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4753945, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+358164,int_stack+353460,int_stack+346908, 0.0, zero_stack, 1.0, int_stack+2859736, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4756297, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+342792,int_stack+444602,int_stack+443342, 0.0, zero_stack, 1.0, int_stack+1496198, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1680683, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+364044,int_stack+342792,int_stack+350436, 0.0, zero_stack, 1.0, int_stack+2893546, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4790107, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+400383,int_stack+364044,int_stack+353460, 0.0, zero_stack, 1.0, int_stack+2896570, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4793131, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+346572,int_stack+400383,int_stack+358164, 0.0, zero_stack, 1.0, int_stack+2901274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4797835, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+355392,int_stack+446142,int_stack+444602, 0.0, zero_stack, 1.0, int_stack+1497458, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1681943, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+408223,int_stack+355392,int_stack+342792, 0.0, zero_stack, 1.0, int_stack+2907154, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4803715, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+415783,int_stack+408223,int_stack+364044, 0.0, zero_stack, 1.0, int_stack+2910934, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4807495, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+355392,int_stack+415783,int_stack+400383, 0.0, zero_stack, 1.0, int_stack+2916982, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4813543, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+400383,int_stack+355392,int_stack+346572, 0.0, zero_stack, 1.0, int_stack+2924822, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4821383, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+412731,int_stack+400383,int_stack+371277,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+7993285,int_stack+412731,int_stack+380538,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+440514,int_stack+448746,int_stack+447990, 0.0, zero_stack, 1.0, int_stack+1507874, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1692359, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+442782,int_stack+449754,int_stack+448746, 0.0, zero_stack, 1.0, int_stack+1508630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1693115, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+342792,int_stack+442782,int_stack+440514, 0.0, zero_stack, 1.0, int_stack+2933642, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4830203, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+445806,int_stack+451050,int_stack+449754, 0.0, zero_stack, 1.0, int_stack+1509638, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1694123, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+347328,int_stack+445806,int_stack+442782, 0.0, zero_stack, 1.0, int_stack+2935910, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4832471, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+353376,int_stack+347328,int_stack+342792, 0.0, zero_stack, 1.0, int_stack+2938934, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4835495, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+440514,int_stack+452670,int_stack+451050, 0.0, zero_stack, 1.0, int_stack+1510934, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1695419, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+360936,int_stack+440514,int_stack+445806, 0.0, zero_stack, 1.0, int_stack+2943470, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4840031, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+368712,int_stack+360936,int_stack+347328, 0.0, zero_stack, 1.0, int_stack+3119950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4860, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+378792,int_stack+368712,int_stack+353376, 0.0, zero_stack, 1.0, int_stack+3125998, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5019346, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+342792,int_stack+454650,int_stack+452670, 0.0, zero_stack, 1.0, int_stack+1512554, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1697039, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+348732,int_stack+342792,int_stack+440514, 0.0, zero_stack, 1.0, int_stack+3133558, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5026906, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+440514,int_stack+348732,int_stack+360936, 0.0, zero_stack, 1.0, int_stack+3138418, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5031766, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+342792,int_stack+440514,int_stack+368712, 0.0, zero_stack, 1.0, int_stack+3146194, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5039542, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8032975,int_stack+342792,int_stack+378792, 0.0, zero_stack, 1.0, int_stack+3156274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5049622, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+8032975,int_stack+400383,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+6093190,int_stack+342792,int_stack+412731,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+379836,int_stack+6093190,int_stack+7993285,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+457971,int_stack+457026, 0.0, zero_stack, 1.0, int_stack+647326, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+781486, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7996120,int_stack+459231,int_stack+457971, 0.0, zero_stack, 1.0, int_stack+649216, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+783376, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7999900,int_stack+7996120,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+3167614, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5060962, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8005570,int_stack+460851,int_stack+459231, 0.0, zero_stack, 1.0, int_stack+651736, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+785896, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8010430,int_stack+8005570,int_stack+7996120, 0.0, zero_stack, 1.0, int_stack+3170449, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5063797, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8017990,int_stack+8010430,int_stack+7999900, 0.0, zero_stack, 1.0, int_stack+3174229, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5067577, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+462876,int_stack+460851, 0.0, zero_stack, 1.0, int_stack+654976, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+789136, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+445986,int_stack+7993285,int_stack+8005570, 0.0, zero_stack, 1.0, int_stack+3357370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5250718, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+9366559,int_stack+445986,int_stack+8010430, 0.0, zero_stack, 1.0, int_stack+3362230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5255578, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7999360,int_stack+9366559,int_stack+8017990, 0.0, zero_stack, 1.0, int_stack+3369790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5263138, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8013535,int_stack+465351,int_stack+462876, 0.0, zero_stack, 1.0, int_stack+659026, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+793186, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+455706,int_stack+8013535,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+3379240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5272588, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8013535,int_stack+455706,int_stack+445986, 0.0, zero_stack, 1.0, int_stack+3385315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5278663, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+445986,int_stack+8013535,int_stack+9366559, 0.0, zero_stack, 1.0, int_stack+3395035, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5288383, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+9366559,int_stack+445986,int_stack+7999360, 0.0, zero_stack, 1.0, int_stack+3407635, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5300983, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+9386404,int_stack+9366559,int_stack+8032975,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+9580885,int_stack+9386404,int_stack+342792,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+9366559,int_stack+9580885,int_stack+6093190,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+468636,int_stack+468321, 0.0, zero_stack, 1.0, int_stack+1537241, 0.0, zero_stack, 1.0, int_stack+1660231, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094135,int_stack+469056,int_stack+468636, 0.0, zero_stack, 1.0, int_stack+1537556, 0.0, zero_stack, 1.0, int_stack+1660546, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6095395,int_stack+6094135,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+3421810, 0.0, zero_stack, 1.0, int_stack+4686454, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6097285,int_stack+469596,int_stack+469056, 0.0, zero_stack, 1.0, int_stack+1537976, 0.0, zero_stack, 1.0, int_stack+1660966, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6098905,int_stack+6097285,int_stack+6094135, 0.0, zero_stack, 1.0, int_stack+3422755, 0.0, zero_stack, 1.0, int_stack+4687399, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6101425,int_stack+6098905,int_stack+6095395, 0.0, zero_stack, 1.0, int_stack+3424015, 0.0, zero_stack, 1.0, int_stack+4688659, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+470271,int_stack+469596, 0.0, zero_stack, 1.0, int_stack+1538516, 0.0, zero_stack, 1.0, int_stack+1661506, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6104575,int_stack+6093190,int_stack+6097285, 0.0, zero_stack, 1.0, int_stack+3425905, 0.0, zero_stack, 1.0, int_stack+4690549, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6107815,int_stack+6104575,int_stack+6098905, 0.0, zero_stack, 1.0, int_stack+3427525, 0.0, zero_stack, 1.0, int_stack+4692169, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6095215,int_stack+6107815,int_stack+6101425, 0.0, zero_stack, 1.0, int_stack+3430045, 0.0, zero_stack, 1.0, int_stack+4694689, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6099940,int_stack+471096,int_stack+470271, 0.0, zero_stack, 1.0, int_stack+1539191, 0.0, zero_stack, 1.0, int_stack+1662181, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6112015,int_stack+6099940,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+3433195, 0.0, zero_stack, 1.0, int_stack+4697839, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6116065,int_stack+6112015,int_stack+6104575, 0.0, zero_stack, 1.0, int_stack+3435220, 0.0, zero_stack, 1.0, int_stack+4699864, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6099940,int_stack+6116065,int_stack+6107815, 0.0, zero_stack, 1.0, int_stack+3438460, 0.0, zero_stack, 1.0, int_stack+4703104, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6106240,int_stack+6099940,int_stack+6095215, 0.0, zero_stack, 1.0, int_stack+3442660, 0.0, zero_stack, 1.0, int_stack+4707304, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+472527,int_stack+472086, 0.0, zero_stack, 1.0, int_stack+1544771, 0.0, zero_stack, 1.0, int_stack+1667761, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094513,int_stack+473115,int_stack+472527, 0.0, zero_stack, 1.0, int_stack+1545212, 0.0, zero_stack, 1.0, int_stack+1668202, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6096277,int_stack+6094513,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+3447385, 0.0, zero_stack, 1.0, int_stack+4712029, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6098923,int_stack+473871,int_stack+473115, 0.0, zero_stack, 1.0, int_stack+1545800, 0.0, zero_stack, 1.0, int_stack+1668790, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6101191,int_stack+6098923,int_stack+6094513, 0.0, zero_stack, 1.0, int_stack+3448708, 0.0, zero_stack, 1.0, int_stack+4713352, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6112855,int_stack+6101191,int_stack+6096277, 0.0, zero_stack, 1.0, int_stack+3450472, 0.0, zero_stack, 1.0, int_stack+4715116, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+474816,int_stack+473871, 0.0, zero_stack, 1.0, int_stack+1546556, 0.0, zero_stack, 1.0, int_stack+1669546, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6117265,int_stack+6093190,int_stack+6098923, 0.0, zero_stack, 1.0, int_stack+3460300, 0.0, zero_stack, 1.0, int_stack+4724944, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6121801,int_stack+6117265,int_stack+6101191, 0.0, zero_stack, 1.0, int_stack+3462568, 0.0, zero_stack, 1.0, int_stack+4727212, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096025,int_stack+6121801,int_stack+6112855, 0.0, zero_stack, 1.0, int_stack+3466096, 0.0, zero_stack, 1.0, int_stack+4730740, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6112855,int_stack+475971,int_stack+474816, 0.0, zero_stack, 1.0, int_stack+1547501, 0.0, zero_stack, 1.0, int_stack+1670491, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6127681,int_stack+6112855,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+3179899, 0.0, zero_stack, 1.0, int_stack+4444543, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6133351,int_stack+6127681,int_stack+6117265, 0.0, zero_stack, 1.0, int_stack+3470506, 0.0, zero_stack, 1.0, int_stack+4735150, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6112855,int_stack+6133351,int_stack+6121801, 0.0, zero_stack, 1.0, int_stack+3475042, 0.0, zero_stack, 1.0, int_stack+4739686, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6121675,int_stack+6112855,int_stack+6096025, 0.0, zero_stack, 1.0, int_stack+3480922, 0.0, zero_stack, 1.0, int_stack+4745566, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9580885,int_stack+6121675,int_stack+6106240,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+477945,int_stack+477357, 0.0, zero_stack, 1.0, int_stack+1555313, 0.0, zero_stack, 1.0, int_stack+1678303, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094954,int_stack+478729,int_stack+477945, 0.0, zero_stack, 1.0, int_stack+1555901, 0.0, zero_stack, 1.0, int_stack+1678891, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6097306,int_stack+6094954,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+3487537, 0.0, zero_stack, 1.0, int_stack+4752181, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6100834,int_stack+479737,int_stack+478729, 0.0, zero_stack, 1.0, int_stack+1556685, 0.0, zero_stack, 1.0, int_stack+1679675, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6103858,int_stack+6100834,int_stack+6094954, 0.0, zero_stack, 1.0, int_stack+3489301, 0.0, zero_stack, 1.0, int_stack+4753945, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6108562,int_stack+6103858,int_stack+6097306, 0.0, zero_stack, 1.0, int_stack+3491653, 0.0, zero_stack, 1.0, int_stack+4756297, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+480997,int_stack+479737, 0.0, zero_stack, 1.0, int_stack+1557693, 0.0, zero_stack, 1.0, int_stack+1680683, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6114442,int_stack+6093190,int_stack+6100834, 0.0, zero_stack, 1.0, int_stack+3525463, 0.0, zero_stack, 1.0, int_stack+4790107, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6130936,int_stack+6114442,int_stack+6103858, 0.0, zero_stack, 1.0, int_stack+3528487, 0.0, zero_stack, 1.0, int_stack+4793131, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096970,int_stack+6130936,int_stack+6108562, 0.0, zero_stack, 1.0, int_stack+3533191, 0.0, zero_stack, 1.0, int_stack+4797835, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6105790,int_stack+482537,int_stack+480997, 0.0, zero_stack, 1.0, int_stack+1558953, 0.0, zero_stack, 1.0, int_stack+1681943, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6138776,int_stack+6105790,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+3539071, 0.0, zero_stack, 1.0, int_stack+4803715, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+9600730,int_stack+6138776,int_stack+6114442, 0.0, zero_stack, 1.0, int_stack+3542851, 0.0, zero_stack, 1.0, int_stack+4807495, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6105790,int_stack+9600730,int_stack+6130936, 0.0, zero_stack, 1.0, int_stack+3548899, 0.0, zero_stack, 1.0, int_stack+4813543, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6130936,int_stack+6105790,int_stack+6096970, 0.0, zero_stack, 1.0, int_stack+3556739, 0.0, zero_stack, 1.0, int_stack+4821383, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+9600730,int_stack+6130936,int_stack+6121675,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+7993285,int_stack+9600730,int_stack+9580885,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9580885,int_stack+485141,int_stack+484385, 0.0, zero_stack, 1.0, int_stack+1569369, 0.0, zero_stack, 1.0, int_stack+1692359, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+9583153,int_stack+486149,int_stack+485141, 0.0, zero_stack, 1.0, int_stack+1570125, 0.0, zero_stack, 1.0, int_stack+1693115, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9586177,int_stack+9583153,int_stack+9580885, 0.0, zero_stack, 1.0, int_stack+3565559, 0.0, zero_stack, 1.0, int_stack+4830203, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+9590713,int_stack+487445,int_stack+486149, 0.0, zero_stack, 1.0, int_stack+1571133, 0.0, zero_stack, 1.0, int_stack+1694123, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+9594601,int_stack+9590713,int_stack+9583153, 0.0, zero_stack, 1.0, int_stack+3567827, 0.0, zero_stack, 1.0, int_stack+4832471, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+9628513,int_stack+9594601,int_stack+9586177, 0.0, zero_stack, 1.0, int_stack+3570851, 0.0, zero_stack, 1.0, int_stack+4835495, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9580885,int_stack+489065,int_stack+487445, 0.0, zero_stack, 1.0, int_stack+1572429, 0.0, zero_stack, 1.0, int_stack+1695419, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+9636073,int_stack+9580885,int_stack+9590713, 0.0, zero_stack, 1.0, int_stack+3575387, 0.0, zero_stack, 1.0, int_stack+4840031, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+9643849,int_stack+9636073,int_stack+9594601, 0.0, zero_stack, 1.0, int_stack+3754702, 0.0, zero_stack, 1.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+9585745,int_stack+9643849,int_stack+9628513, 0.0, zero_stack, 1.0, int_stack+3760750, 0.0, zero_stack, 1.0, int_stack+5019346, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+9628513,int_stack+491045,int_stack+489065, 0.0, zero_stack, 1.0, int_stack+1574049, 0.0, zero_stack, 1.0, int_stack+1697039, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6093190,int_stack+9628513,int_stack+9580885, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+5026906, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6102910,int_stack+6093190,int_stack+9636073, 0.0, zero_stack, 1.0, int_stack+3768310, 0.0, zero_stack, 1.0, int_stack+5031766, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+9628513,int_stack+6102910,int_stack+9643849, 0.0, zero_stack, 1.0, int_stack+3776086, 0.0, zero_stack, 1.0, int_stack+5039542, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8032975,int_stack+9628513,int_stack+9585745, 0.0, zero_stack, 1.0, int_stack+3786166, 0.0, zero_stack, 1.0, int_stack+5049622, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+8032975,int_stack+6130936,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+6093190,int_stack+342792,int_stack+9600730,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+9580885,int_stack+6093190,int_stack+7993285,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+494366,int_stack+493421, 0.0, zero_stack, 1.0, int_stack+692046, 0.0, zero_stack, 1.0, int_stack+781486, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7996120,int_stack+495626,int_stack+494366, 0.0, zero_stack, 1.0, int_stack+693936, 0.0, zero_stack, 1.0, int_stack+783376, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7999900,int_stack+7996120,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+3797506, 0.0, zero_stack, 1.0, int_stack+5060962, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8005570,int_stack+497246,int_stack+495626, 0.0, zero_stack, 1.0, int_stack+696456, 0.0, zero_stack, 1.0, int_stack+785896, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8010430,int_stack+8005570,int_stack+7996120, 0.0, zero_stack, 1.0, int_stack+3800341, 0.0, zero_stack, 1.0, int_stack+5063797, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8017990,int_stack+8010430,int_stack+7999900, 0.0, zero_stack, 1.0, int_stack+3804121, 0.0, zero_stack, 1.0, int_stack+5067577, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+499271,int_stack+497246, 0.0, zero_stack, 1.0, int_stack+699696, 0.0, zero_stack, 1.0, int_stack+789136, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+9459169,int_stack+7993285,int_stack+8005570, 0.0, zero_stack, 1.0, int_stack+3987262, 0.0, zero_stack, 1.0, int_stack+5250718, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+9468889,int_stack+9459169,int_stack+8010430, 0.0, zero_stack, 1.0, int_stack+3992122, 0.0, zero_stack, 1.0, int_stack+5255578, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7999360,int_stack+9468889,int_stack+8017990, 0.0, zero_stack, 1.0, int_stack+3999682, 0.0, zero_stack, 1.0, int_stack+5263138, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8013535,int_stack+501746,int_stack+499271, 0.0, zero_stack, 1.0, int_stack+703746, 0.0, zero_stack, 1.0, int_stack+793186, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+445986,int_stack+8013535,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+4009132, 0.0, zero_stack, 1.0, int_stack+5272588, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8013535,int_stack+445986,int_stack+9459169, 0.0, zero_stack, 1.0, int_stack+4015207, 0.0, zero_stack, 1.0, int_stack+5278663, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+445986,int_stack+8013535,int_stack+9468889, 0.0, zero_stack, 1.0, int_stack+4024927, 0.0, zero_stack, 1.0, int_stack+5288383, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+9459169,int_stack+445986,int_stack+7999360, 0.0, zero_stack, 1.0, int_stack+4037527, 0.0, zero_stack, 1.0, int_stack+5300983, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+445986,int_stack+9459169,int_stack+8032975,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+9647035,int_stack+445986,int_stack+342792,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+9721123,int_stack+9647035,int_stack+6093190,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+505031,int_stack+504716, 0.0, zero_stack, 1.0, int_stack+1598736, 1.0, int_stack+1660231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094135,int_stack+505451,int_stack+505031, 0.0, zero_stack, 1.0, int_stack+1599051, 1.0, int_stack+1660546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6095395,int_stack+6094135,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+4051702, 1.0, int_stack+4686454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6097285,int_stack+505991,int_stack+505451, 0.0, zero_stack, 1.0, int_stack+1599471, 1.0, int_stack+1660966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6098905,int_stack+6097285,int_stack+6094135, 0.0, zero_stack, 1.0, int_stack+4052647, 1.0, int_stack+4687399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6101425,int_stack+6098905,int_stack+6095395, 0.0, zero_stack, 1.0, int_stack+4053907, 1.0, int_stack+4688659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+506666,int_stack+505991, 0.0, zero_stack, 1.0, int_stack+1600011, 1.0, int_stack+1661506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6104575,int_stack+6093190,int_stack+6097285, 0.0, zero_stack, 1.0, int_stack+4055797, 1.0, int_stack+4690549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6107815,int_stack+6104575,int_stack+6098905, 0.0, zero_stack, 1.0, int_stack+4057417, 1.0, int_stack+4692169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6095215,int_stack+6107815,int_stack+6101425, 0.0, zero_stack, 1.0, int_stack+4059937, 1.0, int_stack+4694689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6099940,int_stack+507491,int_stack+506666, 0.0, zero_stack, 1.0, int_stack+1600686, 1.0, int_stack+1662181, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6112015,int_stack+6099940,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+4063087, 1.0, int_stack+4697839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6116065,int_stack+6112015,int_stack+6104575, 0.0, zero_stack, 1.0, int_stack+4065112, 1.0, int_stack+4699864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6099940,int_stack+6116065,int_stack+6107815, 0.0, zero_stack, 1.0, int_stack+4068352, 1.0, int_stack+4703104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6106240,int_stack+6099940,int_stack+6095215, 0.0, zero_stack, 1.0, int_stack+4072552, 1.0, int_stack+4707304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+508922,int_stack+508481, 0.0, zero_stack, 1.0, int_stack+1606266, 1.0, int_stack+1667761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094513,int_stack+509510,int_stack+508922, 0.0, zero_stack, 1.0, int_stack+1606707, 1.0, int_stack+1668202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6096277,int_stack+6094513,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+4077277, 1.0, int_stack+4712029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6098923,int_stack+510266,int_stack+509510, 0.0, zero_stack, 1.0, int_stack+1607295, 1.0, int_stack+1668790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6101191,int_stack+6098923,int_stack+6094513, 0.0, zero_stack, 1.0, int_stack+4078600, 1.0, int_stack+4713352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6112855,int_stack+6101191,int_stack+6096277, 0.0, zero_stack, 1.0, int_stack+4080364, 1.0, int_stack+4715116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+511211,int_stack+510266, 0.0, zero_stack, 1.0, int_stack+1608051, 1.0, int_stack+1669546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6117265,int_stack+6093190,int_stack+6098923, 0.0, zero_stack, 1.0, int_stack+4083010, 1.0, int_stack+4724944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6121801,int_stack+6117265,int_stack+6101191, 0.0, zero_stack, 1.0, int_stack+4085278, 1.0, int_stack+4727212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096025,int_stack+6121801,int_stack+6112855, 0.0, zero_stack, 1.0, int_stack+4095592, 1.0, int_stack+4730740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6112855,int_stack+512366,int_stack+511211, 0.0, zero_stack, 1.0, int_stack+1608996, 1.0, int_stack+1670491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6127681,int_stack+6112855,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+3809791, 1.0, int_stack+4444543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6133351,int_stack+6127681,int_stack+6117265, 0.0, zero_stack, 1.0, int_stack+4100002, 1.0, int_stack+4735150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6112855,int_stack+6133351,int_stack+6121801, 0.0, zero_stack, 1.0, int_stack+4104538, 1.0, int_stack+4739686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6121675,int_stack+6112855,int_stack+6096025, 0.0, zero_stack, 1.0, int_stack+4110418, 1.0, int_stack+4745566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+9647035,int_stack+6121675,int_stack+6106240,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+514340,int_stack+513752, 0.0, zero_stack, 1.0, int_stack+1616808, 1.0, int_stack+1678303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094954,int_stack+515124,int_stack+514340, 0.0, zero_stack, 1.0, int_stack+1617396, 1.0, int_stack+1678891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6097306,int_stack+6094954,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+4146139, 1.0, int_stack+4752181, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6100834,int_stack+516132,int_stack+515124, 0.0, zero_stack, 1.0, int_stack+1618180, 1.0, int_stack+1679675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6103858,int_stack+6100834,int_stack+6094954, 0.0, zero_stack, 1.0, int_stack+4147903, 1.0, int_stack+4753945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6108562,int_stack+6103858,int_stack+6097306, 0.0, zero_stack, 1.0, int_stack+4150255, 1.0, int_stack+4756297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+517392,int_stack+516132, 0.0, zero_stack, 1.0, int_stack+1619188, 1.0, int_stack+1680683, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6114442,int_stack+6093190,int_stack+6100834, 0.0, zero_stack, 1.0, int_stack+4153783, 1.0, int_stack+4790107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6130936,int_stack+6114442,int_stack+6103858, 0.0, zero_stack, 1.0, int_stack+4156807, 1.0, int_stack+4793131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096970,int_stack+6130936,int_stack+6108562, 0.0, zero_stack, 1.0, int_stack+4161511, 1.0, int_stack+4797835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6105790,int_stack+518932,int_stack+517392, 0.0, zero_stack, 1.0, int_stack+1620448, 1.0, int_stack+1681943, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6138776,int_stack+6105790,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+4167391, 1.0, int_stack+4803715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+9666880,int_stack+6138776,int_stack+6114442, 0.0, zero_stack, 1.0, int_stack+4171171, 1.0, int_stack+4807495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6105790,int_stack+9666880,int_stack+6130936, 0.0, zero_stack, 1.0, int_stack+4177219, 1.0, int_stack+4813543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6130936,int_stack+6105790,int_stack+6096970, 0.0, zero_stack, 1.0, int_stack+4185059, 1.0, int_stack+4821383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+9666880,int_stack+6130936,int_stack+6121675,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+445986,int_stack+9666880,int_stack+9647035,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9647035,int_stack+521536,int_stack+520780, 0.0, zero_stack, 1.0, int_stack+1630864, 1.0, int_stack+1692359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+9649303,int_stack+522544,int_stack+521536, 0.0, zero_stack, 1.0, int_stack+1631620, 1.0, int_stack+1693115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9652327,int_stack+9649303,int_stack+9647035, 0.0, zero_stack, 1.0, int_stack+4193879, 1.0, int_stack+4830203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+9656863,int_stack+523840,int_stack+522544, 0.0, zero_stack, 1.0, int_stack+1632628, 1.0, int_stack+1694123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+9660751,int_stack+9656863,int_stack+9649303, 0.0, zero_stack, 1.0, int_stack+4196147, 1.0, int_stack+4832471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+9694663,int_stack+9660751,int_stack+9652327, 0.0, zero_stack, 1.0, int_stack+4199171, 1.0, int_stack+4835495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9647035,int_stack+525460,int_stack+523840, 0.0, zero_stack, 1.0, int_stack+1633924, 1.0, int_stack+1695419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+9702223,int_stack+9647035,int_stack+9656863, 0.0, zero_stack, 1.0, int_stack+4203707, 1.0, int_stack+4840031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+9709999,int_stack+9702223,int_stack+9660751, 0.0, zero_stack, 1.0, int_stack+4384594, 1.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+9651895,int_stack+9709999,int_stack+9694663, 0.0, zero_stack, 1.0, int_stack+4390642, 1.0, int_stack+5019346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+9694663,int_stack+527440,int_stack+525460, 0.0, zero_stack, 1.0, int_stack+1635544, 1.0, int_stack+1697039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6093190,int_stack+9694663,int_stack+9647035, 0.0, zero_stack, 1.0, int_stack+4398202, 1.0, int_stack+5026906, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6102910,int_stack+6093190,int_stack+9702223, 0.0, zero_stack, 1.0, int_stack+4403062, 1.0, int_stack+5031766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+9694663,int_stack+6102910,int_stack+9709999, 0.0, zero_stack, 1.0, int_stack+4410838, 1.0, int_stack+5039542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6093190,int_stack+9694663,int_stack+9651895, 0.0, zero_stack, 1.0, int_stack+4420918, 1.0, int_stack+5049622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+6093190,int_stack+6130936,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+9666880,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+9647035,int_stack+7993285,int_stack+445986,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+445986,int_stack+530761,int_stack+529816, 0.0, zero_stack, 1.0, int_stack+736766, 1.0, int_stack+781486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+448821,int_stack+532021,int_stack+530761, 0.0, zero_stack, 1.0, int_stack+738656, 1.0, int_stack+783376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+452601,int_stack+448821,int_stack+445986, 0.0, zero_stack, 1.0, int_stack+4432258, 1.0, int_stack+5060962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+458271,int_stack+533641,int_stack+532021, 0.0, zero_stack, 1.0, int_stack+741176, 1.0, int_stack+785896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+463131,int_stack+458271,int_stack+448821, 0.0, zero_stack, 1.0, int_stack+4435093, 1.0, int_stack+5063797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+470691,int_stack+463131,int_stack+452601, 0.0, zero_stack, 1.0, int_stack+4438873, 1.0, int_stack+5067577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+445986,int_stack+535666,int_stack+533641, 0.0, zero_stack, 1.0, int_stack+744416, 1.0, int_stack+789136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+480141,int_stack+445986,int_stack+458271, 0.0, zero_stack, 1.0, int_stack+4622014, 1.0, int_stack+5250718, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+489861,int_stack+480141,int_stack+463131, 0.0, zero_stack, 1.0, int_stack+4626874, 1.0, int_stack+5255578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+452061,int_stack+489861,int_stack+470691, 0.0, zero_stack, 1.0, int_stack+4634434, 1.0, int_stack+5263138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+466236,int_stack+538141,int_stack+535666, 0.0, zero_stack, 1.0, int_stack+748466, 1.0, int_stack+793186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+502461,int_stack+466236,int_stack+445986, 0.0, zero_stack, 1.0, int_stack+4643884, 1.0, int_stack+5272588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+514611,int_stack+502461,int_stack+480141, 0.0, zero_stack, 1.0, int_stack+4649959, 1.0, int_stack+5278663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+466236,int_stack+514611,int_stack+489861, 0.0, zero_stack, 1.0, int_stack+4659679, 1.0, int_stack+5288383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+485136,int_stack+466236,int_stack+452061, 0.0, zero_stack, 1.0, int_stack+4672279, 1.0, int_stack+5300983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+7851724,int_stack+485136,int_stack+6093190,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+445986,int_stack+7851724,int_stack+342792,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+9813733,int_stack+445986,int_stack+7993285,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+541426,int_stack+541111, 0.0, zero_stack, 2.0, int_stack+1660231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+541846,int_stack+541426, 0.0, zero_stack, 2.0, int_stack+1660546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285, 0.0, zero_stack, 2.0, int_stack+4686454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+542386,int_stack+541846, 0.0, zero_stack, 2.0, int_stack+1660966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230, 0.0, zero_stack, 2.0, int_stack+4687399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490, 0.0, zero_stack, 2.0, int_stack+4688659, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+543061,int_stack+542386, 0.0, zero_stack, 2.0, int_stack+1661506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380, 0.0, zero_stack, 2.0, int_stack+4690549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000, 0.0, zero_stack, 2.0, int_stack+4692169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520, 0.0, zero_stack, 2.0, int_stack+4694689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+543886,int_stack+543061, 0.0, zero_stack, 2.0, int_stack+1662181, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285, 0.0, zero_stack, 2.0, int_stack+4697839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670, 0.0, zero_stack, 2.0, int_stack+4699864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910, 0.0, zero_stack, 2.0, int_stack+4703104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310, 0.0, zero_stack, 2.0, int_stack+4707304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+545317,int_stack+544876, 0.0, zero_stack, 2.0, int_stack+1667761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+545905,int_stack+545317, 0.0, zero_stack, 2.0, int_stack+1668202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 0.0, zero_stack, 2.0, int_stack+4712029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+546661,int_stack+545905, 0.0, zero_stack, 2.0, int_stack+1668790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 0.0, zero_stack, 2.0, int_stack+4713352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8012950,int_stack+8001286,int_stack+7996372, 0.0, zero_stack, 2.0, int_stack+4715116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+547606,int_stack+546661, 0.0, zero_stack, 2.0, int_stack+1669546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8017360,int_stack+7993285,int_stack+7999018, 0.0, zero_stack, 2.0, int_stack+4724944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8021896,int_stack+8017360,int_stack+8001286, 0.0, zero_stack, 2.0, int_stack+4727212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8021896,int_stack+8012950, 0.0, zero_stack, 2.0, int_stack+4730740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8012950,int_stack+548761,int_stack+547606, 0.0, zero_stack, 2.0, int_stack+1670491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8027776,int_stack+8012950,int_stack+7993285, 0.0, zero_stack, 2.0, int_stack+4444543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8033446,int_stack+8027776,int_stack+8017360, 0.0, zero_stack, 2.0, int_stack+4735150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8012950,int_stack+8033446,int_stack+8021896, 0.0, zero_stack, 2.0, int_stack+4739686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8021770,int_stack+8012950,int_stack+7996120, 0.0, zero_stack, 2.0, int_stack+4745566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+445986,int_stack+8021770,int_stack+8006335,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+550735,int_stack+550147, 0.0, zero_stack, 2.0, int_stack+1678303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7995049,int_stack+551519,int_stack+550735, 0.0, zero_stack, 2.0, int_stack+1678891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7997401,int_stack+7995049,int_stack+7993285, 0.0, zero_stack, 2.0, int_stack+4752181, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8000929,int_stack+552527,int_stack+551519, 0.0, zero_stack, 2.0, int_stack+1679675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8003953,int_stack+8000929,int_stack+7995049, 0.0, zero_stack, 2.0, int_stack+4753945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8008657,int_stack+8003953,int_stack+7997401, 0.0, zero_stack, 2.0, int_stack+4756297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+553787,int_stack+552527, 0.0, zero_stack, 2.0, int_stack+1680683, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8014537,int_stack+7993285,int_stack+8000929, 0.0, zero_stack, 2.0, int_stack+4790107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8031031,int_stack+8014537,int_stack+8003953, 0.0, zero_stack, 2.0, int_stack+4793131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7997065,int_stack+8031031,int_stack+8008657, 0.0, zero_stack, 2.0, int_stack+4797835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8005885,int_stack+555327,int_stack+553787, 0.0, zero_stack, 2.0, int_stack+1681943, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8038871,int_stack+8005885,int_stack+7993285, 0.0, zero_stack, 2.0, int_stack+4803715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+465831,int_stack+8038871,int_stack+8014537, 0.0, zero_stack, 2.0, int_stack+4807495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8005885,int_stack+465831,int_stack+8031031, 0.0, zero_stack, 2.0, int_stack+4813543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8031031,int_stack+8005885,int_stack+7997065, 0.0, zero_stack, 2.0, int_stack+4821383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+465831,int_stack+8031031,int_stack+8021770,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+493614,int_stack+465831,int_stack+445986,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+445986,int_stack+557931,int_stack+557175, 0.0, zero_stack, 2.0, int_stack+1692359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+448254,int_stack+558939,int_stack+557931, 0.0, zero_stack, 2.0, int_stack+1693115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+451278,int_stack+448254,int_stack+445986, 0.0, zero_stack, 2.0, int_stack+4830203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+455814,int_stack+560235,int_stack+558939, 0.0, zero_stack, 2.0, int_stack+1694123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+459702,int_stack+455814,int_stack+448254, 0.0, zero_stack, 2.0, int_stack+4832471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+533304,int_stack+459702,int_stack+451278, 0.0, zero_stack, 2.0, int_stack+4835495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+445986,int_stack+561855,int_stack+560235, 0.0, zero_stack, 2.0, int_stack+1695419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+540864,int_stack+445986,int_stack+455814, 0.0, zero_stack, 2.0, int_stack+4840031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+548640,int_stack+540864,int_stack+459702, 0.0, zero_stack, 2.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+450846,int_stack+548640,int_stack+533304, 0.0, zero_stack, 2.0, int_stack+5019346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+533304,int_stack+563835,int_stack+561855, 0.0, zero_stack, 2.0, int_stack+1697039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7993285,int_stack+533304,int_stack+445986, 0.0, zero_stack, 2.0, int_stack+5026906, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8003005,int_stack+7993285,int_stack+540864, 0.0, zero_stack, 2.0, int_stack+5031766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+533304,int_stack+8003005,int_stack+548640, 0.0, zero_stack, 2.0, int_stack+5039542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+7993285,int_stack+533304,int_stack+450846, 0.0, zero_stack, 2.0, int_stack+5049622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+7993285,int_stack+8031031,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+6093190,int_stack+342792,int_stack+465831,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+9906343,int_stack+6093190,int_stack+493614,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8009161,int_stack+567156,int_stack+566211, 0.0, zero_stack, 2.0, int_stack+781486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8011996,int_stack+568416,int_stack+567156, 0.0, zero_stack, 2.0, int_stack+783376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8015776,int_stack+8011996,int_stack+8009161, 0.0, zero_stack, 2.0, int_stack+5060962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8021446,int_stack+570036,int_stack+568416, 0.0, zero_stack, 2.0, int_stack+785896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8026306,int_stack+8021446,int_stack+8011996, 0.0, zero_stack, 2.0, int_stack+5063797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8033866,int_stack+8026306,int_stack+8015776, 0.0, zero_stack, 2.0, int_stack+5067577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+8009161,int_stack+572061,int_stack+570036, 0.0, zero_stack, 2.0, int_stack+789136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+445986,int_stack+8009161,int_stack+8021446, 0.0, zero_stack, 2.0, int_stack+5250718, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+455706,int_stack+445986,int_stack+8026306, 0.0, zero_stack, 2.0, int_stack+5255578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8015236,int_stack+455706,int_stack+8033866, 0.0, zero_stack, 2.0, int_stack+5263138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8029411,int_stack+574536,int_stack+572061, 0.0, zero_stack, 2.0, int_stack+793186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+468306,int_stack+8029411,int_stack+8009161, 0.0, zero_stack, 2.0, int_stack+5272588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8029411,int_stack+468306,int_stack+445986, 0.0, zero_stack, 2.0, int_stack+5278663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+468306,int_stack+8029411,int_stack+455706, 0.0, zero_stack, 2.0, int_stack+5288383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+445986,int_stack+468306,int_stack+8015236, 0.0, zero_stack, 2.0, int_stack+5300983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+465831,int_stack+445986,int_stack+7993285,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+9972493,int_stack+465831,int_stack+342792,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+445986,int_stack+9972493,int_stack+6093190,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+577821,int_stack+577506, 1.0, int_stack+1414251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1721726,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094135,int_stack+578241,int_stack+577821, 1.0, int_stack+1414566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1722041,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6095395,int_stack+6094135,int_stack+6093190, 1.0, int_stack+2024330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5315158,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6097285,int_stack+578781,int_stack+578241, 1.0, int_stack+1414986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1722461,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6098905,int_stack+6097285,int_stack+6094135, 1.0, int_stack+2025275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5316103,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6101425,int_stack+6098905,int_stack+6095395, 1.0, int_stack+2026535, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5317363,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+579456,int_stack+578781, 1.0, int_stack+1415526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1723001,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6104575,int_stack+6093190,int_stack+6097285, 1.0, int_stack+2028425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5319253,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6107815,int_stack+6104575,int_stack+6098905, 1.0, int_stack+2030045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5320873,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6095215,int_stack+6107815,int_stack+6101425, 1.0, int_stack+2032565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5323393,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6099940,int_stack+580281,int_stack+579456, 1.0, int_stack+1416201, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1723676,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6112015,int_stack+6099940,int_stack+6093190, 1.0, int_stack+2035715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1998755,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6116065,int_stack+6112015,int_stack+6104575, 1.0, int_stack+2037740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5326543,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6099940,int_stack+6116065,int_stack+6107815, 1.0, int_stack+2040980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5329783,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6106240,int_stack+6099940,int_stack+6095215, 1.0, int_stack+2045180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2000780,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+581712,int_stack+581271, 1.0, int_stack+1421781, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1729256,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094513,int_stack+582300,int_stack+581712, 1.0, int_stack+1422222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1729697,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6096277,int_stack+6094513,int_stack+6093190, 1.0, int_stack+2092892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5340598,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6098923,int_stack+583056,int_stack+582300, 1.0, int_stack+1422810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1730285,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6101191,int_stack+6098923,int_stack+6094513, 1.0, int_stack+2094215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5341921,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6112855,int_stack+6101191,int_stack+6096277, 1.0, int_stack+2095979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5343685,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2092892,int_stack+584001,int_stack+583056, 1.0, int_stack+1423566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1731041,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6093190,int_stack+2092892,int_stack+6098923, 1.0, int_stack+2098625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5346331,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6117265,int_stack+6093190,int_stack+6101191, 1.0, int_stack+2100893, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5348599,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2095727,int_stack+6117265,int_stack+6112855, 1.0, int_stack+2104421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5352127,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6112855,int_stack+585156,int_stack+584001, 1.0, int_stack+1424511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1731986,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2102342,int_stack+6112855,int_stack+2092892, 1.0, int_stack+2108831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5073247,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6097726,int_stack+2102342,int_stack+6093190, 1.0, int_stack+2111666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2049905,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2102342,int_stack+6097726,int_stack+6117265, 1.0, int_stack+2116202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5356537,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6093190,int_stack+2102342,int_stack+2095727, 1.0, int_stack+2122082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5362417,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+2092892,int_stack+6093190,int_stack+6106240,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6102451,int_stack+587130,int_stack+586542, 1.0, int_stack+1432323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1739798,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6104215,int_stack+587914,int_stack+587130, 1.0, int_stack+1432911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1740386,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6106567,int_stack+6104215,int_stack+6102451, 1.0, int_stack+2206719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2054441,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6110095,int_stack+588922,int_stack+587914, 1.0, int_stack+1433695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1741170,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6113119,int_stack+6110095,int_stack+6104215, 1.0, int_stack+2208483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2062820,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6117823,int_stack+6113119,int_stack+6106567, 1.0, int_stack+2210835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2065172,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6102451,int_stack+590182,int_stack+588922, 1.0, int_stack+1434703, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1742178,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6123703,int_stack+6102451,int_stack+6110095, 1.0, int_stack+2214363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2068700,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6129751,int_stack+6123703,int_stack+6113119, 1.0, int_stack+2217387, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5398138,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6106231,int_stack+6129751,int_stack+6117823, 1.0, int_stack+2222091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5402842,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6115051,int_stack+591722,int_stack+590182, 1.0, int_stack+1435963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1743438,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6137591,int_stack+6115051,int_stack+6102451, 1.0, int_stack+2227971, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2128697,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2112737,int_stack+6137591,int_stack+6123703, 1.0, int_stack+2231751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5408722,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6115051,int_stack+2112737,int_stack+6129751, 1.0, int_stack+2237799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5414770,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2112737,int_stack+6115051,int_stack+6106231, 1.0, int_stack+2245639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5422610,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+6102451,int_stack+2112737,int_stack+6093190,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+9972493,int_stack+6102451,int_stack+2092892,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2092892,int_stack+594326,int_stack+593570, 1.0, int_stack+1446379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1754610,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2095160,int_stack+595334,int_stack+594326, 1.0, int_stack+1447135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1756374,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2098184,int_stack+2095160,int_stack+2092892, 1.0, int_stack+2397592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2166623,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2102720,int_stack+596630,int_stack+595334, 1.0, int_stack+1448143, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1758678,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2106608,int_stack+2102720,int_stack+2095160, 1.0, int_stack+2399860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2168891,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6093190,int_stack+2106608,int_stack+2098184, 1.0, int_stack+2402884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2171915,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2092892,int_stack+598250,int_stack+596630, 1.0, int_stack+1449439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1761594,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6130234,int_stack+2092892,int_stack+2102720, 1.0, int_stack+2407420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5471561,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6138010,int_stack+6130234,int_stack+2106608, 1.0, int_stack+2411308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5607919,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2097752,int_stack+6138010,int_stack+6093190, 1.0, int_stack+2417356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5613967,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6093190,int_stack+600230,int_stack+598250, 1.0, int_stack+1451059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1765194,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10012183,int_stack+6093190,int_stack+2092892, 1.0, int_stack+2424916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2254459,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10021903,int_stack+10012183,int_stack+6130234, 1.0, int_stack+2429776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5621527,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+342792,int_stack+10021903,int_stack+6138010, 1.0, int_stack+2437552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5629303,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6130234,int_stack+342792,int_stack+2097752, 1.0, int_stack+2447632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5639383,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+6130234,int_stack+2112737,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+6102451,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+2359405,int_stack+7993285,int_stack+9972493,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9972493,int_stack+605756,int_stack+603551, 1.0, int_stack+602606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+827151,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+9975328,int_stack+608636,int_stack+605756, 1.0, int_stack+604496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+830301,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9979108,int_stack+9975328,int_stack+9972493, 1.0, int_stack+2471257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2346040,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+9984778,int_stack+612281,int_stack+608636, 1.0, int_stack+607016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+834441,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+9989638,int_stack+9984778,int_stack+9975328, 1.0, int_stack+2713168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2176451,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+9997198,int_stack+9989638,int_stack+9979108, 1.0, int_stack+2716948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2348875,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9972493,int_stack+616781,int_stack+612281, 1.0, int_stack+610256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+839706,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10006648,int_stack+9972493,int_stack+9984778, 1.0, int_stack+2722618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2354545,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10016368,int_stack+10006648,int_stack+9989638, 1.0, int_stack+2727478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5825359,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+9978568,int_stack+10016368,int_stack+9997198, 1.0, int_stack+2735038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5832919,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+9992743,int_stack+619256,int_stack+616781, 1.0, int_stack+614306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+843756,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10028968,int_stack+9992743,int_stack+9972493, 1.0, int_stack+2744488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2458972,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2092892,int_stack+10028968,int_stack+10006648, 1.0, int_stack+2750563, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5842369,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+9992743,int_stack+2092892,int_stack+10016368, 1.0, int_stack+2760283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5852089,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2092892,int_stack+9992743,int_stack+9978568, 1.0, int_stack+2772883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5864689,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+9972493,int_stack+2092892,int_stack+6130234,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+538596,int_stack+9972493,int_stack+342792,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+9972493,int_stack+538596,int_stack+7993285,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+622541,int_stack+622226, 1.0, int_stack+1475746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1721726, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+622961,int_stack+622541, 1.0, int_stack+1476061, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1722041, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285, 1.0, int_stack+2787058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5315158, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+623501,int_stack+622961, 1.0, int_stack+1476481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1722461, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230, 1.0, int_stack+2788003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5316103, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490, 1.0, int_stack+2789263, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5317363, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+624176,int_stack+623501, 1.0, int_stack+1477021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1723001, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380, 1.0, int_stack+2791153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5319253, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000, 1.0, int_stack+2792773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5320873, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520, 1.0, int_stack+2795293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5323393, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+625001,int_stack+624176, 1.0, int_stack+1477696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1723676, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285, 1.0, int_stack+2798443, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1998755, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670, 1.0, int_stack+2800468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5326543, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910, 1.0, int_stack+2803708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5329783, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310, 1.0, int_stack+2807908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2000780, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+626432,int_stack+625991, 1.0, int_stack+1483276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1729256, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+627020,int_stack+626432, 1.0, int_stack+1483717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1729697, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 1.0, int_stack+2812633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5340598, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+627776,int_stack+627020, 1.0, int_stack+1484305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1730285, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 1.0, int_stack+2813956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5341921, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8012950,int_stack+8001286,int_stack+7996372, 1.0, int_stack+2815720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5343685, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+628721,int_stack+627776, 1.0, int_stack+1485061, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1731041, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8017360,int_stack+7993285,int_stack+7999018, 1.0, int_stack+2825548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5346331, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8021896,int_stack+8017360,int_stack+8001286, 1.0, int_stack+2827816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5348599, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8021896,int_stack+8012950, 1.0, int_stack+2831344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5352127, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8012950,int_stack+629876,int_stack+628721, 1.0, int_stack+1486006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1731986, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2825548,int_stack+8012950,int_stack+7993285, 1.0, int_stack+2835754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5073247, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8027776,int_stack+2825548,int_stack+8017360, 1.0, int_stack+2838589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2049905, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2825548,int_stack+8027776,int_stack+8021896, 1.0, int_stack+2843125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5356537, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2834368,int_stack+2825548,int_stack+7996120, 1.0, int_stack+2849005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5362417, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+8012950,int_stack+2834368,int_stack+8006335,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2825548,int_stack+631850,int_stack+631262, 1.0, int_stack+1493818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1739798, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2827312,int_stack+632634,int_stack+631850, 1.0, int_stack+1494406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1740386, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2829664,int_stack+2827312,int_stack+2825548, 1.0, int_stack+2855620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2054441, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2843629,int_stack+633642,int_stack+632634, 1.0, int_stack+1495190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1741170, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2846653,int_stack+2843629,int_stack+2827312, 1.0, int_stack+2857384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2062820, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2851357,int_stack+2846653,int_stack+2829664, 1.0, int_stack+2859736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2065172, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2825548,int_stack+634902,int_stack+633642, 1.0, int_stack+1496198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1742178, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2857237,int_stack+2825548,int_stack+2843629, 1.0, int_stack+2893546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2068700, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7993285,int_stack+2857237,int_stack+2846653, 1.0, int_stack+2896570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5398138, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8001125,int_stack+7993285,int_stack+2851357, 1.0, int_stack+2901274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5402842, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2893546,int_stack+636442,int_stack+634902, 1.0, int_stack+1497458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1743438, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2898166,int_stack+2893546,int_stack+2825548, 1.0, int_stack+2907154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2128697, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2843629,int_stack+2898166,int_stack+2857237, 1.0, int_stack+2910934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5408722, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2893546,int_stack+2843629,int_stack+7993285, 1.0, int_stack+2916982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5414770, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2843629,int_stack+2893546,int_stack+8001125, 1.0, int_stack+2924822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5422610, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2893546,int_stack+2843629,int_stack+2834368,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+2893546,int_stack+8012950,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2921329,int_stack+639046,int_stack+638290, 1.0, int_stack+1507874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1754610, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2923597,int_stack+640054,int_stack+639046, 1.0, int_stack+1508630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1756374, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2926621,int_stack+2923597,int_stack+2921329, 1.0, int_stack+2933642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2166623, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2931157,int_stack+641350,int_stack+640054, 1.0, int_stack+1509638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1758678, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7993285,int_stack+2931157,int_stack+2923597, 1.0, int_stack+2935910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2168891, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7999333,int_stack+7993285,int_stack+2926621, 1.0, int_stack+2938934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2171915, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2921329,int_stack+642970,int_stack+641350, 1.0, int_stack+1510934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1761594, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2935045,int_stack+2921329,int_stack+2931157, 1.0, int_stack+2943470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5471561, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8006893,int_stack+2935045,int_stack+7993285, 1.0, int_stack+3119950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5607919, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8016973,int_stack+8006893,int_stack+7999333, 1.0, int_stack+3125998, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5613967, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3119950,int_stack+644950,int_stack+642970, 1.0, int_stack+1512554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1765194, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7993285,int_stack+3119950,int_stack+2921329, 1.0, int_stack+3133558, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2254459, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2921329,int_stack+7993285,int_stack+2935045, 1.0, int_stack+3138418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5621527, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3119950,int_stack+2921329,int_stack+8006893, 1.0, int_stack+3146194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5629303, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2921329,int_stack+3119950,int_stack+8016973, 1.0, int_stack+3156274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5639383, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+2921329,int_stack+2843629,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+2893546,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+578286,int_stack+7993285,int_stack+538596,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+650476,int_stack+648271, 1.0, int_stack+647326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+827151, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+653356,int_stack+650476, 1.0, int_stack+649216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+830301, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 1.0, int_stack+3167614, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2346040, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+657001,int_stack+653356, 1.0, int_stack+651736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+834441, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 1.0, int_stack+3170449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2176451, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 1.0, int_stack+3174229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2348875, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+661501,int_stack+657001, 1.0, int_stack+654976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+839706, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2893546,int_stack+538596,int_stack+550881, 1.0, int_stack+3357370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2354545, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2903266,int_stack+2893546,int_stack+555741, 1.0, int_stack+3362230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5825359, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+2903266,int_stack+563301, 1.0, int_stack+3369790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5832919, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3357370,int_stack+663976,int_stack+661501, 1.0, int_stack+659026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+843756, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3364795,int_stack+3357370,int_stack+538596, 1.0, int_stack+3379240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2458972, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+3364795,int_stack+2893546, 1.0, int_stack+3385315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5842369, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3357370,int_stack+558846,int_stack+2903266, 1.0, int_stack+3395035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5852089, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2893546,int_stack+3357370,int_stack+544671, 1.0, int_stack+3407635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5864689, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3357370,int_stack+2893546,int_stack+2921329,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2709967,int_stack+3357370,int_stack+342792,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+10065103,int_stack+2709967,int_stack+7993285,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+667261,int_stack+666946, 1.0, int_stack+1537241, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1721726, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+667681,int_stack+667261, 1.0, int_stack+1537556, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1722041, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285, 1.0, int_stack+3421810, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5315158, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+668221,int_stack+667681, 1.0, int_stack+1537976, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1722461, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230, 1.0, int_stack+3422755, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5316103, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490, 1.0, int_stack+3424015, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5317363, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+668896,int_stack+668221, 1.0, int_stack+1538516, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1723001, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380, 1.0, int_stack+3425905, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5319253, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000, 1.0, int_stack+3427525, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5320873, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520, 1.0, int_stack+3430045, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5323393, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+669721,int_stack+668896, 1.0, int_stack+1539191, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1723676, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285, 1.0, int_stack+3433195, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1998755, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670, 1.0, int_stack+3435220, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5326543, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910, 1.0, int_stack+3438460, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5329783, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310, 1.0, int_stack+3442660, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2000780, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+671152,int_stack+670711, 1.0, int_stack+1544771, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1729256, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+671740,int_stack+671152, 1.0, int_stack+1545212, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1729697, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 1.0, int_stack+3447385, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5340598, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+672496,int_stack+671740, 1.0, int_stack+1545800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1730285, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 1.0, int_stack+3448708, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5341921, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8012950,int_stack+8001286,int_stack+7996372, 1.0, int_stack+3450472, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5343685, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+673441,int_stack+672496, 1.0, int_stack+1546556, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1731041, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8017360,int_stack+7993285,int_stack+7999018, 1.0, int_stack+3460300, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5346331, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8021896,int_stack+8017360,int_stack+8001286, 1.0, int_stack+3462568, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5348599, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8021896,int_stack+8012950, 1.0, int_stack+3466096, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5352127, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8012950,int_stack+674596,int_stack+673441, 1.0, int_stack+1547501, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1731986, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3460300,int_stack+8012950,int_stack+7993285, 1.0, int_stack+3179899, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5073247, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8027776,int_stack+3460300,int_stack+8017360, 1.0, int_stack+3470506, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2049905, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3460300,int_stack+8027776,int_stack+8021896, 1.0, int_stack+3475042, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5356537, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3469120,int_stack+3460300,int_stack+7996120, 1.0, int_stack+3480922, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5362417, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+8012950,int_stack+3469120,int_stack+8006335,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3460300,int_stack+676570,int_stack+675982, 1.0, int_stack+1555313, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1739798, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3462064,int_stack+677354,int_stack+676570, 1.0, int_stack+1555901, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1740386, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3464416,int_stack+3462064,int_stack+3460300, 1.0, int_stack+3487537, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2054441, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3478381,int_stack+678362,int_stack+677354, 1.0, int_stack+1556685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1741170, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3481405,int_stack+3478381,int_stack+3462064, 1.0, int_stack+3489301, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2062820, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7993285,int_stack+3481405,int_stack+3464416, 1.0, int_stack+3491653, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2065172, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3460300,int_stack+679622,int_stack+678362, 1.0, int_stack+1557693, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1742178, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3486109,int_stack+3460300,int_stack+3478381, 1.0, int_stack+3525463, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2068700, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7999165,int_stack+3486109,int_stack+3481405, 1.0, int_stack+3528487, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5398138, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8032795,int_stack+7999165,int_stack+7993285, 1.0, int_stack+3533191, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5402842, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+7993285,int_stack+681162,int_stack+679622, 1.0, int_stack+1558953, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1743438, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3525463,int_stack+7993285,int_stack+3460300, 1.0, int_stack+3539071, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2128697, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2709967,int_stack+3525463,int_stack+3486109, 1.0, int_stack+3542851, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5408722, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3525463,int_stack+2709967,int_stack+7999165, 1.0, int_stack+3548899, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5414770, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2709967,int_stack+3525463,int_stack+8032795, 1.0, int_stack+3556739, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5422610, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3525463,int_stack+2709967,int_stack+3469120,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+3525463,int_stack+8012950,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3553246,int_stack+683766,int_stack+683010, 1.0, int_stack+1569369, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1754610, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3555514,int_stack+684774,int_stack+683766, 1.0, int_stack+1570125, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1756374, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3558538,int_stack+3555514,int_stack+3553246, 1.0, int_stack+3565559, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2166623, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3563074,int_stack+686070,int_stack+684774, 1.0, int_stack+1571133, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1758678, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2722315,int_stack+3563074,int_stack+3555514, 1.0, int_stack+3567827, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2168891, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2728363,int_stack+2722315,int_stack+3558538, 1.0, int_stack+3570851, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2171915, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3553246,int_stack+687690,int_stack+686070, 1.0, int_stack+1572429, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1761594, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3566962,int_stack+3553246,int_stack+3563074, 1.0, int_stack+3575387, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5471561, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2735923,int_stack+3566962,int_stack+2722315, 1.0, int_stack+3754702, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5607919, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2746003,int_stack+2735923,int_stack+2728363, 1.0, int_stack+3760750, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5613967, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3754702,int_stack+689670,int_stack+687690, 1.0, int_stack+1574049, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1765194, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2722315,int_stack+3754702,int_stack+3553246, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2254459, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3553246,int_stack+2722315,int_stack+3566962, 1.0, int_stack+3768310, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5621527, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3566206,int_stack+3553246,int_stack+2735923, 1.0, int_stack+3776086, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5629303, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2722315,int_stack+3566206,int_stack+2746003, 1.0, int_stack+3786166, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5639383, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+2722315,int_stack+2709967,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+3525463,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+2738191,int_stack+7993285,int_stack+538596,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+695196,int_stack+692991, 1.0, int_stack+692046, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+827151, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+698076,int_stack+695196, 1.0, int_stack+693936, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+830301, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 1.0, int_stack+3797506, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2346040, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+701721,int_stack+698076, 1.0, int_stack+696456, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+834441, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+550881,int_stack+0,int_stack+541431, 1.0, int_stack+3800341, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2176451, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+558441,int_stack+550881,int_stack+545211, 1.0, int_stack+3804121, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2348875, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+706221,int_stack+701721, 1.0, int_stack+699696, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+839706, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+567891,int_stack+538596,int_stack+0, 1.0, int_stack+3987262, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2354545, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3525463,int_stack+567891,int_stack+550881, 1.0, int_stack+3992122, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5825359, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3538063,int_stack+3525463,int_stack+558441, 1.0, int_stack+3999682, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5832919, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+3987262,int_stack+708696,int_stack+706221, 1.0, int_stack+703746, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+843756, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3994687,int_stack+3987262,int_stack+538596, 1.0, int_stack+4009132, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2458972, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+538596,int_stack+3994687,int_stack+567891, 1.0, int_stack+4015207, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5842369, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+554796,int_stack+538596,int_stack+3525463, 1.0, int_stack+4024927, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5852089, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3987262,int_stack+554796,int_stack+3538063, 1.0, int_stack+4037527, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5864689, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3525463,int_stack+3987262,int_stack+2722315,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3357370,int_stack+3525463,int_stack+342792,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+10157713,int_stack+3357370,int_stack+7993285,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+711981,int_stack+711666, 1.0, int_stack+1598736, 0.0, zero_stack, 1.0, int_stack+1721726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+712401,int_stack+711981, 1.0, int_stack+1599051, 0.0, zero_stack, 1.0, int_stack+1722041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285, 1.0, int_stack+4051702, 0.0, zero_stack, 1.0, int_stack+5315158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+712941,int_stack+712401, 1.0, int_stack+1599471, 0.0, zero_stack, 1.0, int_stack+1722461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230, 1.0, int_stack+4052647, 0.0, zero_stack, 1.0, int_stack+5316103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490, 1.0, int_stack+4053907, 0.0, zero_stack, 1.0, int_stack+5317363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+713616,int_stack+712941, 1.0, int_stack+1600011, 0.0, zero_stack, 1.0, int_stack+1723001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380, 1.0, int_stack+4055797, 0.0, zero_stack, 1.0, int_stack+5319253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000, 1.0, int_stack+4057417, 0.0, zero_stack, 1.0, int_stack+5320873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520, 1.0, int_stack+4059937, 0.0, zero_stack, 1.0, int_stack+5323393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+714441,int_stack+713616, 1.0, int_stack+1600686, 0.0, zero_stack, 1.0, int_stack+1723676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285, 1.0, int_stack+4063087, 0.0, zero_stack, 1.0, int_stack+1998755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670, 1.0, int_stack+4065112, 0.0, zero_stack, 1.0, int_stack+5326543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910, 1.0, int_stack+4068352, 0.0, zero_stack, 1.0, int_stack+5329783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310, 1.0, int_stack+4072552, 0.0, zero_stack, 1.0, int_stack+2000780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+715872,int_stack+715431, 1.0, int_stack+1606266, 0.0, zero_stack, 1.0, int_stack+1729256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+716460,int_stack+715872, 1.0, int_stack+1606707, 0.0, zero_stack, 1.0, int_stack+1729697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 1.0, int_stack+4077277, 0.0, zero_stack, 1.0, int_stack+5340598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+717216,int_stack+716460, 1.0, int_stack+1607295, 0.0, zero_stack, 1.0, int_stack+1730285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 1.0, int_stack+4078600, 0.0, zero_stack, 1.0, int_stack+5341921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8012950,int_stack+8001286,int_stack+7996372, 1.0, int_stack+4080364, 0.0, zero_stack, 1.0, int_stack+5343685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+718161,int_stack+717216, 1.0, int_stack+1608051, 0.0, zero_stack, 1.0, int_stack+1731041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8017360,int_stack+7993285,int_stack+7999018, 1.0, int_stack+4083010, 0.0, zero_stack, 1.0, int_stack+5346331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8021896,int_stack+8017360,int_stack+8001286, 1.0, int_stack+4085278, 0.0, zero_stack, 1.0, int_stack+5348599, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8021896,int_stack+8012950, 1.0, int_stack+4095592, 0.0, zero_stack, 1.0, int_stack+5352127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4095592,int_stack+719316,int_stack+718161, 1.0, int_stack+1608996, 0.0, zero_stack, 1.0, int_stack+1731986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8027776,int_stack+4095592,int_stack+7993285, 1.0, int_stack+3809791, 0.0, zero_stack, 1.0, int_stack+5073247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8033446,int_stack+8027776,int_stack+8017360, 1.0, int_stack+4100002, 0.0, zero_stack, 1.0, int_stack+2049905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4095592,int_stack+8033446,int_stack+8021896, 1.0, int_stack+4104538, 0.0, zero_stack, 1.0, int_stack+5356537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8012950,int_stack+4095592,int_stack+7996120, 1.0, int_stack+4110418, 0.0, zero_stack, 1.0, int_stack+5362417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+4095592,int_stack+8012950,int_stack+8006335,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+721290,int_stack+720702, 1.0, int_stack+1616808, 0.0, zero_stack, 1.0, int_stack+1739798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7995049,int_stack+722074,int_stack+721290, 1.0, int_stack+1617396, 0.0, zero_stack, 1.0, int_stack+1740386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7997401,int_stack+7995049,int_stack+7993285, 1.0, int_stack+4146139, 0.0, zero_stack, 1.0, int_stack+2054441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8000929,int_stack+723082,int_stack+722074, 1.0, int_stack+1618180, 0.0, zero_stack, 1.0, int_stack+1741170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8003953,int_stack+8000929,int_stack+7995049, 1.0, int_stack+4147903, 0.0, zero_stack, 1.0, int_stack+2062820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8022211,int_stack+8003953,int_stack+7997401, 1.0, int_stack+4150255, 0.0, zero_stack, 1.0, int_stack+2065172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4146139,int_stack+724342,int_stack+723082, 1.0, int_stack+1619188, 0.0, zero_stack, 1.0, int_stack+1742178, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7993285,int_stack+4146139,int_stack+8000929, 1.0, int_stack+4153783, 0.0, zero_stack, 1.0, int_stack+2068700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8028091,int_stack+7993285,int_stack+8003953, 1.0, int_stack+4156807, 0.0, zero_stack, 1.0, int_stack+5398138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4149919,int_stack+8028091,int_stack+8022211, 1.0, int_stack+4161511, 0.0, zero_stack, 1.0, int_stack+5402842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8022211,int_stack+725882,int_stack+724342, 1.0, int_stack+1620448, 0.0, zero_stack, 1.0, int_stack+1743438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4158739,int_stack+8022211,int_stack+4146139, 1.0, int_stack+4167391, 0.0, zero_stack, 1.0, int_stack+2128697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+7999333,int_stack+4158739,int_stack+7993285, 1.0, int_stack+4171171, 0.0, zero_stack, 1.0, int_stack+5408722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4158739,int_stack+7999333,int_stack+8028091, 1.0, int_stack+4177219, 0.0, zero_stack, 1.0, int_stack+5414770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+7993285,int_stack+4158739,int_stack+4149919, 1.0, int_stack+4185059, 0.0, zero_stack, 1.0, int_stack+5422610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+4146139,int_stack+7993285,int_stack+8012950,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+4146139,int_stack+4095592,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4095592,int_stack+728486,int_stack+727730, 1.0, int_stack+1630864, 0.0, zero_stack, 1.0, int_stack+1754610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4097860,int_stack+729494,int_stack+728486, 1.0, int_stack+1631620, 0.0, zero_stack, 1.0, int_stack+1756374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4100884,int_stack+4097860,int_stack+4095592, 1.0, int_stack+4193879, 0.0, zero_stack, 1.0, int_stack+2166623, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4105420,int_stack+730790,int_stack+729494, 1.0, int_stack+1632628, 0.0, zero_stack, 1.0, int_stack+1758678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4109308,int_stack+4105420,int_stack+4097860, 1.0, int_stack+4196147, 0.0, zero_stack, 1.0, int_stack+2168891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8005633,int_stack+4109308,int_stack+4100884, 1.0, int_stack+4199171, 0.0, zero_stack, 1.0, int_stack+2171915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+732410,int_stack+730790, 1.0, int_stack+1633924, 0.0, zero_stack, 1.0, int_stack+1761594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4095592,int_stack+0,int_stack+4105420, 1.0, int_stack+4203707, 0.0, zero_stack, 1.0, int_stack+5471561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8013193,int_stack+4095592,int_stack+4109308, 1.0, int_stack+4384594, 0.0, zero_stack, 1.0, int_stack+5607919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4103368,int_stack+8013193,int_stack+8005633, 1.0, int_stack+4390642, 0.0, zero_stack, 1.0, int_stack+5613967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8005633,int_stack+734390,int_stack+732410, 1.0, int_stack+1635544, 0.0, zero_stack, 1.0, int_stack+1765194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4384594,int_stack+8005633,int_stack+0, 1.0, int_stack+4398202, 0.0, zero_stack, 1.0, int_stack+2254459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8023273,int_stack+4384594,int_stack+4095592, 1.0, int_stack+4403062, 0.0, zero_stack, 1.0, int_stack+5621527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4384594,int_stack+8023273,int_stack+8013193, 1.0, int_stack+4410838, 0.0, zero_stack, 1.0, int_stack+5629303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4399714,int_stack+4384594,int_stack+4103368, 1.0, int_stack+4420918, 0.0, zero_stack, 1.0, int_stack+5639383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+4399714,int_stack+7993285,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+4146139,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+3357370,int_stack+7993285,int_stack+538596,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+739916,int_stack+737711, 1.0, int_stack+736766, 0.0, zero_stack, 1.0, int_stack+827151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+742796,int_stack+739916, 1.0, int_stack+738656, 0.0, zero_stack, 1.0, int_stack+830301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 1.0, int_stack+4432258, 0.0, zero_stack, 1.0, int_stack+2346040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+746441,int_stack+742796, 1.0, int_stack+741176, 0.0, zero_stack, 1.0, int_stack+834441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+550881,int_stack+0,int_stack+541431, 1.0, int_stack+4435093, 0.0, zero_stack, 1.0, int_stack+2176451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+558441,int_stack+550881,int_stack+545211, 1.0, int_stack+4438873, 0.0, zero_stack, 1.0, int_stack+2348875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+750941,int_stack+746441, 1.0, int_stack+744416, 0.0, zero_stack, 1.0, int_stack+839706, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+567891,int_stack+538596,int_stack+0, 1.0, int_stack+4622014, 0.0, zero_stack, 1.0, int_stack+2354545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4146139,int_stack+567891,int_stack+550881, 1.0, int_stack+4626874, 0.0, zero_stack, 1.0, int_stack+5825359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4158739,int_stack+4146139,int_stack+558441, 1.0, int_stack+4634434, 0.0, zero_stack, 1.0, int_stack+5832919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+4622014,int_stack+753416,int_stack+750941, 1.0, int_stack+748466, 0.0, zero_stack, 1.0, int_stack+843756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4629439,int_stack+4622014,int_stack+538596, 1.0, int_stack+4643884, 0.0, zero_stack, 1.0, int_stack+2458972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+538596,int_stack+4629439,int_stack+567891, 1.0, int_stack+4649959, 0.0, zero_stack, 1.0, int_stack+5842369, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+554796,int_stack+538596,int_stack+4146139, 1.0, int_stack+4659679, 0.0, zero_stack, 1.0, int_stack+5852089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4622014,int_stack+554796,int_stack+4158739, 1.0, int_stack+4672279, 0.0, zero_stack, 1.0, int_stack+5864689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+4146139,int_stack+4622014,int_stack+4399714,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3987262,int_stack+4146139,int_stack+342792,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+644436,int_stack+3987262,int_stack+7993285,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+756701,int_stack+756386, 1.0, int_stack+1660231, 1.0, int_stack+1721726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+757121,int_stack+756701, 1.0, int_stack+1660546, 1.0, int_stack+1722041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285, 1.0, int_stack+4686454, 1.0, int_stack+5315158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+757661,int_stack+757121, 1.0, int_stack+1660966, 1.0, int_stack+1722461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230, 1.0, int_stack+4687399, 1.0, int_stack+5316103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490, 1.0, int_stack+4688659, 1.0, int_stack+5317363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+758336,int_stack+757661, 1.0, int_stack+1661506, 1.0, int_stack+1723001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380, 1.0, int_stack+4690549, 1.0, int_stack+5319253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000, 1.0, int_stack+4692169, 1.0, int_stack+5320873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520, 1.0, int_stack+4694689, 1.0, int_stack+5323393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+759161,int_stack+758336, 1.0, int_stack+1662181, 1.0, int_stack+1723676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285, 1.0, int_stack+4697839, 1.0, int_stack+1998755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670, 1.0, int_stack+4699864, 1.0, int_stack+5326543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910, 1.0, int_stack+4703104, 1.0, int_stack+5329783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310, 1.0, int_stack+4707304, 1.0, int_stack+2000780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+760592,int_stack+760151, 1.0, int_stack+1667761, 1.0, int_stack+1729256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+761180,int_stack+760592, 1.0, int_stack+1668202, 1.0, int_stack+1729697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 1.0, int_stack+4712029, 1.0, int_stack+5340598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+761936,int_stack+761180, 1.0, int_stack+1668790, 1.0, int_stack+1730285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 1.0, int_stack+4713352, 1.0, int_stack+5341921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8012950,int_stack+8001286,int_stack+7996372, 1.0, int_stack+4715116, 1.0, int_stack+5343685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+762881,int_stack+761936, 1.0, int_stack+1669546, 1.0, int_stack+1731041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8017360,int_stack+7993285,int_stack+7999018, 1.0, int_stack+4724944, 1.0, int_stack+5346331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8021896,int_stack+8017360,int_stack+8001286, 1.0, int_stack+4727212, 1.0, int_stack+5348599, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8021896,int_stack+8012950, 1.0, int_stack+4730740, 1.0, int_stack+5352127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8012950,int_stack+764036,int_stack+762881, 1.0, int_stack+1670491, 1.0, int_stack+1731986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4724944,int_stack+8012950,int_stack+7993285, 1.0, int_stack+4444543, 1.0, int_stack+5073247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8027776,int_stack+4724944,int_stack+8017360, 1.0, int_stack+4735150, 1.0, int_stack+2049905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4724944,int_stack+8027776,int_stack+8021896, 1.0, int_stack+4739686, 1.0, int_stack+5356537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4733764,int_stack+4724944,int_stack+7996120, 1.0, int_stack+4745566, 1.0, int_stack+5362417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+8012950,int_stack+4733764,int_stack+8006335,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4724944,int_stack+766010,int_stack+765422, 1.0, int_stack+1678303, 1.0, int_stack+1739798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4726708,int_stack+766794,int_stack+766010, 1.0, int_stack+1678891, 1.0, int_stack+1740386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4729060,int_stack+4726708,int_stack+4724944, 1.0, int_stack+4752181, 1.0, int_stack+2054441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4743025,int_stack+767802,int_stack+766794, 1.0, int_stack+1679675, 1.0, int_stack+1741170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+4746049,int_stack+4743025,int_stack+4726708, 1.0, int_stack+4753945, 1.0, int_stack+2062820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7993285,int_stack+4746049,int_stack+4729060, 1.0, int_stack+4756297, 1.0, int_stack+2065172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+4724944,int_stack+769062,int_stack+767802, 1.0, int_stack+1680683, 1.0, int_stack+1742178, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4750753,int_stack+4724944,int_stack+4743025, 1.0, int_stack+4790107, 1.0, int_stack+2068700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7999165,int_stack+4750753,int_stack+4746049, 1.0, int_stack+4793131, 1.0, int_stack+5398138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8032795,int_stack+7999165,int_stack+7993285, 1.0, int_stack+4797835, 1.0, int_stack+5402842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+7993285,int_stack+770602,int_stack+769062, 1.0, int_stack+1681943, 1.0, int_stack+1743438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+4790107,int_stack+7993285,int_stack+4724944, 1.0, int_stack+4803715, 1.0, int_stack+2128697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3987262,int_stack+4790107,int_stack+4750753, 1.0, int_stack+4807495, 1.0, int_stack+5408722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+4790107,int_stack+3987262,int_stack+7999165, 1.0, int_stack+4813543, 1.0, int_stack+5414770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3987262,int_stack+4790107,int_stack+8032795, 1.0, int_stack+4821383, 1.0, int_stack+5422610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+4790107,int_stack+3987262,int_stack+4733764,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+4790107,int_stack+8012950,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4817890,int_stack+773206,int_stack+772450, 1.0, int_stack+1692359, 1.0, int_stack+1754610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4820158,int_stack+774214,int_stack+773206, 1.0, int_stack+1693115, 1.0, int_stack+1756374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4823182,int_stack+4820158,int_stack+4817890, 1.0, int_stack+4830203, 1.0, int_stack+2166623, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+4827718,int_stack+775510,int_stack+774214, 1.0, int_stack+1694123, 1.0, int_stack+1758678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3999610,int_stack+4827718,int_stack+4820158, 1.0, int_stack+4832471, 1.0, int_stack+2168891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+4005658,int_stack+3999610,int_stack+4823182, 1.0, int_stack+4835495, 1.0, int_stack+2171915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+777130,int_stack+775510, 1.0, int_stack+1695419, 1.0, int_stack+1761594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4817890,int_stack+0,int_stack+4827718, 1.0, int_stack+4840031, 1.0, int_stack+5471561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4825666,int_stack+4817890,int_stack+3999610, 1.0, int_stack+4860, 1.0, int_stack+5607919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+4013218,int_stack+4825666,int_stack+4005658, 1.0, int_stack+5019346, 1.0, int_stack+5613967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5019346,int_stack+779110,int_stack+777130, 1.0, int_stack+1697039, 1.0, int_stack+1765194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3999610,int_stack+5019346,int_stack+0, 1.0, int_stack+5026906, 1.0, int_stack+2254459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4024558,int_stack+3999610,int_stack+4817890, 1.0, int_stack+5031766, 1.0, int_stack+5621527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5019346,int_stack+4024558,int_stack+4825666, 1.0, int_stack+5039542, 1.0, int_stack+5629303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4024558,int_stack+5019346,int_stack+4013218, 1.0, int_stack+5049622, 1.0, int_stack+5639383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+4024558,int_stack+3987262,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+4790107,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+4622014,int_stack+7993285,int_stack+538596,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+784636,int_stack+782431, 1.0, int_stack+781486, 1.0, int_stack+827151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+787516,int_stack+784636, 1.0, int_stack+783376, 1.0, int_stack+830301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 1.0, int_stack+5060962, 1.0, int_stack+2346040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+791161,int_stack+787516, 1.0, int_stack+785896, 1.0, int_stack+834441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 1.0, int_stack+5063797, 1.0, int_stack+2176451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 1.0, int_stack+5067577, 1.0, int_stack+2348875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+795661,int_stack+791161, 1.0, int_stack+789136, 1.0, int_stack+839706, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4790107,int_stack+538596,int_stack+550881, 1.0, int_stack+5250718, 1.0, int_stack+2354545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4799827,int_stack+4790107,int_stack+555741, 1.0, int_stack+5255578, 1.0, int_stack+5825359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+4799827,int_stack+563301, 1.0, int_stack+5263138, 1.0, int_stack+5832919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5250718,int_stack+798136,int_stack+795661, 1.0, int_stack+793186, 1.0, int_stack+843756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5258143,int_stack+5250718,int_stack+538596, 1.0, int_stack+5272588, 1.0, int_stack+2458972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+5258143,int_stack+4790107, 1.0, int_stack+5278663, 1.0, int_stack+5842369, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5250718,int_stack+558846,int_stack+4799827, 1.0, int_stack+5288383, 1.0, int_stack+5852089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+4790107,int_stack+5250718,int_stack+544671, 1.0, int_stack+5300983, 1.0, int_stack+5864689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+5250718,int_stack+4790107,int_stack+4024558,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3987262,int_stack+5250718,int_stack+342792,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+10250323,int_stack+3987262,int_stack+7993285,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+801421,int_stack+801106, 2.0, int_stack+1721726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+801841,int_stack+801421, 2.0, int_stack+1722041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285, 2.0, int_stack+5315158, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+802381,int_stack+801841, 2.0, int_stack+1722461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230, 2.0, int_stack+5316103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490, 2.0, int_stack+5317363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+803056,int_stack+802381, 2.0, int_stack+1723001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380, 2.0, int_stack+5319253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000, 2.0, int_stack+5320873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520, 2.0, int_stack+5323393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+803881,int_stack+803056, 2.0, int_stack+1723676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285, 2.0, int_stack+1998755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670, 2.0, int_stack+5326543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910, 2.0, int_stack+5329783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310, 2.0, int_stack+2000780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1998755,int_stack+805312,int_stack+804871, 2.0, int_stack+1729256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2000078,int_stack+805900,int_stack+805312, 2.0, int_stack+1729697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2001842,int_stack+2000078,int_stack+1998755, 2.0, int_stack+5340598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7993285,int_stack+806656,int_stack+805900, 2.0, int_stack+1730285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7995553,int_stack+7993285,int_stack+2000078, 2.0, int_stack+5341921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7999081,int_stack+7995553,int_stack+2001842, 2.0, int_stack+5343685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5340598,int_stack+807601,int_stack+806656, 2.0, int_stack+1731041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1998755,int_stack+5340598,int_stack+7993285, 2.0, int_stack+5346331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8012950,int_stack+1998755,int_stack+7995553, 2.0, int_stack+5348599, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5343433,int_stack+8012950,int_stack+7999081, 2.0, int_stack+5352127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+7993285,int_stack+808756,int_stack+807601, 2.0, int_stack+1731986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7996750,int_stack+7993285,int_stack+5340598, 2.0, int_stack+5073247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8018830,int_stack+7996750,int_stack+1998755, 2.0, int_stack+2049905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+7993285,int_stack+8018830,int_stack+8012950, 2.0, int_stack+5356537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8012950,int_stack+7993285,int_stack+5343433, 2.0, int_stack+5362417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+8022211,int_stack+8012950,int_stack+8006335,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+810730,int_stack+810142, 2.0, int_stack+1739798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7995049,int_stack+811514,int_stack+810730, 2.0, int_stack+1740386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7997401,int_stack+7995049,int_stack+7993285, 2.0, int_stack+2054441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8000929,int_stack+812522,int_stack+811514, 2.0, int_stack+1741170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8003953,int_stack+8000929,int_stack+7995049, 2.0, int_stack+2062820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8042056,int_stack+8003953,int_stack+7997401, 2.0, int_stack+2065172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2062820,int_stack+813782,int_stack+812522, 2.0, int_stack+1742178, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7993285,int_stack+2062820,int_stack+8000929, 2.0, int_stack+2068700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5340598,int_stack+7993285,int_stack+8003953, 2.0, int_stack+5398138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7999333,int_stack+5340598,int_stack+8042056, 2.0, int_stack+5402842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8042056,int_stack+815322,int_stack+813782, 2.0, int_stack+1743438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5398138,int_stack+8042056,int_stack+2062820, 2.0, int_stack+2128697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5348438,int_stack+5398138,int_stack+7993285, 2.0, int_stack+5408722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5398138,int_stack+5348438,int_stack+5340598, 2.0, int_stack+5414770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5340598,int_stack+5398138,int_stack+7999333, 2.0, int_stack+5422610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+5398138,int_stack+5340598,int_stack+8012950,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+5398138,int_stack+8022211,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5425921,int_stack+817926,int_stack+817170, 2.0, int_stack+1754610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5428189,int_stack+818934,int_stack+817926, 2.0, int_stack+1756374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5352946,int_stack+5428189,int_stack+5425921, 2.0, int_stack+2166623, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5357482,int_stack+820230,int_stack+818934, 2.0, int_stack+1758678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5361370,int_stack+5357482,int_stack+5428189, 2.0, int_stack+2168891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7993285,int_stack+5361370,int_stack+5352946, 2.0, int_stack+2171915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2166623,int_stack+821850,int_stack+820230, 2.0, int_stack+1761594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8000845,int_stack+2166623,int_stack+5357482, 2.0, int_stack+5471561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8008621,int_stack+8000845,int_stack+5361370, 2.0, int_stack+5607919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5352946,int_stack+8008621,int_stack+7993285, 2.0, int_stack+5613967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+7993285,int_stack+823830,int_stack+821850, 2.0, int_stack+1765194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5607919,int_stack+7993285,int_stack+2166623, 2.0, int_stack+2254459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8018701,int_stack+5607919,int_stack+8000845, 2.0, int_stack+5621527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5607919,int_stack+8018701,int_stack+8008621, 2.0, int_stack+5629303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5623039,int_stack+5607919,int_stack+5352946, 2.0, int_stack+5639383, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+5623039,int_stack+5340598,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+5398138,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+3987262,int_stack+7993285,int_stack+538596,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+831561,int_stack+828096, 2.0, int_stack+827151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+836061,int_stack+831561, 2.0, int_stack+830301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 2.0, int_stack+2346040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+841731,int_stack+836061, 2.0, int_stack+834441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 2.0, int_stack+2176451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 2.0, int_stack+2348875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2346040,int_stack+846231,int_stack+841731, 2.0, int_stack+839706, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+538596,int_stack+2346040,int_stack+550881, 2.0, int_stack+2354545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5398138,int_stack+538596,int_stack+555741, 2.0, int_stack+5825359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+548316,int_stack+5398138,int_stack+563301, 2.0, int_stack+5832919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5825359,int_stack+848706,int_stack+846231, 2.0, int_stack+843756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+562491,int_stack+5825359,int_stack+2346040, 2.0, int_stack+2458972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+5825359,int_stack+562491,int_stack+538596, 2.0, int_stack+5842369, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5410738,int_stack+5825359,int_stack+5398138, 2.0, int_stack+5852089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5825359,int_stack+5410738,int_stack+548316, 2.0, int_stack+5864689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+5250718,int_stack+5825359,int_stack+5623039,441);
 /*--- compute (id|hh) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+737046,int_stack+5250718,int_stack+342792,441);
 /*--- compute (hf|hh) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+10342933,int_stack+737046,int_stack+7993285,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+851991,int_stack+851676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1798206,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+852411,int_stack+851991, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1798521,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+827151,int_stack+7994230,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+826206,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7995490,int_stack+852951,int_stack+852411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1798941,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+830301,int_stack+7995490,int_stack+7994230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829041,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7997110,int_stack+830301,int_stack+827151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2648728,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+853626,int_stack+852951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1799481,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+834441,int_stack+7993285,int_stack+7995490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+832821,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8000260,int_stack+834441,int_stack+830301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2650618,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8004460,int_stack+8000260,int_stack+7997110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2653138,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+830301,int_stack+854451,int_stack+853626, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800156,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7995310,int_stack+830301,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837681,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8009185,int_stack+7995310,int_stack+834441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2656288,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+7993285,int_stack+8009185,int_stack+8000260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2659528,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8009185,int_stack+7993285,int_stack+8004460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2663728,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+855882,int_stack+855441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1805736,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+856470,int_stack+855882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1806177,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5878864,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+857226,int_stack+856470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1806765,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880187,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8015800,int_stack+8001286,int_stack+7996372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5881951,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+858171,int_stack+857226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1807521,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8020210,int_stack+7993285,int_stack+7999018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2199194,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8024746,int_stack+8020210,int_stack+8001286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2201462,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8024746,int_stack+8015800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2668453,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8015800,int_stack+859326,int_stack+858171, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1808466,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8002735,int_stack+8015800,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2672863,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8030626,int_stack+8002735,int_stack+8020210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5988358,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8015800,int_stack+8030626,int_stack+8024746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5992894,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8024620,int_stack+8015800,int_stack+7996120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2692684,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+737046,int_stack+8024620,int_stack+8009185, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2056205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+861300,int_stack+860712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1816278,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7995049,int_stack+862084,int_stack+861300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1816866,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7997401,int_stack+7995049,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2699299,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8000929,int_stack+863092,int_stack+862084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1817650,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8003953,int_stack+8000929,int_stack+7995049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2701063,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8008657,int_stack+8003953,int_stack+7997401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2703415,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+864352,int_stack+863092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1818658,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8014537,int_stack+7993285,int_stack+8000929, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2706943,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8033881,int_stack+8014537,int_stack+8003953, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2080985,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7997065,int_stack+8033881,int_stack+8008657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2085689,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8005885,int_stack+865892,int_stack+864352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1819918,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+756891,int_stack+8005885,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2465047,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+764451,int_stack+756891,int_stack+8014537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2259319,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8005885,int_stack+764451,int_stack+8033881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2005505,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8033881,int_stack+8005885,int_stack+7997065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2013345,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+756891,int_stack+8033881,int_stack+8024620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2137517, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+756891,int_stack+737046, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2146778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+737046,int_stack+868496,int_stack+867740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1830334,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+739314,int_stack+869504,int_stack+868496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1831090,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+742338,int_stack+739314,int_stack+737046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6234751,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+746874,int_stack+870800,int_stack+869504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1832098,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+750762,int_stack+746874,int_stack+739314, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6237019,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+784674,int_stack+750762,int_stack+742338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6240043,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+737046,int_stack+872420,int_stack+870800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1833394,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+792234,int_stack+737046,int_stack+746874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6244579,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+800010,int_stack+792234,int_stack+750762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6248467,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+741906,int_stack+800010,int_stack+784674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10908,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+784674,int_stack+874400,int_stack+872420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1835014,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+810090,int_stack+784674,int_stack+737046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2132477,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+7993285,int_stack+810090,int_stack+792234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6336412,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+810090,int_stack+7993285,int_stack+800010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6344188,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+7993285,int_stack+810090,int_stack+741906, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6354268,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+7993285,int_stack+8033881, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2266219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+6093190,int_stack+342792,int_stack+756891, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2278567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+737046,int_stack+6093190,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2306350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+877721,int_stack+876776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058751,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+878981,int_stack+877721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060641,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1948304,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+880601,int_stack+878981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1063161,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1951139,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6540244,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+882626,int_stack+880601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1066401,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8009161,int_stack+538596,int_stack+550881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1932491,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8018881,int_stack+8009161,int_stack+555741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6545914,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+8018881,int_stack+563301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6553474,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+885101,int_stack+882626, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1070451,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8031481,int_stack+558846,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6562924,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+8031481,int_stack+8009161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6568999,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+803196,int_stack+558846,int_stack+8018881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6578719,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8009161,int_stack+803196,int_stack+544671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6591319,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+5250718,int_stack+8009161,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2474092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+10435543,int_stack+5250718,int_stack+342792, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2489968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+10509631,int_stack+10435543,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2527012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+888386,int_stack+888071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1798206, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094135,int_stack+888806,int_stack+888386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1798521, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+827151,int_stack+6094135,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+826206, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6095395,int_stack+889346,int_stack+888806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1798941, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+830301,int_stack+6095395,int_stack+6094135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829041, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6097015,int_stack+830301,int_stack+827151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2648728, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+890021,int_stack+889346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1799481, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+834441,int_stack+6093190,int_stack+6095395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+832821, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6100165,int_stack+834441,int_stack+830301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2650618, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6104365,int_stack+6100165,int_stack+6097015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2653138, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+830301,int_stack+890846,int_stack+890021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800156, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6095215,int_stack+830301,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837681, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6109090,int_stack+6095215,int_stack+834441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2656288, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6093190,int_stack+6109090,int_stack+6100165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2659528, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6109090,int_stack+6093190,int_stack+6104365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2663728, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+892277,int_stack+891836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1805736, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094513,int_stack+892865,int_stack+892277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1806177, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6096277,int_stack+6094513,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5878864, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6098923,int_stack+893621,int_stack+892865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1806765, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6101191,int_stack+6098923,int_stack+6094513, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880187, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6115705,int_stack+6101191,int_stack+6096277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5881951, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+894566,int_stack+893621, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1807521, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6120115,int_stack+6093190,int_stack+6098923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2199194, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6124651,int_stack+6120115,int_stack+6101191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2201462, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096025,int_stack+6124651,int_stack+6115705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2668453, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6115705,int_stack+895721,int_stack+894566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1808466, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6102640,int_stack+6115705,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2672863, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6130531,int_stack+6102640,int_stack+6120115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5988358, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6115705,int_stack+6130531,int_stack+6124651, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5992894, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6124525,int_stack+6115705,int_stack+6096025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2692684, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+10435543,int_stack+6124525,int_stack+6109090, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2818933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+897695,int_stack+897107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1816278, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094954,int_stack+898479,int_stack+897695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1816866, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6097306,int_stack+6094954,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2699299, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6100834,int_stack+899487,int_stack+898479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1817650, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6103858,int_stack+6100834,int_stack+6094954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2701063, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6108562,int_stack+6103858,int_stack+6097306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2703415, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+900747,int_stack+899487, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1818658, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6114442,int_stack+6093190,int_stack+6100834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2706943, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6133786,int_stack+6114442,int_stack+6103858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2080985, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096970,int_stack+6133786,int_stack+6108562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2085689, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6105790,int_stack+902287,int_stack+900747, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1819918, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+10455388,int_stack+6105790,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2465047, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10462948,int_stack+10455388,int_stack+6114442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2259319, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6105790,int_stack+10462948,int_stack+6133786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2005505, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6133786,int_stack+6105790,int_stack+6096970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2013345, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+10455388,int_stack+6133786,int_stack+6124525, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2864440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+10455388,int_stack+10435543, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2873701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10435543,int_stack+904891,int_stack+904135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1830334, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10437811,int_stack+905899,int_stack+904891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1831090, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10440835,int_stack+10437811,int_stack+10435543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6234751, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+10445371,int_stack+907195,int_stack+905899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1832098, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+10449259,int_stack+10445371,int_stack+10437811, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6237019, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10483171,int_stack+10449259,int_stack+10440835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6240043, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+10435543,int_stack+908815,int_stack+907195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1833394, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10490731,int_stack+10435543,int_stack+10445371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6244579, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+10498507,int_stack+10490731,int_stack+10449259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6248467, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+10440403,int_stack+10498507,int_stack+10483171, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10908, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+10483171,int_stack+910795,int_stack+908815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1835014, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6093190,int_stack+10483171,int_stack+10435543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2132477, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6102910,int_stack+6093190,int_stack+10490731, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6336412, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+10483171,int_stack+6102910,int_stack+10498507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6344188, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6093190,int_stack+10483171,int_stack+10440403, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6354268, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+6093190,int_stack+6133786, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3040129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+10455388, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3052477, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+10435543,int_stack+7993285,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3080260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+914116,int_stack+913171, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058751, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+915376,int_stack+914116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060641, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1948304, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+916996,int_stack+915376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1063161, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1951139, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6540244, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+919021,int_stack+916996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1066401, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6109066,int_stack+538596,int_stack+550881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1932491, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6118786,int_stack+6109066,int_stack+555741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6545914, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+6118786,int_stack+563301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6553474, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+921496,int_stack+919021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1070451, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6131386,int_stack+558846,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6562924, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+6131386,int_stack+6109066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6568999, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5250718,int_stack+558846,int_stack+6118786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6578719, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6109066,int_stack+5250718,int_stack+544671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6591319, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+5250718,int_stack+6109066,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3182734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+839706,int_stack+5250718,int_stack+342792, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3198610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+10602241,int_stack+839706,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3235654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+924781,int_stack+924466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1798206, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+925201,int_stack+924781, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1798521, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+827151,int_stack+7994230,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+826206, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7995490,int_stack+925741,int_stack+925201, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1798941, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+830301,int_stack+7995490,int_stack+7994230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829041, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7997110,int_stack+830301,int_stack+827151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2648728, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+926416,int_stack+925741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1799481, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+834441,int_stack+7993285,int_stack+7995490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+832821, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8000260,int_stack+834441,int_stack+830301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2650618, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8004460,int_stack+8000260,int_stack+7997110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2653138, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+830301,int_stack+927241,int_stack+926416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800156, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7995310,int_stack+830301,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837681, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8009185,int_stack+7995310,int_stack+834441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2656288, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+7993285,int_stack+8009185,int_stack+8000260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2659528, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8009185,int_stack+7993285,int_stack+8004460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2663728, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+928672,int_stack+928231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1805736, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+929260,int_stack+928672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1806177, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5878864, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+930016,int_stack+929260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1806765, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880187, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8015800,int_stack+8001286,int_stack+7996372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5881951, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+930961,int_stack+930016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1807521, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8020210,int_stack+7993285,int_stack+7999018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2199194, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8024746,int_stack+8020210,int_stack+8001286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2201462, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8024746,int_stack+8015800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2668453, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8015800,int_stack+932116,int_stack+930961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1808466, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8002735,int_stack+8015800,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2672863, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8030626,int_stack+8002735,int_stack+8020210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5988358, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8015800,int_stack+8030626,int_stack+8024746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5992894, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8024620,int_stack+8015800,int_stack+7996120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2692684, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+839706,int_stack+8024620,int_stack+8009185, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3453685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+934090,int_stack+933502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1816278, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7995049,int_stack+934874,int_stack+934090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1816866, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7997401,int_stack+7995049,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2699299, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8000929,int_stack+935882,int_stack+934874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1817650, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8003953,int_stack+8000929,int_stack+7995049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2701063, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8008657,int_stack+8003953,int_stack+7997401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2703415, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+937142,int_stack+935882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1818658, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8014537,int_stack+7993285,int_stack+8000929, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2706943, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8033881,int_stack+8014537,int_stack+8003953, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2080985, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7997065,int_stack+8033881,int_stack+8008657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2085689, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8005885,int_stack+938682,int_stack+937142, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1819918, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+859551,int_stack+8005885,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2465047, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+867111,int_stack+859551,int_stack+8014537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2259319, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8005885,int_stack+867111,int_stack+8033881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2005505, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8033881,int_stack+8005885,int_stack+7997065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2013345, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+859551,int_stack+8033881,int_stack+8024620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3496357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+859551,int_stack+839706, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3505618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+839706,int_stack+941286,int_stack+940530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1830334, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+841974,int_stack+942294,int_stack+941286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1831090, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+844998,int_stack+841974,int_stack+839706, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6234751, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+849534,int_stack+943590,int_stack+942294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1832098, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+853422,int_stack+849534,int_stack+841974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6237019, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+887334,int_stack+853422,int_stack+844998, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6240043, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+839706,int_stack+945210,int_stack+943590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1833394, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+894894,int_stack+839706,int_stack+849534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6244579, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+902670,int_stack+894894,int_stack+853422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6248467, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+844566,int_stack+902670,int_stack+887334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10908, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+887334,int_stack+947190,int_stack+945210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1835014, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+912750,int_stack+887334,int_stack+839706, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2132477, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+922470,int_stack+912750,int_stack+894894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6336412, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+887334,int_stack+922470,int_stack+902670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6344188, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+902454,int_stack+887334,int_stack+844566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6354268, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+902454,int_stack+8033881, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3674881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+859551, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3687229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+5250718,int_stack+7993285,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3715012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+950511,int_stack+949566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058751, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+951771,int_stack+950511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060641, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1948304, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+953391,int_stack+951771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1063161, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1951139, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6540244, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+955416,int_stack+953391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1066401, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+839706,int_stack+538596,int_stack+550881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1932491, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+849426,int_stack+839706,int_stack+555741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6545914, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+849426,int_stack+563301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6553474, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+957891,int_stack+955416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1070451, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+862026,int_stack+558846,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6562924, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+862026,int_stack+839706, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6568999, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+862026,int_stack+558846,int_stack+849426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6578719, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+839706,int_stack+862026,int_stack+544671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6591319, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+6093190,int_stack+839706,int_stack+902454, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3812626, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+839706,int_stack+6093190,int_stack+342792, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3828502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+10694851,int_stack+839706,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3865546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+961176,int_stack+960861, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1798206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+961596,int_stack+961176, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1798521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+827151,int_stack+7994230,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+826206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7995490,int_stack+962136,int_stack+961596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1798941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+830301,int_stack+7995490,int_stack+7994230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+829041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7997110,int_stack+830301,int_stack+827151, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2648728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+962811,int_stack+962136, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1799481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+834441,int_stack+7993285,int_stack+7995490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+832821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8000260,int_stack+834441,int_stack+830301, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2650618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8004460,int_stack+8000260,int_stack+7997110, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2653138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+830301,int_stack+963636,int_stack+962811, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7995310,int_stack+830301,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8009185,int_stack+7995310,int_stack+834441, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2656288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+7993285,int_stack+8009185,int_stack+8000260, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2659528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8009185,int_stack+7993285,int_stack+8004460, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2663728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+965067,int_stack+964626, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1805736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+965655,int_stack+965067, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1806177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5878864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+966411,int_stack+965655, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1806765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8015800,int_stack+8001286,int_stack+7996372, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5881951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+967356,int_stack+966411, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1807521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8020210,int_stack+7993285,int_stack+7999018, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2199194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8024746,int_stack+8020210,int_stack+8001286, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2201462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8024746,int_stack+8015800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2668453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8015800,int_stack+968511,int_stack+967356, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1808466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8002735,int_stack+8015800,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2672863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8030626,int_stack+8002735,int_stack+8020210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5988358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8015800,int_stack+8030626,int_stack+8024746, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5992894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8024620,int_stack+8015800,int_stack+7996120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2692684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+839706,int_stack+8024620,int_stack+8009185, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4088977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+970485,int_stack+969897, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1816278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7995049,int_stack+971269,int_stack+970485, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1816866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7997401,int_stack+7995049,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2699299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8000929,int_stack+972277,int_stack+971269, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1817650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8003953,int_stack+8000929,int_stack+7995049, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2701063, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8008657,int_stack+8003953,int_stack+7997401, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2703415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+973537,int_stack+972277, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1818658, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8014537,int_stack+7993285,int_stack+8000929, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2706943, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8033881,int_stack+8014537,int_stack+8003953, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2080985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7997065,int_stack+8033881,int_stack+8008657, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2085689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8005885,int_stack+975077,int_stack+973537, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1819918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+859551,int_stack+8005885,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2465047, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+867111,int_stack+859551,int_stack+8014537, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2259319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8005885,int_stack+867111,int_stack+8033881, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2005505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8033881,int_stack+8005885,int_stack+7997065, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2013345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+859551,int_stack+8033881,int_stack+8024620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4117033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+859551,int_stack+839706, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4126294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+839706,int_stack+977681,int_stack+976925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1830334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+841974,int_stack+978689,int_stack+977681, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1831090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+844998,int_stack+841974,int_stack+839706, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6234751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+849534,int_stack+979985,int_stack+978689, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1832098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+853422,int_stack+849534,int_stack+841974, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6237019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+887334,int_stack+853422,int_stack+844998, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6240043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+839706,int_stack+981605,int_stack+979985, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1833394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+894894,int_stack+839706,int_stack+849534, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6244579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+902670,int_stack+894894,int_stack+853422, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6248467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+844566,int_stack+902670,int_stack+887334, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+10908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+887334,int_stack+983585,int_stack+981605, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1835014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+912750,int_stack+887334,int_stack+839706, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2132477, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+922470,int_stack+912750,int_stack+894894, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6336412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+887334,int_stack+922470,int_stack+902670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6344188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+902454,int_stack+887334,int_stack+844566, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6354268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+902454,int_stack+8033881, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4304773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+859551, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4317121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+918330,int_stack+7993285,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4344904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+986906,int_stack+985961, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1058751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+988166,int_stack+986906, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1948304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+989786,int_stack+988166, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1063161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1951139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6540244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+991811,int_stack+989786, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1066401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+839706,int_stack+538596,int_stack+550881, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1932491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+849426,int_stack+839706,int_stack+555741, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6545914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+849426,int_stack+563301, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6553474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+994286,int_stack+991811, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1070451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+862026,int_stack+558846,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6562924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+862026,int_stack+839706, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6568999, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+862026,int_stack+558846,int_stack+849426, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6578719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+839706,int_stack+862026,int_stack+544671, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6591319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+6093190,int_stack+839706,int_stack+902454, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4447378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+839706,int_stack+6093190,int_stack+342792, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4463254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+10787461,int_stack+839706,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4500298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+997571,int_stack+997256, 0.0, zero_stack, 1.0, int_stack+1798206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+997991,int_stack+997571, 0.0, zero_stack, 1.0, int_stack+1798521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+827151,int_stack+7994230,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+826206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7995490,int_stack+998531,int_stack+997991, 0.0, zero_stack, 1.0, int_stack+1798941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+830301,int_stack+7995490,int_stack+7994230, 0.0, zero_stack, 1.0, int_stack+829041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7997110,int_stack+830301,int_stack+827151, 0.0, zero_stack, 1.0, int_stack+2648728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+999206,int_stack+998531, 0.0, zero_stack, 1.0, int_stack+1799481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+834441,int_stack+7993285,int_stack+7995490, 0.0, zero_stack, 1.0, int_stack+832821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8000260,int_stack+834441,int_stack+830301, 0.0, zero_stack, 1.0, int_stack+2650618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8004460,int_stack+8000260,int_stack+7997110, 0.0, zero_stack, 1.0, int_stack+2653138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+830301,int_stack+1000031,int_stack+999206, 0.0, zero_stack, 1.0, int_stack+1800156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7995310,int_stack+830301,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+837681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8009185,int_stack+7995310,int_stack+834441, 0.0, zero_stack, 1.0, int_stack+2656288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+7993285,int_stack+8009185,int_stack+8000260, 0.0, zero_stack, 1.0, int_stack+2659528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8009185,int_stack+7993285,int_stack+8004460, 0.0, zero_stack, 1.0, int_stack+2663728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1001462,int_stack+1001021, 0.0, zero_stack, 1.0, int_stack+1805736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+1002050,int_stack+1001462, 0.0, zero_stack, 1.0, int_stack+1806177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+5878864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+1002806,int_stack+1002050, 0.0, zero_stack, 1.0, int_stack+1806765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 0.0, zero_stack, 1.0, int_stack+5880187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8015800,int_stack+8001286,int_stack+7996372, 0.0, zero_stack, 1.0, int_stack+5881951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1003751,int_stack+1002806, 0.0, zero_stack, 1.0, int_stack+1807521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8020210,int_stack+7993285,int_stack+7999018, 0.0, zero_stack, 1.0, int_stack+2199194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8024746,int_stack+8020210,int_stack+8001286, 0.0, zero_stack, 1.0, int_stack+2201462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8024746,int_stack+8015800, 0.0, zero_stack, 1.0, int_stack+2668453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8015800,int_stack+1004906,int_stack+1003751, 0.0, zero_stack, 1.0, int_stack+1808466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8002735,int_stack+8015800,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+2672863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8030626,int_stack+8002735,int_stack+8020210, 0.0, zero_stack, 1.0, int_stack+5988358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8015800,int_stack+8030626,int_stack+8024746, 0.0, zero_stack, 1.0, int_stack+5992894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8024620,int_stack+8015800,int_stack+7996120, 0.0, zero_stack, 1.0, int_stack+2692684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+839706,int_stack+8024620,int_stack+8009185, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4718329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1006880,int_stack+1006292, 0.0, zero_stack, 1.0, int_stack+1816278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7995049,int_stack+1007664,int_stack+1006880, 0.0, zero_stack, 1.0, int_stack+1816866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7997401,int_stack+7995049,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+2699299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8000929,int_stack+1008672,int_stack+1007664, 0.0, zero_stack, 1.0, int_stack+1817650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8003953,int_stack+8000929,int_stack+7995049, 0.0, zero_stack, 1.0, int_stack+2701063, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8008657,int_stack+8003953,int_stack+7997401, 0.0, zero_stack, 1.0, int_stack+2703415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1009932,int_stack+1008672, 0.0, zero_stack, 1.0, int_stack+1818658, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8014537,int_stack+7993285,int_stack+8000929, 0.0, zero_stack, 1.0, int_stack+2706943, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8033881,int_stack+8014537,int_stack+8003953, 0.0, zero_stack, 1.0, int_stack+2080985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7997065,int_stack+8033881,int_stack+8008657, 0.0, zero_stack, 1.0, int_stack+2085689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8005885,int_stack+1011472,int_stack+1009932, 0.0, zero_stack, 1.0, int_stack+1819918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+859551,int_stack+8005885,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+2465047, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+867111,int_stack+859551,int_stack+8014537, 0.0, zero_stack, 1.0, int_stack+2259319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8005885,int_stack+867111,int_stack+8033881, 0.0, zero_stack, 1.0, int_stack+2005505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8033881,int_stack+8005885,int_stack+7997065, 0.0, zero_stack, 1.0, int_stack+2013345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+859551,int_stack+8033881,int_stack+8024620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4761001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+859551,int_stack+839706, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4770262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+839706,int_stack+1014076,int_stack+1013320, 0.0, zero_stack, 1.0, int_stack+1830334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+841974,int_stack+1015084,int_stack+1014076, 0.0, zero_stack, 1.0, int_stack+1831090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+844998,int_stack+841974,int_stack+839706, 0.0, zero_stack, 1.0, int_stack+6234751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+849534,int_stack+1016380,int_stack+1015084, 0.0, zero_stack, 1.0, int_stack+1832098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+853422,int_stack+849534,int_stack+841974, 0.0, zero_stack, 1.0, int_stack+6237019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+887334,int_stack+853422,int_stack+844998, 0.0, zero_stack, 1.0, int_stack+6240043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+839706,int_stack+1018000,int_stack+1016380, 0.0, zero_stack, 1.0, int_stack+1833394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+894894,int_stack+839706,int_stack+849534, 0.0, zero_stack, 1.0, int_stack+6244579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+902670,int_stack+894894,int_stack+853422, 0.0, zero_stack, 1.0, int_stack+6248467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+844566,int_stack+902670,int_stack+887334, 0.0, zero_stack, 1.0, int_stack+10908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+887334,int_stack+1019980,int_stack+1018000, 0.0, zero_stack, 1.0, int_stack+1835014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7993285,int_stack+887334,int_stack+839706, 0.0, zero_stack, 1.0, int_stack+2132477, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8003005,int_stack+7993285,int_stack+894894, 0.0, zero_stack, 1.0, int_stack+6336412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+887334,int_stack+8003005,int_stack+902670, 0.0, zero_stack, 1.0, int_stack+6344188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+902454,int_stack+887334,int_stack+844566, 0.0, zero_stack, 1.0, int_stack+6354268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+902454,int_stack+8033881, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4939525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+859551, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4951873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+10880071,int_stack+7993285,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4979656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1023301,int_stack+1022356, 0.0, zero_stack, 1.0, int_stack+1058751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1024561,int_stack+1023301, 0.0, zero_stack, 1.0, int_stack+1060641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 0.0, zero_stack, 1.0, int_stack+1948304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1026181,int_stack+1024561, 0.0, zero_stack, 1.0, int_stack+1063161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 0.0, zero_stack, 1.0, int_stack+1951139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 0.0, zero_stack, 1.0, int_stack+6540244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+1028206,int_stack+1026181, 0.0, zero_stack, 1.0, int_stack+1066401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+839706,int_stack+538596,int_stack+550881, 0.0, zero_stack, 1.0, int_stack+1932491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+849426,int_stack+839706,int_stack+555741, 0.0, zero_stack, 1.0, int_stack+6545914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+849426,int_stack+563301, 0.0, zero_stack, 1.0, int_stack+6553474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+1030681,int_stack+1028206, 0.0, zero_stack, 1.0, int_stack+1070451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+862026,int_stack+558846,int_stack+538596, 0.0, zero_stack, 1.0, int_stack+6562924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+862026,int_stack+839706, 0.0, zero_stack, 1.0, int_stack+6568999, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+862026,int_stack+558846,int_stack+849426, 0.0, zero_stack, 1.0, int_stack+6578719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+839706,int_stack+862026,int_stack+544671, 0.0, zero_stack, 1.0, int_stack+6591319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+6093190,int_stack+839706,int_stack+902454, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5076082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+839706,int_stack+6093190,int_stack+342792, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5091958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+10946221,int_stack+839706,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5129002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1033966,int_stack+1033651, 1.0, int_stack+1798206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+1034386,int_stack+1033966, 1.0, int_stack+1798521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+827151,int_stack+7994230,int_stack+7993285, 1.0, int_stack+826206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7995490,int_stack+1034926,int_stack+1034386, 1.0, int_stack+1798941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+830301,int_stack+7995490,int_stack+7994230, 1.0, int_stack+829041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7997110,int_stack+830301,int_stack+827151, 1.0, int_stack+2648728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1035601,int_stack+1034926, 1.0, int_stack+1799481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+834441,int_stack+7993285,int_stack+7995490, 1.0, int_stack+832821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8000260,int_stack+834441,int_stack+830301, 1.0, int_stack+2650618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8004460,int_stack+8000260,int_stack+7997110, 1.0, int_stack+2653138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2648728,int_stack+1036426,int_stack+1035601, 1.0, int_stack+1800156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2651203,int_stack+2648728,int_stack+7993285, 1.0, int_stack+837681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+837681,int_stack+2651203,int_stack+834441, 1.0, int_stack+2656288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+843081,int_stack+837681,int_stack+8000260, 1.0, int_stack+2659528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+849381,int_stack+843081,int_stack+8004460, 1.0, int_stack+2663728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+855996,int_stack+1037857,int_stack+1037416, 1.0, int_stack+1805736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+857319,int_stack+1038445,int_stack+1037857, 1.0, int_stack+1806177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+859083,int_stack+857319,int_stack+855996, 1.0, int_stack+5878864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+861729,int_stack+1039201,int_stack+1038445, 1.0, int_stack+1806765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+863997,int_stack+861729,int_stack+857319, 1.0, int_stack+5880187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+867525,int_stack+863997,int_stack+859083, 1.0, int_stack+5881951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+855996,int_stack+1040146,int_stack+1039201, 1.0, int_stack+1807521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+871935,int_stack+855996,int_stack+861729, 1.0, int_stack+2199194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+876471,int_stack+871935,int_stack+863997, 1.0, int_stack+2201462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2199194,int_stack+876471,int_stack+867525, 1.0, int_stack+2668453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2205809,int_stack+1041301,int_stack+1040146, 1.0, int_stack+1808466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2209274,int_stack+2205809,int_stack+855996, 1.0, int_stack+2672863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+855996,int_stack+2209274,int_stack+871935, 1.0, int_stack+5988358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+863556,int_stack+855996,int_stack+876471, 1.0, int_stack+5992894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+872376,int_stack+863556,int_stack+2199194, 1.0, int_stack+2692684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+2199194,int_stack+872376,int_stack+849381, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5333983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2219039,int_stack+1043275,int_stack+1042687, 1.0, int_stack+1816278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2220803,int_stack+1044059,int_stack+1043275, 1.0, int_stack+1816866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2223155,int_stack+2220803,int_stack+2219039, 1.0, int_stack+2699299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2226683,int_stack+1045067,int_stack+1044059, 1.0, int_stack+1817650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2229707,int_stack+2226683,int_stack+2220803, 1.0, int_stack+2701063, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2234411,int_stack+2229707,int_stack+2223155, 1.0, int_stack+2703415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2219039,int_stack+1046327,int_stack+1045067, 1.0, int_stack+1818658, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2240291,int_stack+2219039,int_stack+2226683, 1.0, int_stack+2706943, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2246339,int_stack+2240291,int_stack+2229707, 1.0, int_stack+2080985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2222819,int_stack+2246339,int_stack+2234411, 1.0, int_stack+2085689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2080985,int_stack+1047867,int_stack+1046327, 1.0, int_stack+1819918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2231639,int_stack+2080985,int_stack+2219039, 1.0, int_stack+2465047, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2080985,int_stack+2231639,int_stack+2240291, 1.0, int_stack+2259319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2231639,int_stack+2080985,int_stack+2246339, 1.0, int_stack+2005505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+2243399,int_stack+2231639,int_stack+2222819, 1.0, int_stack+2013345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+881637,int_stack+2243399,int_stack+872376, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5369032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+881637,int_stack+2199194, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5378293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2199194,int_stack+1050471,int_stack+1049715, 1.0, int_stack+1830334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2201462,int_stack+1051479,int_stack+1050471, 1.0, int_stack+1831090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2204486,int_stack+2201462,int_stack+2199194, 1.0, int_stack+6234751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2209022,int_stack+1052775,int_stack+1051479, 1.0, int_stack+1832098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2212910,int_stack+2209022,int_stack+2201462, 1.0, int_stack+6237019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2218958,int_stack+2212910,int_stack+2204486, 1.0, int_stack+6240043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6234751,int_stack+1054395,int_stack+1052775, 1.0, int_stack+1833394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2199194,int_stack+6234751,int_stack+2209022, 1.0, int_stack+6244579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2226518,int_stack+2199194,int_stack+2212910, 1.0, int_stack+6248467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6239611,int_stack+2226518,int_stack+2218958, 1.0, int_stack+10908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+2206970,int_stack+1056375,int_stack+1054395, 1.0, int_stack+1835014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+2212910,int_stack+2206970,int_stack+6234751, 1.0, int_stack+2132477, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+7993285,int_stack+2212910,int_stack+2199194, 1.0, int_stack+6336412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+2199194,int_stack+7993285,int_stack+2226518, 1.0, int_stack+6344188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+7993285,int_stack+2199194,int_stack+6239611, 1.0, int_stack+6354268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+7993285,int_stack+2243399, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5431430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+6093190,int_stack+342792,int_stack+881637, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5443778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+2199194,int_stack+6093190,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5568229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1061901,int_stack+1059696, 1.0, int_stack+1058751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1064781,int_stack+1061901, 1.0, int_stack+1060641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 1.0, int_stack+1948304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1068426,int_stack+1064781, 1.0, int_stack+1063161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 1.0, int_stack+1951139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 1.0, int_stack+6540244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1948304,int_stack+1072926,int_stack+1068426, 1.0, int_stack+1066401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+538596,int_stack+1948304,int_stack+550881, 1.0, int_stack+1932491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8009161,int_stack+538596,int_stack+555741, 1.0, int_stack+6545914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+548316,int_stack+8009161,int_stack+563301, 1.0, int_stack+6553474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6540244,int_stack+1075401,int_stack+1072926, 1.0, int_stack+1070451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6547669,int_stack+6540244,int_stack+1948304, 1.0, int_stack+6562924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8021761,int_stack+6547669,int_stack+538596, 1.0, int_stack+6568999, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6540244,int_stack+8021761,int_stack+8009161, 1.0, int_stack+6578719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8009161,int_stack+6540244,int_stack+548316, 1.0, int_stack+6591319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+6540244,int_stack+8009161,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5650723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2648728,int_stack+6540244,int_stack+342792, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5666599, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+984480,int_stack+2648728,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5703643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1078686,int_stack+1078371,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6094135,int_stack+1079106,int_stack+1078686,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6095395,int_stack+6094135,int_stack+6093190,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6097285,int_stack+1079646,int_stack+1079106,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6098905,int_stack+6097285,int_stack+6094135,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6101425,int_stack+6098905,int_stack+6095395,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1080321,int_stack+1079646,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6104575,int_stack+6093190,int_stack+6097285,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6107815,int_stack+6104575,int_stack+6098905,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6095215,int_stack+6107815,int_stack+6101425,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6099940,int_stack+1081146,int_stack+1080321,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6112015,int_stack+6099940,int_stack+6093190,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6116065,int_stack+6112015,int_stack+6104575,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6099940,int_stack+6116065,int_stack+6107815,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6106240,int_stack+6099940,int_stack+6095215,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1082577,int_stack+1082136,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6094513,int_stack+1083165,int_stack+1082577,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6096277,int_stack+6094513,int_stack+6093190,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6098923,int_stack+1083921,int_stack+1083165,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6101191,int_stack+6098923,int_stack+6094513,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6112855,int_stack+6101191,int_stack+6096277,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1084866,int_stack+1083921,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6117265,int_stack+6093190,int_stack+6098923,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6121801,int_stack+6117265,int_stack+6101191,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6096025,int_stack+6121801,int_stack+6112855,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6112855,int_stack+1086021,int_stack+1084866,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6127681,int_stack+6112855,int_stack+6093190,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6133351,int_stack+6127681,int_stack+6117265,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6112855,int_stack+6133351,int_stack+6121801,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6121675,int_stack+6112855,int_stack+6096025,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+2648728,int_stack+6121675,int_stack+6106240, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2192579, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1087995,int_stack+1087407,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6094954,int_stack+1088779,int_stack+1087995,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6097306,int_stack+6094954,int_stack+6093190,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6100834,int_stack+1089787,int_stack+1088779,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6103858,int_stack+6100834,int_stack+6094954,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6108562,int_stack+6103858,int_stack+6097306,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1091047,int_stack+1089787,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6114442,int_stack+6093190,int_stack+6100834,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6130936,int_stack+6114442,int_stack+6103858,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6096970,int_stack+6130936,int_stack+6108562,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6105790,int_stack+1092587,int_stack+1091047,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6138776,int_stack+6105790,int_stack+6093190,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2668573,int_stack+6138776,int_stack+6114442,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6105790,int_stack+2668573,int_stack+6130936,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6130936,int_stack+6105790,int_stack+6096970,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2668573,int_stack+6130936,int_stack+6121675, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2071724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+2668573,int_stack+2648728, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+6214906, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2648728,int_stack+1095191,int_stack+1094435,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2650996,int_stack+1096199,int_stack+1095191,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2654020,int_stack+2650996,int_stack+2648728,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2658556,int_stack+1097495,int_stack+1096199,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2662444,int_stack+2658556,int_stack+2650996,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2696356,int_stack+2662444,int_stack+2654020,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2648728,int_stack+1099115,int_stack+1097495,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2703916,int_stack+2648728,int_stack+2658556,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2711692,int_stack+2703916,int_stack+2662444,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+2653588,int_stack+2711692,int_stack+2696356,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2696356,int_stack+1101095,int_stack+1099115,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2721772,int_stack+2696356,int_stack+2648728,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6093190,int_stack+2721772,int_stack+2703916,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2721772,int_stack+6093190,int_stack+2711692,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6093190,int_stack+2721772,int_stack+2653588,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+6093190,int_stack+6130936, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+6256591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+2668573, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+6268939, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+2648728,int_stack+7993285,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+6296722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1104416,int_stack+1103471,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1105676,int_stack+1104416,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1107296,int_stack+1105676,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+1109321,int_stack+1107296,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6109066,int_stack+538596,int_stack+550881,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6118786,int_stack+6109066,int_stack+555741,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+6118786,int_stack+563301,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+1111796,int_stack+1109321,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6131386,int_stack+558846,int_stack+538596,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+6131386,int_stack+6109066,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2714878,int_stack+558846,int_stack+6118786,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6109066,int_stack+2714878,int_stack+544671,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+6540244,int_stack+6109066,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+6365608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+803196,int_stack+6540244,int_stack+342792, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+6381484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+11038831,int_stack+803196,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+6418528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1115081,int_stack+1114766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1859701,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+1115501,int_stack+1115081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1860016,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6605494,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+1116041,int_stack+1115501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1860436,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6606439,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6607699,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1116716,int_stack+1116041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1860976,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1759974,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6609589,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6612109,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+1117541,int_stack+1116716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1861651,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6615259,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6617284,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6620524,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6624724,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1118972,int_stack+1118531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1867231,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+1119560,int_stack+1118972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1867672,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2091569,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+1120316,int_stack+1119560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1868260,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6629449,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8012950,int_stack+8001286,int_stack+7996372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6631213,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1121261,int_stack+1120316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1869016,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8017360,int_stack+7993285,int_stack+7999018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6642364,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8021896,int_stack+8017360,int_stack+8001286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6644632,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8021896,int_stack+8012950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6648160,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8012950,int_stack+1122416,int_stack+1121261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1869961,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8027776,int_stack+8012950,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6652570,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8033446,int_stack+8027776,int_stack+8017360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6655405,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8012950,int_stack+8033446,int_stack+8021896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6659941,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8021770,int_stack+8012950,int_stack+7996120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6665821,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+803196,int_stack+8021770,int_stack+8006335, 0.0, zero_stack, 1.0, int_stack+2056205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1124390,int_stack+1123802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1877773,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7995049,int_stack+1125174,int_stack+1124390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1878361,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7997401,int_stack+7995049,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6672436,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8000929,int_stack+1126182,int_stack+1125174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1879145,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8003953,int_stack+8000929,int_stack+7995049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6674200,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8008657,int_stack+8003953,int_stack+7997401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6676552,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1127442,int_stack+1126182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1880153,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8014537,int_stack+7993285,int_stack+8000929, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6710362,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8031031,int_stack+8014537,int_stack+8003953, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6713386,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7997065,int_stack+8031031,int_stack+8008657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6718090,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8005885,int_stack+1128982,int_stack+1127442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1881413,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8038871,int_stack+8005885,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6723970,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+823041,int_stack+8038871,int_stack+8014537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6727750,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8005885,int_stack+823041,int_stack+8031031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6733798,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8031031,int_stack+8005885,int_stack+7997065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6741638,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+823041,int_stack+8031031,int_stack+8021770, 0.0, zero_stack, 1.0, int_stack+2137517, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+823041,int_stack+803196, 0.0, zero_stack, 1.0, int_stack+2146778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+803196,int_stack+1131586,int_stack+1130830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1891829,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+805464,int_stack+1132594,int_stack+1131586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1892585,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+808488,int_stack+805464,int_stack+803196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6750458,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+813024,int_stack+1133890,int_stack+1132594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1893593,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+816912,int_stack+813024,int_stack+805464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6752726,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+850824,int_stack+816912,int_stack+808488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6755750,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+803196,int_stack+1135510,int_stack+1133890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1894889,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+858384,int_stack+803196,int_stack+813024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6760286,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+866160,int_stack+858384,int_stack+816912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6938386,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+808056,int_stack+866160,int_stack+850824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6944434,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+850824,int_stack+1137490,int_stack+1135510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1896509,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+876240,int_stack+850824,int_stack+803196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6951994,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+885960,int_stack+876240,int_stack+858384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6956854,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+850824,int_stack+885960,int_stack+866160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6964630,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+865944,int_stack+850824,int_stack+808056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6974710,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+865944,int_stack+8031031, 0.0, zero_stack, 1.0, int_stack+2266219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+823041, 0.0, zero_stack, 1.0, int_stack+2278567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+11131441,int_stack+7993285,int_stack+538596, 0.0, zero_stack, 1.0, int_stack+2306350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1140811,int_stack+1139866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1321841,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1142071,int_stack+1140811, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323731,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6986050,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1143691,int_stack+1142071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1326251,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6988885,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6992665,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+1145716,int_stack+1143691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1329491,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+803196,int_stack+538596,int_stack+550881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7175806,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+812916,int_stack+803196,int_stack+555741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7180666,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+812916,int_stack+563301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7188226,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+1148191,int_stack+1145716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1333541,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+825516,int_stack+558846,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7197676,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+825516,int_stack+803196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7203751,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+825516,int_stack+558846,int_stack+812916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7213471,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+803196,int_stack+825516,int_stack+544671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7226071,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+6540244,int_stack+803196,int_stack+865944, 0.0, zero_stack, 1.0, int_stack+2474092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+803196,int_stack+6540244,int_stack+342792, 0.0, zero_stack, 1.0, int_stack+2489968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+11197591,int_stack+803196,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+2527012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1151476,int_stack+1151161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1859701, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+1151896,int_stack+1151476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1860016, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6605494, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+1152436,int_stack+1151896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1860436, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6606439, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6607699, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1153111,int_stack+1152436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1860976, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1759974, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6609589, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6612109, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+1153936,int_stack+1153111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1861651, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6615259, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6617284, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6620524, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6624724, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1155367,int_stack+1154926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1867231, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+1155955,int_stack+1155367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1867672, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2091569, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+1156711,int_stack+1155955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1868260, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6629449, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8012950,int_stack+8001286,int_stack+7996372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6631213, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1157656,int_stack+1156711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1869016, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8017360,int_stack+7993285,int_stack+7999018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6642364, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8021896,int_stack+8017360,int_stack+8001286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6644632, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8021896,int_stack+8012950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6648160, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8012950,int_stack+1158811,int_stack+1157656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1869961, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8027776,int_stack+8012950,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6652570, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8033446,int_stack+8027776,int_stack+8017360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6655405, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8012950,int_stack+8033446,int_stack+8021896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6659941, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8021770,int_stack+8012950,int_stack+7996120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6665821, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+803196,int_stack+8021770,int_stack+8006335, 0.0, zero_stack, 1.0, int_stack+2818933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1160785,int_stack+1160197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1877773, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7995049,int_stack+1161569,int_stack+1160785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1878361, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7997401,int_stack+7995049,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6672436, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8000929,int_stack+1162577,int_stack+1161569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1879145, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8003953,int_stack+8000929,int_stack+7995049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6674200, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8008657,int_stack+8003953,int_stack+7997401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6676552, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1163837,int_stack+1162577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1880153, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8014537,int_stack+7993285,int_stack+8000929, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6710362, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8031031,int_stack+8014537,int_stack+8003953, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6713386, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7997065,int_stack+8031031,int_stack+8008657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6718090, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8005885,int_stack+1165377,int_stack+1163837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1881413, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8038871,int_stack+8005885,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6723970, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+823041,int_stack+8038871,int_stack+8014537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6727750, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8005885,int_stack+823041,int_stack+8031031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6733798, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8031031,int_stack+8005885,int_stack+7997065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6741638, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+823041,int_stack+8031031,int_stack+8021770, 0.0, zero_stack, 1.0, int_stack+2864440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+823041,int_stack+803196, 0.0, zero_stack, 1.0, int_stack+2873701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+803196,int_stack+1167981,int_stack+1167225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1891829, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+805464,int_stack+1168989,int_stack+1167981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1892585, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+808488,int_stack+805464,int_stack+803196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6750458, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+813024,int_stack+1170285,int_stack+1168989, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1893593, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+816912,int_stack+813024,int_stack+805464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6752726, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+850824,int_stack+816912,int_stack+808488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6755750, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+803196,int_stack+1171905,int_stack+1170285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1894889, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+858384,int_stack+803196,int_stack+813024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6760286, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+866160,int_stack+858384,int_stack+816912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6938386, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+808056,int_stack+866160,int_stack+850824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6944434, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+850824,int_stack+1173885,int_stack+1171905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1896509, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+876240,int_stack+850824,int_stack+803196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6951994, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+885960,int_stack+876240,int_stack+858384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6956854, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+850824,int_stack+885960,int_stack+866160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6964630, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+865944,int_stack+850824,int_stack+808056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6974710, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+865944,int_stack+8031031, 0.0, zero_stack, 1.0, int_stack+3040129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+823041, 0.0, zero_stack, 1.0, int_stack+3052477, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1077090,int_stack+7993285,int_stack+538596, 0.0, zero_stack, 1.0, int_stack+3080260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1177206,int_stack+1176261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1321841, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1178466,int_stack+1177206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323731, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6986050, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1180086,int_stack+1178466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1326251, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6988885, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6992665, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+1182111,int_stack+1180086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1329491, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+803196,int_stack+538596,int_stack+550881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7175806, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+812916,int_stack+803196,int_stack+555741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7180666, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+812916,int_stack+563301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7188226, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+1184586,int_stack+1182111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1333541, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+825516,int_stack+558846,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7197676, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+825516,int_stack+803196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7203751, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+825516,int_stack+558846,int_stack+812916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7213471, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+803196,int_stack+825516,int_stack+544671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7226071, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+6540244,int_stack+803196,int_stack+865944, 0.0, zero_stack, 1.0, int_stack+3182734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+803196,int_stack+6540244,int_stack+342792, 0.0, zero_stack, 1.0, int_stack+3198610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+11290201,int_stack+803196,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+3235654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1187871,int_stack+1187556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1859701, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+1188291,int_stack+1187871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1860016, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6605494, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+1188831,int_stack+1188291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1860436, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6606439, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6607699, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1189506,int_stack+1188831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1860976, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1759974, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6609589, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6612109, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+1190331,int_stack+1189506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1861651, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6615259, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6617284, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6620524, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6624724, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1191762,int_stack+1191321, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1867231, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+1192350,int_stack+1191762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1867672, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2091569, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+1193106,int_stack+1192350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1868260, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6629449, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8012950,int_stack+8001286,int_stack+7996372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6631213, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1194051,int_stack+1193106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1869016, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8017360,int_stack+7993285,int_stack+7999018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6642364, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8021896,int_stack+8017360,int_stack+8001286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6644632, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8021896,int_stack+8012950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6648160, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8012950,int_stack+1195206,int_stack+1194051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1869961, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8027776,int_stack+8012950,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6652570, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8033446,int_stack+8027776,int_stack+8017360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6655405, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8012950,int_stack+8033446,int_stack+8021896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6659941, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8021770,int_stack+8012950,int_stack+7996120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6665821, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+803196,int_stack+8021770,int_stack+8006335, 0.0, zero_stack, 1.0, int_stack+3453685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1197180,int_stack+1196592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1877773, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7995049,int_stack+1197964,int_stack+1197180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1878361, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7997401,int_stack+7995049,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6672436, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8000929,int_stack+1198972,int_stack+1197964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1879145, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8003953,int_stack+8000929,int_stack+7995049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6674200, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8008657,int_stack+8003953,int_stack+7997401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6676552, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1200232,int_stack+1198972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1880153, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8014537,int_stack+7993285,int_stack+8000929, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6710362, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8031031,int_stack+8014537,int_stack+8003953, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6713386, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7997065,int_stack+8031031,int_stack+8008657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6718090, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8005885,int_stack+1201772,int_stack+1200232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1881413, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8038871,int_stack+8005885,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6723970, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+823041,int_stack+8038871,int_stack+8014537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6727750, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8005885,int_stack+823041,int_stack+8031031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6733798, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8031031,int_stack+8005885,int_stack+7997065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6741638, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+823041,int_stack+8031031,int_stack+8021770, 0.0, zero_stack, 1.0, int_stack+3496357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+823041,int_stack+803196, 0.0, zero_stack, 1.0, int_stack+3505618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+803196,int_stack+1204376,int_stack+1203620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1891829, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+805464,int_stack+1205384,int_stack+1204376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1892585, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+808488,int_stack+805464,int_stack+803196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6750458, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+813024,int_stack+1206680,int_stack+1205384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1893593, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+816912,int_stack+813024,int_stack+805464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6752726, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+850824,int_stack+816912,int_stack+808488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6755750, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+803196,int_stack+1208300,int_stack+1206680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1894889, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+858384,int_stack+803196,int_stack+813024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6760286, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+866160,int_stack+858384,int_stack+816912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6938386, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+808056,int_stack+866160,int_stack+850824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6944434, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+850824,int_stack+1210280,int_stack+1208300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1896509, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+876240,int_stack+850824,int_stack+803196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6951994, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+885960,int_stack+876240,int_stack+858384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6956854, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+850824,int_stack+885960,int_stack+866160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6964630, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+865944,int_stack+850824,int_stack+808056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6974710, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+865944,int_stack+8031031, 0.0, zero_stack, 1.0, int_stack+3674881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+823041, 0.0, zero_stack, 1.0, int_stack+3687229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1143240,int_stack+7993285,int_stack+538596, 0.0, zero_stack, 1.0, int_stack+3715012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1213601,int_stack+1212656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1321841, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1214861,int_stack+1213601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323731, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6986050, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1216481,int_stack+1214861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1326251, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6988885, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6992665, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+1218506,int_stack+1216481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1329491, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+803196,int_stack+538596,int_stack+550881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7175806, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+812916,int_stack+803196,int_stack+555741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7180666, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+812916,int_stack+563301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7188226, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+1220981,int_stack+1218506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1333541, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+825516,int_stack+558846,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7197676, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+825516,int_stack+803196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7203751, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+825516,int_stack+558846,int_stack+812916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7213471, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+803196,int_stack+825516,int_stack+544671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7226071, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+6540244,int_stack+803196,int_stack+865944, 0.0, zero_stack, 1.0, int_stack+3812626, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+803196,int_stack+6540244,int_stack+342792, 0.0, zero_stack, 1.0, int_stack+3828502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+11382811,int_stack+803196,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+3865546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1224266,int_stack+1223951, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1859701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+1224686,int_stack+1224266, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1860016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6605494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+1225226,int_stack+1224686, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1860436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6606439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6607699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1225901,int_stack+1225226, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1860976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1759974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6609589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6612109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+1226726,int_stack+1225901, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1861651, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6615259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6617284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6620524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6624724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1228157,int_stack+1227716, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1867231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+1228745,int_stack+1228157, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1867672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2091569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+1229501,int_stack+1228745, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1868260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6629449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8012950,int_stack+8001286,int_stack+7996372, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6631213, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1230446,int_stack+1229501, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1869016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8017360,int_stack+7993285,int_stack+7999018, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6642364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8021896,int_stack+8017360,int_stack+8001286, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6644632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8021896,int_stack+8012950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6648160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8012950,int_stack+1231601,int_stack+1230446, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1869961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8027776,int_stack+8012950,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6652570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8033446,int_stack+8027776,int_stack+8017360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6655405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8012950,int_stack+8033446,int_stack+8021896, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6659941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8021770,int_stack+8012950,int_stack+7996120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6665821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+803196,int_stack+8021770,int_stack+8006335, 0.0, zero_stack, 1.0, int_stack+4088977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1233575,int_stack+1232987, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1877773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7995049,int_stack+1234359,int_stack+1233575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1878361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7997401,int_stack+7995049,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6672436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8000929,int_stack+1235367,int_stack+1234359, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1879145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8003953,int_stack+8000929,int_stack+7995049, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6674200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8008657,int_stack+8003953,int_stack+7997401, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6676552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1236627,int_stack+1235367, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1880153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8014537,int_stack+7993285,int_stack+8000929, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6710362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8031031,int_stack+8014537,int_stack+8003953, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6713386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7997065,int_stack+8031031,int_stack+8008657, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6718090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8005885,int_stack+1238167,int_stack+1236627, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1881413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8038871,int_stack+8005885,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6723970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+823041,int_stack+8038871,int_stack+8014537, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6727750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8005885,int_stack+823041,int_stack+8031031, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6733798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8031031,int_stack+8005885,int_stack+7997065, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6741638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+823041,int_stack+8031031,int_stack+8021770, 0.0, zero_stack, 1.0, int_stack+4117033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+823041,int_stack+803196, 0.0, zero_stack, 1.0, int_stack+4126294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+803196,int_stack+1240771,int_stack+1240015, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1891829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+805464,int_stack+1241779,int_stack+1240771, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1892585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+808488,int_stack+805464,int_stack+803196, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6750458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+813024,int_stack+1243075,int_stack+1241779, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1893593, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+816912,int_stack+813024,int_stack+805464, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6752726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+850824,int_stack+816912,int_stack+808488, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6755750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+803196,int_stack+1244695,int_stack+1243075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1894889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+858384,int_stack+803196,int_stack+813024, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6760286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+866160,int_stack+858384,int_stack+816912, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6938386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+808056,int_stack+866160,int_stack+850824, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6944434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+850824,int_stack+1246675,int_stack+1244695, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1896509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+876240,int_stack+850824,int_stack+803196, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6951994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+885960,int_stack+876240,int_stack+858384, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6956854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+850824,int_stack+885960,int_stack+866160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6964630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+865944,int_stack+850824,int_stack+808056, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6974710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+865944,int_stack+8031031, 0.0, zero_stack, 1.0, int_stack+4304773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+823041, 0.0, zero_stack, 1.0, int_stack+4317121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+11475421,int_stack+7993285,int_stack+538596, 0.0, zero_stack, 1.0, int_stack+4344904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1249996,int_stack+1249051, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1321841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1251256,int_stack+1249996, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323731, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6986050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1252876,int_stack+1251256, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1326251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6988885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6992665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+1254901,int_stack+1252876, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1329491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+803196,int_stack+538596,int_stack+550881, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7175806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+812916,int_stack+803196,int_stack+555741, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7180666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+812916,int_stack+563301, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7188226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+1257376,int_stack+1254901, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1333541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+825516,int_stack+558846,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7197676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+825516,int_stack+803196, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7203751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+825516,int_stack+558846,int_stack+812916, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7213471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+803196,int_stack+825516,int_stack+544671, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7226071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+6540244,int_stack+803196,int_stack+865944, 0.0, zero_stack, 1.0, int_stack+4447378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+803196,int_stack+6540244,int_stack+342792, 0.0, zero_stack, 1.0, int_stack+4463254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+11541571,int_stack+803196,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+4500298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1260661,int_stack+1260346, 0.0, zero_stack, 1.0, int_stack+1859701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+1261081,int_stack+1260661, 0.0, zero_stack, 1.0, int_stack+1860016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+6605494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+1261621,int_stack+1261081, 0.0, zero_stack, 1.0, int_stack+1860436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230, 0.0, zero_stack, 1.0, int_stack+6606439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490, 0.0, zero_stack, 1.0, int_stack+6607699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1262296,int_stack+1261621, 0.0, zero_stack, 1.0, int_stack+1860976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380, 0.0, zero_stack, 1.0, int_stack+1759974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000, 0.0, zero_stack, 1.0, int_stack+6609589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520, 0.0, zero_stack, 1.0, int_stack+6612109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+1263121,int_stack+1262296, 0.0, zero_stack, 1.0, int_stack+1861651, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+6615259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670, 0.0, zero_stack, 1.0, int_stack+6617284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910, 0.0, zero_stack, 1.0, int_stack+6620524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310, 0.0, zero_stack, 1.0, int_stack+6624724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1264552,int_stack+1264111, 0.0, zero_stack, 1.0, int_stack+1867231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+1265140,int_stack+1264552, 0.0, zero_stack, 1.0, int_stack+1867672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+2091569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+1265896,int_stack+1265140, 0.0, zero_stack, 1.0, int_stack+1868260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 0.0, zero_stack, 1.0, int_stack+6629449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8012950,int_stack+8001286,int_stack+7996372, 0.0, zero_stack, 1.0, int_stack+6631213, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1266841,int_stack+1265896, 0.0, zero_stack, 1.0, int_stack+1869016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8017360,int_stack+7993285,int_stack+7999018, 0.0, zero_stack, 1.0, int_stack+6642364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8021896,int_stack+8017360,int_stack+8001286, 0.0, zero_stack, 1.0, int_stack+6644632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8021896,int_stack+8012950, 0.0, zero_stack, 1.0, int_stack+6648160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8012950,int_stack+1267996,int_stack+1266841, 0.0, zero_stack, 1.0, int_stack+1869961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8027776,int_stack+8012950,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+6652570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8033446,int_stack+8027776,int_stack+8017360, 0.0, zero_stack, 1.0, int_stack+6655405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8012950,int_stack+8033446,int_stack+8021896, 0.0, zero_stack, 1.0, int_stack+6659941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8021770,int_stack+8012950,int_stack+7996120, 0.0, zero_stack, 1.0, int_stack+6665821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+803196,int_stack+8021770,int_stack+8006335, 0.0, zero_stack, 1.0, int_stack+4718329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1269970,int_stack+1269382, 0.0, zero_stack, 1.0, int_stack+1877773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7995049,int_stack+1270754,int_stack+1269970, 0.0, zero_stack, 1.0, int_stack+1878361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7997401,int_stack+7995049,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+6672436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8000929,int_stack+1271762,int_stack+1270754, 0.0, zero_stack, 1.0, int_stack+1879145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8003953,int_stack+8000929,int_stack+7995049, 0.0, zero_stack, 1.0, int_stack+6674200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8008657,int_stack+8003953,int_stack+7997401, 0.0, zero_stack, 1.0, int_stack+6676552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1273022,int_stack+1271762, 0.0, zero_stack, 1.0, int_stack+1880153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8014537,int_stack+7993285,int_stack+8000929, 0.0, zero_stack, 1.0, int_stack+6710362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8031031,int_stack+8014537,int_stack+8003953, 0.0, zero_stack, 1.0, int_stack+6713386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7997065,int_stack+8031031,int_stack+8008657, 0.0, zero_stack, 1.0, int_stack+6718090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8005885,int_stack+1274562,int_stack+1273022, 0.0, zero_stack, 1.0, int_stack+1881413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8038871,int_stack+8005885,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+6723970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+823041,int_stack+8038871,int_stack+8014537, 0.0, zero_stack, 1.0, int_stack+6727750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8005885,int_stack+823041,int_stack+8031031, 0.0, zero_stack, 1.0, int_stack+6733798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8031031,int_stack+8005885,int_stack+7997065, 0.0, zero_stack, 1.0, int_stack+6741638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+823041,int_stack+8031031,int_stack+8021770, 0.0, zero_stack, 1.0, int_stack+4761001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+823041,int_stack+803196, 0.0, zero_stack, 1.0, int_stack+4770262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+803196,int_stack+1277166,int_stack+1276410, 0.0, zero_stack, 1.0, int_stack+1891829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+805464,int_stack+1278174,int_stack+1277166, 0.0, zero_stack, 1.0, int_stack+1892585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+808488,int_stack+805464,int_stack+803196, 0.0, zero_stack, 1.0, int_stack+6750458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+813024,int_stack+1279470,int_stack+1278174, 0.0, zero_stack, 1.0, int_stack+1893593, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+816912,int_stack+813024,int_stack+805464, 0.0, zero_stack, 1.0, int_stack+6752726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+850824,int_stack+816912,int_stack+808488, 0.0, zero_stack, 1.0, int_stack+6755750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+803196,int_stack+1281090,int_stack+1279470, 0.0, zero_stack, 1.0, int_stack+1894889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+858384,int_stack+803196,int_stack+813024, 0.0, zero_stack, 1.0, int_stack+6760286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+866160,int_stack+858384,int_stack+816912, 0.0, zero_stack, 1.0, int_stack+6938386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+808056,int_stack+866160,int_stack+850824, 0.0, zero_stack, 1.0, int_stack+6944434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+850824,int_stack+1283070,int_stack+1281090, 0.0, zero_stack, 1.0, int_stack+1896509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+876240,int_stack+850824,int_stack+803196, 0.0, zero_stack, 1.0, int_stack+6951994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+885960,int_stack+876240,int_stack+858384, 0.0, zero_stack, 1.0, int_stack+6956854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+850824,int_stack+885960,int_stack+866160, 0.0, zero_stack, 1.0, int_stack+6964630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+865944,int_stack+850824,int_stack+808056, 0.0, zero_stack, 1.0, int_stack+6974710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+865944,int_stack+8031031, 0.0, zero_stack, 1.0, int_stack+4939525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+823041, 0.0, zero_stack, 1.0, int_stack+4951873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1209390,int_stack+7993285,int_stack+538596, 0.0, zero_stack, 1.0, int_stack+4979656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1286391,int_stack+1285446, 0.0, zero_stack, 1.0, int_stack+1321841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1287651,int_stack+1286391, 0.0, zero_stack, 1.0, int_stack+1323731, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 0.0, zero_stack, 1.0, int_stack+6986050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1289271,int_stack+1287651, 0.0, zero_stack, 1.0, int_stack+1326251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 0.0, zero_stack, 1.0, int_stack+6988885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 0.0, zero_stack, 1.0, int_stack+6992665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+1291296,int_stack+1289271, 0.0, zero_stack, 1.0, int_stack+1329491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+803196,int_stack+538596,int_stack+550881, 0.0, zero_stack, 1.0, int_stack+7175806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+812916,int_stack+803196,int_stack+555741, 0.0, zero_stack, 1.0, int_stack+7180666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+812916,int_stack+563301, 0.0, zero_stack, 1.0, int_stack+7188226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+1293771,int_stack+1291296, 0.0, zero_stack, 1.0, int_stack+1333541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+825516,int_stack+558846,int_stack+538596, 0.0, zero_stack, 1.0, int_stack+7197676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+825516,int_stack+803196, 0.0, zero_stack, 1.0, int_stack+7203751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+825516,int_stack+558846,int_stack+812916, 0.0, zero_stack, 1.0, int_stack+7213471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+803196,int_stack+825516,int_stack+544671, 0.0, zero_stack, 1.0, int_stack+7226071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+6540244,int_stack+803196,int_stack+865944, 0.0, zero_stack, 1.0, int_stack+5076082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+803196,int_stack+6540244,int_stack+342792, 0.0, zero_stack, 1.0, int_stack+5091958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+11634181,int_stack+803196,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+5129002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1297056,int_stack+1296741, 1.0, int_stack+1859701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+1297476,int_stack+1297056, 1.0, int_stack+1860016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285, 1.0, int_stack+6605494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+1298016,int_stack+1297476, 1.0, int_stack+1860436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230, 1.0, int_stack+6606439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490, 1.0, int_stack+6607699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1298691,int_stack+1298016, 1.0, int_stack+1860976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380, 1.0, int_stack+1759974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000, 1.0, int_stack+6609589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520, 1.0, int_stack+6612109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+1299516,int_stack+1298691, 1.0, int_stack+1861651, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285, 1.0, int_stack+6615259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670, 1.0, int_stack+6617284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910, 1.0, int_stack+6620524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310, 1.0, int_stack+6624724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1300947,int_stack+1300506, 1.0, int_stack+1867231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+1301535,int_stack+1300947, 1.0, int_stack+1867672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 1.0, int_stack+2091569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+1302291,int_stack+1301535, 1.0, int_stack+1868260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 1.0, int_stack+6629449, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8012950,int_stack+8001286,int_stack+7996372, 1.0, int_stack+6631213, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1303236,int_stack+1302291, 1.0, int_stack+1869016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8017360,int_stack+7993285,int_stack+7999018, 1.0, int_stack+6642364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8021896,int_stack+8017360,int_stack+8001286, 1.0, int_stack+6644632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8021896,int_stack+8012950, 1.0, int_stack+6648160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8012950,int_stack+1304391,int_stack+1303236, 1.0, int_stack+1869961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6642364,int_stack+8012950,int_stack+7993285, 1.0, int_stack+6652570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8027776,int_stack+6642364,int_stack+8017360, 1.0, int_stack+6655405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6642364,int_stack+8027776,int_stack+8021896, 1.0, int_stack+6659941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6651184,int_stack+6642364,int_stack+7996120, 1.0, int_stack+6665821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+8012950,int_stack+6651184,int_stack+8006335, 0.0, zero_stack, 1.0, int_stack+5333983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6642364,int_stack+1306365,int_stack+1305777, 1.0, int_stack+1877773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6644128,int_stack+1307149,int_stack+1306365, 1.0, int_stack+1878361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6646480,int_stack+6644128,int_stack+6642364, 1.0, int_stack+6672436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6660445,int_stack+1308157,int_stack+1307149, 1.0, int_stack+1879145, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6663469,int_stack+6660445,int_stack+6644128, 1.0, int_stack+6674200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6668173,int_stack+6663469,int_stack+6646480, 1.0, int_stack+6676552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6642364,int_stack+1309417,int_stack+1308157, 1.0, int_stack+1880153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6674053,int_stack+6642364,int_stack+6660445, 1.0, int_stack+6710362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7993285,int_stack+6674053,int_stack+6663469, 1.0, int_stack+6713386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8001125,int_stack+7993285,int_stack+6668173, 1.0, int_stack+6718090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6710362,int_stack+1310957,int_stack+1309417, 1.0, int_stack+1881413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6714982,int_stack+6710362,int_stack+6642364, 1.0, int_stack+6723970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6660445,int_stack+6714982,int_stack+6674053, 1.0, int_stack+6727750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6710362,int_stack+6660445,int_stack+7993285, 1.0, int_stack+6733798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6660445,int_stack+6710362,int_stack+8001125, 1.0, int_stack+6741638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+6710362,int_stack+6660445,int_stack+6651184, 0.0, zero_stack, 1.0, int_stack+5369032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+6710362,int_stack+8012950, 0.0, zero_stack, 1.0, int_stack+5378293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6738145,int_stack+1313561,int_stack+1312805, 1.0, int_stack+1891829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6740413,int_stack+1314569,int_stack+1313561, 1.0, int_stack+1892585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6743437,int_stack+6740413,int_stack+6738145, 1.0, int_stack+6750458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6747973,int_stack+1315865,int_stack+1314569, 1.0, int_stack+1893593, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7993285,int_stack+6747973,int_stack+6740413, 1.0, int_stack+6752726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7999333,int_stack+7993285,int_stack+6743437, 1.0, int_stack+6755750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6738145,int_stack+1317485,int_stack+1315865, 1.0, int_stack+1894889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6751861,int_stack+6738145,int_stack+6747973, 1.0, int_stack+6760286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8006893,int_stack+6751861,int_stack+7993285, 1.0, int_stack+6938386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8016973,int_stack+8006893,int_stack+7999333, 1.0, int_stack+6944434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6938386,int_stack+1319465,int_stack+1317485, 1.0, int_stack+1896509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7993285,int_stack+6938386,int_stack+6738145, 1.0, int_stack+6951994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6738145,int_stack+7993285,int_stack+6751861, 1.0, int_stack+6956854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6938386,int_stack+6738145,int_stack+8006893, 1.0, int_stack+6964630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6738145,int_stack+6938386,int_stack+8016973, 1.0, int_stack+6974710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+6738145,int_stack+6660445, 0.0, zero_stack, 1.0, int_stack+5431430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+6710362, 0.0, zero_stack, 1.0, int_stack+5443778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+803196,int_stack+7993285,int_stack+538596, 0.0, zero_stack, 1.0, int_stack+5568229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1324991,int_stack+1322786, 1.0, int_stack+1321841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1327871,int_stack+1324991, 1.0, int_stack+1323731, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 1.0, int_stack+6986050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1331516,int_stack+1327871, 1.0, int_stack+1326251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 1.0, int_stack+6988885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 1.0, int_stack+6992665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+1336016,int_stack+1331516, 1.0, int_stack+1329491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6710362,int_stack+538596,int_stack+550881, 1.0, int_stack+7175806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6720082,int_stack+6710362,int_stack+555741, 1.0, int_stack+7180666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+6720082,int_stack+563301, 1.0, int_stack+7188226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+7175806,int_stack+1338491,int_stack+1336016, 1.0, int_stack+1333541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7183231,int_stack+7175806,int_stack+538596, 1.0, int_stack+7197676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+7183231,int_stack+6710362, 1.0, int_stack+7203751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+7175806,int_stack+558846,int_stack+6720082, 1.0, int_stack+7213471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6710362,int_stack+7175806,int_stack+544671, 1.0, int_stack+7226071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+7175806,int_stack+6710362,int_stack+6738145, 0.0, zero_stack, 1.0, int_stack+5650723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+6540244,int_stack+7175806,int_stack+342792, 0.0, zero_stack, 1.0, int_stack+5666599, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+11726791,int_stack+6540244,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+5703643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1341776,int_stack+1341461,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+1342196,int_stack+1341776,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+1342736,int_stack+1342196,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1343411,int_stack+1342736,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+1344236,int_stack+1343411,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1345667,int_stack+1345226,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+1346255,int_stack+1345667,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+1347011,int_stack+1346255,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+8012950,int_stack+8001286,int_stack+7996372,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1347956,int_stack+1347011,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+8017360,int_stack+7993285,int_stack+7999018,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+8021896,int_stack+8017360,int_stack+8001286,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8021896,int_stack+8012950,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+8012950,int_stack+1349111,int_stack+1347956,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+8027776,int_stack+8012950,int_stack+7993285,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+8033446,int_stack+8027776,int_stack+8017360,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+8012950,int_stack+8033446,int_stack+8021896,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+8021770,int_stack+8012950,int_stack+7996120,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+6540244,int_stack+8021770,int_stack+8006335, 0.0, zero_stack, 1.0, int_stack+2192579, 1.0, int_stack+6635749, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1351085,int_stack+1350497,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7995049,int_stack+1351869,int_stack+1351085,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7997401,int_stack+7995049,int_stack+7993285,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+8000929,int_stack+1352877,int_stack+1351869,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+8003953,int_stack+8000929,int_stack+7995049,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+8008657,int_stack+8003953,int_stack+7997401,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1354137,int_stack+1352877,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+8014537,int_stack+7993285,int_stack+8000929,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+8031031,int_stack+8014537,int_stack+8003953,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7997065,int_stack+8031031,int_stack+8008657,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+8005885,int_stack+1355677,int_stack+1354137,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+8038871,int_stack+8005885,int_stack+7993285,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6560089,int_stack+8038871,int_stack+8014537,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+8005885,int_stack+6560089,int_stack+8031031,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+8031031,int_stack+8005885,int_stack+7997065,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+6560089,int_stack+8031031,int_stack+8021770, 0.0, zero_stack, 1.0, int_stack+2071724, 1.0, int_stack+6681256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+6560089,int_stack+6540244, 0.0, zero_stack, 1.0, int_stack+6214906, 1.0, int_stack+6690517, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6540244,int_stack+1358281,int_stack+1357525,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6542512,int_stack+1359289,int_stack+1358281,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6545536,int_stack+6542512,int_stack+6540244,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6550072,int_stack+1360585,int_stack+1359289,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6553960,int_stack+6550072,int_stack+6542512,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6587872,int_stack+6553960,int_stack+6545536,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6540244,int_stack+1362205,int_stack+1360585,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6595432,int_stack+6540244,int_stack+6550072,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6603208,int_stack+6595432,int_stack+6553960,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6545104,int_stack+6603208,int_stack+6587872,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6587872,int_stack+1364185,int_stack+1362205,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6613288,int_stack+6587872,int_stack+6540244,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+7993285,int_stack+6613288,int_stack+6595432,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6613288,int_stack+7993285,int_stack+6603208,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+7993285,int_stack+6613288,int_stack+6545104,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+7993285,int_stack+8031031, 0.0, zero_stack, 1.0, int_stack+6256591, 1.0, int_stack+6858565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+6093190,int_stack+342792,int_stack+6560089, 0.0, zero_stack, 1.0, int_stack+6268939, 1.0, int_stack+6870913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+6540244,int_stack+6093190,int_stack+538596, 0.0, zero_stack, 1.0, int_stack+6296722, 1.0, int_stack+6898696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1367506,int_stack+1366561,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1368766,int_stack+1367506,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1370386,int_stack+1368766,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+1372411,int_stack+1370386,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+8009161,int_stack+538596,int_stack+550881,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+8018881,int_stack+8009161,int_stack+555741,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+8018881,int_stack+563301,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+1374886,int_stack+1372411,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+8031481,int_stack+558846,int_stack+538596,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+8031481,int_stack+8009161,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6606394,int_stack+558846,int_stack+8018881,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+8009161,int_stack+6606394,int_stack+544671,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+7175806,int_stack+8009161,int_stack+7993285, 0.0, zero_stack, 1.0, int_stack+6365608, 1.0, int_stack+7001170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1275540,int_stack+7175806,int_stack+342792, 0.0, zero_stack, 1.0, int_stack+6381484, 1.0, int_stack+7017046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+11819401,int_stack+1275540,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+6418528, 1.0, int_stack+7054090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1378171,int_stack+1377856,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6094135,int_stack+1378591,int_stack+1378171,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6095395,int_stack+6094135,int_stack+6093190,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6097285,int_stack+1379131,int_stack+1378591,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6098905,int_stack+6097285,int_stack+6094135,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6101425,int_stack+6098905,int_stack+6095395,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1379806,int_stack+1379131,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6104575,int_stack+6093190,int_stack+6097285,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6107815,int_stack+6104575,int_stack+6098905,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6095215,int_stack+6107815,int_stack+6101425,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6099940,int_stack+1380631,int_stack+1379806,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6112015,int_stack+6099940,int_stack+6093190,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6116065,int_stack+6112015,int_stack+6104575,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6099940,int_stack+6116065,int_stack+6107815,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6106240,int_stack+6099940,int_stack+6095215,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1382062,int_stack+1381621,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6094513,int_stack+1382650,int_stack+1382062,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6096277,int_stack+6094513,int_stack+6093190,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6098923,int_stack+1383406,int_stack+1382650,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6101191,int_stack+6098923,int_stack+6094513,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6112855,int_stack+6101191,int_stack+6096277,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1384351,int_stack+1383406,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6117265,int_stack+6093190,int_stack+6098923,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6121801,int_stack+6117265,int_stack+6101191,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6096025,int_stack+6121801,int_stack+6112855,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6112855,int_stack+1385506,int_stack+1384351,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6127681,int_stack+6112855,int_stack+6093190,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6133351,int_stack+6127681,int_stack+6117265,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6112855,int_stack+6133351,int_stack+6121801,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6121675,int_stack+6112855,int_stack+6096025,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+1275540,int_stack+6121675,int_stack+6106240, 0.0, zero_stack, 2.0, int_stack+6635749, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1387480,int_stack+1386892,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6094954,int_stack+1388264,int_stack+1387480,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6097306,int_stack+6094954,int_stack+6093190,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6100834,int_stack+1389272,int_stack+1388264,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6103858,int_stack+6100834,int_stack+6094954,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6108562,int_stack+6103858,int_stack+6097306,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1390532,int_stack+1389272,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6114442,int_stack+6093190,int_stack+6100834,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6130936,int_stack+6114442,int_stack+6103858,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6096970,int_stack+6130936,int_stack+6108562,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6105790,int_stack+1392072,int_stack+1390532,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6138776,int_stack+6105790,int_stack+6093190,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1295385,int_stack+6138776,int_stack+6114442,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6105790,int_stack+1295385,int_stack+6130936,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6130936,int_stack+6105790,int_stack+6096970,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1295385,int_stack+6130936,int_stack+6121675, 0.0, zero_stack, 2.0, int_stack+6681256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+1295385,int_stack+1275540, 0.0, zero_stack, 2.0, int_stack+6690517, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1275540,int_stack+1394676,int_stack+1393920,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1277808,int_stack+1395684,int_stack+1394676,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1280832,int_stack+1277808,int_stack+1275540,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1285368,int_stack+1396980,int_stack+1395684,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1289256,int_stack+1285368,int_stack+1277808,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1323168,int_stack+1289256,int_stack+1280832,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1275540,int_stack+1398600,int_stack+1396980,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1330728,int_stack+1275540,int_stack+1285368,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1338504,int_stack+1330728,int_stack+1289256,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1280400,int_stack+1338504,int_stack+1323168,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1323168,int_stack+1400580,int_stack+1398600,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1348584,int_stack+1323168,int_stack+1275540,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1358304,int_stack+1348584,int_stack+1330728,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1323168,int_stack+1358304,int_stack+1338504,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+1338288,int_stack+1323168,int_stack+1280400,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+1338288,int_stack+6130936, 0.0, zero_stack, 2.0, int_stack+6858565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+6093190,int_stack+342792,int_stack+1295385, 0.0, zero_stack, 2.0, int_stack+6870913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+11912011,int_stack+6093190,int_stack+538596, 0.0, zero_stack, 2.0, int_stack+6898696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1403901,int_stack+1402956,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1405161,int_stack+1403901,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1406781,int_stack+1405161,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+1408806,int_stack+1406781,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1275540,int_stack+538596,int_stack+550881,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1285260,int_stack+1275540,int_stack+555741,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+1285260,int_stack+563301,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+1411281,int_stack+1408806,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1297860,int_stack+558846,int_stack+538596,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+1297860,int_stack+1275540,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1297860,int_stack+558846,int_stack+1285260,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+1275540,int_stack+1297860,int_stack+544671,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1354164,int_stack+1275540,int_stack+1338288, 0.0, zero_stack, 2.0, int_stack+7001170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1275540,int_stack+1354164,int_stack+342792, 0.0, zero_stack, 2.0, int_stack+7017046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+11978161,int_stack+1275540,int_stack+6093190, 0.0, zero_stack, 2.0, int_stack+7054090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1418331,int_stack+1418016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1924961,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094135,int_stack+1418751,int_stack+1418331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1925276,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6095395,int_stack+6094135,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7240246,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6097285,int_stack+1419291,int_stack+1418751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1925696,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6098905,int_stack+6097285,int_stack+6094135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7241191,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6101425,int_stack+6098905,int_stack+6095395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6633859,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1419966,int_stack+1419291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1926236,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6104575,int_stack+6093190,int_stack+6097285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7242451,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6107815,int_stack+6104575,int_stack+6098905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7244071,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6095215,int_stack+6107815,int_stack+6101425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7246591,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6099940,int_stack+1420791,int_stack+1419966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1926911,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6112015,int_stack+6099940,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7249741,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6116065,int_stack+6112015,int_stack+6104575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7251766,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6099940,int_stack+6116065,int_stack+6107815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7255006,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6106240,int_stack+6099940,int_stack+6095215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7259206,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1427493,int_stack+1427052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1937762,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094513,int_stack+1428081,int_stack+1427493, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1938203,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6096277,int_stack+6094513,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7263931,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6098923,int_stack+1428837,int_stack+1428081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1938791,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6101191,int_stack+6098923,int_stack+6094513, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7265254,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6112855,int_stack+6101191,int_stack+6096277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7267018,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1429782,int_stack+1428837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1939547,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6117265,int_stack+6093190,int_stack+6098923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7276846,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6121801,int_stack+6117265,int_stack+6101191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7279114,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096025,int_stack+6121801,int_stack+6112855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7282642,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6112855,int_stack+1430937,int_stack+1429782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1940492,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6127681,int_stack+6112855,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6998335,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6133351,int_stack+6127681,int_stack+6117265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7287052,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6112855,int_stack+6133351,int_stack+6121801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7291588,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6121675,int_stack+6112855,int_stack+6096025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7297468,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+1275540,int_stack+6121675,int_stack+6106240, 1.0, int_stack+2056205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1439939,int_stack+1439351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1955332,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094954,int_stack+1440723,int_stack+1439939, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1955920,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6097306,int_stack+6094954,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7304083,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6100834,int_stack+1441731,int_stack+1440723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1956704,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6103858,int_stack+6100834,int_stack+6094954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7305847,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6108562,int_stack+6103858,int_stack+6097306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7308199,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1442991,int_stack+1441731, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1957712,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6114442,int_stack+6093190,int_stack+6100834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7342009,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6130936,int_stack+6114442,int_stack+6103858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7345033,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096970,int_stack+6130936,int_stack+6108562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7349737,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6105790,int_stack+1444531,int_stack+1442991, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1958972,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6138776,int_stack+6105790,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7355617,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1295385,int_stack+6138776,int_stack+6114442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7359397,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6105790,int_stack+1295385,int_stack+6130936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7365445,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6130936,int_stack+6105790,int_stack+6096970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7373285,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1295385,int_stack+6130936,int_stack+6121675, 1.0, int_stack+2137517, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+1295385,int_stack+1275540, 1.0, int_stack+2146778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1275540,int_stack+1456171,int_stack+1455415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1969388,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1277808,int_stack+1457179,int_stack+1456171, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1970144,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1280832,int_stack+1277808,int_stack+1275540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7382105,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1285368,int_stack+1458475,int_stack+1457179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1971152,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1289256,int_stack+1285368,int_stack+1277808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7384373,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1323168,int_stack+1289256,int_stack+1280832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7387397,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1275540,int_stack+1460095,int_stack+1458475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1972448,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1330728,int_stack+1275540,int_stack+1285368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7391933,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1338504,int_stack+1330728,int_stack+1289256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18468,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1280400,int_stack+1338504,int_stack+1323168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5884597,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1323168,int_stack+1462075,int_stack+1460095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1974068,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1348584,int_stack+1323168,int_stack+1275540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7395821,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1358304,int_stack+1348584,int_stack+1330728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5892157,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1323168,int_stack+1358304,int_stack+1338504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5899933,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1338288,int_stack+1323168,int_stack+1280400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7573138,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+1338288,int_stack+6130936, 1.0, int_stack+2266219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+6093190,int_stack+342792,int_stack+1295385, 1.0, int_stack+2278567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1354164,int_stack+6093190,int_stack+538596, 1.0, int_stack+2306350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1465396,int_stack+1464451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1778586,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1466656,int_stack+1465396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1780476,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2180231,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1468276,int_stack+1466656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1782996,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2183066,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2186846,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+1470301,int_stack+1468276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1786236,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1275540,int_stack+538596,int_stack+550881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5910013,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1285260,int_stack+1275540,int_stack+555741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5914873,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+1285260,int_stack+563301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5922433,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+1472776,int_stack+1470301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1790286,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1297860,int_stack+558846,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5931883,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+1297860,int_stack+1275540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5937958,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1297860,int_stack+558846,int_stack+1285260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5947678,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1275540,int_stack+1297860,int_stack+544671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5960278,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1420314,int_stack+1275540,int_stack+1338288, 1.0, int_stack+2474092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1275540,int_stack+1420314,int_stack+342792, 1.0, int_stack+2489968, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+2265344,int_stack+1275540,int_stack+6093190, 1.0, int_stack+2527012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1479826,int_stack+1479511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1924961, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094135,int_stack+1480246,int_stack+1479826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1925276, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6095395,int_stack+6094135,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7240246, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6097285,int_stack+1480786,int_stack+1480246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1925696, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6098905,int_stack+6097285,int_stack+6094135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7241191, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6101425,int_stack+6098905,int_stack+6095395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6633859, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1481461,int_stack+1480786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1926236, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6104575,int_stack+6093190,int_stack+6097285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7242451, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6107815,int_stack+6104575,int_stack+6098905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7244071, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6095215,int_stack+6107815,int_stack+6101425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7246591, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6099940,int_stack+1482286,int_stack+1481461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1926911, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6112015,int_stack+6099940,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7249741, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6116065,int_stack+6112015,int_stack+6104575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7251766, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6099940,int_stack+6116065,int_stack+6107815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7255006, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6106240,int_stack+6099940,int_stack+6095215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7259206, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1488988,int_stack+1488547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1937762, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094513,int_stack+1489576,int_stack+1488988, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1938203, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6096277,int_stack+6094513,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7263931, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6098923,int_stack+1490332,int_stack+1489576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1938791, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6101191,int_stack+6098923,int_stack+6094513, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7265254, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6112855,int_stack+6101191,int_stack+6096277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7267018, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1491277,int_stack+1490332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1939547, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6117265,int_stack+6093190,int_stack+6098923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7276846, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6121801,int_stack+6117265,int_stack+6101191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7279114, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096025,int_stack+6121801,int_stack+6112855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7282642, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6112855,int_stack+1492432,int_stack+1491277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1940492, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6127681,int_stack+6112855,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6998335, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6133351,int_stack+6127681,int_stack+6117265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7287052, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6112855,int_stack+6133351,int_stack+6121801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7291588, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6121675,int_stack+6112855,int_stack+6096025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7297468, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+1275540,int_stack+6121675,int_stack+6106240, 1.0, int_stack+2818933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1501434,int_stack+1500846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1955332, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094954,int_stack+1502218,int_stack+1501434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1955920, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6097306,int_stack+6094954,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7304083, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6100834,int_stack+1503226,int_stack+1502218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1956704, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6103858,int_stack+6100834,int_stack+6094954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7305847, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6108562,int_stack+6103858,int_stack+6097306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7308199, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1504486,int_stack+1503226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1957712, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6114442,int_stack+6093190,int_stack+6100834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7342009, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6130936,int_stack+6114442,int_stack+6103858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7345033, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096970,int_stack+6130936,int_stack+6108562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7349737, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6105790,int_stack+1506026,int_stack+1504486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1958972, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6138776,int_stack+6105790,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7355617, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1295385,int_stack+6138776,int_stack+6114442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7359397, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6105790,int_stack+1295385,int_stack+6130936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7365445, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6130936,int_stack+6105790,int_stack+6096970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7373285, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1295385,int_stack+6130936,int_stack+6121675, 1.0, int_stack+2864440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+1295385,int_stack+1275540, 1.0, int_stack+2873701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1275540,int_stack+1517666,int_stack+1516910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1969388, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1277808,int_stack+1518674,int_stack+1517666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1970144, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1280832,int_stack+1277808,int_stack+1275540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7382105, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1285368,int_stack+1519970,int_stack+1518674, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1971152, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1289256,int_stack+1285368,int_stack+1277808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7384373, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1323168,int_stack+1289256,int_stack+1280832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7387397, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1275540,int_stack+1521590,int_stack+1519970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1972448, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1330728,int_stack+1275540,int_stack+1285368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7391933, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1338504,int_stack+1330728,int_stack+1289256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18468, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1280400,int_stack+1338504,int_stack+1323168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5884597, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1323168,int_stack+1523570,int_stack+1521590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1974068, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6093190,int_stack+1323168,int_stack+1275540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7395821, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6102910,int_stack+6093190,int_stack+1330728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5892157, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1323168,int_stack+6102910,int_stack+1338504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5899933, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+1338288,int_stack+1323168,int_stack+1280400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7573138, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+1338288,int_stack+6130936, 1.0, int_stack+3040129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+6093190,int_stack+342792,int_stack+1295385, 1.0, int_stack+3052477, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+1420314,int_stack+6093190,int_stack+538596, 1.0, int_stack+3080260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1526891,int_stack+1525946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1778586, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1528151,int_stack+1526891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1780476, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2180231, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1529771,int_stack+1528151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1782996, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2183066, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2186846, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+1531796,int_stack+1529771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1786236, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3040129,int_stack+538596,int_stack+550881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5910013, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3049849,int_stack+3040129,int_stack+555741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5914873, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+3049849,int_stack+563301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5922433, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+1534271,int_stack+1531796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1790286, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+3062449,int_stack+558846,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5931883, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+3062449,int_stack+3040129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5937958, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+3062449,int_stack+558846,int_stack+3049849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5947678, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3040129,int_stack+3062449,int_stack+544671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5960278, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3059974,int_stack+3040129,int_stack+1338288, 1.0, int_stack+3182734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3107602,int_stack+3059974,int_stack+342792, 1.0, int_stack+3198610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+2080985,int_stack+3107602,int_stack+6093190, 1.0, int_stack+3235654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1541321,int_stack+1541006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1924961, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094135,int_stack+1541741,int_stack+1541321, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1925276, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6095395,int_stack+6094135,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7240246, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6097285,int_stack+1542281,int_stack+1541741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1925696, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6098905,int_stack+6097285,int_stack+6094135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7241191, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6101425,int_stack+6098905,int_stack+6095395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6633859, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1542956,int_stack+1542281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1926236, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6104575,int_stack+6093190,int_stack+6097285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7242451, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6107815,int_stack+6104575,int_stack+6098905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7244071, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6095215,int_stack+6107815,int_stack+6101425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7246591, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6099940,int_stack+1543781,int_stack+1542956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1926911, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6112015,int_stack+6099940,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7249741, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6116065,int_stack+6112015,int_stack+6104575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7251766, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6099940,int_stack+6116065,int_stack+6107815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7255006, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6106240,int_stack+6099940,int_stack+6095215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7259206, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1550483,int_stack+1550042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1937762, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094513,int_stack+1551071,int_stack+1550483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1938203, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6096277,int_stack+6094513,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7263931, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6098923,int_stack+1551827,int_stack+1551071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1938791, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6101191,int_stack+6098923,int_stack+6094513, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7265254, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6112855,int_stack+6101191,int_stack+6096277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7267018, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1552772,int_stack+1551827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1939547, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6117265,int_stack+6093190,int_stack+6098923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7276846, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6121801,int_stack+6117265,int_stack+6101191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7279114, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096025,int_stack+6121801,int_stack+6112855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7282642, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6112855,int_stack+1553927,int_stack+1552772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1940492, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6127681,int_stack+6112855,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6998335, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6133351,int_stack+6127681,int_stack+6117265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7287052, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6112855,int_stack+6133351,int_stack+6121801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7291588, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6121675,int_stack+6112855,int_stack+6096025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7297468, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+342792,int_stack+6121675,int_stack+6106240, 1.0, int_stack+3453685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1562929,int_stack+1562341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1955332, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094954,int_stack+1563713,int_stack+1562929, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1955920, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6097306,int_stack+6094954,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7304083, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6100834,int_stack+1564721,int_stack+1563713, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1956704, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6103858,int_stack+6100834,int_stack+6094954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7305847, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6108562,int_stack+6103858,int_stack+6097306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7308199, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1565981,int_stack+1564721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1957712, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6114442,int_stack+6093190,int_stack+6100834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7342009, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6130936,int_stack+6114442,int_stack+6103858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7345033, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096970,int_stack+6130936,int_stack+6108562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7349737, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6105790,int_stack+1567521,int_stack+1565981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1958972, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6138776,int_stack+6105790,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7355617, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+362637,int_stack+6138776,int_stack+6114442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7359397, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6105790,int_stack+362637,int_stack+6130936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7365445, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6130936,int_stack+6105790,int_stack+6096970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7373285, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+6093190,int_stack+6130936,int_stack+6121675, 1.0, int_stack+3496357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+6093190,int_stack+342792, 1.0, int_stack+3505618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+342792,int_stack+1579161,int_stack+1578405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1969388, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+345060,int_stack+1580169,int_stack+1579161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1970144, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+348084,int_stack+345060,int_stack+342792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7382105, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+352620,int_stack+1581465,int_stack+1580169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1971152, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+356508,int_stack+352620,int_stack+345060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7384373, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+362556,int_stack+356508,int_stack+348084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7387397, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+342792,int_stack+1583085,int_stack+1581465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1972448, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+370116,int_stack+342792,int_stack+352620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7391933, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3040129,int_stack+370116,int_stack+356508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18468, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+347652,int_stack+3040129,int_stack+362556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5884597, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+358992,int_stack+1585065,int_stack+1583085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1974068, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6120973,int_stack+358992,int_stack+342792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7395821, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3050209,int_stack+6120973,int_stack+370116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5892157, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+358992,int_stack+3050209,int_stack+3040129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5899933, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3040129,int_stack+358992,int_stack+347652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7573138, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+3040129,int_stack+6130936, 1.0, int_stack+3674881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+6093190, 1.0, int_stack+3687229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+3056005,int_stack+7993285,int_stack+538596, 1.0, int_stack+3715012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1588386,int_stack+1587441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1778586, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1589646,int_stack+1588386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1780476, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2180231, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1591266,int_stack+1589646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1782996, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2183066, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2186846, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+1593291,int_stack+1591266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1786236, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6093190,int_stack+538596,int_stack+550881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5910013, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6102910,int_stack+6093190,int_stack+555741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5914873, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+6102910,int_stack+563301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5922433, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+1595766,int_stack+1593291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1790286, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6115510,int_stack+558846,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5931883, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+6115510,int_stack+6093190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5937958, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6115510,int_stack+558846,int_stack+6102910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5947678, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6093190,int_stack+6115510,int_stack+544671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5960278, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3674881,int_stack+6093190,int_stack+3040129, 1.0, int_stack+3812626, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3722509,int_stack+3674881,int_stack+342792, 1.0, int_stack+3828502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3122155,int_stack+3722509,int_stack+7993285, 1.0, int_stack+3865546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1602816,int_stack+1602501, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1924961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+1603236,int_stack+1602816, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1925276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7240246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+1603776,int_stack+1603236, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1925696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7241191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6633859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1604451,int_stack+1603776, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1926236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7242451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7244071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7246591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+1605276,int_stack+1604451, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1926911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7249741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7251766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7255006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7259206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1611978,int_stack+1611537, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1937762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+1612566,int_stack+1611978, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1938203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7263931, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+1613322,int_stack+1612566, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1938791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7265254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8012950,int_stack+8001286,int_stack+7996372, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7267018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1614267,int_stack+1613322, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1939547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8017360,int_stack+7993285,int_stack+7999018, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7276846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8021896,int_stack+8017360,int_stack+8001286, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7279114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8021896,int_stack+8012950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7282642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8012950,int_stack+1615422,int_stack+1614267, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1940492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8027776,int_stack+8012950,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6998335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8033446,int_stack+8027776,int_stack+8017360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7287052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8012950,int_stack+8033446,int_stack+8021896, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7291588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8021770,int_stack+8012950,int_stack+7996120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7297468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+342792,int_stack+8021770,int_stack+8006335, 1.0, int_stack+4088977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1624424,int_stack+1623836, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1955332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7995049,int_stack+1625208,int_stack+1624424, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1955920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7997401,int_stack+7995049,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7304083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8000929,int_stack+1626216,int_stack+1625208, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1956704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8003953,int_stack+8000929,int_stack+7995049, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7305847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8008657,int_stack+8003953,int_stack+7997401, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7308199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1627476,int_stack+1626216, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1957712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8014537,int_stack+7993285,int_stack+8000929, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7342009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8031031,int_stack+8014537,int_stack+8003953, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7345033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7997065,int_stack+8031031,int_stack+8008657, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7349737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8005885,int_stack+1629016,int_stack+1627476, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1958972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8038871,int_stack+8005885,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7355617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+362637,int_stack+8038871,int_stack+8014537, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7359397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8005885,int_stack+362637,int_stack+8031031, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7365445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8031031,int_stack+8005885,int_stack+7997065, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7373285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+7993285,int_stack+8031031,int_stack+8021770, 1.0, int_stack+4117033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+7993285,int_stack+342792, 1.0, int_stack+4126294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+342792,int_stack+1640656,int_stack+1639900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1969388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+345060,int_stack+1641664,int_stack+1640656, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1970144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+348084,int_stack+345060,int_stack+342792, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7382105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+352620,int_stack+1642960,int_stack+1641664, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1971152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+356508,int_stack+352620,int_stack+345060, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7384373, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+362556,int_stack+356508,int_stack+348084, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7387397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+342792,int_stack+1644580,int_stack+1642960, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1972448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+370116,int_stack+342792,int_stack+352620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7391933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3674881,int_stack+370116,int_stack+356508, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+347652,int_stack+3674881,int_stack+362556, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5884597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+358992,int_stack+1646560,int_stack+1644580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1974068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8021068,int_stack+358992,int_stack+342792, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7395821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+3684961,int_stack+8021068,int_stack+370116, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5892157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+358992,int_stack+3684961,int_stack+3674881, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5899933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3040129,int_stack+358992,int_stack+347652, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7573138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+3040129,int_stack+8031031, 1.0, int_stack+4304773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+6093190,int_stack+342792,int_stack+7993285, 1.0, int_stack+4317121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+3674881,int_stack+6093190,int_stack+538596, 1.0, int_stack+4344904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1649881,int_stack+1648936, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1778586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1651141,int_stack+1649881, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1780476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2180231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1652761,int_stack+1651141, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1782996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2183066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2186846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+1654786,int_stack+1652761, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1786236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7993285,int_stack+538596,int_stack+550881, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5910013, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8003005,int_stack+7993285,int_stack+555741, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5914873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+8003005,int_stack+563301, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5922433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+1657261,int_stack+1654786, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1790286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8015605,int_stack+558846,int_stack+538596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5931883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+8015605,int_stack+7993285, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5937958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8015605,int_stack+558846,int_stack+8003005, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5947678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+7993285,int_stack+8015605,int_stack+544671, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5960278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+4304773,int_stack+7993285,int_stack+3040129, 1.0, int_stack+4447378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+4352401,int_stack+4304773,int_stack+342792, 1.0, int_stack+4463254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3741031,int_stack+4352401,int_stack+6093190, 1.0, int_stack+4500298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1664311,int_stack+1663996, 0.0, zero_stack, 1.0, int_stack+1924961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094135,int_stack+1664731,int_stack+1664311, 0.0, zero_stack, 1.0, int_stack+1925276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6095395,int_stack+6094135,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+7240246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6097285,int_stack+1665271,int_stack+1664731, 0.0, zero_stack, 1.0, int_stack+1925696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6098905,int_stack+6097285,int_stack+6094135, 0.0, zero_stack, 1.0, int_stack+7241191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6101425,int_stack+6098905,int_stack+6095395, 0.0, zero_stack, 1.0, int_stack+6633859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1665946,int_stack+1665271, 0.0, zero_stack, 1.0, int_stack+1926236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6104575,int_stack+6093190,int_stack+6097285, 0.0, zero_stack, 1.0, int_stack+7242451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6107815,int_stack+6104575,int_stack+6098905, 0.0, zero_stack, 1.0, int_stack+7244071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6095215,int_stack+6107815,int_stack+6101425, 0.0, zero_stack, 1.0, int_stack+7246591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6099940,int_stack+1666771,int_stack+1665946, 0.0, zero_stack, 1.0, int_stack+1926911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6112015,int_stack+6099940,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+7249741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6116065,int_stack+6112015,int_stack+6104575, 0.0, zero_stack, 1.0, int_stack+7251766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6099940,int_stack+6116065,int_stack+6107815, 0.0, zero_stack, 1.0, int_stack+7255006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6106240,int_stack+6099940,int_stack+6095215, 0.0, zero_stack, 1.0, int_stack+7259206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1673473,int_stack+1673032, 0.0, zero_stack, 1.0, int_stack+1937762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094513,int_stack+1674061,int_stack+1673473, 0.0, zero_stack, 1.0, int_stack+1938203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6096277,int_stack+6094513,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+7263931, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6098923,int_stack+1674817,int_stack+1674061, 0.0, zero_stack, 1.0, int_stack+1938791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6101191,int_stack+6098923,int_stack+6094513, 0.0, zero_stack, 1.0, int_stack+7265254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6112855,int_stack+6101191,int_stack+6096277, 0.0, zero_stack, 1.0, int_stack+7267018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1675762,int_stack+1674817, 0.0, zero_stack, 1.0, int_stack+1939547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6117265,int_stack+6093190,int_stack+6098923, 0.0, zero_stack, 1.0, int_stack+7276846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6121801,int_stack+6117265,int_stack+6101191, 0.0, zero_stack, 1.0, int_stack+7279114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096025,int_stack+6121801,int_stack+6112855, 0.0, zero_stack, 1.0, int_stack+7282642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6112855,int_stack+1676917,int_stack+1675762, 0.0, zero_stack, 1.0, int_stack+1940492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6127681,int_stack+6112855,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+6998335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+6133351,int_stack+6127681,int_stack+6117265, 0.0, zero_stack, 1.0, int_stack+7287052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6112855,int_stack+6133351,int_stack+6121801, 0.0, zero_stack, 1.0, int_stack+7291588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6121675,int_stack+6112855,int_stack+6096025, 0.0, zero_stack, 1.0, int_stack+7297468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+342792,int_stack+6121675,int_stack+6106240, 1.0, int_stack+4718329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1685919,int_stack+1685331, 0.0, zero_stack, 1.0, int_stack+1955332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6094954,int_stack+1686703,int_stack+1685919, 0.0, zero_stack, 1.0, int_stack+1955920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6097306,int_stack+6094954,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+7304083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6100834,int_stack+1687711,int_stack+1686703, 0.0, zero_stack, 1.0, int_stack+1956704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+6103858,int_stack+6100834,int_stack+6094954, 0.0, zero_stack, 1.0, int_stack+7305847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6108562,int_stack+6103858,int_stack+6097306, 0.0, zero_stack, 1.0, int_stack+7308199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1688971,int_stack+1687711, 0.0, zero_stack, 1.0, int_stack+1957712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6114442,int_stack+6093190,int_stack+6100834, 0.0, zero_stack, 1.0, int_stack+7342009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6130936,int_stack+6114442,int_stack+6103858, 0.0, zero_stack, 1.0, int_stack+7345033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6096970,int_stack+6130936,int_stack+6108562, 0.0, zero_stack, 1.0, int_stack+7349737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+6105790,int_stack+1690511,int_stack+1688971, 0.0, zero_stack, 1.0, int_stack+1958972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6138776,int_stack+6105790,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+7355617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+362637,int_stack+6138776,int_stack+6114442, 0.0, zero_stack, 1.0, int_stack+7359397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6105790,int_stack+362637,int_stack+6130936, 0.0, zero_stack, 1.0, int_stack+7365445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6130936,int_stack+6105790,int_stack+6096970, 0.0, zero_stack, 1.0, int_stack+7373285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+6093190,int_stack+6130936,int_stack+6121675, 1.0, int_stack+4761001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+6093190,int_stack+342792, 1.0, int_stack+4770262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+342792,int_stack+1702151,int_stack+1701395, 0.0, zero_stack, 1.0, int_stack+1969388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+345060,int_stack+1703159,int_stack+1702151, 0.0, zero_stack, 1.0, int_stack+1970144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+348084,int_stack+345060,int_stack+342792, 0.0, zero_stack, 1.0, int_stack+7382105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+352620,int_stack+1704455,int_stack+1703159, 0.0, zero_stack, 1.0, int_stack+1971152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+356508,int_stack+352620,int_stack+345060, 0.0, zero_stack, 1.0, int_stack+7384373, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+362556,int_stack+356508,int_stack+348084, 0.0, zero_stack, 1.0, int_stack+7387397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+342792,int_stack+1706075,int_stack+1704455, 0.0, zero_stack, 1.0, int_stack+1972448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+370116,int_stack+342792,int_stack+352620, 0.0, zero_stack, 1.0, int_stack+7391933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+4304773,int_stack+370116,int_stack+356508, 0.0, zero_stack, 1.0, int_stack+18468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+347652,int_stack+4304773,int_stack+362556, 0.0, zero_stack, 1.0, int_stack+5884597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+358992,int_stack+1708055,int_stack+1706075, 0.0, zero_stack, 1.0, int_stack+1974068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6120973,int_stack+358992,int_stack+342792, 0.0, zero_stack, 1.0, int_stack+7395821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+4314853,int_stack+6120973,int_stack+370116, 0.0, zero_stack, 1.0, int_stack+5892157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+358992,int_stack+4314853,int_stack+4304773, 0.0, zero_stack, 1.0, int_stack+5899933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3040129,int_stack+358992,int_stack+347652, 0.0, zero_stack, 1.0, int_stack+7573138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+3040129,int_stack+6130936, 1.0, int_stack+4939525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+6093190, 1.0, int_stack+4951873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+4304773,int_stack+7993285,int_stack+538596, 1.0, int_stack+4979656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1711376,int_stack+1710431, 0.0, zero_stack, 1.0, int_stack+1778586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1712636,int_stack+1711376, 0.0, zero_stack, 1.0, int_stack+1780476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596, 0.0, zero_stack, 1.0, int_stack+2180231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1714256,int_stack+1712636, 0.0, zero_stack, 1.0, int_stack+1782996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431, 0.0, zero_stack, 1.0, int_stack+2183066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211, 0.0, zero_stack, 1.0, int_stack+2186846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+1716281,int_stack+1714256, 0.0, zero_stack, 1.0, int_stack+1786236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6093190,int_stack+538596,int_stack+550881, 0.0, zero_stack, 1.0, int_stack+5910013, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6102910,int_stack+6093190,int_stack+555741, 0.0, zero_stack, 1.0, int_stack+5914873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+6102910,int_stack+563301, 0.0, zero_stack, 1.0, int_stack+5922433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+1718756,int_stack+1716281, 0.0, zero_stack, 1.0, int_stack+1790286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6115510,int_stack+558846,int_stack+538596, 0.0, zero_stack, 1.0, int_stack+5931883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+6115510,int_stack+6093190, 0.0, zero_stack, 1.0, int_stack+5937958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+6115510,int_stack+558846,int_stack+6102910, 0.0, zero_stack, 1.0, int_stack+5947678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+6093190,int_stack+6115510,int_stack+544671, 0.0, zero_stack, 1.0, int_stack+5960278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+4939525,int_stack+6093190,int_stack+3040129, 1.0, int_stack+5076082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+4987153,int_stack+4939525,int_stack+342792, 1.0, int_stack+5091958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4370923,int_stack+4987153,int_stack+7993285, 1.0, int_stack+5129002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1725806,int_stack+1725491, 1.0, int_stack+1924961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994230,int_stack+1726226,int_stack+1725806, 1.0, int_stack+1925276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7995490,int_stack+7994230,int_stack+7993285, 1.0, int_stack+7240246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7997380,int_stack+1726766,int_stack+1726226, 1.0, int_stack+1925696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7999000,int_stack+7997380,int_stack+7994230, 1.0, int_stack+7241191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8001520,int_stack+7999000,int_stack+7995490, 1.0, int_stack+6633859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1727441,int_stack+1726766, 1.0, int_stack+1926236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8004670,int_stack+7993285,int_stack+7997380, 1.0, int_stack+7242451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8007910,int_stack+8004670,int_stack+7999000, 1.0, int_stack+7244071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7995310,int_stack+8007910,int_stack+8001520, 1.0, int_stack+7246591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8000035,int_stack+1728266,int_stack+1727441, 1.0, int_stack+1926911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+8012110,int_stack+8000035,int_stack+7993285, 1.0, int_stack+7249741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8016160,int_stack+8012110,int_stack+8004670, 1.0, int_stack+7251766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8000035,int_stack+8016160,int_stack+8007910, 1.0, int_stack+7255006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+8006335,int_stack+8000035,int_stack+7995310, 1.0, int_stack+7259206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7993285,int_stack+1734968,int_stack+1734527, 1.0, int_stack+1937762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7994608,int_stack+1735556,int_stack+1734968, 1.0, int_stack+1938203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7996372,int_stack+7994608,int_stack+7993285, 1.0, int_stack+7263931, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7999018,int_stack+1736312,int_stack+1735556, 1.0, int_stack+1938791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+8001286,int_stack+7999018,int_stack+7994608, 1.0, int_stack+7265254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8012950,int_stack+8001286,int_stack+7996372, 1.0, int_stack+7267018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7993285,int_stack+1737257,int_stack+1736312, 1.0, int_stack+1939547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+8017360,int_stack+7993285,int_stack+7999018, 1.0, int_stack+7276846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+8021896,int_stack+8017360,int_stack+8001286, 1.0, int_stack+7279114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7996120,int_stack+8021896,int_stack+8012950, 1.0, int_stack+7282642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8012950,int_stack+1738412,int_stack+1737257, 1.0, int_stack+1940492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7276846,int_stack+8012950,int_stack+7993285, 1.0, int_stack+6998335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+8027776,int_stack+7276846,int_stack+8017360, 1.0, int_stack+7287052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+7276846,int_stack+8027776,int_stack+8021896, 1.0, int_stack+7291588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+7285666,int_stack+7276846,int_stack+7996120, 1.0, int_stack+7297468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+8012950,int_stack+7285666,int_stack+8006335, 1.0, int_stack+5333983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7276846,int_stack+1747414,int_stack+1746826, 1.0, int_stack+1955332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7278610,int_stack+1748198,int_stack+1747414, 1.0, int_stack+1955920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7280962,int_stack+7278610,int_stack+7276846, 1.0, int_stack+7304083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7294927,int_stack+1749206,int_stack+1748198, 1.0, int_stack+1956704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7297951,int_stack+7294927,int_stack+7278610, 1.0, int_stack+7305847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+7993285,int_stack+7297951,int_stack+7280962, 1.0, int_stack+7308199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7276846,int_stack+1750466,int_stack+1749206, 1.0, int_stack+1957712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7302655,int_stack+7276846,int_stack+7294927, 1.0, int_stack+7342009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7999165,int_stack+7302655,int_stack+7297951, 1.0, int_stack+7345033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+8032795,int_stack+7999165,int_stack+7993285, 1.0, int_stack+7349737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+7993285,int_stack+1752006,int_stack+1750466, 1.0, int_stack+1958972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7342009,int_stack+7993285,int_stack+7276846, 1.0, int_stack+7355617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+342792,int_stack+7342009,int_stack+7302655, 1.0, int_stack+7359397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+7342009,int_stack+342792,int_stack+7999165, 1.0, int_stack+7365445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+342792,int_stack+7342009,int_stack+8032795, 1.0, int_stack+7373285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+7342009,int_stack+342792,int_stack+7285666, 1.0, int_stack+5369032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+7342009,int_stack+8012950, 1.0, int_stack+5378293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7369792,int_stack+1770306,int_stack+1769550, 1.0, int_stack+1969388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7372060,int_stack+1771314,int_stack+1770306, 1.0, int_stack+1970144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7375084,int_stack+7372060,int_stack+7369792, 1.0, int_stack+7382105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7379620,int_stack+1772610,int_stack+1771314, 1.0, int_stack+1971152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+355140,int_stack+7379620,int_stack+7372060, 1.0, int_stack+7384373, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+361188,int_stack+355140,int_stack+7375084, 1.0, int_stack+7387397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+7369792,int_stack+1774230,int_stack+1772610, 1.0, int_stack+1972448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7383508,int_stack+7369792,int_stack+7379620, 1.0, int_stack+7391933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+368748,int_stack+7383508,int_stack+355140, 1.0, int_stack+18468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+7276846,int_stack+368748,int_stack+361188, 1.0, int_stack+5884597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+355140,int_stack+1776210,int_stack+1774230, 1.0, int_stack+1974068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7288186,int_stack+355140,int_stack+7369792, 1.0, int_stack+7395821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+7369792,int_stack+7288186,int_stack+7383508, 1.0, int_stack+5892157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+7288186,int_stack+7369792,int_stack+368748, 1.0, int_stack+5899933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+3040129,int_stack+7288186,int_stack+7276846, 1.0, int_stack+7573138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+7993285,int_stack+3040129,int_stack+342792, 1.0, int_stack+5431430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+6093190,int_stack+7993285,int_stack+7342009, 1.0, int_stack+5443778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+4939525,int_stack+6093190,int_stack+538596, 1.0, int_stack+5568229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5568229,int_stack+1781736,int_stack+1779531, 1.0, int_stack+1778586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5571064,int_stack+1784616,int_stack+1781736, 1.0, int_stack+1780476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5574844,int_stack+5571064,int_stack+5568229, 1.0, int_stack+2180231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5580514,int_stack+1788261,int_stack+1784616, 1.0, int_stack+1782996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+5585374,int_stack+5580514,int_stack+5571064, 1.0, int_stack+2183066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5592934,int_stack+5585374,int_stack+5574844, 1.0, int_stack+2186846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5568229,int_stack+1792761,int_stack+1788261, 1.0, int_stack+1786236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+5602384,int_stack+5568229,int_stack+5580514, 1.0, int_stack+5910013, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+5612104,int_stack+5602384,int_stack+5585374, 1.0, int_stack+5914873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5574304,int_stack+5612104,int_stack+5592934, 1.0, int_stack+5922433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5588479,int_stack+1795236,int_stack+1792761, 1.0, int_stack+1790286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+5624704,int_stack+5588479,int_stack+5568229, 1.0, int_stack+5931883, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+538596,int_stack+5624704,int_stack+5602384, 1.0, int_stack+5937958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5624704,int_stack+538596,int_stack+5612104, 1.0, int_stack+5947678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+538596,int_stack+5624704,int_stack+5574304, 1.0, int_stack+5960278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+5568229,int_stack+538596,int_stack+3040129, 1.0, int_stack+5650723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+5005675,int_stack+5568229,int_stack+7993285, 1.0, int_stack+5666599, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+5568229,int_stack+5005675,int_stack+6093190, 1.0, int_stack+5703643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1802286,int_stack+1801971,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6094135,int_stack+1802706,int_stack+1802286,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6095395,int_stack+6094135,int_stack+6093190,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6097285,int_stack+1803246,int_stack+1802706,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6098905,int_stack+6097285,int_stack+6094135,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6101425,int_stack+6098905,int_stack+6095395,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1803921,int_stack+1803246,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6104575,int_stack+6093190,int_stack+6097285,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6107815,int_stack+6104575,int_stack+6098905,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6095215,int_stack+6107815,int_stack+6101425,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6099940,int_stack+1804746,int_stack+1803921,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6112015,int_stack+6099940,int_stack+6093190,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6116065,int_stack+6112015,int_stack+6104575,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6099940,int_stack+6116065,int_stack+6107815,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6106240,int_stack+6099940,int_stack+6095215,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1811448,int_stack+1811007,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6094513,int_stack+1812036,int_stack+1811448,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6096277,int_stack+6094513,int_stack+6093190,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6098923,int_stack+1812792,int_stack+1812036,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6101191,int_stack+6098923,int_stack+6094513,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6112855,int_stack+6101191,int_stack+6096277,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1813737,int_stack+1812792,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6117265,int_stack+6093190,int_stack+6098923,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6121801,int_stack+6117265,int_stack+6101191,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6096025,int_stack+6121801,int_stack+6112855,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6112855,int_stack+1814892,int_stack+1813737,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6127681,int_stack+6112855,int_stack+6093190,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6133351,int_stack+6127681,int_stack+6117265,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6112855,int_stack+6133351,int_stack+6121801,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6121675,int_stack+6112855,int_stack+6096025,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+5005675,int_stack+6121675,int_stack+6106240, 1.0, int_stack+2192579, 0.0, zero_stack, 1.0, int_stack+7270231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1823894,int_stack+1823306,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6094954,int_stack+1824678,int_stack+1823894,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6097306,int_stack+6094954,int_stack+6093190,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6100834,int_stack+1825686,int_stack+1824678,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6103858,int_stack+6100834,int_stack+6094954,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6108562,int_stack+6103858,int_stack+6097306,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1826946,int_stack+1825686,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6114442,int_stack+6093190,int_stack+6100834,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6130936,int_stack+6114442,int_stack+6103858,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6096970,int_stack+6130936,int_stack+6108562,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6105790,int_stack+1828486,int_stack+1826946,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6138776,int_stack+6105790,int_stack+6093190,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+5025520,int_stack+6138776,int_stack+6114442,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6105790,int_stack+5025520,int_stack+6130936,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6130936,int_stack+6105790,int_stack+6096970,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+5025520,int_stack+6130936,int_stack+6121675, 1.0, int_stack+2071724, 0.0, zero_stack, 1.0, int_stack+7312903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+5025520,int_stack+5005675, 1.0, int_stack+6214906, 0.0, zero_stack, 1.0, int_stack+7322164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6214906,int_stack+1840126,int_stack+1839370,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6217174,int_stack+1841134,int_stack+1840126,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6220198,int_stack+6217174,int_stack+6214906,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6224734,int_stack+1842430,int_stack+1841134,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6228622,int_stack+6224734,int_stack+6217174,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6234670,int_stack+6228622,int_stack+6220198,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6214906,int_stack+1844050,int_stack+1842430,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6242230,int_stack+6214906,int_stack+6224734,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+5005675,int_stack+6242230,int_stack+6228622,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7573138,int_stack+5005675,int_stack+6234670,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6219766,int_stack+1846030,int_stack+1844050,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6225706,int_stack+6219766,int_stack+6214906,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+5053303,int_stack+6225706,int_stack+6242230,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6214906,int_stack+5053303,int_stack+5005675,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+3040129,int_stack+6214906,int_stack+7573138,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+3040129,int_stack+6130936, 1.0, int_stack+6256591, 0.0, zero_stack, 1.0, int_stack+7493317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+6093190,int_stack+342792,int_stack+5025520, 1.0, int_stack+6268939, 0.0, zero_stack, 1.0, int_stack+7505665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+6214906,int_stack+6093190,int_stack+538596, 1.0, int_stack+6296722, 0.0, zero_stack, 1.0, int_stack+7533448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1849351,int_stack+1848406,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1850611,int_stack+1849351,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1852231,int_stack+1850611,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+1854256,int_stack+1852231,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7573138,int_stack+538596,int_stack+550881,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6281056,int_stack+7573138,int_stack+555741,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+6281056,int_stack+563301,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+1856731,int_stack+1854256,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6293656,int_stack+558846,int_stack+538596,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+6293656,int_stack+7573138,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6293656,int_stack+558846,int_stack+6281056,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6312556,int_stack+6293656,int_stack+544671,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+5005675,int_stack+6312556,int_stack+3040129, 1.0, int_stack+6365608, 0.0, zero_stack, 1.0, int_stack+7584478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+6281056,int_stack+5005675,int_stack+342792, 1.0, int_stack+6381484, 0.0, zero_stack, 1.0, int_stack+7600354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+5005675,int_stack+6281056,int_stack+6093190, 1.0, int_stack+6418528, 0.0, zero_stack, 1.0, int_stack+7637398, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1863781,int_stack+1863466,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6094135,int_stack+1864201,int_stack+1863781,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6095395,int_stack+6094135,int_stack+6093190,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6097285,int_stack+1864741,int_stack+1864201,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6098905,int_stack+6097285,int_stack+6094135,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6101425,int_stack+6098905,int_stack+6095395,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1865416,int_stack+1864741,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6104575,int_stack+6093190,int_stack+6097285,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6107815,int_stack+6104575,int_stack+6098905,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6095215,int_stack+6107815,int_stack+6101425,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6099940,int_stack+1866241,int_stack+1865416,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6112015,int_stack+6099940,int_stack+6093190,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6116065,int_stack+6112015,int_stack+6104575,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6099940,int_stack+6116065,int_stack+6107815,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6106240,int_stack+6099940,int_stack+6095215,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1872943,int_stack+1872502,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6094513,int_stack+1873531,int_stack+1872943,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6096277,int_stack+6094513,int_stack+6093190,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6098923,int_stack+1874287,int_stack+1873531,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6101191,int_stack+6098923,int_stack+6094513,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6112855,int_stack+6101191,int_stack+6096277,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1875232,int_stack+1874287,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6117265,int_stack+6093190,int_stack+6098923,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6121801,int_stack+6117265,int_stack+6101191,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6096025,int_stack+6121801,int_stack+6112855,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6112855,int_stack+1876387,int_stack+1875232,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6127681,int_stack+6112855,int_stack+6093190,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6133351,int_stack+6127681,int_stack+6117265,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6112855,int_stack+6133351,int_stack+6121801,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6121675,int_stack+6112855,int_stack+6096025,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+6281056,int_stack+6121675,int_stack+6106240, 1.0, int_stack+6635749, 1.0, int_stack+7270231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1885389,int_stack+1884801,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6094954,int_stack+1886173,int_stack+1885389,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6097306,int_stack+6094954,int_stack+6093190,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6100834,int_stack+1887181,int_stack+1886173,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6103858,int_stack+6100834,int_stack+6094954,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6108562,int_stack+6103858,int_stack+6097306,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1888441,int_stack+1887181,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6114442,int_stack+6093190,int_stack+6100834,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6130936,int_stack+6114442,int_stack+6103858,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6096970,int_stack+6130936,int_stack+6108562,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6105790,int_stack+1889981,int_stack+1888441,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6138776,int_stack+6105790,int_stack+6093190,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6300901,int_stack+6138776,int_stack+6114442,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6105790,int_stack+6300901,int_stack+6130936,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6130936,int_stack+6105790,int_stack+6096970,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+6300901,int_stack+6130936,int_stack+6121675, 1.0, int_stack+6681256, 1.0, int_stack+7312903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+6300901,int_stack+6281056, 1.0, int_stack+6690517, 1.0, int_stack+7322164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6281056,int_stack+1901621,int_stack+1900865,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6283324,int_stack+1902629,int_stack+1901621,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6286348,int_stack+6283324,int_stack+6281056,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6290884,int_stack+1903925,int_stack+1902629,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6294772,int_stack+6290884,int_stack+6283324,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6328684,int_stack+6294772,int_stack+6286348,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6281056,int_stack+1905545,int_stack+1903925,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6336244,int_stack+6281056,int_stack+6290884,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6344020,int_stack+6336244,int_stack+6294772,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7573138,int_stack+6344020,int_stack+6328684,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6328684,int_stack+1907525,int_stack+1905545,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6285916,int_stack+6328684,int_stack+6281056,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6354100,int_stack+6285916,int_stack+6336244,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6281056,int_stack+6354100,int_stack+6344020,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+3040129,int_stack+6281056,int_stack+7573138,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+3040129,int_stack+6130936, 1.0, int_stack+6858565, 1.0, int_stack+7493317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+6093190,int_stack+342792,int_stack+6300901, 1.0, int_stack+6870913, 1.0, int_stack+7505665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+6281056,int_stack+6093190,int_stack+538596, 1.0, int_stack+6898696, 1.0, int_stack+7533448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1910846,int_stack+1909901,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1912106,int_stack+1910846,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1913726,int_stack+1912106,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+1915751,int_stack+1913726,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6858565,int_stack+538596,int_stack+550881,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6868285,int_stack+6858565,int_stack+555741,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+6868285,int_stack+563301,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+1918226,int_stack+1915751,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6880885,int_stack+558846,int_stack+538596,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+6880885,int_stack+6858565,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6880885,int_stack+558846,int_stack+6868285,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6858565,int_stack+6880885,int_stack+544671,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+6878410,int_stack+6858565,int_stack+3040129, 1.0, int_stack+7001170, 1.0, int_stack+7584478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+6926038,int_stack+6878410,int_stack+342792, 1.0, int_stack+7017046, 1.0, int_stack+7600354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+6347206,int_stack+6926038,int_stack+6093190, 1.0, int_stack+7054090, 1.0, int_stack+7637398, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1929041,int_stack+1928726,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6094135,int_stack+1929461,int_stack+1929041,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6095395,int_stack+6094135,int_stack+6093190,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6097285,int_stack+1930001,int_stack+1929461,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6098905,int_stack+6097285,int_stack+6094135,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6101425,int_stack+6098905,int_stack+6095395,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1930676,int_stack+1930001,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6104575,int_stack+6093190,int_stack+6097285,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6107815,int_stack+6104575,int_stack+6098905,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6095215,int_stack+6107815,int_stack+6101425,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6099940,int_stack+1931501,int_stack+1930676,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6112015,int_stack+6099940,int_stack+6093190,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6116065,int_stack+6112015,int_stack+6104575,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6099940,int_stack+6116065,int_stack+6107815,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6106240,int_stack+6099940,int_stack+6095215,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1943474,int_stack+1943033,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6094513,int_stack+1944062,int_stack+1943474,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6096277,int_stack+6094513,int_stack+6093190,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6098923,int_stack+1944818,int_stack+1944062,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6101191,int_stack+6098923,int_stack+6094513,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6112855,int_stack+6101191,int_stack+6096277,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1945763,int_stack+1944818,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6117265,int_stack+6093190,int_stack+6098923,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6121801,int_stack+6117265,int_stack+6101191,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6096025,int_stack+6121801,int_stack+6112855,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6112855,int_stack+1946918,int_stack+1945763,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6127681,int_stack+6112855,int_stack+6093190,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6133351,int_stack+6127681,int_stack+6117265,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6112855,int_stack+6133351,int_stack+6121801,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6121675,int_stack+6112855,int_stack+6096025,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+342792,int_stack+6121675,int_stack+6106240, 2.0, int_stack+7270231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+6093190,int_stack+1962948,int_stack+1962360,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6094954,int_stack+1963732,int_stack+1962948,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+6097306,int_stack+6094954,int_stack+6093190,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+6100834,int_stack+1964740,int_stack+1963732,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6103858,int_stack+6100834,int_stack+6094954,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+6108562,int_stack+6103858,int_stack+6097306,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+6093190,int_stack+1966000,int_stack+1964740,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6114442,int_stack+6093190,int_stack+6100834,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6130936,int_stack+6114442,int_stack+6103858,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+6096970,int_stack+6130936,int_stack+6108562,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+6105790,int_stack+1967540,int_stack+1966000,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6138776,int_stack+6105790,int_stack+6093190,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+362637,int_stack+6138776,int_stack+6114442,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6105790,int_stack+362637,int_stack+6130936,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6130936,int_stack+6105790,int_stack+6096970,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+6093190,int_stack+6130936,int_stack+6121675, 2.0, int_stack+7312903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+538596,int_stack+6093190,int_stack+342792, 2.0, int_stack+7322164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+342792,int_stack+1979180,int_stack+1978424,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+345060,int_stack+1980188,int_stack+1979180,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+348084,int_stack+345060,int_stack+342792,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+352620,int_stack+1981484,int_stack+1980188,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+356508,int_stack+352620,int_stack+345060,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+362556,int_stack+356508,int_stack+348084,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+342792,int_stack+1983104,int_stack+1981484,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+370116,int_stack+342792,int_stack+352620,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3040129,int_stack+370116,int_stack+356508,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7573138,int_stack+3040129,int_stack+362556,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+347652,int_stack+1985084,int_stack+1983104,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+353592,int_stack+347652,int_stack+342792,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+6858565,int_stack+353592,int_stack+370116,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+342792,int_stack+6858565,int_stack+3040129,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+3040129,int_stack+342792,int_stack+7573138,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+342792,int_stack+3040129,int_stack+6130936, 2.0, int_stack+7493317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+7993285,int_stack+342792,int_stack+6093190, 2.0, int_stack+7505665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+6858565,int_stack+7993285,int_stack+538596, 2.0, int_stack+7533448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+538596,int_stack+1988405,int_stack+1987460,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+541431,int_stack+1989665,int_stack+1988405,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+545211,int_stack+541431,int_stack+538596,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+550881,int_stack+1991285,int_stack+1989665,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+555741,int_stack+550881,int_stack+541431,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+563301,int_stack+555741,int_stack+545211,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+538596,int_stack+1993310,int_stack+1991285,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+6093190,int_stack+538596,int_stack+550881,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+6102910,int_stack+6093190,int_stack+555741,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+544671,int_stack+6102910,int_stack+563301,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+558846,int_stack+1995785,int_stack+1993310,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+6115510,int_stack+558846,int_stack+538596,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+558846,int_stack+6115510,int_stack+6093190,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+6115510,int_stack+558846,int_stack+6102910,45);
 /*--- compute (l0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+6093190,int_stack+6115510,int_stack+544671,45);
 /*--- compute (kp|hh) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+7493317,int_stack+6093190,int_stack+3040129, 2.0, int_stack+7584478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (id|hh) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+6924715,int_stack+7493317,int_stack+342792, 2.0, int_stack+7600354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hf|hh) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+7493317,int_stack+6924715,int_stack+7993285, 2.0, int_stack+7637398, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+6924715,int_stack+2947519,int_stack+2582578,441);
     Libderiv->ABCD[11] = int_stack + 6924715;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+7585927,int_stack+3582271,int_stack+3291220,441);
     Libderiv->ABCD[10] = int_stack + 7585927;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+1486464,int_stack+4212163,int_stack+3921112,441);
     Libderiv->ABCD[9] = int_stack + 1486464;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+1585689,int_stack+4846915,int_stack+4555864,441);
     Libderiv->ABCD[8] = int_stack + 1585689;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+1684914,int_stack+5475619,int_stack+5184568,441);
     Libderiv->ABCD[7] = int_stack + 1684914;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+1784139,int_stack+6000580,int_stack+5759209,441);
     Libderiv->ABCD[6] = int_stack + 1784139;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+1883364,int_stack+6765955,int_stack+6474094, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6148756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[2] = int_stack + 1883364;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+7175806,int_stack+7400707,int_stack+7109656, 0.0, zero_stack, 1.0, int_stack+6148756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[1] = int_stack + 7175806;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+7275031,int_stack+7900675,int_stack+7692964, 1.0, int_stack+6148756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[0] = int_stack + 7275031;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+7374256,int_stack+7759114,int_stack+8048851,441);
     Libderiv->ABCD[155] = int_stack + 7374256;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+7759114,int_stack+8255239,int_stack+8115001,441);
     Libderiv->ABCD[143] = int_stack + 7759114;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+7858339,int_stack+8347849,int_stack+24516,441);
     Libderiv->ABCD[142] = int_stack + 7858339;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+7957564,int_stack+8514547,int_stack+8181151,441);
     Libderiv->ABCD[131] = int_stack + 7957564;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+8056789,int_stack+8681245,int_stack+117882,441);
     Libderiv->ABCD[130] = int_stack + 8056789;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+8156014,int_stack+8847943,int_stack+8607157,441);
     Libderiv->ABCD[129] = int_stack + 8156014;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+8255239,int_stack+9014641,int_stack+184032,441);
     Libderiv->ABCD[119] = int_stack + 8255239;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+6606394,int_stack+9181339,int_stack+8940553,441);
     Libderiv->ABCD[118] = int_stack + 6606394;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+6705619,int_stack+9273949,int_stack+9107251,441);
     Libderiv->ABCD[117] = int_stack + 6705619;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+5316868,int_stack+250182,int_stack+8440459,441);
     Libderiv->ABCD[116] = int_stack + 5316868;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+8354464,int_stack+9488275,int_stack+8773855,441);
     Libderiv->ABCD[107] = int_stack + 8354464;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+8453689,int_stack+9366559,int_stack+379836,441);
     Libderiv->ABCD[106] = int_stack + 8453689;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+8552914,int_stack+9721123,int_stack+9580885,441);
     Libderiv->ABCD[105] = int_stack + 8552914;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+8652139,int_stack+9813733,int_stack+9647035,441);
     Libderiv->ABCD[104] = int_stack + 8652139;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+8751364,int_stack+445986,int_stack+9906343,441);
     Libderiv->ABCD[103] = int_stack + 8751364;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+8850589,int_stack+9972493,int_stack+2359405,441);
     Libderiv->ABCD[95] = int_stack + 8850589;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+8949814,int_stack+10065103,int_stack+578286,441);
     Libderiv->ABCD[94] = int_stack + 8949814;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+9049039,int_stack+10157713,int_stack+2738191,441);
     Libderiv->ABCD[93] = int_stack + 9049039;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+9148264,int_stack+644436,int_stack+3357370,441);
     Libderiv->ABCD[92] = int_stack + 9148264;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+3357370,int_stack+10250323,int_stack+4622014,441);
     Libderiv->ABCD[91] = int_stack + 3357370;
 /*--- compute (gg|hh) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+4622014,int_stack+10342933,int_stack+3987262,441);
     Libderiv->ABCD[90] = int_stack + 4622014;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+3987262,int_stack+10509631,int_stack+737046, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2582578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[47] = int_stack + 3987262;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4086487,int_stack+10602241,int_stack+10435543, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3291220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[46] = int_stack + 4086487;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4185712,int_stack+10694851,int_stack+5250718, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3921112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[45] = int_stack + 4185712;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4721239,int_stack+10787461,int_stack+918330, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4555864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[44] = int_stack + 4721239;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4820464,int_stack+10946221,int_stack+10880071, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5184568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[43] = int_stack + 4820464;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+3456595,int_stack+984480,int_stack+2199194, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5759209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[42] = int_stack + 3456595;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+3555820,int_stack+11038831,int_stack+2648728, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+6474094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[38] = int_stack + 3555820;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+2648728,int_stack+11197591,int_stack+11131441, 0.0, zero_stack, 1.0, int_stack+2582578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[35] = int_stack + 2648728;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+2747953,int_stack+11290201,int_stack+1077090, 0.0, zero_stack, 1.0, int_stack+3291220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[34] = int_stack + 2747953;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+2847178,int_stack+11382811,int_stack+1143240, 0.0, zero_stack, 1.0, int_stack+3921112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[33] = int_stack + 2847178;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+2946403,int_stack+11541571,int_stack+11475421, 0.0, zero_stack, 1.0, int_stack+4555864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[32] = int_stack + 2946403;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+9247489,int_stack+11634181,int_stack+1209390, 0.0, zero_stack, 1.0, int_stack+5184568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[31] = int_stack + 9247489;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+9346714,int_stack+11726791,int_stack+803196, 0.0, zero_stack, 1.0, int_stack+5759209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[30] = int_stack + 9346714;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+9445939,int_stack+11819401,int_stack+6540244, 0.0, zero_stack, 1.0, int_stack+6474094, 1.0, int_stack+7109656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[26] = int_stack + 9445939;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+9545164,int_stack+11978161,int_stack+11912011, 0.0, zero_stack, 2.0, int_stack+7109656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[25] = int_stack + 9545164;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+9644389,int_stack+2265344,int_stack+1354164, 1.0, int_stack+2582578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[23] = int_stack + 9644389;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+9743614,int_stack+2080985,int_stack+1420314, 1.0, int_stack+3291220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[22] = int_stack + 9743614;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+9842839,int_stack+3122155,int_stack+3056005, 1.0, int_stack+3921112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[21] = int_stack + 9842839;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+3045628,int_stack+3741031,int_stack+3674881, 1.0, int_stack+4555864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[20] = int_stack + 3045628;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+3144853,int_stack+4370923,int_stack+4304773, 1.0, int_stack+5184568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[19] = int_stack + 3144853;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+3244078,int_stack+5568229,int_stack+4939525, 1.0, int_stack+5759209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[18] = int_stack + 3244078;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4284937,int_stack+5005675,int_stack+6214906, 1.0, int_stack+6474094, 0.0, zero_stack, 1.0, int_stack+7692964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[14] = int_stack + 4284937;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4384162,int_stack+6347206,int_stack+6281056, 1.0, int_stack+7109656, 1.0, int_stack+7692964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[13] = int_stack + 4384162;
 /*--- compute (gg|hh) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+4483387,int_stack+7493317,int_stack+6858565, 2.0, int_stack+7692964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[12] = int_stack + 4483387;

}
