/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_hdgf(Libderiv_t *, prim_data *);

  /* Computes derivatives of (hd|gf) integrals */

void d12hrr_order_hdgf(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[7][7][11] = int_stack + 0;
 Libderiv->deriv_classes[7][7][10] = int_stack + 1296;
 Libderiv->deriv_classes[7][7][9] = int_stack + 2592;
 Libderiv->deriv_classes[7][7][8] = int_stack + 3888;
 Libderiv->deriv_classes[7][7][7] = int_stack + 5184;
 Libderiv->dvrr_classes[7][6] = int_stack + 6480;
 Libderiv->deriv_classes[7][7][6] = int_stack + 7488;
 Libderiv->deriv_classes[7][7][2] = int_stack + 8784;
 Libderiv->deriv_classes[7][7][1] = int_stack + 10080;
 Libderiv->dvrr_classes[6][7] = int_stack + 11376;
 Libderiv->deriv_classes[7][7][0] = int_stack + 12384;
 Libderiv->deriv2_classes[5][4][143] = int_stack + 13680;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 13995;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 14436;
 Libderiv->deriv2_classes[5][7][143] = int_stack + 15024;
 Libderiv->deriv2_classes[6][4][143] = int_stack + 15780;
 Libderiv->deriv2_classes[6][5][143] = int_stack + 16200;
 Libderiv->deriv2_classes[6][6][143] = int_stack + 16788;
 Libderiv->deriv2_classes[6][7][143] = int_stack + 17572;
 Libderiv->deriv2_classes[7][4][143] = int_stack + 18580;
 Libderiv->deriv2_classes[7][5][143] = int_stack + 19120;
 Libderiv->deriv2_classes[7][6][143] = int_stack + 19876;
 Libderiv->deriv2_classes[7][7][143] = int_stack + 20884;
 Libderiv->deriv2_classes[5][4][131] = int_stack + 22180;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 22495;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 22936;
 Libderiv->deriv2_classes[5][7][131] = int_stack + 23524;
 Libderiv->deriv2_classes[6][4][131] = int_stack + 24280;
 Libderiv->deriv2_classes[6][5][131] = int_stack + 24700;
 Libderiv->deriv2_classes[6][6][131] = int_stack + 25288;
 Libderiv->deriv2_classes[6][7][131] = int_stack + 26072;
 Libderiv->deriv2_classes[7][4][131] = int_stack + 27080;
 Libderiv->deriv2_classes[7][5][131] = int_stack + 27620;
 Libderiv->deriv2_classes[7][6][131] = int_stack + 28376;
 Libderiv->deriv2_classes[7][7][131] = int_stack + 29384;
 Libderiv->deriv2_classes[5][4][130] = int_stack + 30680;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 30995;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 31436;
 Libderiv->deriv2_classes[5][7][130] = int_stack + 32024;
 Libderiv->deriv2_classes[6][4][130] = int_stack + 32780;
 Libderiv->deriv2_classes[6][5][130] = int_stack + 33200;
 Libderiv->deriv2_classes[6][6][130] = int_stack + 33788;
 Libderiv->deriv2_classes[6][7][130] = int_stack + 34572;
 Libderiv->deriv2_classes[7][4][130] = int_stack + 35580;
 Libderiv->deriv2_classes[7][5][130] = int_stack + 36120;
 Libderiv->deriv2_classes[7][6][130] = int_stack + 36876;
 Libderiv->deriv2_classes[7][7][130] = int_stack + 37884;
 Libderiv->deriv2_classes[5][4][119] = int_stack + 39180;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 39495;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 39936;
 Libderiv->deriv2_classes[5][7][119] = int_stack + 40524;
 Libderiv->deriv2_classes[6][4][119] = int_stack + 41280;
 Libderiv->deriv2_classes[6][5][119] = int_stack + 41700;
 Libderiv->deriv2_classes[6][6][119] = int_stack + 42288;
 Libderiv->deriv2_classes[6][7][119] = int_stack + 43072;
 Libderiv->deriv2_classes[7][4][119] = int_stack + 44080;
 Libderiv->deriv2_classes[7][5][119] = int_stack + 44620;
 Libderiv->deriv2_classes[7][6][119] = int_stack + 45376;
 Libderiv->deriv2_classes[7][7][119] = int_stack + 46384;
 Libderiv->deriv2_classes[5][4][118] = int_stack + 47680;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 47995;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 48436;
 Libderiv->deriv2_classes[5][7][118] = int_stack + 49024;
 Libderiv->deriv2_classes[6][4][118] = int_stack + 49780;
 Libderiv->deriv2_classes[6][5][118] = int_stack + 50200;
 Libderiv->deriv2_classes[6][6][118] = int_stack + 50788;
 Libderiv->deriv2_classes[6][7][118] = int_stack + 51572;
 Libderiv->deriv2_classes[7][4][118] = int_stack + 52580;
 Libderiv->deriv2_classes[7][5][118] = int_stack + 53120;
 Libderiv->deriv2_classes[7][6][118] = int_stack + 53876;
 Libderiv->deriv2_classes[7][7][118] = int_stack + 54884;
 Libderiv->deriv2_classes[5][4][117] = int_stack + 56180;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 56495;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 56936;
 Libderiv->deriv2_classes[5][7][117] = int_stack + 57524;
 Libderiv->deriv2_classes[6][4][117] = int_stack + 58280;
 Libderiv->deriv2_classes[6][5][117] = int_stack + 58700;
 Libderiv->deriv2_classes[6][6][117] = int_stack + 59288;
 Libderiv->deriv2_classes[6][7][117] = int_stack + 60072;
 Libderiv->deriv2_classes[7][4][117] = int_stack + 61080;
 Libderiv->deriv2_classes[7][5][117] = int_stack + 61620;
 Libderiv->deriv2_classes[7][6][117] = int_stack + 62376;
 Libderiv->deriv2_classes[7][7][117] = int_stack + 63384;
 Libderiv->deriv2_classes[5][4][107] = int_stack + 64680;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 64995;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 65436;
 Libderiv->deriv2_classes[5][7][107] = int_stack + 66024;
 Libderiv->deriv2_classes[6][4][107] = int_stack + 66780;
 Libderiv->deriv2_classes[6][5][107] = int_stack + 67200;
 Libderiv->deriv2_classes[6][6][107] = int_stack + 67788;
 Libderiv->deriv2_classes[6][7][107] = int_stack + 68572;
 Libderiv->deriv2_classes[7][4][107] = int_stack + 69580;
 Libderiv->deriv2_classes[7][5][107] = int_stack + 70120;
 Libderiv->deriv2_classes[7][6][107] = int_stack + 70876;
 Libderiv->deriv2_classes[7][7][107] = int_stack + 71884;
 Libderiv->deriv2_classes[5][4][106] = int_stack + 73180;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 73495;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 73936;
 Libderiv->deriv2_classes[5][7][106] = int_stack + 74524;
 Libderiv->deriv2_classes[6][4][106] = int_stack + 75280;
 Libderiv->deriv2_classes[6][5][106] = int_stack + 75700;
 Libderiv->deriv2_classes[6][6][106] = int_stack + 76288;
 Libderiv->deriv2_classes[6][7][106] = int_stack + 77072;
 Libderiv->deriv2_classes[7][4][106] = int_stack + 78080;
 Libderiv->deriv2_classes[7][5][106] = int_stack + 78620;
 Libderiv->deriv2_classes[7][6][106] = int_stack + 79376;
 Libderiv->deriv2_classes[7][7][106] = int_stack + 80384;
 Libderiv->deriv2_classes[5][4][105] = int_stack + 81680;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 81995;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 82436;
 Libderiv->deriv2_classes[5][7][105] = int_stack + 83024;
 Libderiv->deriv2_classes[6][4][105] = int_stack + 83780;
 Libderiv->deriv2_classes[6][5][105] = int_stack + 84200;
 Libderiv->deriv2_classes[6][6][105] = int_stack + 84788;
 Libderiv->deriv2_classes[6][7][105] = int_stack + 85572;
 Libderiv->deriv2_classes[7][4][105] = int_stack + 86580;
 Libderiv->deriv2_classes[7][5][105] = int_stack + 87120;
 Libderiv->deriv2_classes[7][6][105] = int_stack + 87876;
 Libderiv->deriv2_classes[7][7][105] = int_stack + 88884;
 Libderiv->deriv2_classes[5][4][104] = int_stack + 90180;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 90495;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 90936;
 Libderiv->deriv2_classes[5][7][104] = int_stack + 91524;
 Libderiv->deriv2_classes[6][4][104] = int_stack + 92280;
 Libderiv->deriv2_classes[6][5][104] = int_stack + 92700;
 Libderiv->deriv2_classes[6][6][104] = int_stack + 93288;
 Libderiv->deriv2_classes[6][7][104] = int_stack + 94072;
 Libderiv->deriv2_classes[7][4][104] = int_stack + 95080;
 Libderiv->deriv2_classes[7][5][104] = int_stack + 95620;
 Libderiv->deriv2_classes[7][6][104] = int_stack + 96376;
 Libderiv->deriv2_classes[7][7][104] = int_stack + 97384;
 Libderiv->deriv2_classes[5][4][95] = int_stack + 98680;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 98995;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 99436;
 Libderiv->deriv2_classes[5][7][95] = int_stack + 100024;
 Libderiv->deriv2_classes[6][4][95] = int_stack + 100780;
 Libderiv->deriv2_classes[6][5][95] = int_stack + 101200;
 Libderiv->deriv2_classes[6][6][95] = int_stack + 101788;
 Libderiv->deriv2_classes[6][7][95] = int_stack + 102572;
 Libderiv->deriv2_classes[7][4][95] = int_stack + 103580;
 Libderiv->deriv2_classes[7][5][95] = int_stack + 104120;
 Libderiv->deriv2_classes[7][6][95] = int_stack + 104876;
 Libderiv->deriv2_classes[7][7][95] = int_stack + 105884;
 Libderiv->deriv2_classes[5][4][94] = int_stack + 107180;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 107495;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 107936;
 Libderiv->deriv2_classes[5][7][94] = int_stack + 108524;
 Libderiv->deriv2_classes[6][4][94] = int_stack + 109280;
 Libderiv->deriv2_classes[6][5][94] = int_stack + 109700;
 Libderiv->deriv2_classes[6][6][94] = int_stack + 110288;
 Libderiv->deriv2_classes[6][7][94] = int_stack + 111072;
 Libderiv->deriv2_classes[7][4][94] = int_stack + 112080;
 Libderiv->deriv2_classes[7][5][94] = int_stack + 112620;
 Libderiv->deriv2_classes[7][6][94] = int_stack + 113376;
 Libderiv->deriv2_classes[7][7][94] = int_stack + 114384;
 Libderiv->deriv2_classes[5][4][93] = int_stack + 115680;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 115995;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 116436;
 Libderiv->deriv2_classes[5][7][93] = int_stack + 117024;
 Libderiv->deriv2_classes[6][4][93] = int_stack + 117780;
 Libderiv->deriv2_classes[6][5][93] = int_stack + 118200;
 Libderiv->deriv2_classes[6][6][93] = int_stack + 118788;
 Libderiv->deriv2_classes[6][7][93] = int_stack + 119572;
 Libderiv->deriv2_classes[7][4][93] = int_stack + 120580;
 Libderiv->deriv2_classes[7][5][93] = int_stack + 121120;
 Libderiv->deriv2_classes[7][6][93] = int_stack + 121876;
 Libderiv->deriv2_classes[7][7][93] = int_stack + 122884;
 Libderiv->deriv2_classes[5][4][92] = int_stack + 124180;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 124495;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 124936;
 Libderiv->deriv2_classes[5][7][92] = int_stack + 125524;
 Libderiv->deriv2_classes[6][4][92] = int_stack + 126280;
 Libderiv->deriv2_classes[6][5][92] = int_stack + 126700;
 Libderiv->deriv2_classes[6][6][92] = int_stack + 127288;
 Libderiv->deriv2_classes[6][7][92] = int_stack + 128072;
 Libderiv->deriv2_classes[7][4][92] = int_stack + 129080;
 Libderiv->deriv2_classes[7][5][92] = int_stack + 129620;
 Libderiv->deriv2_classes[7][6][92] = int_stack + 130376;
 Libderiv->deriv2_classes[7][7][92] = int_stack + 131384;
 Libderiv->deriv2_classes[5][4][91] = int_stack + 132680;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 132995;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 133436;
 Libderiv->deriv2_classes[5][7][91] = int_stack + 134024;
 Libderiv->deriv2_classes[6][4][91] = int_stack + 134780;
 Libderiv->deriv2_classes[6][5][91] = int_stack + 135200;
 Libderiv->deriv2_classes[6][6][91] = int_stack + 135788;
 Libderiv->deriv2_classes[6][7][91] = int_stack + 136572;
 Libderiv->deriv2_classes[7][4][91] = int_stack + 137580;
 Libderiv->deriv2_classes[7][5][91] = int_stack + 138120;
 Libderiv->deriv2_classes[7][6][91] = int_stack + 138876;
 Libderiv->deriv2_classes[7][7][91] = int_stack + 139884;
 Libderiv->deriv2_classes[5][4][83] = int_stack + 141180;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 141495;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 141936;
 Libderiv->deriv2_classes[5][7][83] = int_stack + 142524;
 Libderiv->deriv2_classes[6][4][83] = int_stack + 143280;
 Libderiv->deriv2_classes[6][5][83] = int_stack + 143700;
 Libderiv->deriv2_classes[6][6][83] = int_stack + 144288;
 Libderiv->deriv2_classes[6][7][83] = int_stack + 145072;
 Libderiv->deriv_classes[7][4][11] = int_stack + 146080;
 Libderiv->deriv2_classes[7][4][83] = int_stack + 146620;
 Libderiv->deriv_classes[7][5][11] = int_stack + 147160;
 Libderiv->deriv2_classes[7][5][83] = int_stack + 147916;
 Libderiv->deriv_classes[7][6][11] = int_stack + 148672;
 Libderiv->deriv2_classes[7][6][83] = int_stack + 149680;
 Libderiv->deriv2_classes[7][7][83] = int_stack + 150688;
 Libderiv->deriv2_classes[5][4][82] = int_stack + 151984;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 152299;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 152740;
 Libderiv->deriv2_classes[5][7][82] = int_stack + 153328;
 Libderiv->deriv2_classes[6][4][82] = int_stack + 154084;
 Libderiv->deriv2_classes[6][5][82] = int_stack + 154504;
 Libderiv->deriv2_classes[6][6][82] = int_stack + 155092;
 Libderiv->deriv2_classes[6][7][82] = int_stack + 155876;
 Libderiv->deriv_classes[7][4][10] = int_stack + 156884;
 Libderiv->deriv2_classes[7][4][82] = int_stack + 157424;
 Libderiv->deriv_classes[7][5][10] = int_stack + 157964;
 Libderiv->deriv2_classes[7][5][82] = int_stack + 158720;
 Libderiv->deriv_classes[7][6][10] = int_stack + 159476;
 Libderiv->deriv2_classes[7][6][82] = int_stack + 160484;
 Libderiv->deriv2_classes[7][7][82] = int_stack + 161492;
 Libderiv->deriv2_classes[5][4][81] = int_stack + 162788;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 163103;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 163544;
 Libderiv->deriv2_classes[5][7][81] = int_stack + 164132;
 Libderiv->deriv2_classes[6][4][81] = int_stack + 164888;
 Libderiv->deriv2_classes[6][5][81] = int_stack + 165308;
 Libderiv->deriv2_classes[6][6][81] = int_stack + 165896;
 Libderiv->deriv2_classes[6][7][81] = int_stack + 166680;
 Libderiv->deriv_classes[7][4][9] = int_stack + 167688;
 Libderiv->deriv2_classes[7][4][81] = int_stack + 168228;
 Libderiv->deriv_classes[7][5][9] = int_stack + 168768;
 Libderiv->deriv2_classes[7][5][81] = int_stack + 169524;
 Libderiv->deriv_classes[7][6][9] = int_stack + 170280;
 Libderiv->deriv2_classes[7][6][81] = int_stack + 171288;
 Libderiv->deriv2_classes[7][7][81] = int_stack + 172296;
 Libderiv->deriv2_classes[5][4][80] = int_stack + 173592;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 173907;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 174348;
 Libderiv->deriv2_classes[5][7][80] = int_stack + 174936;
 Libderiv->deriv2_classes[6][4][80] = int_stack + 175692;
 Libderiv->deriv2_classes[6][5][80] = int_stack + 176112;
 Libderiv->deriv2_classes[6][6][80] = int_stack + 176700;
 Libderiv->deriv2_classes[6][7][80] = int_stack + 177484;
 Libderiv->deriv_classes[7][4][8] = int_stack + 178492;
 Libderiv->deriv2_classes[7][4][80] = int_stack + 179032;
 Libderiv->deriv_classes[7][5][8] = int_stack + 179572;
 Libderiv->deriv2_classes[7][5][80] = int_stack + 180328;
 Libderiv->deriv_classes[7][6][8] = int_stack + 181084;
 Libderiv->deriv2_classes[7][6][80] = int_stack + 182092;
 Libderiv->deriv2_classes[7][7][80] = int_stack + 183100;
 Libderiv->deriv2_classes[5][4][79] = int_stack + 184396;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 184711;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 185152;
 Libderiv->deriv2_classes[5][7][79] = int_stack + 185740;
 Libderiv->deriv2_classes[6][4][79] = int_stack + 186496;
 Libderiv->deriv2_classes[6][5][79] = int_stack + 186916;
 Libderiv->deriv2_classes[6][6][79] = int_stack + 187504;
 Libderiv->deriv2_classes[6][7][79] = int_stack + 188288;
 Libderiv->deriv_classes[7][4][7] = int_stack + 189296;
 Libderiv->deriv2_classes[7][4][79] = int_stack + 189836;
 Libderiv->deriv_classes[7][5][7] = int_stack + 190376;
 Libderiv->deriv2_classes[7][5][79] = int_stack + 191132;
 Libderiv->deriv_classes[7][6][7] = int_stack + 191888;
 Libderiv->deriv2_classes[7][6][79] = int_stack + 192896;
 Libderiv->deriv2_classes[7][7][79] = int_stack + 193904;
 Libderiv->deriv2_classes[5][4][78] = int_stack + 195200;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 195515;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 195956;
 Libderiv->deriv2_classes[5][7][78] = int_stack + 196544;
 Libderiv->deriv2_classes[6][4][78] = int_stack + 197300;
 Libderiv->deriv2_classes[6][5][78] = int_stack + 197720;
 Libderiv->deriv2_classes[6][6][78] = int_stack + 198308;
 Libderiv->deriv2_classes[6][7][78] = int_stack + 199092;
 Libderiv->dvrr_classes[7][4] = int_stack + 200100;
 Libderiv->deriv_classes[7][4][6] = int_stack + 200640;
 Libderiv->deriv2_classes[7][4][78] = int_stack + 201180;
 Libderiv->dvrr_classes[7][5] = int_stack + 201720;
 Libderiv->deriv_classes[7][5][6] = int_stack + 202476;
 Libderiv->deriv2_classes[7][5][78] = int_stack + 203232;
 Libderiv->deriv_classes[7][6][6] = int_stack + 203988;
 Libderiv->deriv2_classes[7][6][78] = int_stack + 204996;
 Libderiv->deriv2_classes[7][7][78] = int_stack + 206004;
 Libderiv->deriv2_classes[5][4][35] = int_stack + 207300;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 207615;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 208056;
 Libderiv->deriv2_classes[5][7][35] = int_stack + 208644;
 Libderiv->deriv2_classes[6][4][35] = int_stack + 209400;
 Libderiv->deriv2_classes[6][5][35] = int_stack + 209820;
 Libderiv->deriv2_classes[6][6][35] = int_stack + 210408;
 Libderiv->deriv2_classes[6][7][35] = int_stack + 211192;
 Libderiv->deriv2_classes[7][4][35] = int_stack + 212200;
 Libderiv->deriv2_classes[7][5][35] = int_stack + 212740;
 Libderiv->deriv2_classes[7][6][35] = int_stack + 213496;
 Libderiv->deriv2_classes[7][7][35] = int_stack + 214504;
 Libderiv->deriv2_classes[5][4][34] = int_stack + 215800;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 216115;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 216556;
 Libderiv->deriv2_classes[5][7][34] = int_stack + 217144;
 Libderiv->deriv2_classes[6][4][34] = int_stack + 217900;
 Libderiv->deriv2_classes[6][5][34] = int_stack + 218320;
 Libderiv->deriv2_classes[6][6][34] = int_stack + 218908;
 Libderiv->deriv2_classes[6][7][34] = int_stack + 219692;
 Libderiv->deriv2_classes[7][4][34] = int_stack + 220700;
 Libderiv->deriv2_classes[7][5][34] = int_stack + 221240;
 Libderiv->deriv2_classes[7][6][34] = int_stack + 221996;
 Libderiv->deriv2_classes[7][7][34] = int_stack + 223004;
 Libderiv->deriv2_classes[5][4][33] = int_stack + 224300;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 224615;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 225056;
 Libderiv->deriv2_classes[5][7][33] = int_stack + 225644;
 Libderiv->deriv2_classes[6][4][33] = int_stack + 226400;
 Libderiv->deriv2_classes[6][5][33] = int_stack + 226820;
 Libderiv->deriv2_classes[6][6][33] = int_stack + 227408;
 Libderiv->deriv2_classes[6][7][33] = int_stack + 228192;
 Libderiv->deriv2_classes[7][4][33] = int_stack + 229200;
 Libderiv->deriv2_classes[7][5][33] = int_stack + 229740;
 Libderiv->deriv2_classes[7][6][33] = int_stack + 230496;
 Libderiv->deriv2_classes[7][7][33] = int_stack + 231504;
 Libderiv->deriv2_classes[5][4][32] = int_stack + 232800;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 233115;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 233556;
 Libderiv->deriv2_classes[5][7][32] = int_stack + 234144;
 Libderiv->deriv2_classes[6][4][32] = int_stack + 234900;
 Libderiv->deriv2_classes[6][5][32] = int_stack + 235320;
 Libderiv->deriv2_classes[6][6][32] = int_stack + 235908;
 Libderiv->deriv2_classes[6][7][32] = int_stack + 236692;
 Libderiv->deriv2_classes[7][4][32] = int_stack + 237700;
 Libderiv->deriv2_classes[7][5][32] = int_stack + 238240;
 Libderiv->deriv2_classes[7][6][32] = int_stack + 238996;
 Libderiv->deriv2_classes[7][7][32] = int_stack + 240004;
 Libderiv->deriv2_classes[5][4][31] = int_stack + 241300;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 241615;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 242056;
 Libderiv->deriv2_classes[5][7][31] = int_stack + 242644;
 Libderiv->deriv2_classes[6][4][31] = int_stack + 243400;
 Libderiv->deriv2_classes[6][5][31] = int_stack + 243820;
 Libderiv->deriv2_classes[6][6][31] = int_stack + 244408;
 Libderiv->deriv2_classes[6][7][31] = int_stack + 245192;
 Libderiv->deriv2_classes[7][4][31] = int_stack + 246200;
 Libderiv->deriv2_classes[7][5][31] = int_stack + 246740;
 Libderiv->deriv2_classes[7][6][31] = int_stack + 247496;
 Libderiv->deriv2_classes[7][7][31] = int_stack + 248504;
 Libderiv->deriv2_classes[5][4][30] = int_stack + 249800;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 250115;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 250556;
 Libderiv->deriv2_classes[5][7][30] = int_stack + 251144;
 Libderiv->deriv2_classes[6][4][30] = int_stack + 251900;
 Libderiv->deriv2_classes[6][5][30] = int_stack + 252320;
 Libderiv->deriv2_classes[6][6][30] = int_stack + 252908;
 Libderiv->deriv2_classes[6][7][30] = int_stack + 253692;
 Libderiv->deriv_classes[7][4][2] = int_stack + 254700;
 Libderiv->deriv2_classes[7][4][30] = int_stack + 255240;
 Libderiv->deriv_classes[7][5][2] = int_stack + 255780;
 Libderiv->deriv2_classes[7][5][30] = int_stack + 256536;
 Libderiv->deriv_classes[7][6][2] = int_stack + 257292;
 Libderiv->deriv2_classes[7][6][30] = int_stack + 258300;
 Libderiv->deriv2_classes[7][7][30] = int_stack + 259308;
 Libderiv->deriv2_classes[5][4][26] = int_stack + 260604;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 260919;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 261360;
 Libderiv->deriv2_classes[5][7][26] = int_stack + 261948;
 Libderiv->deriv2_classes[6][4][26] = int_stack + 262704;
 Libderiv->deriv2_classes[6][5][26] = int_stack + 263124;
 Libderiv->deriv2_classes[6][6][26] = int_stack + 263712;
 Libderiv->deriv2_classes[6][7][26] = int_stack + 264496;
 Libderiv->deriv2_classes[7][4][26] = int_stack + 265504;
 Libderiv->deriv2_classes[7][5][26] = int_stack + 266044;
 Libderiv->deriv2_classes[7][6][26] = int_stack + 266800;
 Libderiv->deriv2_classes[7][7][26] = int_stack + 267808;
 Libderiv->deriv2_classes[5][4][23] = int_stack + 269104;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 269419;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 269860;
 Libderiv->deriv2_classes[5][7][23] = int_stack + 270448;
 Libderiv->deriv2_classes[6][4][23] = int_stack + 271204;
 Libderiv->deriv2_classes[6][5][23] = int_stack + 271624;
 Libderiv->deriv2_classes[6][6][23] = int_stack + 272212;
 Libderiv->deriv2_classes[6][7][23] = int_stack + 272996;
 Libderiv->deriv2_classes[7][4][23] = int_stack + 274004;
 Libderiv->deriv2_classes[7][5][23] = int_stack + 274544;
 Libderiv->deriv2_classes[7][6][23] = int_stack + 275300;
 Libderiv->deriv2_classes[7][7][23] = int_stack + 276308;
 Libderiv->deriv2_classes[5][4][22] = int_stack + 277604;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 277919;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 278360;
 Libderiv->deriv2_classes[5][7][22] = int_stack + 278948;
 Libderiv->deriv2_classes[6][4][22] = int_stack + 279704;
 Libderiv->deriv2_classes[6][5][22] = int_stack + 280124;
 Libderiv->deriv2_classes[6][6][22] = int_stack + 280712;
 Libderiv->deriv2_classes[6][7][22] = int_stack + 281496;
 Libderiv->deriv2_classes[7][4][22] = int_stack + 282504;
 Libderiv->deriv2_classes[7][5][22] = int_stack + 283044;
 Libderiv->deriv2_classes[7][6][22] = int_stack + 283800;
 Libderiv->deriv2_classes[7][7][22] = int_stack + 284808;
 Libderiv->deriv2_classes[5][4][21] = int_stack + 286104;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 286419;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 286860;
 Libderiv->deriv2_classes[5][7][21] = int_stack + 287448;
 Libderiv->deriv2_classes[6][4][21] = int_stack + 288204;
 Libderiv->deriv2_classes[6][5][21] = int_stack + 288624;
 Libderiv->deriv2_classes[6][6][21] = int_stack + 289212;
 Libderiv->deriv2_classes[6][7][21] = int_stack + 289996;
 Libderiv->deriv2_classes[7][4][21] = int_stack + 291004;
 Libderiv->deriv2_classes[7][5][21] = int_stack + 291544;
 Libderiv->deriv2_classes[7][6][21] = int_stack + 292300;
 Libderiv->deriv2_classes[7][7][21] = int_stack + 293308;
 Libderiv->deriv2_classes[5][4][20] = int_stack + 294604;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 294919;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 295360;
 Libderiv->deriv2_classes[5][7][20] = int_stack + 295948;
 Libderiv->deriv2_classes[6][4][20] = int_stack + 296704;
 Libderiv->deriv2_classes[6][5][20] = int_stack + 297124;
 Libderiv->deriv2_classes[6][6][20] = int_stack + 297712;
 Libderiv->deriv2_classes[6][7][20] = int_stack + 298496;
 Libderiv->deriv2_classes[7][4][20] = int_stack + 299504;
 Libderiv->deriv2_classes[7][5][20] = int_stack + 300044;
 Libderiv->deriv2_classes[7][6][20] = int_stack + 300800;
 Libderiv->deriv2_classes[7][7][20] = int_stack + 301808;
 Libderiv->deriv2_classes[5][4][19] = int_stack + 303104;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 303419;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 303860;
 Libderiv->deriv2_classes[5][7][19] = int_stack + 304448;
 Libderiv->deriv2_classes[6][4][19] = int_stack + 305204;
 Libderiv->deriv2_classes[6][5][19] = int_stack + 305624;
 Libderiv->deriv2_classes[6][6][19] = int_stack + 306212;
 Libderiv->deriv2_classes[6][7][19] = int_stack + 306996;
 Libderiv->deriv2_classes[7][4][19] = int_stack + 308004;
 Libderiv->deriv2_classes[7][5][19] = int_stack + 308544;
 Libderiv->deriv2_classes[7][6][19] = int_stack + 309300;
 Libderiv->deriv2_classes[7][7][19] = int_stack + 310308;
 Libderiv->deriv2_classes[5][4][18] = int_stack + 311604;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 311919;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 312360;
 Libderiv->deriv2_classes[5][7][18] = int_stack + 312948;
 Libderiv->deriv2_classes[6][4][18] = int_stack + 313704;
 Libderiv->deriv2_classes[6][5][18] = int_stack + 314124;
 Libderiv->deriv2_classes[6][6][18] = int_stack + 314712;
 Libderiv->deriv2_classes[6][7][18] = int_stack + 315496;
 Libderiv->deriv_classes[7][4][1] = int_stack + 316504;
 Libderiv->deriv2_classes[7][4][18] = int_stack + 317044;
 Libderiv->deriv_classes[7][5][1] = int_stack + 317584;
 Libderiv->deriv2_classes[7][5][18] = int_stack + 318340;
 Libderiv->deriv_classes[7][6][1] = int_stack + 319096;
 Libderiv->deriv2_classes[7][6][18] = int_stack + 320104;
 Libderiv->deriv2_classes[7][7][18] = int_stack + 321112;
 Libderiv->deriv2_classes[5][4][14] = int_stack + 322408;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 322723;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 323164;
 Libderiv->deriv2_classes[5][7][14] = int_stack + 323752;
 Libderiv->deriv2_classes[6][4][14] = int_stack + 324508;
 Libderiv->deriv2_classes[6][5][14] = int_stack + 324928;
 Libderiv->deriv2_classes[6][6][14] = int_stack + 325516;
 Libderiv->deriv2_classes[6][7][14] = int_stack + 326300;
 Libderiv->deriv2_classes[7][4][14] = int_stack + 327308;
 Libderiv->deriv2_classes[7][5][14] = int_stack + 327848;
 Libderiv->deriv2_classes[7][6][14] = int_stack + 328604;
 Libderiv->deriv2_classes[7][7][14] = int_stack + 329612;
 Libderiv->deriv2_classes[5][4][13] = int_stack + 330908;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 331223;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 331664;
 Libderiv->deriv2_classes[5][7][13] = int_stack + 332252;
 Libderiv->deriv2_classes[6][4][13] = int_stack + 333008;
 Libderiv->deriv2_classes[6][5][13] = int_stack + 333428;
 Libderiv->deriv2_classes[6][6][13] = int_stack + 334016;
 Libderiv->deriv2_classes[6][7][13] = int_stack + 334800;
 Libderiv->deriv2_classes[7][4][13] = int_stack + 335808;
 Libderiv->deriv2_classes[7][5][13] = int_stack + 336348;
 Libderiv->deriv2_classes[7][6][13] = int_stack + 337104;
 Libderiv->deriv2_classes[7][7][13] = int_stack + 338112;
 Libderiv->deriv_classes[5][4][11] = int_stack + 339408;
 Libderiv->deriv_classes[5][5][11] = int_stack + 339723;
 Libderiv->deriv_classes[5][6][11] = int_stack + 340164;
 Libderiv->deriv_classes[5][7][11] = int_stack + 340752;
 Libderiv->deriv2_classes[5][4][11] = int_stack + 341508;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 341823;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 342264;
 Libderiv->deriv2_classes[5][7][11] = int_stack + 342852;
 Libderiv->deriv_classes[6][4][11] = int_stack + 343608;
 Libderiv->deriv_classes[6][5][11] = int_stack + 344028;
 Libderiv->deriv_classes[6][6][11] = int_stack + 344616;
 Libderiv->deriv_classes[6][7][11] = int_stack + 345400;
 Libderiv->deriv2_classes[6][4][11] = int_stack + 346408;
 Libderiv->deriv2_classes[6][5][11] = int_stack + 346828;
 Libderiv->deriv2_classes[6][6][11] = int_stack + 347416;
 Libderiv->deriv2_classes[6][7][11] = int_stack + 348200;
 Libderiv->deriv2_classes[7][4][11] = int_stack + 349208;
 Libderiv->deriv2_classes[7][5][11] = int_stack + 349748;
 Libderiv->deriv2_classes[7][6][11] = int_stack + 350504;
 Libderiv->deriv2_classes[7][7][11] = int_stack + 351512;
 Libderiv->deriv_classes[5][4][10] = int_stack + 352808;
 Libderiv->deriv_classes[5][5][10] = int_stack + 353123;
 Libderiv->deriv_classes[5][6][10] = int_stack + 353564;
 Libderiv->deriv_classes[5][7][10] = int_stack + 354152;
 Libderiv->deriv2_classes[5][4][10] = int_stack + 354908;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 355223;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 355664;
 Libderiv->deriv2_classes[5][7][10] = int_stack + 356252;
 Libderiv->deriv_classes[6][4][10] = int_stack + 357008;
 Libderiv->deriv_classes[6][5][10] = int_stack + 357428;
 Libderiv->deriv_classes[6][6][10] = int_stack + 358016;
 Libderiv->deriv_classes[6][7][10] = int_stack + 358800;
 Libderiv->deriv2_classes[6][4][10] = int_stack + 359808;
 Libderiv->deriv2_classes[6][5][10] = int_stack + 360228;
 Libderiv->deriv2_classes[6][6][10] = int_stack + 360816;
 Libderiv->deriv2_classes[6][7][10] = int_stack + 361600;
 Libderiv->deriv2_classes[7][4][10] = int_stack + 362608;
 Libderiv->deriv2_classes[7][5][10] = int_stack + 363148;
 Libderiv->deriv2_classes[7][6][10] = int_stack + 363904;
 Libderiv->deriv2_classes[7][7][10] = int_stack + 364912;
 Libderiv->deriv_classes[5][4][9] = int_stack + 366208;
 Libderiv->deriv_classes[5][5][9] = int_stack + 366523;
 Libderiv->deriv_classes[5][6][9] = int_stack + 366964;
 Libderiv->deriv_classes[5][7][9] = int_stack + 367552;
 Libderiv->deriv2_classes[5][4][9] = int_stack + 368308;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 368623;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 369064;
 Libderiv->deriv2_classes[5][7][9] = int_stack + 369652;
 Libderiv->deriv_classes[6][4][9] = int_stack + 370408;
 Libderiv->deriv_classes[6][5][9] = int_stack + 370828;
 Libderiv->deriv_classes[6][6][9] = int_stack + 371416;
 Libderiv->deriv_classes[6][7][9] = int_stack + 372200;
 Libderiv->deriv2_classes[6][4][9] = int_stack + 373208;
 Libderiv->deriv2_classes[6][5][9] = int_stack + 373628;
 Libderiv->deriv2_classes[6][6][9] = int_stack + 374216;
 Libderiv->deriv2_classes[6][7][9] = int_stack + 375000;
 Libderiv->deriv2_classes[7][4][9] = int_stack + 376008;
 Libderiv->deriv2_classes[7][5][9] = int_stack + 376548;
 Libderiv->deriv2_classes[7][6][9] = int_stack + 377304;
 Libderiv->deriv2_classes[7][7][9] = int_stack + 378312;
 Libderiv->deriv_classes[5][4][8] = int_stack + 379608;
 Libderiv->deriv_classes[5][5][8] = int_stack + 379923;
 Libderiv->deriv_classes[5][6][8] = int_stack + 380364;
 Libderiv->deriv_classes[5][7][8] = int_stack + 380952;
 Libderiv->deriv2_classes[5][4][8] = int_stack + 381708;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 382023;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 382464;
 Libderiv->deriv2_classes[5][7][8] = int_stack + 383052;
 Libderiv->deriv_classes[6][4][8] = int_stack + 383808;
 Libderiv->deriv_classes[6][5][8] = int_stack + 384228;
 Libderiv->deriv_classes[6][6][8] = int_stack + 384816;
 Libderiv->deriv_classes[6][7][8] = int_stack + 385600;
 Libderiv->deriv2_classes[6][4][8] = int_stack + 386608;
 Libderiv->deriv2_classes[6][5][8] = int_stack + 387028;
 Libderiv->deriv2_classes[6][6][8] = int_stack + 387616;
 Libderiv->deriv2_classes[6][7][8] = int_stack + 388400;
 Libderiv->deriv2_classes[7][4][8] = int_stack + 389408;
 Libderiv->deriv2_classes[7][5][8] = int_stack + 389948;
 Libderiv->deriv2_classes[7][6][8] = int_stack + 390704;
 Libderiv->deriv2_classes[7][7][8] = int_stack + 391712;
 Libderiv->deriv_classes[5][4][7] = int_stack + 393008;
 Libderiv->deriv_classes[5][5][7] = int_stack + 393323;
 Libderiv->deriv_classes[5][6][7] = int_stack + 393764;
 Libderiv->deriv_classes[5][7][7] = int_stack + 394352;
 Libderiv->deriv2_classes[5][4][7] = int_stack + 395108;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 395423;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 395864;
 Libderiv->deriv2_classes[5][7][7] = int_stack + 396452;
 Libderiv->deriv_classes[6][4][7] = int_stack + 397208;
 Libderiv->deriv_classes[6][5][7] = int_stack + 397628;
 Libderiv->deriv_classes[6][6][7] = int_stack + 398216;
 Libderiv->deriv_classes[6][7][7] = int_stack + 399000;
 Libderiv->deriv2_classes[6][4][7] = int_stack + 400008;
 Libderiv->deriv2_classes[6][5][7] = int_stack + 400428;
 Libderiv->deriv2_classes[6][6][7] = int_stack + 401016;
 Libderiv->deriv2_classes[6][7][7] = int_stack + 401800;
 Libderiv->deriv2_classes[7][4][7] = int_stack + 402808;
 Libderiv->deriv2_classes[7][5][7] = int_stack + 403348;
 Libderiv->deriv2_classes[7][6][7] = int_stack + 404104;
 Libderiv->deriv2_classes[7][7][7] = int_stack + 405112;
 Libderiv->deriv_classes[5][4][6] = int_stack + 406408;
 Libderiv->deriv_classes[5][5][6] = int_stack + 406723;
 Libderiv->deriv_classes[5][6][6] = int_stack + 407164;
 Libderiv->deriv_classes[5][7][6] = int_stack + 407752;
 Libderiv->deriv2_classes[5][4][6] = int_stack + 408508;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 408823;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 409264;
 Libderiv->deriv2_classes[5][7][6] = int_stack + 409852;
 Libderiv->dvrr_classes[6][4] = int_stack + 410608;
 Libderiv->deriv_classes[6][4][6] = int_stack + 411028;
 Libderiv->dvrr_classes[6][5] = int_stack + 411448;
 Libderiv->deriv_classes[6][5][6] = int_stack + 412036;
 Libderiv->dvrr_classes[6][6] = int_stack + 412624;
 Libderiv->deriv_classes[6][6][6] = int_stack + 413408;
 Libderiv->deriv_classes[6][7][6] = int_stack + 414192;
 Libderiv->deriv2_classes[6][4][6] = int_stack + 415200;
 Libderiv->deriv2_classes[6][5][6] = int_stack + 415620;
 Libderiv->deriv2_classes[6][6][6] = int_stack + 416208;
 Libderiv->deriv2_classes[6][7][6] = int_stack + 416992;
 Libderiv->deriv_classes[7][4][0] = int_stack + 418000;
 Libderiv->deriv2_classes[7][4][6] = int_stack + 418540;
 Libderiv->deriv_classes[7][5][0] = int_stack + 419080;
 Libderiv->deriv2_classes[7][5][6] = int_stack + 419836;
 Libderiv->deriv_classes[7][6][0] = int_stack + 420592;
 Libderiv->deriv2_classes[7][6][6] = int_stack + 421600;
 Libderiv->deriv2_classes[7][7][6] = int_stack + 422608;
 Libderiv->deriv_classes[5][4][2] = int_stack + 423904;
 Libderiv->deriv_classes[5][5][2] = int_stack + 424219;
 Libderiv->deriv_classes[5][6][2] = int_stack + 424660;
 Libderiv->deriv_classes[5][7][2] = int_stack + 425248;
 Libderiv->deriv2_classes[5][4][2] = int_stack + 426004;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 426319;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 426760;
 Libderiv->deriv2_classes[5][7][2] = int_stack + 427348;
 Libderiv->deriv_classes[6][4][2] = int_stack + 428104;
 Libderiv->deriv_classes[6][5][2] = int_stack + 428524;
 Libderiv->deriv_classes[6][6][2] = int_stack + 429112;
 Libderiv->deriv_classes[6][7][2] = int_stack + 429896;
 Libderiv->deriv2_classes[6][4][2] = int_stack + 430904;
 Libderiv->deriv2_classes[6][5][2] = int_stack + 431324;
 Libderiv->deriv2_classes[6][6][2] = int_stack + 431912;
 Libderiv->deriv2_classes[6][7][2] = int_stack + 432696;
 Libderiv->deriv2_classes[7][4][2] = int_stack + 433704;
 Libderiv->deriv2_classes[7][5][2] = int_stack + 434244;
 Libderiv->deriv2_classes[7][6][2] = int_stack + 435000;
 Libderiv->deriv2_classes[7][7][2] = int_stack + 436008;
 Libderiv->deriv_classes[5][4][1] = int_stack + 437304;
 Libderiv->deriv_classes[5][5][1] = int_stack + 437619;
 Libderiv->deriv_classes[5][6][1] = int_stack + 438060;
 Libderiv->deriv_classes[5][7][1] = int_stack + 438648;
 Libderiv->deriv2_classes[5][4][1] = int_stack + 439404;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 439719;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 440160;
 Libderiv->deriv2_classes[5][7][1] = int_stack + 440748;
 Libderiv->deriv_classes[6][4][1] = int_stack + 441504;
 Libderiv->deriv_classes[6][5][1] = int_stack + 441924;
 Libderiv->deriv_classes[6][6][1] = int_stack + 442512;
 Libderiv->deriv_classes[6][7][1] = int_stack + 443296;
 Libderiv->deriv2_classes[6][4][1] = int_stack + 444304;
 Libderiv->deriv2_classes[6][5][1] = int_stack + 444724;
 Libderiv->deriv2_classes[6][6][1] = int_stack + 445312;
 Libderiv->deriv2_classes[6][7][1] = int_stack + 446096;
 Libderiv->deriv2_classes[7][4][1] = int_stack + 447104;
 Libderiv->deriv2_classes[7][5][1] = int_stack + 447644;
 Libderiv->deriv2_classes[7][6][1] = int_stack + 448400;
 Libderiv->deriv2_classes[7][7][1] = int_stack + 449408;
 Libderiv->dvrr_classes[5][4] = int_stack + 450704;
 Libderiv->dvrr_classes[5][5] = int_stack + 451019;
 Libderiv->dvrr_classes[5][6] = int_stack + 451460;
 Libderiv->dvrr_classes[5][7] = int_stack + 452048;
 Libderiv->deriv_classes[5][4][0] = int_stack + 452804;
 Libderiv->deriv_classes[5][5][0] = int_stack + 453119;
 Libderiv->deriv_classes[5][6][0] = int_stack + 453560;
 Libderiv->deriv_classes[5][7][0] = int_stack + 454148;
 Libderiv->deriv2_classes[5][4][0] = int_stack + 454904;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 455219;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 455660;
 Libderiv->deriv2_classes[5][7][0] = int_stack + 456248;
 Libderiv->deriv_classes[6][4][0] = int_stack + 457004;
 Libderiv->deriv_classes[6][5][0] = int_stack + 457424;
 Libderiv->deriv_classes[6][6][0] = int_stack + 458012;
 Libderiv->deriv_classes[6][7][0] = int_stack + 458796;
 Libderiv->deriv2_classes[6][4][0] = int_stack + 459804;
 Libderiv->deriv2_classes[6][5][0] = int_stack + 460224;
 Libderiv->deriv2_classes[6][6][0] = int_stack + 460812;
 Libderiv->deriv2_classes[6][7][0] = int_stack + 461596;
 Libderiv->deriv2_classes[7][4][0] = int_stack + 462604;
 Libderiv->deriv2_classes[7][5][0] = int_stack + 463144;
 Libderiv->deriv2_classes[7][6][0] = int_stack + 463900;
 Libderiv->deriv2_classes[7][7][0] = int_stack + 464908;
 memset(int_stack,0,3729632);

 Libderiv->dvrr_stack = int_stack + 1375498;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_hdgf(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+466204,int_stack+451019,int_stack+450704,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+467149,int_stack+451460,int_stack+451019,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+468472,int_stack+467149,int_stack+466204,21);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+470362,int_stack+339723,int_stack+339408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450704,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+471307,int_stack+340164,int_stack+339723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+451019,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+472630,int_stack+471307,int_stack+470362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+466204,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+474520,int_stack+340752,int_stack+340164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+451460,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+476284,int_stack+474520,int_stack+471307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467149,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+478930,int_stack+476284,int_stack+472630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468472,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+474520,int_stack+411448,int_stack+410608,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+475780,int_stack+412624,int_stack+411448,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+482080,int_stack+475780,int_stack+474520,28);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+477544,int_stack+344028,int_stack+343608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410608,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+484600,int_stack+344616,int_stack+344028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411448,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+486364,int_stack+484600,int_stack+477544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+474520,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+488884,int_stack+345400,int_stack+344616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412624,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+491236,int_stack+488884,int_stack+484600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475780,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+494764,int_stack+491236,int_stack+486364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482080,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+498964,int_stack+494764,int_stack+478930,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+488884,int_stack+201720,int_stack+200100,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+490504,int_stack+6480,int_stack+201720,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+508414,int_stack+490504,int_stack+488884,36);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+492772,int_stack+147160,int_stack+146080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200100,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+511654,int_stack+148672,int_stack+147160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201720,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+513922,int_stack+511654,int_stack+492772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+488884,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+517162,int_stack+0,int_stack+148672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6480,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+520186,int_stack+517162,int_stack+511654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490504,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+524722,int_stack+520186,int_stack+513922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508414,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+530122,int_stack+524722,int_stack+494764,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+517162,int_stack+353123,int_stack+352808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450704, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+518107,int_stack+353564,int_stack+353123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+451019, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+519430,int_stack+518107,int_stack+517162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+466204, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+521320,int_stack+354152,int_stack+353564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+451460, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+523084,int_stack+521320,int_stack+518107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467149, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+525730,int_stack+523084,int_stack+519430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468472, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+521320,int_stack+357428,int_stack+357008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410608, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+522580,int_stack+358016,int_stack+357428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411448, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+542722,int_stack+522580,int_stack+521320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+474520, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+545242,int_stack+358800,int_stack+358016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412624, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+547594,int_stack+545242,int_stack+522580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475780, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+551122,int_stack+547594,int_stack+542722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482080, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+555322,int_stack+551122,int_stack+525730,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+545242,int_stack+157964,int_stack+156884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200100, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+546862,int_stack+159476,int_stack+157964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201720, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+564772,int_stack+546862,int_stack+545242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+488884, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+568012,int_stack+1296,int_stack+159476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6480, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+571036,int_stack+568012,int_stack+546862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490504, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+575572,int_stack+571036,int_stack+564772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508414, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+580972,int_stack+575572,int_stack+551122,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+568012,int_stack+366523,int_stack+366208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450704, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+568957,int_stack+366964,int_stack+366523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+451019, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+570280,int_stack+568957,int_stack+568012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+466204, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+572170,int_stack+367552,int_stack+366964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+451460, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+573934,int_stack+572170,int_stack+568957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467149, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+576580,int_stack+573934,int_stack+570280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468472, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+572170,int_stack+370828,int_stack+370408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410608, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+573430,int_stack+371416,int_stack+370828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411448, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+0,int_stack+573430,int_stack+572170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+474520, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+593572,int_stack+372200,int_stack+371416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412624, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+595924,int_stack+593572,int_stack+573430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475780, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+599452,int_stack+595924,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482080, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+603652,int_stack+599452,int_stack+576580,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+593572,int_stack+168768,int_stack+167688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200100, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+595192,int_stack+170280,int_stack+168768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201720, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+613102,int_stack+595192,int_stack+593572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+488884, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+616342,int_stack+2592,int_stack+170280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6480, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+619366,int_stack+616342,int_stack+595192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490504, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+623902,int_stack+619366,int_stack+613102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508414, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+629302,int_stack+623902,int_stack+599452,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+616342,int_stack+379923,int_stack+379608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+617287,int_stack+380364,int_stack+379923, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+451019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+618610,int_stack+617287,int_stack+616342, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+466204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+620500,int_stack+380952,int_stack+380364, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+451460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+622264,int_stack+620500,int_stack+617287, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467149, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+624910,int_stack+622264,int_stack+618610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+620500,int_stack+384228,int_stack+383808, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+621760,int_stack+384816,int_stack+384228, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+641902,int_stack+621760,int_stack+620500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+474520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+644422,int_stack+385600,int_stack+384816, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+646774,int_stack+644422,int_stack+621760, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+475780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+650302,int_stack+646774,int_stack+641902, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+654502,int_stack+650302,int_stack+624910,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+644422,int_stack+179572,int_stack+178492, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+646042,int_stack+181084,int_stack+179572, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+663952,int_stack+646042,int_stack+644422, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+488884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+667192,int_stack+3888,int_stack+181084, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+670216,int_stack+667192,int_stack+646042, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+674752,int_stack+670216,int_stack+663952, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+680152,int_stack+674752,int_stack+650302,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+667192,int_stack+393323,int_stack+393008, 0.0, zero_stack, 1.0, int_stack+450704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+668137,int_stack+393764,int_stack+393323, 0.0, zero_stack, 1.0, int_stack+451019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+669460,int_stack+668137,int_stack+667192, 0.0, zero_stack, 1.0, int_stack+466204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+671350,int_stack+394352,int_stack+393764, 0.0, zero_stack, 1.0, int_stack+451460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+673114,int_stack+671350,int_stack+668137, 0.0, zero_stack, 1.0, int_stack+467149, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+675760,int_stack+673114,int_stack+669460, 0.0, zero_stack, 1.0, int_stack+468472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+671350,int_stack+397628,int_stack+397208, 0.0, zero_stack, 1.0, int_stack+410608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+672610,int_stack+398216,int_stack+397628, 0.0, zero_stack, 1.0, int_stack+411448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+2520,int_stack+672610,int_stack+671350, 0.0, zero_stack, 1.0, int_stack+474520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+692752,int_stack+399000,int_stack+398216, 0.0, zero_stack, 1.0, int_stack+412624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+695104,int_stack+692752,int_stack+672610, 0.0, zero_stack, 1.0, int_stack+475780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+698632,int_stack+695104,int_stack+2520, 0.0, zero_stack, 1.0, int_stack+482080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+702832,int_stack+698632,int_stack+675760,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+692752,int_stack+190376,int_stack+189296, 0.0, zero_stack, 1.0, int_stack+200100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+694372,int_stack+191888,int_stack+190376, 0.0, zero_stack, 1.0, int_stack+201720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+712282,int_stack+694372,int_stack+692752, 0.0, zero_stack, 1.0, int_stack+488884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+715522,int_stack+5184,int_stack+191888, 0.0, zero_stack, 1.0, int_stack+6480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+718546,int_stack+715522,int_stack+694372, 0.0, zero_stack, 1.0, int_stack+490504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+723082,int_stack+718546,int_stack+712282, 0.0, zero_stack, 1.0, int_stack+508414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+728482,int_stack+723082,int_stack+698632,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+715522,int_stack+406723,int_stack+406408, 1.0, int_stack+450704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716467,int_stack+407164,int_stack+406723, 1.0, int_stack+451019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+717790,int_stack+716467,int_stack+715522, 1.0, int_stack+466204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+719680,int_stack+407752,int_stack+407164, 1.0, int_stack+451460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+721444,int_stack+719680,int_stack+716467, 1.0, int_stack+467149, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+724090,int_stack+721444,int_stack+717790, 1.0, int_stack+468472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+719680,int_stack+412036,int_stack+411028, 1.0, int_stack+410608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+720940,int_stack+413408,int_stack+412036, 1.0, int_stack+411448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+741082,int_stack+720940,int_stack+719680, 1.0, int_stack+474520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+743602,int_stack+414192,int_stack+413408, 1.0, int_stack+412624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+745954,int_stack+743602,int_stack+720940, 1.0, int_stack+475780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+749482,int_stack+745954,int_stack+741082, 1.0, int_stack+482080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+753682,int_stack+749482,int_stack+724090,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+743602,int_stack+202476,int_stack+200640, 1.0, int_stack+200100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+745222,int_stack+203988,int_stack+202476, 1.0, int_stack+201720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+763132,int_stack+745222,int_stack+743602, 1.0, int_stack+488884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+766372,int_stack+7488,int_stack+203988, 1.0, int_stack+6480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+769396,int_stack+766372,int_stack+745222, 1.0, int_stack+490504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+773932,int_stack+769396,int_stack+763132, 1.0, int_stack+508414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+779332,int_stack+773932,int_stack+749482,150);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+508414,int_stack+452048,int_stack+451460,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+766372,int_stack+508414,int_stack+467149,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+508414,int_stack+766372,int_stack+468472,21);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+766372,int_stack+11376,int_stack+412624,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+768724,int_stack+766372,int_stack+475780,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+772252,int_stack+768724,int_stack+482080,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+791932,int_stack+772252,int_stack+508414,150);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+482080,int_stack+424219,int_stack+423904,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+483025,int_stack+424660,int_stack+424219,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+766372,int_stack+483025,int_stack+482080,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+768262,int_stack+425248,int_stack+424660,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+776452,int_stack+768262,int_stack+483025,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+768262,int_stack+776452,int_stack+766372,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+776452,int_stack+428524,int_stack+428104,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+488884,int_stack+429112,int_stack+428524,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+474520,int_stack+488884,int_stack+776452,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+466204,int_stack+429896,int_stack+429112,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+5040,int_stack+466204,int_stack+488884,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+801382,int_stack+5040,int_stack+474520,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+805582,int_stack+801382,int_stack+768262, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+777712,int_stack+255780,int_stack+254700,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5040,int_stack+257292,int_stack+255780,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+466204,int_stack+5040,int_stack+777712,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+815032,int_stack+8784,int_stack+257292,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+818056,int_stack+815032,int_stack+5040,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+822592,int_stack+818056,int_stack+466204,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+827992,int_stack+822592,int_stack+801382, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+772252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+815032,int_stack+437619,int_stack+437304,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+815977,int_stack+438060,int_stack+437619,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+817300,int_stack+815977,int_stack+815032,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+819190,int_stack+438648,int_stack+438060,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+820954,int_stack+819190,int_stack+815977,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+823600,int_stack+820954,int_stack+817300,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+819190,int_stack+441924,int_stack+441504,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+820450,int_stack+442512,int_stack+441924,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+7308,int_stack+820450,int_stack+819190,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+840592,int_stack+443296,int_stack+442512,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+842944,int_stack+840592,int_stack+820450,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+846472,int_stack+842944,int_stack+7308,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+850672,int_stack+846472,int_stack+823600, 0.0, zero_stack, 1.0, int_stack+508414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+840592,int_stack+317584,int_stack+316504,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+842212,int_stack+319096,int_stack+317584,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+860122,int_stack+842212,int_stack+840592,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+863362,int_stack+10080,int_stack+319096,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+866386,int_stack+863362,int_stack+842212,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+870922,int_stack+866386,int_stack+860122,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+876322,int_stack+870922,int_stack+846472, 0.0, zero_stack, 1.0, int_stack+772252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+863362,int_stack+453119,int_stack+452804,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+864307,int_stack+453560,int_stack+453119,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+865630,int_stack+864307,int_stack+863362,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+867520,int_stack+454148,int_stack+453560,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+869284,int_stack+867520,int_stack+864307,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+871930,int_stack+869284,int_stack+865630,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+867520,int_stack+457424,int_stack+457004,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+868780,int_stack+458012,int_stack+457424,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+9828,int_stack+868780,int_stack+867520,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+888922,int_stack+458796,int_stack+458012,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+891274,int_stack+888922,int_stack+868780,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+894802,int_stack+891274,int_stack+9828,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+899002,int_stack+894802,int_stack+871930, 1.0, int_stack+508414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+508414,int_stack+419080,int_stack+418000,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+888922,int_stack+420592,int_stack+419080,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+891190,int_stack+888922,int_stack+508414,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+908452,int_stack+12384,int_stack+420592,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+911476,int_stack+908452,int_stack+888922,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+916012,int_stack+911476,int_stack+891190,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+921412,int_stack+916012,int_stack+894802, 1.0, int_stack+772252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+908452,int_stack+13995,int_stack+13680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+339408,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+909397,int_stack+14436,int_stack+13995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+339723,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+910720,int_stack+909397,int_stack+908452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+470362,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+912610,int_stack+15024,int_stack+14436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+340164,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+914374,int_stack+912610,int_stack+909397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+471307,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+917020,int_stack+914374,int_stack+910720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+472630,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+908452,int_stack+16200,int_stack+15780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+343608,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+909712,int_stack+16788,int_stack+16200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+344028,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+911476,int_stack+909712,int_stack+908452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+477544,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+913996,int_stack+17572,int_stack+16788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+344616,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+913996,int_stack+909712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+484600,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+771412,int_stack+12348,int_stack+911476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+486364,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+934012,int_stack+771412,int_stack+917020,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+510034,int_stack+19120,int_stack+18580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+146080,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12348,int_stack+19876,int_stack+19120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+147160,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14616,int_stack+12348,int_stack+510034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+492772,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+908452,int_stack+20884,int_stack+19876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+148672,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+911476,int_stack+908452,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+511654,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+916012,int_stack+911476,int_stack+14616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+513922,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+943462,int_stack+916012,int_stack+771412,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+771412,int_stack+22495,int_stack+22180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+339408, 1.0, int_stack+352808,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+772357,int_stack+22936,int_stack+22495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+339723, 1.0, int_stack+353123,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+773680,int_stack+772357,int_stack+771412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470362, 1.0, int_stack+517162,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12348,int_stack+23524,int_stack+22936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+340164, 1.0, int_stack+353564,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+14112,int_stack+12348,int_stack+772357, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+471307, 1.0, int_stack+518107,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+16758,int_stack+14112,int_stack+773680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+472630, 1.0, int_stack+519430,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+24700,int_stack+24280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+343608, 1.0, int_stack+357008,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13608,int_stack+25288,int_stack+24700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344028, 1.0, int_stack+357428,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+771412,int_stack+13608,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477544, 1.0, int_stack+521320,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+773932,int_stack+26072,int_stack+25288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344616, 1.0, int_stack+358016,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+19908,int_stack+773932,int_stack+13608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484600, 1.0, int_stack+522580,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+19908,int_stack+771412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486364, 1.0, int_stack+542722,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+908452,int_stack+12348,int_stack+16758,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+510034,int_stack+27620,int_stack+27080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146080, 1.0, int_stack+156884,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+771412,int_stack+28376,int_stack+27620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147160, 1.0, int_stack+157964,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+16548,int_stack+771412,int_stack+510034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492772, 1.0, int_stack+545242,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+19788,int_stack+29384,int_stack+28376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148672, 1.0, int_stack+159476,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+22812,int_stack+19788,int_stack+771412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511654, 1.0, int_stack+546862,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+956062,int_stack+22812,int_stack+16548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+513922, 1.0, int_stack+564772,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+16548,int_stack+956062,int_stack+12348,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+30995,int_stack+30680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+352808, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+31436,int_stack+30995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+353123, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14616,int_stack+13293,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+517162, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+956062,int_stack+32024,int_stack+31436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+353564, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+957826,int_stack+956062,int_stack+13293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+518107, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+29148,int_stack+957826,int_stack+14616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+519430, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+956062,int_stack+33200,int_stack+32780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+357008, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+957322,int_stack+33788,int_stack+33200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+357428, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+959086,int_stack+957322,int_stack+956062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+521320, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12348,int_stack+34572,int_stack+33788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+358016, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+771412,int_stack+12348,int_stack+957322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+522580, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+771412,int_stack+959086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+542722, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+956062,int_stack+12348,int_stack+29148,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+510034,int_stack+36120,int_stack+35580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+156884, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29148,int_stack+36876,int_stack+36120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+157964, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+31416,int_stack+29148,int_stack+510034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+545242, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+771412,int_stack+37884,int_stack+36876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+159476, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+965512,int_stack+771412,int_stack+29148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+546862, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+970048,int_stack+965512,int_stack+31416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+564772, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+975448,int_stack+970048,int_stack+12348,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+39495,int_stack+39180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+339408, 0.0, zero_stack, 1.0, int_stack+366208,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+39936,int_stack+39495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+339723, 0.0, zero_stack, 1.0, int_stack+366523,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14616,int_stack+13293,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470362, 0.0, zero_stack, 1.0, int_stack+568012,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+965512,int_stack+40524,int_stack+39936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+340164, 0.0, zero_stack, 1.0, int_stack+366964,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+967276,int_stack+965512,int_stack+13293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+471307, 0.0, zero_stack, 1.0, int_stack+568957,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+969922,int_stack+967276,int_stack+14616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+472630, 0.0, zero_stack, 1.0, int_stack+570280,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+41700,int_stack+41280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+343608, 0.0, zero_stack, 1.0, int_stack+370408,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966772,int_stack+42288,int_stack+41700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344028, 0.0, zero_stack, 1.0, int_stack+370828,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+12348,int_stack+966772,int_stack+965512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477544, 0.0, zero_stack, 1.0, int_stack+572170,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+973072,int_stack+43072,int_stack+42288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344616, 0.0, zero_stack, 1.0, int_stack+371416,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29148,int_stack+973072,int_stack+966772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484600, 0.0, zero_stack, 1.0, int_stack+573430,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+965512,int_stack+29148,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486364, 0.0, zero_stack, 1.0, int_stack+0,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+29148,int_stack+965512,int_stack+969922,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+510034,int_stack+44620,int_stack+44080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146080, 0.0, zero_stack, 1.0, int_stack+167688,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12348,int_stack+45376,int_stack+44620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147160, 0.0, zero_stack, 1.0, int_stack+168768,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+38598,int_stack+12348,int_stack+510034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492772, 0.0, zero_stack, 1.0, int_stack+593572,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+41838,int_stack+46384,int_stack+45376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148672, 0.0, zero_stack, 1.0, int_stack+170280,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+969712,int_stack+41838,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511654, 0.0, zero_stack, 1.0, int_stack+595192,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+41838,int_stack+969712,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+513922, 0.0, zero_stack, 1.0, int_stack+613102,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+988048,int_stack+41838,int_stack+965512,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+47995,int_stack+47680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+352808, 1.0, int_stack+366208, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966457,int_stack+48436,int_stack+47995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+353123, 1.0, int_stack+366523, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+967780,int_stack+966457,int_stack+965512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+517162, 1.0, int_stack+568012, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+969670,int_stack+49024,int_stack+48436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+353564, 1.0, int_stack+366964, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+971434,int_stack+969670,int_stack+966457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+518107, 1.0, int_stack+568957, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+971434,int_stack+967780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519430, 1.0, int_stack+570280, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+50200,int_stack+49780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357008, 1.0, int_stack+370408, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966772,int_stack+50788,int_stack+50200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357428, 1.0, int_stack+370828, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+968536,int_stack+966772,int_stack+965512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+521320, 1.0, int_stack+572170, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+971056,int_stack+51572,int_stack+50788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+358016, 1.0, int_stack+371416, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+41748,int_stack+971056,int_stack+966772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+522580, 1.0, int_stack+573430, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+41748,int_stack+968536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+542722, 1.0, int_stack+0, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+41748,int_stack+12348,int_stack+38598,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+510034,int_stack+53120,int_stack+52580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156884, 1.0, int_stack+167688, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38598,int_stack+53876,int_stack+53120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157964, 1.0, int_stack+168768, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+965512,int_stack+38598,int_stack+510034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+545242, 1.0, int_stack+593572, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+968752,int_stack+54884,int_stack+53876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159476, 1.0, int_stack+170280, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+51198,int_stack+968752,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546862, 1.0, int_stack+595192, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+968752,int_stack+51198,int_stack+965512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+564772, 1.0, int_stack+613102, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1000648,int_stack+968752,int_stack+12348,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+56495,int_stack+56180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+366208, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+56936,int_stack+56495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+366523, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14616,int_stack+13293,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+568012, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+965512,int_stack+57524,int_stack+56936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+366964, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+967276,int_stack+965512,int_stack+13293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+568957, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+967276,int_stack+14616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+570280, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+58700,int_stack+58280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+370408, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966772,int_stack+59288,int_stack+58700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+370828, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+968536,int_stack+966772,int_stack+965512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+572170, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+971056,int_stack+60072,int_stack+59288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+371416, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+971056,int_stack+966772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+573430, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+971056,int_stack+12348,int_stack+968536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+51198,int_stack+971056,int_stack+38598,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+510034,int_stack+61620,int_stack+61080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+167688, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38598,int_stack+62376,int_stack+61620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+168768, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+12348,int_stack+38598,int_stack+510034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+593572, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+965512,int_stack+63384,int_stack+62376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+170280, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+771412,int_stack+965512,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+595192, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+965512,int_stack+771412,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+613102, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1013248,int_stack+965512,int_stack+971056,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+64995,int_stack+64680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+339408, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+379608,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966457,int_stack+65436,int_stack+64995, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+339723, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+379923,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+967780,int_stack+966457,int_stack+965512, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470362, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+616342,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+969670,int_stack+66024,int_stack+65436, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+340164, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+380364,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+971434,int_stack+969670,int_stack+966457, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+471307, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617287,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+971434,int_stack+967780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+472630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+618610,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+67200,int_stack+66780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+343608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+383808,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966772,int_stack+67788,int_stack+67200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344028, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384228,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+968536,int_stack+966772,int_stack+965512, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477544, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+620500,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+971056,int_stack+68572,int_stack+67788, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344616, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384816,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+971056,int_stack+966772, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621760,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+971056,int_stack+12348,int_stack+968536, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486364, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+641902,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1025848,int_stack+971056,int_stack+38598,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+510034,int_stack+70120,int_stack+69580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178492,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38598,int_stack+70876,int_stack+70120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179572,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+12348,int_stack+38598,int_stack+510034, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492772, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+644422,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+965512,int_stack+71884,int_stack+70876, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148672, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181084,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+771412,int_stack+965512,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511654, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646042,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+965512,int_stack+771412,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+513922, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663952,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1035298,int_stack+965512,int_stack+971056,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+73495,int_stack+73180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+352808, 0.0, zero_stack, 1.0, int_stack+379608, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966457,int_stack+73936,int_stack+73495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+353123, 0.0, zero_stack, 1.0, int_stack+379923, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+967780,int_stack+966457,int_stack+965512, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+517162, 0.0, zero_stack, 1.0, int_stack+616342, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+969670,int_stack+74524,int_stack+73936, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+353564, 0.0, zero_stack, 1.0, int_stack+380364, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+971434,int_stack+969670,int_stack+966457, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+518107, 0.0, zero_stack, 1.0, int_stack+617287, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+971434,int_stack+967780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519430, 0.0, zero_stack, 1.0, int_stack+618610, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+75700,int_stack+75280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357008, 0.0, zero_stack, 1.0, int_stack+383808, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966772,int_stack+76288,int_stack+75700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357428, 0.0, zero_stack, 1.0, int_stack+384228, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+968536,int_stack+966772,int_stack+965512, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+521320, 0.0, zero_stack, 1.0, int_stack+620500, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+971056,int_stack+77072,int_stack+76288, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+358016, 0.0, zero_stack, 1.0, int_stack+384816, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+971056,int_stack+966772, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+522580, 0.0, zero_stack, 1.0, int_stack+621760, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+971056,int_stack+12348,int_stack+968536, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+542722, 0.0, zero_stack, 1.0, int_stack+641902, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+60648,int_stack+971056,int_stack+38598,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+510034,int_stack+78620,int_stack+78080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156884, 0.0, zero_stack, 1.0, int_stack+178492, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38598,int_stack+79376,int_stack+78620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157964, 0.0, zero_stack, 1.0, int_stack+179572, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+12348,int_stack+38598,int_stack+510034, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+545242, 0.0, zero_stack, 1.0, int_stack+644422, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+965512,int_stack+80384,int_stack+79376, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159476, 0.0, zero_stack, 1.0, int_stack+181084, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+771412,int_stack+965512,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546862, 0.0, zero_stack, 1.0, int_stack+646042, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+965512,int_stack+771412,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+564772, 0.0, zero_stack, 1.0, int_stack+663952, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1047898,int_stack+965512,int_stack+971056,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+81995,int_stack+81680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366208, 1.0, int_stack+379608, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966457,int_stack+82436,int_stack+81995, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366523, 1.0, int_stack+379923, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+967780,int_stack+966457,int_stack+965512, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+568012, 1.0, int_stack+616342, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+969670,int_stack+83024,int_stack+82436, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366964, 1.0, int_stack+380364, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+971434,int_stack+969670,int_stack+966457, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+568957, 1.0, int_stack+617287, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+971434,int_stack+967780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+570280, 1.0, int_stack+618610, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+84200,int_stack+83780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370408, 1.0, int_stack+383808, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966772,int_stack+84788,int_stack+84200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370828, 1.0, int_stack+384228, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+968536,int_stack+966772,int_stack+965512, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+572170, 1.0, int_stack+620500, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+971056,int_stack+85572,int_stack+84788, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371416, 1.0, int_stack+384816, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+971056,int_stack+966772, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+573430, 1.0, int_stack+621760, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+971056,int_stack+12348,int_stack+968536, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+641902, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+70098,int_stack+971056,int_stack+38598,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+510034,int_stack+87120,int_stack+86580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167688, 1.0, int_stack+178492, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38598,int_stack+87876,int_stack+87120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168768, 1.0, int_stack+179572, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+12348,int_stack+38598,int_stack+510034, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+593572, 1.0, int_stack+644422, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+965512,int_stack+88884,int_stack+87876, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+170280, 1.0, int_stack+181084, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+771412,int_stack+965512,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595192, 1.0, int_stack+646042, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+965512,int_stack+771412,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+613102, 1.0, int_stack+663952, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1060498,int_stack+965512,int_stack+971056,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+90495,int_stack+90180, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+379608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966457,int_stack+90936,int_stack+90495, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+379923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+967780,int_stack+966457,int_stack+965512, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+616342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+969670,int_stack+91524,int_stack+90936, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+380364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+971434,int_stack+969670,int_stack+966457, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+617287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+971434,int_stack+967780, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+618610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+92700,int_stack+92280, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+383808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966772,int_stack+93288,int_stack+92700, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+384228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+968536,int_stack+966772,int_stack+965512, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+620500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+971056,int_stack+94072,int_stack+93288, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+384816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+971056,int_stack+966772, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+621760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+971056,int_stack+12348,int_stack+968536, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+641902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+79548,int_stack+971056,int_stack+38598,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+510034,int_stack+95620,int_stack+95080, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+178492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38598,int_stack+96376,int_stack+95620, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+179572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+12348,int_stack+38598,int_stack+510034, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+644422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+965512,int_stack+97384,int_stack+96376, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+181084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+771412,int_stack+965512,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+646042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+965512,int_stack+771412,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+663952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1073098,int_stack+965512,int_stack+971056,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+98995,int_stack+98680, 0.0, zero_stack, 1.0, int_stack+339408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393008,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966457,int_stack+99436,int_stack+98995, 0.0, zero_stack, 1.0, int_stack+339723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393323,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+967780,int_stack+966457,int_stack+965512, 0.0, zero_stack, 1.0, int_stack+470362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+667192,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+969670,int_stack+100024,int_stack+99436, 0.0, zero_stack, 1.0, int_stack+340164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393764,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+971434,int_stack+969670,int_stack+966457, 0.0, zero_stack, 1.0, int_stack+471307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+668137,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+971434,int_stack+967780, 0.0, zero_stack, 1.0, int_stack+472630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+669460,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+101200,int_stack+100780, 0.0, zero_stack, 1.0, int_stack+343608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397208,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966772,int_stack+101788,int_stack+101200, 0.0, zero_stack, 1.0, int_stack+344028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397628,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+968536,int_stack+966772,int_stack+965512, 0.0, zero_stack, 1.0, int_stack+477544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+671350,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+971056,int_stack+102572,int_stack+101788, 0.0, zero_stack, 1.0, int_stack+344616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398216,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+971056,int_stack+966772, 0.0, zero_stack, 1.0, int_stack+484600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+672610,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+971056,int_stack+12348,int_stack+968536, 0.0, zero_stack, 1.0, int_stack+486364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+88998,int_stack+971056,int_stack+38598,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+510034,int_stack+104120,int_stack+103580, 0.0, zero_stack, 1.0, int_stack+146080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189296,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38598,int_stack+104876,int_stack+104120, 0.0, zero_stack, 1.0, int_stack+147160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190376,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+12348,int_stack+38598,int_stack+510034, 0.0, zero_stack, 1.0, int_stack+492772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+692752,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+965512,int_stack+105884,int_stack+104876, 0.0, zero_stack, 1.0, int_stack+148672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+191888,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+771412,int_stack+965512,int_stack+38598, 0.0, zero_stack, 1.0, int_stack+511654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+694372,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+965512,int_stack+771412,int_stack+12348, 0.0, zero_stack, 1.0, int_stack+513922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+712282,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1085698,int_stack+965512,int_stack+971056,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+107495,int_stack+107180, 0.0, zero_stack, 1.0, int_stack+352808, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393008, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966457,int_stack+107936,int_stack+107495, 0.0, zero_stack, 1.0, int_stack+353123, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393323, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+967780,int_stack+966457,int_stack+965512, 0.0, zero_stack, 1.0, int_stack+517162, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+667192, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+969670,int_stack+108524,int_stack+107936, 0.0, zero_stack, 1.0, int_stack+353564, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393764, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+971434,int_stack+969670,int_stack+966457, 0.0, zero_stack, 1.0, int_stack+518107, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+668137, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+971434,int_stack+967780, 0.0, zero_stack, 1.0, int_stack+519430, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+669460, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+109700,int_stack+109280, 0.0, zero_stack, 1.0, int_stack+357008, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397208, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966772,int_stack+110288,int_stack+109700, 0.0, zero_stack, 1.0, int_stack+357428, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397628, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+968536,int_stack+966772,int_stack+965512, 0.0, zero_stack, 1.0, int_stack+521320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+671350, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+971056,int_stack+111072,int_stack+110288, 0.0, zero_stack, 1.0, int_stack+358016, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398216, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+971056,int_stack+966772, 0.0, zero_stack, 1.0, int_stack+522580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+672610, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+971056,int_stack+12348,int_stack+968536, 0.0, zero_stack, 1.0, int_stack+542722, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+98448,int_stack+971056,int_stack+38598,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+510034,int_stack+112620,int_stack+112080, 0.0, zero_stack, 1.0, int_stack+156884, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189296, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38598,int_stack+113376,int_stack+112620, 0.0, zero_stack, 1.0, int_stack+157964, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190376, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+12348,int_stack+38598,int_stack+510034, 0.0, zero_stack, 1.0, int_stack+545242, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+692752, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+965512,int_stack+114384,int_stack+113376, 0.0, zero_stack, 1.0, int_stack+159476, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+191888, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+771412,int_stack+965512,int_stack+38598, 0.0, zero_stack, 1.0, int_stack+546862, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+694372, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+965512,int_stack+771412,int_stack+12348, 0.0, zero_stack, 1.0, int_stack+564772, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+712282, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1098298,int_stack+965512,int_stack+971056,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+115995,int_stack+115680, 0.0, zero_stack, 1.0, int_stack+366208, 0.0, zero_stack, 1.0, int_stack+393008, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966457,int_stack+116436,int_stack+115995, 0.0, zero_stack, 1.0, int_stack+366523, 0.0, zero_stack, 1.0, int_stack+393323, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+967780,int_stack+966457,int_stack+965512, 0.0, zero_stack, 1.0, int_stack+568012, 0.0, zero_stack, 1.0, int_stack+667192, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+969670,int_stack+117024,int_stack+116436, 0.0, zero_stack, 1.0, int_stack+366964, 0.0, zero_stack, 1.0, int_stack+393764, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+971434,int_stack+969670,int_stack+966457, 0.0, zero_stack, 1.0, int_stack+568957, 0.0, zero_stack, 1.0, int_stack+668137, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+971434,int_stack+967780, 0.0, zero_stack, 1.0, int_stack+570280, 0.0, zero_stack, 1.0, int_stack+669460, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+118200,int_stack+117780, 0.0, zero_stack, 1.0, int_stack+370408, 0.0, zero_stack, 1.0, int_stack+397208, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966772,int_stack+118788,int_stack+118200, 0.0, zero_stack, 1.0, int_stack+370828, 0.0, zero_stack, 1.0, int_stack+397628, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+968536,int_stack+966772,int_stack+965512, 0.0, zero_stack, 1.0, int_stack+572170, 0.0, zero_stack, 1.0, int_stack+671350, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+971056,int_stack+119572,int_stack+118788, 0.0, zero_stack, 1.0, int_stack+371416, 0.0, zero_stack, 1.0, int_stack+398216, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+971056,int_stack+966772, 0.0, zero_stack, 1.0, int_stack+573430, 0.0, zero_stack, 1.0, int_stack+672610, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+971056,int_stack+12348,int_stack+968536, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+107898,int_stack+971056,int_stack+38598,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+510034,int_stack+121120,int_stack+120580, 0.0, zero_stack, 1.0, int_stack+167688, 0.0, zero_stack, 1.0, int_stack+189296, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38598,int_stack+121876,int_stack+121120, 0.0, zero_stack, 1.0, int_stack+168768, 0.0, zero_stack, 1.0, int_stack+190376, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+12348,int_stack+38598,int_stack+510034, 0.0, zero_stack, 1.0, int_stack+593572, 0.0, zero_stack, 1.0, int_stack+692752, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+965512,int_stack+122884,int_stack+121876, 0.0, zero_stack, 1.0, int_stack+170280, 0.0, zero_stack, 1.0, int_stack+191888, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+771412,int_stack+965512,int_stack+38598, 0.0, zero_stack, 1.0, int_stack+595192, 0.0, zero_stack, 1.0, int_stack+694372, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+965512,int_stack+771412,int_stack+12348, 0.0, zero_stack, 1.0, int_stack+613102, 0.0, zero_stack, 1.0, int_stack+712282, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1110898,int_stack+965512,int_stack+971056,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+124495,int_stack+124180, 0.0, zero_stack, 1.0, int_stack+379608, 1.0, int_stack+393008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966457,int_stack+124936,int_stack+124495, 0.0, zero_stack, 1.0, int_stack+379923, 1.0, int_stack+393323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+967780,int_stack+966457,int_stack+965512, 0.0, zero_stack, 1.0, int_stack+616342, 1.0, int_stack+667192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+969670,int_stack+125524,int_stack+124936, 0.0, zero_stack, 1.0, int_stack+380364, 1.0, int_stack+393764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+971434,int_stack+969670,int_stack+966457, 0.0, zero_stack, 1.0, int_stack+617287, 1.0, int_stack+668137, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+971434,int_stack+967780, 0.0, zero_stack, 1.0, int_stack+618610, 1.0, int_stack+669460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+126700,int_stack+126280, 0.0, zero_stack, 1.0, int_stack+383808, 1.0, int_stack+397208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966772,int_stack+127288,int_stack+126700, 0.0, zero_stack, 1.0, int_stack+384228, 1.0, int_stack+397628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+968536,int_stack+966772,int_stack+965512, 0.0, zero_stack, 1.0, int_stack+620500, 1.0, int_stack+671350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+971056,int_stack+128072,int_stack+127288, 0.0, zero_stack, 1.0, int_stack+384816, 1.0, int_stack+398216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+971056,int_stack+966772, 0.0, zero_stack, 1.0, int_stack+621760, 1.0, int_stack+672610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+971056,int_stack+12348,int_stack+968536, 0.0, zero_stack, 1.0, int_stack+641902, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+117348,int_stack+971056,int_stack+38598,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+510034,int_stack+129620,int_stack+129080, 0.0, zero_stack, 1.0, int_stack+178492, 1.0, int_stack+189296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38598,int_stack+130376,int_stack+129620, 0.0, zero_stack, 1.0, int_stack+179572, 1.0, int_stack+190376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+12348,int_stack+38598,int_stack+510034, 0.0, zero_stack, 1.0, int_stack+644422, 1.0, int_stack+692752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+965512,int_stack+131384,int_stack+130376, 0.0, zero_stack, 1.0, int_stack+181084, 1.0, int_stack+191888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+771412,int_stack+965512,int_stack+38598, 0.0, zero_stack, 1.0, int_stack+646042, 1.0, int_stack+694372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+965512,int_stack+771412,int_stack+12348, 0.0, zero_stack, 1.0, int_stack+663952, 1.0, int_stack+712282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1123498,int_stack+965512,int_stack+971056,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+132995,int_stack+132680, 0.0, zero_stack, 2.0, int_stack+393008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966457,int_stack+133436,int_stack+132995, 0.0, zero_stack, 2.0, int_stack+393323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+967780,int_stack+966457,int_stack+965512, 0.0, zero_stack, 2.0, int_stack+667192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+969670,int_stack+134024,int_stack+133436, 0.0, zero_stack, 2.0, int_stack+393764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+971434,int_stack+969670,int_stack+966457, 0.0, zero_stack, 2.0, int_stack+668137, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+971434,int_stack+967780, 0.0, zero_stack, 2.0, int_stack+669460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+135200,int_stack+134780, 0.0, zero_stack, 2.0, int_stack+397208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966772,int_stack+135788,int_stack+135200, 0.0, zero_stack, 2.0, int_stack+397628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+968536,int_stack+966772,int_stack+965512, 0.0, zero_stack, 2.0, int_stack+671350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+971056,int_stack+136572,int_stack+135788, 0.0, zero_stack, 2.0, int_stack+398216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+971056,int_stack+966772, 0.0, zero_stack, 2.0, int_stack+672610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+971056,int_stack+12348,int_stack+968536, 0.0, zero_stack, 2.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+126798,int_stack+971056,int_stack+38598,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+510034,int_stack+138120,int_stack+137580, 0.0, zero_stack, 2.0, int_stack+189296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38598,int_stack+138876,int_stack+138120, 0.0, zero_stack, 2.0, int_stack+190376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+12348,int_stack+38598,int_stack+510034, 0.0, zero_stack, 2.0, int_stack+692752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+965512,int_stack+139884,int_stack+138876, 0.0, zero_stack, 2.0, int_stack+191888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+771412,int_stack+965512,int_stack+38598, 0.0, zero_stack, 2.0, int_stack+694372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+965512,int_stack+771412,int_stack+12348, 0.0, zero_stack, 2.0, int_stack+712282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1136098,int_stack+965512,int_stack+971056,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+141495,int_stack+141180, 1.0, int_stack+339408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406408,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966457,int_stack+141936,int_stack+141495, 1.0, int_stack+339723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406723,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+967780,int_stack+966457,int_stack+965512, 1.0, int_stack+470362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+715522,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+969670,int_stack+142524,int_stack+141936, 1.0, int_stack+340164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+407164,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+971434,int_stack+969670,int_stack+966457, 1.0, int_stack+471307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+716467,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+971434,int_stack+967780, 1.0, int_stack+472630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+717790,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+143700,int_stack+143280, 1.0, int_stack+343608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411028,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966772,int_stack+144288,int_stack+143700, 1.0, int_stack+344028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412036,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+968536,int_stack+966772,int_stack+965512, 1.0, int_stack+477544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+719680,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+971056,int_stack+145072,int_stack+144288, 1.0, int_stack+344616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+413408,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+971056,int_stack+966772, 1.0, int_stack+484600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+720940,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+971056,int_stack+12348,int_stack+968536, 1.0, int_stack+486364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+741082,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+136248,int_stack+971056,int_stack+38598,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+510034,int_stack+147916,int_stack+146620, 1.0, int_stack+146080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200640,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38598,int_stack+149680,int_stack+147916, 1.0, int_stack+147160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202476,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+12348,int_stack+38598,int_stack+510034, 1.0, int_stack+492772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+743602,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+965512,int_stack+150688,int_stack+149680, 1.0, int_stack+148672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203988,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+484348,int_stack+965512,int_stack+38598, 1.0, int_stack+511654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+745222,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+965512,int_stack+484348,int_stack+12348, 1.0, int_stack+513922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+763132,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1148698,int_stack+965512,int_stack+971056,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+965512,int_stack+152299,int_stack+151984, 1.0, int_stack+352808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406408, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+966457,int_stack+152740,int_stack+152299, 1.0, int_stack+353123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406723, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+477040,int_stack+966457,int_stack+965512, 1.0, int_stack+517162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+715522, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+967780,int_stack+153328,int_stack+152740, 1.0, int_stack+353564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+407164, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+969544,int_stack+967780,int_stack+966457, 1.0, int_stack+518107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+716467, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+969544,int_stack+477040, 1.0, int_stack+519430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+717790, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+477040,int_stack+154504,int_stack+154084, 1.0, int_stack+357008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411028, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+965512,int_stack+155092,int_stack+154504, 1.0, int_stack+357428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412036, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+967276,int_stack+965512,int_stack+477040, 1.0, int_stack+521320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+719680, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+969796,int_stack+155876,int_stack+155092, 1.0, int_stack+358016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+413408, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+969796,int_stack+965512, 1.0, int_stack+522580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+720940, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+969796,int_stack+12348,int_stack+967276, 1.0, int_stack+542722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+741082, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+510034,int_stack+969796,int_stack+38598,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+158720,int_stack+157424, 1.0, int_stack+156884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200640, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+542722,int_stack+160484,int_stack+158720, 1.0, int_stack+157964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202476, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+12348,int_stack+542722,int_stack+38598, 1.0, int_stack+545242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+743602, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+161492,int_stack+160484, 1.0, int_stack+159476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203988, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+484348,int_stack+38598,int_stack+542722, 1.0, int_stack+546862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+745222, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+542722,int_stack+484348,int_stack+12348, 1.0, int_stack+564772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+763132, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+145698,int_stack+542722,int_stack+969796,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+542722,int_stack+163103,int_stack+162788, 1.0, int_stack+366208, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406408, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+543667,int_stack+163544,int_stack+163103, 1.0, int_stack+366523, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406723, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+477040,int_stack+543667,int_stack+542722, 1.0, int_stack+568012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+715522, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+544990,int_stack+164132,int_stack+163544, 1.0, int_stack+366964, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+407164, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+546754,int_stack+544990,int_stack+543667, 1.0, int_stack+568957, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+716467, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+546754,int_stack+477040, 1.0, int_stack+570280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+717790, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+477040,int_stack+165308,int_stack+164888, 1.0, int_stack+370408, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411028, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+542722,int_stack+165896,int_stack+165308, 1.0, int_stack+370828, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412036, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+544486,int_stack+542722,int_stack+477040, 1.0, int_stack+572170, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+719680, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+547006,int_stack+166680,int_stack+165896, 1.0, int_stack+371416, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+413408, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+564772,int_stack+547006,int_stack+542722, 1.0, int_stack+573430, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+720940, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+564772,int_stack+544486, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+741082, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+564772,int_stack+12348,int_stack+38598,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+169524,int_stack+168228, 1.0, int_stack+167688, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200640, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+171288,int_stack+169524, 1.0, int_stack+168768, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202476, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+542722,int_stack+0,int_stack+38598, 1.0, int_stack+593572, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+743602, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+172296,int_stack+171288, 1.0, int_stack+170280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203988, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+484348,int_stack+38598,int_stack+0, 1.0, int_stack+595192, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+745222, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+593572,int_stack+484348,int_stack+542722, 1.0, int_stack+613102, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+763132, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+158298,int_stack+593572,int_stack+12348,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+173907,int_stack+173592, 1.0, int_stack+379608, 0.0, zero_stack, 1.0, int_stack+406408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+174348,int_stack+173907, 1.0, int_stack+379923, 0.0, zero_stack, 1.0, int_stack+406723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+477040,int_stack+13293,int_stack+12348, 1.0, int_stack+616342, 0.0, zero_stack, 1.0, int_stack+715522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+14616,int_stack+174936,int_stack+174348, 1.0, int_stack+380364, 0.0, zero_stack, 1.0, int_stack+407164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+593572,int_stack+14616,int_stack+13293, 1.0, int_stack+617287, 0.0, zero_stack, 1.0, int_stack+716467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+593572,int_stack+477040, 1.0, int_stack+618610, 0.0, zero_stack, 1.0, int_stack+717790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+477040,int_stack+176112,int_stack+175692, 1.0, int_stack+383808, 0.0, zero_stack, 1.0, int_stack+411028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+593572,int_stack+176700,int_stack+176112, 1.0, int_stack+384228, 0.0, zero_stack, 1.0, int_stack+412036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+0,int_stack+593572,int_stack+477040, 1.0, int_stack+620500, 0.0, zero_stack, 1.0, int_stack+719680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+595336,int_stack+177484,int_stack+176700, 1.0, int_stack+384816, 0.0, zero_stack, 1.0, int_stack+413408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+595336,int_stack+593572, 1.0, int_stack+621760, 0.0, zero_stack, 1.0, int_stack+720940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+593572,int_stack+12348,int_stack+0, 1.0, int_stack+641902, 0.0, zero_stack, 1.0, int_stack+741082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+613102,int_stack+593572,int_stack+38598,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+180328,int_stack+179032, 1.0, int_stack+178492, 0.0, zero_stack, 1.0, int_stack+200640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+641902,int_stack+182092,int_stack+180328, 1.0, int_stack+179572, 0.0, zero_stack, 1.0, int_stack+202476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+12348,int_stack+641902,int_stack+38598, 1.0, int_stack+644422, 0.0, zero_stack, 1.0, int_stack+743602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+183100,int_stack+182092, 1.0, int_stack+181084, 0.0, zero_stack, 1.0, int_stack+203988, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+484348,int_stack+38598,int_stack+641902, 1.0, int_stack+646042, 0.0, zero_stack, 1.0, int_stack+745222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+641902,int_stack+484348,int_stack+12348, 1.0, int_stack+663952, 0.0, zero_stack, 1.0, int_stack+763132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+170898,int_stack+641902,int_stack+593572,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+593572,int_stack+184711,int_stack+184396, 1.0, int_stack+393008, 1.0, int_stack+406408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+594517,int_stack+185152,int_stack+184711, 1.0, int_stack+393323, 1.0, int_stack+406723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+477040,int_stack+594517,int_stack+593572, 1.0, int_stack+667192, 1.0, int_stack+715522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+595840,int_stack+185740,int_stack+185152, 1.0, int_stack+393764, 1.0, int_stack+407164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+641902,int_stack+595840,int_stack+594517, 1.0, int_stack+668137, 1.0, int_stack+716467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+641902,int_stack+477040, 1.0, int_stack+669460, 1.0, int_stack+717790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+477040,int_stack+186916,int_stack+186496, 1.0, int_stack+397208, 1.0, int_stack+411028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+641902,int_stack+187504,int_stack+186916, 1.0, int_stack+397628, 1.0, int_stack+412036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+0,int_stack+641902,int_stack+477040, 1.0, int_stack+671350, 1.0, int_stack+719680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+643666,int_stack+188288,int_stack+187504, 1.0, int_stack+398216, 1.0, int_stack+413408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+646018,int_stack+643666,int_stack+641902, 1.0, int_stack+672610, 1.0, int_stack+720940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+646018,int_stack+0, 1.0, int_stack+2520, 1.0, int_stack+741082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+663952,int_stack+12348,int_stack+38598,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+191132,int_stack+189836, 1.0, int_stack+189296, 1.0, int_stack+200640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+192896,int_stack+191132, 1.0, int_stack+190376, 1.0, int_stack+202476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+641902,int_stack+0,int_stack+38598, 1.0, int_stack+692752, 1.0, int_stack+743602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+193904,int_stack+192896, 1.0, int_stack+191888, 1.0, int_stack+203988, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+484348,int_stack+38598,int_stack+0, 1.0, int_stack+694372, 1.0, int_stack+745222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+692752,int_stack+484348,int_stack+641902, 1.0, int_stack+712282, 1.0, int_stack+763132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1161298,int_stack+692752,int_stack+12348,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+195515,int_stack+195200, 2.0, int_stack+406408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+195956,int_stack+195515, 2.0, int_stack+406723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+477040,int_stack+13293,int_stack+12348, 2.0, int_stack+715522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+14616,int_stack+196544,int_stack+195956, 2.0, int_stack+407164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+692752,int_stack+14616,int_stack+13293, 2.0, int_stack+716467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+692752,int_stack+477040, 2.0, int_stack+717790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+477040,int_stack+197720,int_stack+197300, 2.0, int_stack+411028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+692752,int_stack+198308,int_stack+197720, 2.0, int_stack+412036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+694516,int_stack+692752,int_stack+477040, 2.0, int_stack+719680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12348,int_stack+199092,int_stack+198308, 2.0, int_stack+413408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+712282,int_stack+12348,int_stack+692752, 2.0, int_stack+720940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+712282,int_stack+694516, 2.0, int_stack+741082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+712282,int_stack+12348,int_stack+38598,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+203232,int_stack+201180, 2.0, int_stack+200640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+741082,int_stack+204996,int_stack+203232, 2.0, int_stack+202476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+692752,int_stack+741082,int_stack+38598, 2.0, int_stack+743602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+206004,int_stack+204996, 2.0, int_stack+203988, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+484348,int_stack+38598,int_stack+741082, 2.0, int_stack+745222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+741082,int_stack+484348,int_stack+692752, 2.0, int_stack+763132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+183498,int_stack+741082,int_stack+12348,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+207615,int_stack+207300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+423904,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+208056,int_stack+207615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+424219,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+477040,int_stack+13293,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482080,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+14616,int_stack+208644,int_stack+208056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+424660,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+741082,int_stack+14616,int_stack+13293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483025,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+741082,int_stack+477040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+766372,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+477040,int_stack+209820,int_stack+209400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+428104,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+741082,int_stack+210408,int_stack+209820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+428524,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+742846,int_stack+741082,int_stack+477040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+776452,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+745366,int_stack+211192,int_stack+210408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429112,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+745366,int_stack+741082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+488884,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+692752,int_stack+12348,int_stack+742846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+474520,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+965512,int_stack+692752,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+212740,int_stack+212200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254700,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12348,int_stack+213496,int_stack+212740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255780,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+763132,int_stack+12348,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777712,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+214504,int_stack+213496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257292,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+484348,int_stack+38598,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+741082,int_stack+484348,int_stack+763132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+466204,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+196098,int_stack+741082,int_stack+692752, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+494764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+692752,int_stack+216115,int_stack+215800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+423904, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+693697,int_stack+216556,int_stack+216115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+424219, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+477040,int_stack+693697,int_stack+692752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482080, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+695020,int_stack+217144,int_stack+216556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+424660, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+741082,int_stack+695020,int_stack+693697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483025, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+741082,int_stack+477040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+766372, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+477040,int_stack+218320,int_stack+217900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+428104, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+741082,int_stack+218908,int_stack+218320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+428524, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+742846,int_stack+741082,int_stack+477040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+776452, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+745366,int_stack+219692,int_stack+218908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429112, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+692752,int_stack+745366,int_stack+741082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+488884, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+692752,int_stack+742846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+474520, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+208698,int_stack+12348,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+525730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+221240,int_stack+220700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254700, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+692752,int_stack+221996,int_stack+221240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255780, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+763132,int_stack+692752,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777712, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+223004,int_stack+221996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257292, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+484348,int_stack+38598,int_stack+692752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+692752,int_stack+484348,int_stack+763132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+466204, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1173898,int_stack+692752,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+224615,int_stack+224300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+423904, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+225056,int_stack+224615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+424219, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+477040,int_stack+13293,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482080, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+14616,int_stack+225644,int_stack+225056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+424660, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+692752,int_stack+14616,int_stack+13293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483025, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+692752,int_stack+477040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+766372, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+477040,int_stack+226820,int_stack+226400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+428104, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+692752,int_stack+227408,int_stack+226820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+428524, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+694516,int_stack+692752,int_stack+477040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+776452, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12348,int_stack+228192,int_stack+227408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429112, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+484348,int_stack+12348,int_stack+692752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+488884, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+484348,int_stack+694516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+474520, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+218148,int_stack+12348,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+576580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+229740,int_stack+229200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254700, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+484348,int_stack+230496,int_stack+229740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255780, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+763132,int_stack+484348,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777712, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+231504,int_stack+230496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257292, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+692752,int_stack+38598,int_stack+484348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+741082,int_stack+692752,int_stack+763132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+466204, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1186498,int_stack+741082,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+233115,int_stack+232800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+423904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+233556,int_stack+233115, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+424219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+477040,int_stack+13293,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+14616,int_stack+234144,int_stack+233556, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+424660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+741082,int_stack+14616,int_stack+13293, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+741082,int_stack+477040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+766372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+477040,int_stack+235320,int_stack+234900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+428104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+741082,int_stack+235908,int_stack+235320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+428524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+742846,int_stack+741082,int_stack+477040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+776452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+745366,int_stack+236692,int_stack+235908, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+745366,int_stack+741082, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+488884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+692752,int_stack+12348,int_stack+742846, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+474520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+227598,int_stack+692752,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+624910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+238240,int_stack+237700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12348,int_stack+238996,int_stack+238240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+763132,int_stack+12348,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+240004,int_stack+238996, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+484348,int_stack+38598,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+741082,int_stack+484348,int_stack+763132, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+466204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1199098,int_stack+741082,int_stack+692752, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+650302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+692752,int_stack+241615,int_stack+241300, 0.0, zero_stack, 1.0, int_stack+423904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+693697,int_stack+242056,int_stack+241615, 0.0, zero_stack, 1.0, int_stack+424219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+477040,int_stack+693697,int_stack+692752, 0.0, zero_stack, 1.0, int_stack+482080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+695020,int_stack+242644,int_stack+242056, 0.0, zero_stack, 1.0, int_stack+424660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+741082,int_stack+695020,int_stack+693697, 0.0, zero_stack, 1.0, int_stack+483025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+741082,int_stack+477040, 0.0, zero_stack, 1.0, int_stack+766372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+477040,int_stack+243820,int_stack+243400, 0.0, zero_stack, 1.0, int_stack+428104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+741082,int_stack+244408,int_stack+243820, 0.0, zero_stack, 1.0, int_stack+428524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+742846,int_stack+741082,int_stack+477040, 0.0, zero_stack, 1.0, int_stack+776452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+745366,int_stack+245192,int_stack+244408, 0.0, zero_stack, 1.0, int_stack+429112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+692752,int_stack+745366,int_stack+741082, 0.0, zero_stack, 1.0, int_stack+488884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+692752,int_stack+742846, 0.0, zero_stack, 1.0, int_stack+474520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1211698,int_stack+12348,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+675760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+246740,int_stack+246200, 0.0, zero_stack, 1.0, int_stack+254700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+692752,int_stack+247496,int_stack+246740, 0.0, zero_stack, 1.0, int_stack+255780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+763132,int_stack+692752,int_stack+38598, 0.0, zero_stack, 1.0, int_stack+777712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+248504,int_stack+247496, 0.0, zero_stack, 1.0, int_stack+257292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+484348,int_stack+38598,int_stack+692752, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+692752,int_stack+484348,int_stack+763132, 0.0, zero_stack, 1.0, int_stack+466204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+237048,int_stack+692752,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+698632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+250115,int_stack+249800, 1.0, int_stack+423904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+250556,int_stack+250115, 1.0, int_stack+424219, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+477040,int_stack+13293,int_stack+12348, 1.0, int_stack+482080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+14616,int_stack+251144,int_stack+250556, 1.0, int_stack+424660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+692752,int_stack+14616,int_stack+13293, 1.0, int_stack+483025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+692752,int_stack+477040, 1.0, int_stack+766372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+477040,int_stack+252320,int_stack+251900, 1.0, int_stack+428104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+692752,int_stack+252908,int_stack+252320, 1.0, int_stack+428524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+694516,int_stack+692752,int_stack+477040, 1.0, int_stack+776452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+482080,int_stack+253692,int_stack+252908, 1.0, int_stack+429112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+484432,int_stack+482080,int_stack+692752, 1.0, int_stack+488884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+484432,int_stack+694516, 1.0, int_stack+474520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+482080,int_stack+12348,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+724090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+256536,int_stack+255240, 1.0, int_stack+254700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+692752,int_stack+258300,int_stack+256536, 1.0, int_stack+255780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+695020,int_stack+692752,int_stack+38598, 1.0, int_stack+777712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+259308,int_stack+258300, 1.0, int_stack+257292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+763132,int_stack+38598,int_stack+692752, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+741082,int_stack+763132,int_stack+695020, 1.0, int_stack+466204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+466204,int_stack+741082,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+749482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+260919,int_stack+260604,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+261360,int_stack+260919,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+14616,int_stack+13293,int_stack+12348,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+741082,int_stack+261948,int_stack+261360,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+742846,int_stack+741082,int_stack+13293,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+742846,int_stack+14616,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+741082,int_stack+263124,int_stack+262704,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+742342,int_stack+263712,int_stack+263124,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+744106,int_stack+742342,int_stack+741082,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+746626,int_stack+264496,int_stack+263712,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+746626,int_stack+742342,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+763132,int_stack+12348,int_stack+744106,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+249648,int_stack+763132,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+768262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+266044,int_stack+265504,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+12348,int_stack+266800,int_stack+266044,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+741082,int_stack+12348,int_stack+38598,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+267808,int_stack+266800,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+744322,int_stack+38598,int_stack+12348,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+692752,int_stack+744322,int_stack+741082,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1221148,int_stack+692752,int_stack+763132, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+801382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+763132,int_stack+269419,int_stack+269104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+437304,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+764077,int_stack+269860,int_stack+269419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+437619,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+765400,int_stack+764077,int_stack+763132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815032,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+692752,int_stack+270448,int_stack+269860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+438060,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+694516,int_stack+692752,int_stack+764077, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815977,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+694516,int_stack+765400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+817300,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+692752,int_stack+271624,int_stack+271204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441504,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+694012,int_stack+272212,int_stack+271624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441924,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+695776,int_stack+694012,int_stack+692752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819190,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+763132,int_stack+272996,int_stack+272212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+442512,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+741082,int_stack+763132,int_stack+694012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+820450,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+741082,int_stack+695776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7308,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+259098,int_stack+12348,int_stack+38598, 0.0, zero_stack, 1.0, int_stack+478930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+274544,int_stack+274004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+316504,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+741082,int_stack+275300,int_stack+274544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317584,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+743350,int_stack+741082,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+840592,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+276308,int_stack+275300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319096,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+763132,int_stack+38598,int_stack+741082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+842212,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+692752,int_stack+763132,int_stack+743350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+860122,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1233748,int_stack+692752,int_stack+12348, 0.0, zero_stack, 1.0, int_stack+494764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+277919,int_stack+277604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+437304, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+278360,int_stack+277919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+437619, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14616,int_stack+13293,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815032, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+692752,int_stack+278948,int_stack+278360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+438060, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+694516,int_stack+692752,int_stack+13293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815977, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+694516,int_stack+14616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+817300, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+692752,int_stack+280124,int_stack+279704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441504, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+694012,int_stack+280712,int_stack+280124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441924, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+695776,int_stack+694012,int_stack+692752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819190, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12348,int_stack+281496,int_stack+280712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+442512, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+763132,int_stack+12348,int_stack+694012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+820450, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+763132,int_stack+695776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7308, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+268548,int_stack+12348,int_stack+38598, 0.0, zero_stack, 1.0, int_stack+525730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+283044,int_stack+282504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+316504, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+763132,int_stack+283800,int_stack+283044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317584, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+692752,int_stack+763132,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+840592, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+284808,int_stack+283800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319096, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+741082,int_stack+38598,int_stack+763132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+842212, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+641902,int_stack+741082,int_stack+692752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+860122, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1246348,int_stack+641902,int_stack+12348, 0.0, zero_stack, 1.0, int_stack+551122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+286419,int_stack+286104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+437304, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+286860,int_stack+286419, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+437619, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14616,int_stack+13293,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815032, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+641902,int_stack+287448,int_stack+286860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+438060, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+643666,int_stack+641902,int_stack+13293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815977, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+643666,int_stack+14616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+817300, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+641902,int_stack+288624,int_stack+288204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441504, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+643162,int_stack+289212,int_stack+288624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441924, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+644926,int_stack+643162,int_stack+641902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819190, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+647446,int_stack+289996,int_stack+289212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+442512, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+647446,int_stack+643162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+820450, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+692752,int_stack+12348,int_stack+644926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7308, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+277998,int_stack+692752,int_stack+38598, 0.0, zero_stack, 1.0, int_stack+576580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+291544,int_stack+291004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+316504, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12348,int_stack+292300,int_stack+291544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317584, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+641902,int_stack+12348,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+840592, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+293308,int_stack+292300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319096, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+645142,int_stack+38598,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+842212, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+741082,int_stack+645142,int_stack+641902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+860122, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1258948,int_stack+741082,int_stack+692752, 0.0, zero_stack, 1.0, int_stack+599452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+692752,int_stack+294919,int_stack+294604, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+437304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+693697,int_stack+295360,int_stack+294919, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+437619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+695020,int_stack+693697,int_stack+692752, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+741082,int_stack+295948,int_stack+295360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+438060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+742846,int_stack+741082,int_stack+693697, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+815977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+742846,int_stack+695020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+817300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+741082,int_stack+297124,int_stack+296704, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+742342,int_stack+297712,int_stack+297124, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+744106,int_stack+742342,int_stack+741082, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+819190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+746626,int_stack+298496,int_stack+297712, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+442512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+692752,int_stack+746626,int_stack+742342, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+820450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+692752,int_stack+744106, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+287448,int_stack+12348,int_stack+38598, 0.0, zero_stack, 1.0, int_stack+624910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+300044,int_stack+299504, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+316504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+692752,int_stack+300800,int_stack+300044, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+695020,int_stack+692752,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+840592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+301808,int_stack+300800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+741082,int_stack+38598,int_stack+692752, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+842212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+641902,int_stack+741082,int_stack+695020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+860122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1271548,int_stack+641902,int_stack+12348, 0.0, zero_stack, 1.0, int_stack+650302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+303419,int_stack+303104, 0.0, zero_stack, 1.0, int_stack+437304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+303860,int_stack+303419, 0.0, zero_stack, 1.0, int_stack+437619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14616,int_stack+13293,int_stack+12348, 0.0, zero_stack, 1.0, int_stack+815032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+641902,int_stack+304448,int_stack+303860, 0.0, zero_stack, 1.0, int_stack+438060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+643666,int_stack+641902,int_stack+13293, 0.0, zero_stack, 1.0, int_stack+815977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+643666,int_stack+14616, 0.0, zero_stack, 1.0, int_stack+817300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+641902,int_stack+305624,int_stack+305204, 0.0, zero_stack, 1.0, int_stack+441504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+643162,int_stack+306212,int_stack+305624, 0.0, zero_stack, 1.0, int_stack+441924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+644926,int_stack+643162,int_stack+641902, 0.0, zero_stack, 1.0, int_stack+819190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+647446,int_stack+306996,int_stack+306212, 0.0, zero_stack, 1.0, int_stack+442512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12348,int_stack+647446,int_stack+643162, 0.0, zero_stack, 1.0, int_stack+820450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+741082,int_stack+12348,int_stack+644926, 0.0, zero_stack, 1.0, int_stack+7308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+296898,int_stack+741082,int_stack+38598, 0.0, zero_stack, 1.0, int_stack+675760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+308544,int_stack+308004, 0.0, zero_stack, 1.0, int_stack+316504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12348,int_stack+309300,int_stack+308544, 0.0, zero_stack, 1.0, int_stack+317584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+641902,int_stack+12348,int_stack+38598, 0.0, zero_stack, 1.0, int_stack+840592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+310308,int_stack+309300, 0.0, zero_stack, 1.0, int_stack+319096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+645142,int_stack+38598,int_stack+12348, 0.0, zero_stack, 1.0, int_stack+842212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+692752,int_stack+645142,int_stack+641902, 0.0, zero_stack, 1.0, int_stack+860122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1284148,int_stack+692752,int_stack+741082, 0.0, zero_stack, 1.0, int_stack+698632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+741082,int_stack+311919,int_stack+311604, 1.0, int_stack+437304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+742027,int_stack+312360,int_stack+311919, 1.0, int_stack+437619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+743350,int_stack+742027,int_stack+741082, 1.0, int_stack+815032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+745240,int_stack+312948,int_stack+312360, 1.0, int_stack+438060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+692752,int_stack+745240,int_stack+742027, 1.0, int_stack+815977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+692752,int_stack+743350, 1.0, int_stack+817300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+692752,int_stack+314124,int_stack+313704, 1.0, int_stack+441504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+694012,int_stack+314712,int_stack+314124, 1.0, int_stack+441924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+695776,int_stack+694012,int_stack+692752, 1.0, int_stack+819190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+815032,int_stack+315496,int_stack+314712, 1.0, int_stack+442512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+741082,int_stack+815032,int_stack+694012, 1.0, int_stack+820450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+741082,int_stack+695776, 1.0, int_stack+7308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+0,int_stack+12348,int_stack+38598, 0.0, zero_stack, 1.0, int_stack+724090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+318340,int_stack+317044, 1.0, int_stack+316504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+741082,int_stack+320104,int_stack+318340, 1.0, int_stack+317584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+743350,int_stack+741082,int_stack+38598, 1.0, int_stack+840592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+321112,int_stack+320104, 1.0, int_stack+319096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+815032,int_stack+38598,int_stack+741082, 1.0, int_stack+842212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+840592,int_stack+815032,int_stack+743350, 1.0, int_stack+860122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+306348,int_stack+840592,int_stack+12348, 0.0, zero_stack, 1.0, int_stack+749482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+322723,int_stack+322408,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+323164,int_stack+322723,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+14616,int_stack+13293,int_stack+12348,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+840592,int_stack+323752,int_stack+323164,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+842356,int_stack+840592,int_stack+13293,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+842356,int_stack+14616,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+840592,int_stack+324928,int_stack+324508,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+841852,int_stack+325516,int_stack+324928,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+843616,int_stack+841852,int_stack+840592,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+12348,int_stack+326300,int_stack+325516,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+815032,int_stack+12348,int_stack+841852,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+815032,int_stack+843616,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1296748,int_stack+12348,int_stack+38598, 0.0, zero_stack, 1.0, int_stack+768262, 1.0, int_stack+823600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+327848,int_stack+327308,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+815032,int_stack+328604,int_stack+327848,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+860122,int_stack+815032,int_stack+38598,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+329612,int_stack+328604,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+817300,int_stack+38598,int_stack+815032,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+840592,int_stack+817300,int_stack+860122,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1306198,int_stack+840592,int_stack+12348, 0.0, zero_stack, 1.0, int_stack+801382, 1.0, int_stack+846472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+331223,int_stack+330908,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+331664,int_stack+331223,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+14616,int_stack+13293,int_stack+12348,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+840592,int_stack+332252,int_stack+331664,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+842356,int_stack+840592,int_stack+13293,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+842356,int_stack+14616,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+840592,int_stack+333428,int_stack+333008,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+841852,int_stack+334016,int_stack+333428,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+843616,int_stack+841852,int_stack+840592,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+12348,int_stack+334800,int_stack+334016,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+815032,int_stack+12348,int_stack+841852,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+815032,int_stack+843616,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+318948,int_stack+12348,int_stack+38598, 0.0, zero_stack, 2.0, int_stack+823600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+336348,int_stack+335808,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+815032,int_stack+337104,int_stack+336348,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+860122,int_stack+815032,int_stack+38598,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+338112,int_stack+337104,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+817300,int_stack+38598,int_stack+815032,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+840592,int_stack+817300,int_stack+860122,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+328398,int_stack+840592,int_stack+12348, 0.0, zero_stack, 2.0, int_stack+846472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+341823,int_stack+341508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452804,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+342264,int_stack+341823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+453119,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14616,int_stack+13293,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+863362,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+840592,int_stack+342852,int_stack+342264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+453560,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+842356,int_stack+840592,int_stack+13293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+864307,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+842356,int_stack+14616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+865630,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+840592,int_stack+346828,int_stack+346408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457004,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+841852,int_stack+347416,int_stack+346828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457424,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+843616,int_stack+841852,int_stack+840592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+867520,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12348,int_stack+348200,int_stack+347416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458012,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+815032,int_stack+12348,int_stack+841852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+868780,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+815032,int_stack+843616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9828,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1318798,int_stack+12348,int_stack+38598, 1.0, int_stack+478930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+349748,int_stack+349208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+418000,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+815032,int_stack+350504,int_stack+349748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+419080,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+860122,int_stack+815032,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508414,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+351512,int_stack+350504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+420592,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+817300,int_stack+38598,int_stack+815032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+888922,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+840592,int_stack+817300,int_stack+860122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+891190,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+340998,int_stack+840592,int_stack+12348, 1.0, int_stack+494764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+355223,int_stack+354908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452804, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+355664,int_stack+355223, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+453119, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14616,int_stack+13293,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+863362, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+840592,int_stack+356252,int_stack+355664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+453560, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+842356,int_stack+840592,int_stack+13293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+864307, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+842356,int_stack+14616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+865630, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+840592,int_stack+360228,int_stack+359808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457004, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+841852,int_stack+360816,int_stack+360228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457424, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+843616,int_stack+841852,int_stack+840592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+867520, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12348,int_stack+361600,int_stack+360816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458012, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+815032,int_stack+12348,int_stack+841852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+868780, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+815032,int_stack+843616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9828, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1328248,int_stack+12348,int_stack+38598, 1.0, int_stack+525730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+363148,int_stack+362608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+418000, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+815032,int_stack+363904,int_stack+363148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+419080, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+860122,int_stack+815032,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508414, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+364912,int_stack+363904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+420592, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+817300,int_stack+38598,int_stack+815032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+888922, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+840592,int_stack+817300,int_stack+860122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+891190, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+353598,int_stack+840592,int_stack+12348, 1.0, int_stack+551122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+368623,int_stack+368308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452804, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+369064,int_stack+368623, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+453119, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14616,int_stack+13293,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+863362, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+840592,int_stack+369652,int_stack+369064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+453560, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+842356,int_stack+840592,int_stack+13293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+864307, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+842356,int_stack+14616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+865630, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+840592,int_stack+373628,int_stack+373208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457004, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+841852,int_stack+374216,int_stack+373628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457424, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+843616,int_stack+841852,int_stack+840592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+867520, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12348,int_stack+375000,int_stack+374216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458012, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+815032,int_stack+12348,int_stack+841852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+868780, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+815032,int_stack+843616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9828, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+542722,int_stack+12348,int_stack+38598, 1.0, int_stack+576580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+376548,int_stack+376008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+418000, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+815032,int_stack+377304,int_stack+376548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+419080, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+860122,int_stack+815032,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508414, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+378312,int_stack+377304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+420592, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+817300,int_stack+38598,int_stack+815032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+888922, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+840592,int_stack+817300,int_stack+860122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+891190, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+366198,int_stack+840592,int_stack+12348, 1.0, int_stack+599452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+382023,int_stack+381708, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+382464,int_stack+382023, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+453119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14616,int_stack+13293,int_stack+12348, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+863362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+840592,int_stack+383052,int_stack+382464, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+453560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+842356,int_stack+840592,int_stack+13293, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+864307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+842356,int_stack+14616, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+865630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+840592,int_stack+387028,int_stack+386608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+841852,int_stack+387616,int_stack+387028, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+843616,int_stack+841852,int_stack+840592, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+867520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12348,int_stack+388400,int_stack+387616, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+815032,int_stack+12348,int_stack+841852, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+868780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+815032,int_stack+843616, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+593572,int_stack+12348,int_stack+38598, 1.0, int_stack+624910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+389948,int_stack+389408, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+418000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+815032,int_stack+390704,int_stack+389948, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+419080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+860122,int_stack+815032,int_stack+38598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+391712,int_stack+390704, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+420592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+817300,int_stack+38598,int_stack+815032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+888922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+840592,int_stack+817300,int_stack+860122, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+891190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+378798,int_stack+840592,int_stack+12348, 1.0, int_stack+650302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+395423,int_stack+395108, 0.0, zero_stack, 1.0, int_stack+452804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+395864,int_stack+395423, 0.0, zero_stack, 1.0, int_stack+453119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14616,int_stack+13293,int_stack+12348, 0.0, zero_stack, 1.0, int_stack+863362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+840592,int_stack+396452,int_stack+395864, 0.0, zero_stack, 1.0, int_stack+453560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+842356,int_stack+840592,int_stack+13293, 0.0, zero_stack, 1.0, int_stack+864307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+842356,int_stack+14616, 0.0, zero_stack, 1.0, int_stack+865630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+840592,int_stack+400428,int_stack+400008, 0.0, zero_stack, 1.0, int_stack+457004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+841852,int_stack+401016,int_stack+400428, 0.0, zero_stack, 1.0, int_stack+457424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+843616,int_stack+841852,int_stack+840592, 0.0, zero_stack, 1.0, int_stack+867520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12348,int_stack+401800,int_stack+401016, 0.0, zero_stack, 1.0, int_stack+458012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+815032,int_stack+12348,int_stack+841852, 0.0, zero_stack, 1.0, int_stack+868780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+815032,int_stack+843616, 0.0, zero_stack, 1.0, int_stack+9828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+641902,int_stack+12348,int_stack+38598, 1.0, int_stack+675760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+403348,int_stack+402808, 0.0, zero_stack, 1.0, int_stack+418000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+815032,int_stack+404104,int_stack+403348, 0.0, zero_stack, 1.0, int_stack+419080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+860122,int_stack+815032,int_stack+38598, 0.0, zero_stack, 1.0, int_stack+508414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+405112,int_stack+404104, 0.0, zero_stack, 1.0, int_stack+420592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+817300,int_stack+38598,int_stack+815032, 0.0, zero_stack, 1.0, int_stack+888922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+840592,int_stack+817300,int_stack+860122, 0.0, zero_stack, 1.0, int_stack+891190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+391398,int_stack+840592,int_stack+12348, 1.0, int_stack+698632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12348,int_stack+408823,int_stack+408508, 1.0, int_stack+452804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13293,int_stack+409264,int_stack+408823, 1.0, int_stack+453119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14616,int_stack+13293,int_stack+12348, 1.0, int_stack+863362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+840592,int_stack+409852,int_stack+409264, 1.0, int_stack+453560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+842356,int_stack+840592,int_stack+13293, 1.0, int_stack+864307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+842356,int_stack+14616, 1.0, int_stack+865630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+840592,int_stack+415620,int_stack+415200, 1.0, int_stack+457004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+841852,int_stack+416208,int_stack+415620, 1.0, int_stack+457424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+843616,int_stack+841852,int_stack+840592, 1.0, int_stack+867520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12348,int_stack+416992,int_stack+416208, 1.0, int_stack+458012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+860122,int_stack+12348,int_stack+841852, 1.0, int_stack+868780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+12348,int_stack+860122,int_stack+843616, 1.0, int_stack+9828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+860122,int_stack+12348,int_stack+38598, 1.0, int_stack+724090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38598,int_stack+419836,int_stack+418540, 1.0, int_stack+418000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+869572,int_stack+421600,int_stack+419836, 1.0, int_stack+419080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+840592,int_stack+869572,int_stack+38598, 1.0, int_stack+508414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38598,int_stack+422608,int_stack+421600, 1.0, int_stack+420592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+815032,int_stack+38598,int_stack+869572, 1.0, int_stack+888922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+741082,int_stack+815032,int_stack+840592, 1.0, int_stack+891190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+403998,int_stack+741082,int_stack+12348, 1.0, int_stack+749482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+741082,int_stack+426319,int_stack+426004,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+742027,int_stack+426760,int_stack+426319,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+743350,int_stack+742027,int_stack+741082,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+745240,int_stack+427348,int_stack+426760,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+747004,int_stack+745240,int_stack+742027,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+747004,int_stack+743350,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+741082,int_stack+431324,int_stack+430904,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+742342,int_stack+431912,int_stack+431324,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+744106,int_stack+742342,int_stack+741082,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+746626,int_stack+432696,int_stack+431912,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+748978,int_stack+746626,int_stack+742342,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+450704,int_stack+748978,int_stack+744106,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+741082,int_stack+450704,int_stack+38598, 1.0, int_stack+768262, 0.0, zero_stack, 1.0, int_stack+871930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+508414,int_stack+434244,int_stack+433704,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+38598,int_stack+435000,int_stack+434244,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+840592,int_stack+38598,int_stack+508414,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+750532,int_stack+436008,int_stack+435000,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+815032,int_stack+750532,int_stack+38598,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+888922,int_stack+815032,int_stack+840592,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+763132,int_stack+888922,int_stack+450704, 1.0, int_stack+801382, 0.0, zero_stack, 1.0, int_stack+894802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+801382,int_stack+439719,int_stack+439404,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+802327,int_stack+440160,int_stack+439719,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+803650,int_stack+802327,int_stack+801382,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+450704,int_stack+440748,int_stack+440160,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+888922,int_stack+450704,int_stack+802327,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+888922,int_stack+803650,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+888922,int_stack+444724,int_stack+444304,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+890182,int_stack+445312,int_stack+444724,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+891946,int_stack+890182,int_stack+888922,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+450704,int_stack+446096,int_stack+445312,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+801382,int_stack+450704,int_stack+890182,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+450704,int_stack+801382,int_stack+891946,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+692752,int_stack+450704,int_stack+38598, 1.0, int_stack+823600, 1.0, int_stack+871930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+508414,int_stack+447644,int_stack+447104,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+38598,int_stack+448400,int_stack+447644,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+801382,int_stack+38598,int_stack+508414,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+888922,int_stack+449408,int_stack+448400,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+840592,int_stack+888922,int_stack+38598,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+888922,int_stack+840592,int_stack+801382,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+815032,int_stack+888922,int_stack+450704, 1.0, int_stack+846472, 1.0, int_stack+894802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+888922,int_stack+455219,int_stack+454904,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+889867,int_stack+455660,int_stack+455219,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+891190,int_stack+889867,int_stack+888922,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+801382,int_stack+456248,int_stack+455660,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+840592,int_stack+801382,int_stack+889867,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+38598,int_stack+840592,int_stack+891190,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+840592,int_stack+460224,int_stack+459804,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+841852,int_stack+460812,int_stack+460224,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+843616,int_stack+841852,int_stack+840592,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+846136,int_stack+461596,int_stack+460812,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+801382,int_stack+846136,int_stack+841852,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+846136,int_stack+801382,int_stack+843616,28);
 /*--- compute (hp|gf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+519484,int_stack+846136,int_stack+38598, 2.0, int_stack+871930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+508414,int_stack+463144,int_stack+462604,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+38598,int_stack+463900,int_stack+463144,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+801382,int_stack+38598,int_stack+508414,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+840592,int_stack+464908,int_stack+463900,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+888922,int_stack+840592,int_stack+38598,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+840592,int_stack+888922,int_stack+801382,36);
 /*--- compute (ip|gf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+416598,int_stack+840592,int_stack+846136, 2.0, int_stack+894802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+429198,int_stack+530122,int_stack+498964,150);
     Libderiv->ABCD[11] = int_stack + 429198;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1337698,int_stack+580972,int_stack+555322,150);
     Libderiv->ABCD[10] = int_stack + 1337698;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+574222,int_stack+629302,int_stack+603652,150);
     Libderiv->ABCD[9] = int_stack + 574222;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+622552,int_stack+680152,int_stack+654502,150);
     Libderiv->ABCD[8] = int_stack + 622552;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+673402,int_stack+728482,int_stack+702832,150);
     Libderiv->ABCD[7] = int_stack + 673402;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+721732,int_stack+779332,int_stack+753682,150);
     Libderiv->ABCD[6] = int_stack + 721732;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1356598,int_stack+827992,int_stack+805582, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+791932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[2] = int_stack + 1356598;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+827632,int_stack+876322,int_stack+850672, 0.0, zero_stack, 1.0, int_stack+791932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[1] = int_stack + 827632;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+869572,int_stack+921412,int_stack+899002, 1.0, int_stack+791932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[0] = int_stack + 869572;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+775732,int_stack+943462,int_stack+934012,150);
     Libderiv->ABCD[155] = int_stack + 775732;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+917902,int_stack+16548,int_stack+908452,150);
     Libderiv->ABCD[143] = int_stack + 917902;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+9450,int_stack+975448,int_stack+956062,150);
     Libderiv->ABCD[142] = int_stack + 9450;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+936802,int_stack+988048,int_stack+29148,150);
     Libderiv->ABCD[131] = int_stack + 936802;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+974962,int_stack+1000648,int_stack+41748,150);
     Libderiv->ABCD[130] = int_stack + 974962;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+28350,int_stack+1013248,int_stack+51198,150);
     Libderiv->ABCD[129] = int_stack + 28350;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+993862,int_stack+1035298,int_stack+1025848,150);
     Libderiv->ABCD[119] = int_stack + 993862;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1012762,int_stack+1047898,int_stack+60648,150);
     Libderiv->ABCD[118] = int_stack + 1012762;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+47250,int_stack+1060498,int_stack+70098,150);
     Libderiv->ABCD[117] = int_stack + 47250;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1031662,int_stack+1073098,int_stack+79548,150);
     Libderiv->ABCD[116] = int_stack + 1031662;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+66150,int_stack+1085698,int_stack+88998,150);
     Libderiv->ABCD[107] = int_stack + 66150;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1050562,int_stack+1098298,int_stack+98448,150);
     Libderiv->ABCD[106] = int_stack + 1050562;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+85050,int_stack+1110898,int_stack+107898,150);
     Libderiv->ABCD[105] = int_stack + 85050;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1069462,int_stack+1123498,int_stack+117348,150);
     Libderiv->ABCD[104] = int_stack + 1069462;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+103950,int_stack+1136098,int_stack+126798,150);
     Libderiv->ABCD[103] = int_stack + 103950;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1088362,int_stack+1148698,int_stack+136248,150);
     Libderiv->ABCD[95] = int_stack + 1088362;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+122850,int_stack+145698,int_stack+510034,150);
     Libderiv->ABCD[94] = int_stack + 122850;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1107262,int_stack+158298,int_stack+564772,150);
     Libderiv->ABCD[93] = int_stack + 1107262;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+141750,int_stack+170898,int_stack+613102,150);
     Libderiv->ABCD[92] = int_stack + 141750;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+160650,int_stack+1161298,int_stack+663952,150);
     Libderiv->ABCD[91] = int_stack + 160650;
 /*--- compute (hd|gf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1126162,int_stack+183498,int_stack+712282,150);
     Libderiv->ABCD[90] = int_stack + 1126162;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1145062,int_stack+196098,int_stack+965512, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[47] = int_stack + 1145062;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+179550,int_stack+1173898,int_stack+208698, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+555322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[46] = int_stack + 179550;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+198450,int_stack+1186498,int_stack+218148, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+603652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[45] = int_stack + 198450;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1163962,int_stack+1199098,int_stack+227598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[44] = int_stack + 1163962;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+217350,int_stack+237048,int_stack+1211698, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+702832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[43] = int_stack + 217350;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1182862,int_stack+466204,int_stack+482080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+753682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[42] = int_stack + 1182862;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1201762,int_stack+1221148,int_stack+249648, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+805582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[38] = int_stack + 1201762;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+236250,int_stack+1233748,int_stack+259098, 0.0, zero_stack, 1.0, int_stack+498964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[35] = int_stack + 236250;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1220662,int_stack+1246348,int_stack+268548, 0.0, zero_stack, 1.0, int_stack+555322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[34] = int_stack + 1220662;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+255150,int_stack+1258948,int_stack+277998, 0.0, zero_stack, 1.0, int_stack+603652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[33] = int_stack + 255150;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1239562,int_stack+1271548,int_stack+287448, 0.0, zero_stack, 1.0, int_stack+654502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[32] = int_stack + 1239562;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+274050,int_stack+1284148,int_stack+296898, 0.0, zero_stack, 1.0, int_stack+702832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[31] = int_stack + 274050;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1258462,int_stack+306348,int_stack+0, 0.0, zero_stack, 1.0, int_stack+753682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[30] = int_stack + 1258462;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+292950,int_stack+1306198,int_stack+1296748, 0.0, zero_stack, 1.0, int_stack+805582, 1.0, int_stack+850672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[26] = int_stack + 292950;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1277362,int_stack+328398,int_stack+318948, 0.0, zero_stack, 2.0, int_stack+850672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[25] = int_stack + 1277362;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+311850,int_stack+340998,int_stack+1318798, 1.0, int_stack+498964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[23] = int_stack + 311850;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+330750,int_stack+353598,int_stack+1328248, 1.0, int_stack+555322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[22] = int_stack + 330750;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+552172,int_stack+366198,int_stack+542722, 1.0, int_stack+603652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[21] = int_stack + 552172;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+349650,int_stack+378798,int_stack+593572, 1.0, int_stack+654502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[20] = int_stack + 349650;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+651352,int_stack+391398,int_stack+641902, 1.0, int_stack+702832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[19] = int_stack + 651352;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+702202,int_stack+403998,int_stack+860122, 1.0, int_stack+753682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[18] = int_stack + 702202;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+368550,int_stack+763132,int_stack+741082, 1.0, int_stack+805582, 0.0, zero_stack, 1.0, int_stack+899002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[14] = int_stack + 368550;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+794632,int_stack+815032,int_stack+692752, 1.0, int_stack+850672, 1.0, int_stack+899002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[13] = int_stack + 794632;
 /*--- compute (hd|gf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+846532,int_stack+416598,int_stack+519484, 2.0, int_stack+899002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,150);
     Libderiv->ABCD[12] = int_stack + 846532;

}
