/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_hphf(Libderiv_t *, prim_data *);

  /* Computes derivatives of (hp|hf) integrals */

void d12hrr_order_hphf(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[6][8][11] = int_stack + 0;
 Libderiv->deriv_classes[6][8][10] = int_stack + 1260;
 Libderiv->deriv_classes[6][8][9] = int_stack + 2520;
 Libderiv->deriv_classes[6][8][8] = int_stack + 3780;
 Libderiv->deriv_classes[6][8][7] = int_stack + 5040;
 Libderiv->dvrr_classes[6][7] = int_stack + 6300;
 Libderiv->deriv_classes[6][8][6] = int_stack + 7308;
 Libderiv->deriv_classes[6][8][2] = int_stack + 8568;
 Libderiv->deriv_classes[6][8][1] = int_stack + 9828;
 Libderiv->dvrr_classes[5][8] = int_stack + 11088;
 Libderiv->deriv_classes[6][8][0] = int_stack + 12033;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 13293;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 13734;
 Libderiv->deriv2_classes[5][7][143] = int_stack + 14322;
 Libderiv->deriv2_classes[5][8][143] = int_stack + 15078;
 Libderiv->deriv2_classes[6][5][143] = int_stack + 16023;
 Libderiv->deriv2_classes[6][6][143] = int_stack + 16611;
 Libderiv->deriv2_classes[6][7][143] = int_stack + 17395;
 Libderiv->deriv2_classes[6][8][143] = int_stack + 18403;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 19663;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 20104;
 Libderiv->deriv2_classes[5][7][131] = int_stack + 20692;
 Libderiv->deriv2_classes[5][8][131] = int_stack + 21448;
 Libderiv->deriv2_classes[6][5][131] = int_stack + 22393;
 Libderiv->deriv2_classes[6][6][131] = int_stack + 22981;
 Libderiv->deriv2_classes[6][7][131] = int_stack + 23765;
 Libderiv->deriv2_classes[6][8][131] = int_stack + 24773;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 26033;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 26474;
 Libderiv->deriv2_classes[5][7][130] = int_stack + 27062;
 Libderiv->deriv2_classes[5][8][130] = int_stack + 27818;
 Libderiv->deriv2_classes[6][5][130] = int_stack + 28763;
 Libderiv->deriv2_classes[6][6][130] = int_stack + 29351;
 Libderiv->deriv2_classes[6][7][130] = int_stack + 30135;
 Libderiv->deriv2_classes[6][8][130] = int_stack + 31143;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 32403;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 32844;
 Libderiv->deriv2_classes[5][7][119] = int_stack + 33432;
 Libderiv->deriv2_classes[5][8][119] = int_stack + 34188;
 Libderiv->deriv2_classes[6][5][119] = int_stack + 35133;
 Libderiv->deriv2_classes[6][6][119] = int_stack + 35721;
 Libderiv->deriv2_classes[6][7][119] = int_stack + 36505;
 Libderiv->deriv2_classes[6][8][119] = int_stack + 37513;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 38773;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 39214;
 Libderiv->deriv2_classes[5][7][118] = int_stack + 39802;
 Libderiv->deriv2_classes[5][8][118] = int_stack + 40558;
 Libderiv->deriv2_classes[6][5][118] = int_stack + 41503;
 Libderiv->deriv2_classes[6][6][118] = int_stack + 42091;
 Libderiv->deriv2_classes[6][7][118] = int_stack + 42875;
 Libderiv->deriv2_classes[6][8][118] = int_stack + 43883;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 45143;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 45584;
 Libderiv->deriv2_classes[5][7][117] = int_stack + 46172;
 Libderiv->deriv2_classes[5][8][117] = int_stack + 46928;
 Libderiv->deriv2_classes[6][5][117] = int_stack + 47873;
 Libderiv->deriv2_classes[6][6][117] = int_stack + 48461;
 Libderiv->deriv2_classes[6][7][117] = int_stack + 49245;
 Libderiv->deriv2_classes[6][8][117] = int_stack + 50253;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 51513;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 51954;
 Libderiv->deriv2_classes[5][7][107] = int_stack + 52542;
 Libderiv->deriv2_classes[5][8][107] = int_stack + 53298;
 Libderiv->deriv2_classes[6][5][107] = int_stack + 54243;
 Libderiv->deriv2_classes[6][6][107] = int_stack + 54831;
 Libderiv->deriv2_classes[6][7][107] = int_stack + 55615;
 Libderiv->deriv2_classes[6][8][107] = int_stack + 56623;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 57883;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 58324;
 Libderiv->deriv2_classes[5][7][106] = int_stack + 58912;
 Libderiv->deriv2_classes[5][8][106] = int_stack + 59668;
 Libderiv->deriv2_classes[6][5][106] = int_stack + 60613;
 Libderiv->deriv2_classes[6][6][106] = int_stack + 61201;
 Libderiv->deriv2_classes[6][7][106] = int_stack + 61985;
 Libderiv->deriv2_classes[6][8][106] = int_stack + 62993;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 64253;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 64694;
 Libderiv->deriv2_classes[5][7][105] = int_stack + 65282;
 Libderiv->deriv2_classes[5][8][105] = int_stack + 66038;
 Libderiv->deriv2_classes[6][5][105] = int_stack + 66983;
 Libderiv->deriv2_classes[6][6][105] = int_stack + 67571;
 Libderiv->deriv2_classes[6][7][105] = int_stack + 68355;
 Libderiv->deriv2_classes[6][8][105] = int_stack + 69363;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 70623;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 71064;
 Libderiv->deriv2_classes[5][7][104] = int_stack + 71652;
 Libderiv->deriv2_classes[5][8][104] = int_stack + 72408;
 Libderiv->deriv2_classes[6][5][104] = int_stack + 73353;
 Libderiv->deriv2_classes[6][6][104] = int_stack + 73941;
 Libderiv->deriv2_classes[6][7][104] = int_stack + 74725;
 Libderiv->deriv2_classes[6][8][104] = int_stack + 75733;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 76993;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 77434;
 Libderiv->deriv2_classes[5][7][95] = int_stack + 78022;
 Libderiv->deriv2_classes[5][8][95] = int_stack + 78778;
 Libderiv->deriv2_classes[6][5][95] = int_stack + 79723;
 Libderiv->deriv2_classes[6][6][95] = int_stack + 80311;
 Libderiv->deriv2_classes[6][7][95] = int_stack + 81095;
 Libderiv->deriv2_classes[6][8][95] = int_stack + 82103;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 83363;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 83804;
 Libderiv->deriv2_classes[5][7][94] = int_stack + 84392;
 Libderiv->deriv2_classes[5][8][94] = int_stack + 85148;
 Libderiv->deriv2_classes[6][5][94] = int_stack + 86093;
 Libderiv->deriv2_classes[6][6][94] = int_stack + 86681;
 Libderiv->deriv2_classes[6][7][94] = int_stack + 87465;
 Libderiv->deriv2_classes[6][8][94] = int_stack + 88473;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 89733;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 90174;
 Libderiv->deriv2_classes[5][7][93] = int_stack + 90762;
 Libderiv->deriv2_classes[5][8][93] = int_stack + 91518;
 Libderiv->deriv2_classes[6][5][93] = int_stack + 92463;
 Libderiv->deriv2_classes[6][6][93] = int_stack + 93051;
 Libderiv->deriv2_classes[6][7][93] = int_stack + 93835;
 Libderiv->deriv2_classes[6][8][93] = int_stack + 94843;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 96103;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 96544;
 Libderiv->deriv2_classes[5][7][92] = int_stack + 97132;
 Libderiv->deriv2_classes[5][8][92] = int_stack + 97888;
 Libderiv->deriv2_classes[6][5][92] = int_stack + 98833;
 Libderiv->deriv2_classes[6][6][92] = int_stack + 99421;
 Libderiv->deriv2_classes[6][7][92] = int_stack + 100205;
 Libderiv->deriv2_classes[6][8][92] = int_stack + 101213;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 102473;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 102914;
 Libderiv->deriv2_classes[5][7][91] = int_stack + 103502;
 Libderiv->deriv2_classes[5][8][91] = int_stack + 104258;
 Libderiv->deriv2_classes[6][5][91] = int_stack + 105203;
 Libderiv->deriv2_classes[6][6][91] = int_stack + 105791;
 Libderiv->deriv2_classes[6][7][91] = int_stack + 106575;
 Libderiv->deriv2_classes[6][8][91] = int_stack + 107583;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 108843;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 109284;
 Libderiv->deriv2_classes[5][7][83] = int_stack + 109872;
 Libderiv->deriv2_classes[5][8][83] = int_stack + 110628;
 Libderiv->deriv_classes[6][5][11] = int_stack + 111573;
 Libderiv->deriv2_classes[6][5][83] = int_stack + 112161;
 Libderiv->deriv_classes[6][6][11] = int_stack + 112749;
 Libderiv->deriv2_classes[6][6][83] = int_stack + 113533;
 Libderiv->deriv_classes[6][7][11] = int_stack + 114317;
 Libderiv->deriv2_classes[6][7][83] = int_stack + 115325;
 Libderiv->deriv2_classes[6][8][83] = int_stack + 116333;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 117593;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 118034;
 Libderiv->deriv2_classes[5][7][82] = int_stack + 118622;
 Libderiv->deriv2_classes[5][8][82] = int_stack + 119378;
 Libderiv->deriv_classes[6][5][10] = int_stack + 120323;
 Libderiv->deriv2_classes[6][5][82] = int_stack + 120911;
 Libderiv->deriv_classes[6][6][10] = int_stack + 121499;
 Libderiv->deriv2_classes[6][6][82] = int_stack + 122283;
 Libderiv->deriv_classes[6][7][10] = int_stack + 123067;
 Libderiv->deriv2_classes[6][7][82] = int_stack + 124075;
 Libderiv->deriv2_classes[6][8][82] = int_stack + 125083;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 126343;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 126784;
 Libderiv->deriv2_classes[5][7][81] = int_stack + 127372;
 Libderiv->deriv2_classes[5][8][81] = int_stack + 128128;
 Libderiv->deriv_classes[6][5][9] = int_stack + 129073;
 Libderiv->deriv2_classes[6][5][81] = int_stack + 129661;
 Libderiv->deriv_classes[6][6][9] = int_stack + 130249;
 Libderiv->deriv2_classes[6][6][81] = int_stack + 131033;
 Libderiv->deriv_classes[6][7][9] = int_stack + 131817;
 Libderiv->deriv2_classes[6][7][81] = int_stack + 132825;
 Libderiv->deriv2_classes[6][8][81] = int_stack + 133833;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 135093;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 135534;
 Libderiv->deriv2_classes[5][7][80] = int_stack + 136122;
 Libderiv->deriv2_classes[5][8][80] = int_stack + 136878;
 Libderiv->deriv_classes[6][5][8] = int_stack + 137823;
 Libderiv->deriv2_classes[6][5][80] = int_stack + 138411;
 Libderiv->deriv_classes[6][6][8] = int_stack + 138999;
 Libderiv->deriv2_classes[6][6][80] = int_stack + 139783;
 Libderiv->deriv_classes[6][7][8] = int_stack + 140567;
 Libderiv->deriv2_classes[6][7][80] = int_stack + 141575;
 Libderiv->deriv2_classes[6][8][80] = int_stack + 142583;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 143843;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 144284;
 Libderiv->deriv2_classes[5][7][79] = int_stack + 144872;
 Libderiv->deriv2_classes[5][8][79] = int_stack + 145628;
 Libderiv->deriv_classes[6][5][7] = int_stack + 146573;
 Libderiv->deriv2_classes[6][5][79] = int_stack + 147161;
 Libderiv->deriv_classes[6][6][7] = int_stack + 147749;
 Libderiv->deriv2_classes[6][6][79] = int_stack + 148533;
 Libderiv->deriv_classes[6][7][7] = int_stack + 149317;
 Libderiv->deriv2_classes[6][7][79] = int_stack + 150325;
 Libderiv->deriv2_classes[6][8][79] = int_stack + 151333;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 152593;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 153034;
 Libderiv->deriv2_classes[5][7][78] = int_stack + 153622;
 Libderiv->deriv2_classes[5][8][78] = int_stack + 154378;
 Libderiv->dvrr_classes[6][5] = int_stack + 155323;
 Libderiv->deriv_classes[6][5][6] = int_stack + 155911;
 Libderiv->deriv2_classes[6][5][78] = int_stack + 156499;
 Libderiv->dvrr_classes[6][6] = int_stack + 157087;
 Libderiv->deriv_classes[6][6][6] = int_stack + 157871;
 Libderiv->deriv2_classes[6][6][78] = int_stack + 158655;
 Libderiv->deriv_classes[6][7][6] = int_stack + 159439;
 Libderiv->deriv2_classes[6][7][78] = int_stack + 160447;
 Libderiv->deriv2_classes[6][8][78] = int_stack + 161455;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 162715;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 163156;
 Libderiv->deriv2_classes[5][7][35] = int_stack + 163744;
 Libderiv->deriv2_classes[5][8][35] = int_stack + 164500;
 Libderiv->deriv2_classes[6][5][35] = int_stack + 165445;
 Libderiv->deriv2_classes[6][6][35] = int_stack + 166033;
 Libderiv->deriv2_classes[6][7][35] = int_stack + 166817;
 Libderiv->deriv2_classes[6][8][35] = int_stack + 167825;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 169085;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 169526;
 Libderiv->deriv2_classes[5][7][34] = int_stack + 170114;
 Libderiv->deriv2_classes[5][8][34] = int_stack + 170870;
 Libderiv->deriv2_classes[6][5][34] = int_stack + 171815;
 Libderiv->deriv2_classes[6][6][34] = int_stack + 172403;
 Libderiv->deriv2_classes[6][7][34] = int_stack + 173187;
 Libderiv->deriv2_classes[6][8][34] = int_stack + 174195;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 175455;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 175896;
 Libderiv->deriv2_classes[5][7][33] = int_stack + 176484;
 Libderiv->deriv2_classes[5][8][33] = int_stack + 177240;
 Libderiv->deriv2_classes[6][5][33] = int_stack + 178185;
 Libderiv->deriv2_classes[6][6][33] = int_stack + 178773;
 Libderiv->deriv2_classes[6][7][33] = int_stack + 179557;
 Libderiv->deriv2_classes[6][8][33] = int_stack + 180565;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 181825;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 182266;
 Libderiv->deriv2_classes[5][7][32] = int_stack + 182854;
 Libderiv->deriv2_classes[5][8][32] = int_stack + 183610;
 Libderiv->deriv2_classes[6][5][32] = int_stack + 184555;
 Libderiv->deriv2_classes[6][6][32] = int_stack + 185143;
 Libderiv->deriv2_classes[6][7][32] = int_stack + 185927;
 Libderiv->deriv2_classes[6][8][32] = int_stack + 186935;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 188195;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 188636;
 Libderiv->deriv2_classes[5][7][31] = int_stack + 189224;
 Libderiv->deriv2_classes[5][8][31] = int_stack + 189980;
 Libderiv->deriv2_classes[6][5][31] = int_stack + 190925;
 Libderiv->deriv2_classes[6][6][31] = int_stack + 191513;
 Libderiv->deriv2_classes[6][7][31] = int_stack + 192297;
 Libderiv->deriv2_classes[6][8][31] = int_stack + 193305;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 194565;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 195006;
 Libderiv->deriv2_classes[5][7][30] = int_stack + 195594;
 Libderiv->deriv2_classes[5][8][30] = int_stack + 196350;
 Libderiv->deriv_classes[6][5][2] = int_stack + 197295;
 Libderiv->deriv2_classes[6][5][30] = int_stack + 197883;
 Libderiv->deriv_classes[6][6][2] = int_stack + 198471;
 Libderiv->deriv2_classes[6][6][30] = int_stack + 199255;
 Libderiv->deriv_classes[6][7][2] = int_stack + 200039;
 Libderiv->deriv2_classes[6][7][30] = int_stack + 201047;
 Libderiv->deriv2_classes[6][8][30] = int_stack + 202055;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 203315;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 203756;
 Libderiv->deriv2_classes[5][7][26] = int_stack + 204344;
 Libderiv->deriv2_classes[5][8][26] = int_stack + 205100;
 Libderiv->deriv2_classes[6][5][26] = int_stack + 206045;
 Libderiv->deriv2_classes[6][6][26] = int_stack + 206633;
 Libderiv->deriv2_classes[6][7][26] = int_stack + 207417;
 Libderiv->deriv2_classes[6][8][26] = int_stack + 208425;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 209685;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 210126;
 Libderiv->deriv2_classes[5][7][23] = int_stack + 210714;
 Libderiv->deriv2_classes[5][8][23] = int_stack + 211470;
 Libderiv->deriv2_classes[6][5][23] = int_stack + 212415;
 Libderiv->deriv2_classes[6][6][23] = int_stack + 213003;
 Libderiv->deriv2_classes[6][7][23] = int_stack + 213787;
 Libderiv->deriv2_classes[6][8][23] = int_stack + 214795;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 216055;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 216496;
 Libderiv->deriv2_classes[5][7][22] = int_stack + 217084;
 Libderiv->deriv2_classes[5][8][22] = int_stack + 217840;
 Libderiv->deriv2_classes[6][5][22] = int_stack + 218785;
 Libderiv->deriv2_classes[6][6][22] = int_stack + 219373;
 Libderiv->deriv2_classes[6][7][22] = int_stack + 220157;
 Libderiv->deriv2_classes[6][8][22] = int_stack + 221165;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 222425;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 222866;
 Libderiv->deriv2_classes[5][7][21] = int_stack + 223454;
 Libderiv->deriv2_classes[5][8][21] = int_stack + 224210;
 Libderiv->deriv2_classes[6][5][21] = int_stack + 225155;
 Libderiv->deriv2_classes[6][6][21] = int_stack + 225743;
 Libderiv->deriv2_classes[6][7][21] = int_stack + 226527;
 Libderiv->deriv2_classes[6][8][21] = int_stack + 227535;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 228795;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 229236;
 Libderiv->deriv2_classes[5][7][20] = int_stack + 229824;
 Libderiv->deriv2_classes[5][8][20] = int_stack + 230580;
 Libderiv->deriv2_classes[6][5][20] = int_stack + 231525;
 Libderiv->deriv2_classes[6][6][20] = int_stack + 232113;
 Libderiv->deriv2_classes[6][7][20] = int_stack + 232897;
 Libderiv->deriv2_classes[6][8][20] = int_stack + 233905;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 235165;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 235606;
 Libderiv->deriv2_classes[5][7][19] = int_stack + 236194;
 Libderiv->deriv2_classes[5][8][19] = int_stack + 236950;
 Libderiv->deriv2_classes[6][5][19] = int_stack + 237895;
 Libderiv->deriv2_classes[6][6][19] = int_stack + 238483;
 Libderiv->deriv2_classes[6][7][19] = int_stack + 239267;
 Libderiv->deriv2_classes[6][8][19] = int_stack + 240275;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 241535;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 241976;
 Libderiv->deriv2_classes[5][7][18] = int_stack + 242564;
 Libderiv->deriv2_classes[5][8][18] = int_stack + 243320;
 Libderiv->deriv_classes[6][5][1] = int_stack + 244265;
 Libderiv->deriv2_classes[6][5][18] = int_stack + 244853;
 Libderiv->deriv_classes[6][6][1] = int_stack + 245441;
 Libderiv->deriv2_classes[6][6][18] = int_stack + 246225;
 Libderiv->deriv_classes[6][7][1] = int_stack + 247009;
 Libderiv->deriv2_classes[6][7][18] = int_stack + 248017;
 Libderiv->deriv2_classes[6][8][18] = int_stack + 249025;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 250285;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 250726;
 Libderiv->deriv2_classes[5][7][14] = int_stack + 251314;
 Libderiv->deriv2_classes[5][8][14] = int_stack + 252070;
 Libderiv->deriv2_classes[6][5][14] = int_stack + 253015;
 Libderiv->deriv2_classes[6][6][14] = int_stack + 253603;
 Libderiv->deriv2_classes[6][7][14] = int_stack + 254387;
 Libderiv->deriv2_classes[6][8][14] = int_stack + 255395;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 256655;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 257096;
 Libderiv->deriv2_classes[5][7][13] = int_stack + 257684;
 Libderiv->deriv2_classes[5][8][13] = int_stack + 258440;
 Libderiv->deriv2_classes[6][5][13] = int_stack + 259385;
 Libderiv->deriv2_classes[6][6][13] = int_stack + 259973;
 Libderiv->deriv2_classes[6][7][13] = int_stack + 260757;
 Libderiv->deriv2_classes[6][8][13] = int_stack + 261765;
 Libderiv->deriv_classes[5][5][11] = int_stack + 263025;
 Libderiv->deriv_classes[5][6][11] = int_stack + 263466;
 Libderiv->deriv_classes[5][7][11] = int_stack + 264054;
 Libderiv->deriv_classes[5][8][11] = int_stack + 264810;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 265755;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 266196;
 Libderiv->deriv2_classes[5][7][11] = int_stack + 266784;
 Libderiv->deriv2_classes[5][8][11] = int_stack + 267540;
 Libderiv->deriv2_classes[6][5][11] = int_stack + 268485;
 Libderiv->deriv2_classes[6][6][11] = int_stack + 269073;
 Libderiv->deriv2_classes[6][7][11] = int_stack + 269857;
 Libderiv->deriv2_classes[6][8][11] = int_stack + 270865;
 Libderiv->deriv_classes[5][5][10] = int_stack + 272125;
 Libderiv->deriv_classes[5][6][10] = int_stack + 272566;
 Libderiv->deriv_classes[5][7][10] = int_stack + 273154;
 Libderiv->deriv_classes[5][8][10] = int_stack + 273910;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 274855;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 275296;
 Libderiv->deriv2_classes[5][7][10] = int_stack + 275884;
 Libderiv->deriv2_classes[5][8][10] = int_stack + 276640;
 Libderiv->deriv2_classes[6][5][10] = int_stack + 277585;
 Libderiv->deriv2_classes[6][6][10] = int_stack + 278173;
 Libderiv->deriv2_classes[6][7][10] = int_stack + 278957;
 Libderiv->deriv2_classes[6][8][10] = int_stack + 279965;
 Libderiv->deriv_classes[5][5][9] = int_stack + 281225;
 Libderiv->deriv_classes[5][6][9] = int_stack + 281666;
 Libderiv->deriv_classes[5][7][9] = int_stack + 282254;
 Libderiv->deriv_classes[5][8][9] = int_stack + 283010;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 283955;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 284396;
 Libderiv->deriv2_classes[5][7][9] = int_stack + 284984;
 Libderiv->deriv2_classes[5][8][9] = int_stack + 285740;
 Libderiv->deriv2_classes[6][5][9] = int_stack + 286685;
 Libderiv->deriv2_classes[6][6][9] = int_stack + 287273;
 Libderiv->deriv2_classes[6][7][9] = int_stack + 288057;
 Libderiv->deriv2_classes[6][8][9] = int_stack + 289065;
 Libderiv->deriv_classes[5][5][8] = int_stack + 290325;
 Libderiv->deriv_classes[5][6][8] = int_stack + 290766;
 Libderiv->deriv_classes[5][7][8] = int_stack + 291354;
 Libderiv->deriv_classes[5][8][8] = int_stack + 292110;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 293055;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 293496;
 Libderiv->deriv2_classes[5][7][8] = int_stack + 294084;
 Libderiv->deriv2_classes[5][8][8] = int_stack + 294840;
 Libderiv->deriv2_classes[6][5][8] = int_stack + 295785;
 Libderiv->deriv2_classes[6][6][8] = int_stack + 296373;
 Libderiv->deriv2_classes[6][7][8] = int_stack + 297157;
 Libderiv->deriv2_classes[6][8][8] = int_stack + 298165;
 Libderiv->deriv_classes[5][5][7] = int_stack + 299425;
 Libderiv->deriv_classes[5][6][7] = int_stack + 299866;
 Libderiv->deriv_classes[5][7][7] = int_stack + 300454;
 Libderiv->deriv_classes[5][8][7] = int_stack + 301210;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 302155;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 302596;
 Libderiv->deriv2_classes[5][7][7] = int_stack + 303184;
 Libderiv->deriv2_classes[5][8][7] = int_stack + 303940;
 Libderiv->deriv2_classes[6][5][7] = int_stack + 304885;
 Libderiv->deriv2_classes[6][6][7] = int_stack + 305473;
 Libderiv->deriv2_classes[6][7][7] = int_stack + 306257;
 Libderiv->deriv2_classes[6][8][7] = int_stack + 307265;
 Libderiv->dvrr_classes[5][5] = int_stack + 308525;
 Libderiv->deriv_classes[5][5][6] = int_stack + 308966;
 Libderiv->dvrr_classes[5][6] = int_stack + 309407;
 Libderiv->deriv_classes[5][6][6] = int_stack + 309995;
 Libderiv->dvrr_classes[5][7] = int_stack + 310583;
 Libderiv->deriv_classes[5][7][6] = int_stack + 311339;
 Libderiv->deriv_classes[5][8][6] = int_stack + 312095;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 313040;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 313481;
 Libderiv->deriv2_classes[5][7][6] = int_stack + 314069;
 Libderiv->deriv2_classes[5][8][6] = int_stack + 314825;
 Libderiv->deriv_classes[6][5][0] = int_stack + 315770;
 Libderiv->deriv2_classes[6][5][6] = int_stack + 316358;
 Libderiv->deriv_classes[6][6][0] = int_stack + 316946;
 Libderiv->deriv2_classes[6][6][6] = int_stack + 317730;
 Libderiv->deriv_classes[6][7][0] = int_stack + 318514;
 Libderiv->deriv2_classes[6][7][6] = int_stack + 319522;
 Libderiv->deriv2_classes[6][8][6] = int_stack + 320530;
 Libderiv->deriv_classes[5][5][2] = int_stack + 321790;
 Libderiv->deriv_classes[5][6][2] = int_stack + 322231;
 Libderiv->deriv_classes[5][7][2] = int_stack + 322819;
 Libderiv->deriv_classes[5][8][2] = int_stack + 323575;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 324520;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 324961;
 Libderiv->deriv2_classes[5][7][2] = int_stack + 325549;
 Libderiv->deriv2_classes[5][8][2] = int_stack + 326305;
 Libderiv->deriv2_classes[6][5][2] = int_stack + 327250;
 Libderiv->deriv2_classes[6][6][2] = int_stack + 327838;
 Libderiv->deriv2_classes[6][7][2] = int_stack + 328622;
 Libderiv->deriv2_classes[6][8][2] = int_stack + 329630;
 Libderiv->deriv_classes[5][5][1] = int_stack + 330890;
 Libderiv->deriv_classes[5][6][1] = int_stack + 331331;
 Libderiv->deriv_classes[5][7][1] = int_stack + 331919;
 Libderiv->deriv_classes[5][8][1] = int_stack + 332675;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 333620;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 334061;
 Libderiv->deriv2_classes[5][7][1] = int_stack + 334649;
 Libderiv->deriv2_classes[5][8][1] = int_stack + 335405;
 Libderiv->deriv2_classes[6][5][1] = int_stack + 336350;
 Libderiv->deriv2_classes[6][6][1] = int_stack + 336938;
 Libderiv->deriv2_classes[6][7][1] = int_stack + 337722;
 Libderiv->deriv2_classes[6][8][1] = int_stack + 338730;
 Libderiv->deriv_classes[5][5][0] = int_stack + 339990;
 Libderiv->deriv_classes[5][6][0] = int_stack + 340431;
 Libderiv->deriv_classes[5][7][0] = int_stack + 341019;
 Libderiv->deriv_classes[5][8][0] = int_stack + 341775;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 342720;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 343161;
 Libderiv->deriv2_classes[5][7][0] = int_stack + 343749;
 Libderiv->deriv2_classes[5][8][0] = int_stack + 344505;
 Libderiv->deriv2_classes[6][5][0] = int_stack + 345450;
 Libderiv->deriv2_classes[6][6][0] = int_stack + 346038;
 Libderiv->deriv2_classes[6][7][0] = int_stack + 346822;
 Libderiv->deriv2_classes[6][8][0] = int_stack + 347830;
 memset(int_stack,0,2792720);

 Libderiv->dvrr_stack = int_stack + 869470;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_hphf(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+349090,int_stack+309407,int_stack+308525,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+350413,int_stack+310583,int_stack+309407,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+352177,int_stack+350413,int_stack+349090,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+354823,int_stack+263466,int_stack+263025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308525,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+356146,int_stack+264054,int_stack+263466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+309407,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+357910,int_stack+356146,int_stack+354823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349090,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+360556,int_stack+264810,int_stack+264054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+310583,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+362824,int_stack+360556,int_stack+356146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+350413,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+366352,int_stack+362824,int_stack+357910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+352177,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+360556,int_stack+157087,int_stack+155323,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+362320,int_stack+6300,int_stack+157087,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+370762,int_stack+362320,int_stack+360556,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+374290,int_stack+112749,int_stack+111573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155323,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+376054,int_stack+114317,int_stack+112749, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157087,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+378406,int_stack+376054,int_stack+374290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360556,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+381934,int_stack+0,int_stack+114317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6300,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+384958,int_stack+381934,int_stack+376054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+362320,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+389662,int_stack+384958,int_stack+378406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370762,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+381934,int_stack+272566,int_stack+272125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308525, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+383257,int_stack+273154,int_stack+272566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+309407, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+385021,int_stack+383257,int_stack+381934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349090, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+395542,int_stack+273910,int_stack+273154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+310583, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+397810,int_stack+395542,int_stack+383257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+350413, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+401338,int_stack+397810,int_stack+385021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+352177, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+395542,int_stack+121499,int_stack+120323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155323, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+397306,int_stack+123067,int_stack+121499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157087, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+405748,int_stack+397306,int_stack+395542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360556, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+409276,int_stack+1260,int_stack+123067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6300, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+412300,int_stack+409276,int_stack+397306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+362320, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+417004,int_stack+412300,int_stack+405748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370762, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+409276,int_stack+281666,int_stack+281225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308525, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+410599,int_stack+282254,int_stack+281666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+309407, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+412363,int_stack+410599,int_stack+409276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349090, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+283010,int_stack+282254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+310583, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+422884,int_stack+0,int_stack+410599, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+350413, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+426412,int_stack+422884,int_stack+412363, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+352177, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+422884,int_stack+130249,int_stack+129073, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155323, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+131817,int_stack+130249, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157087, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+430822,int_stack+0,int_stack+422884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360556, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+434350,int_stack+2520,int_stack+131817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6300, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+437374,int_stack+434350,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+362320, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+442078,int_stack+437374,int_stack+430822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370762, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+434350,int_stack+290766,int_stack+290325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+424648,int_stack+291354,int_stack+290766, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+309407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+435673,int_stack+424648,int_stack+434350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+438319,int_stack+292110,int_stack+291354, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+310583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+447958,int_stack+438319,int_stack+424648, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+350413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+451486,int_stack+447958,int_stack+435673, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+352177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+447958,int_stack+138999,int_stack+137823, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+438319,int_stack+140567,int_stack+138999, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+455896,int_stack+438319,int_stack+447958, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+459424,int_stack+3780,int_stack+140567, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+462448,int_stack+459424,int_stack+438319, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+362320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+467152,int_stack+462448,int_stack+455896, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+459424,int_stack+299866,int_stack+299425, 0.0, zero_stack, 1.0, int_stack+308525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+449722,int_stack+300454,int_stack+299866, 0.0, zero_stack, 1.0, int_stack+309407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+460747,int_stack+449722,int_stack+459424, 0.0, zero_stack, 1.0, int_stack+349090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+463393,int_stack+301210,int_stack+300454, 0.0, zero_stack, 1.0, int_stack+310583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+473032,int_stack+463393,int_stack+449722, 0.0, zero_stack, 1.0, int_stack+350413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+476560,int_stack+473032,int_stack+460747, 0.0, zero_stack, 1.0, int_stack+352177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+473032,int_stack+147749,int_stack+146573, 0.0, zero_stack, 1.0, int_stack+155323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+463393,int_stack+149317,int_stack+147749, 0.0, zero_stack, 1.0, int_stack+157087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+480970,int_stack+463393,int_stack+473032, 0.0, zero_stack, 1.0, int_stack+360556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+484498,int_stack+5040,int_stack+149317, 0.0, zero_stack, 1.0, int_stack+6300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+487522,int_stack+484498,int_stack+463393, 0.0, zero_stack, 1.0, int_stack+362320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+492226,int_stack+487522,int_stack+480970, 0.0, zero_stack, 1.0, int_stack+370762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+484498,int_stack+309995,int_stack+308966, 1.0, int_stack+308525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+474796,int_stack+311339,int_stack+309995, 1.0, int_stack+309407, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+485821,int_stack+474796,int_stack+484498, 1.0, int_stack+349090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+488467,int_stack+312095,int_stack+311339, 1.0, int_stack+310583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2352,int_stack+488467,int_stack+474796, 1.0, int_stack+350413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+498106,int_stack+2352,int_stack+485821, 1.0, int_stack+352177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2352,int_stack+157871,int_stack+155911, 1.0, int_stack+155323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+488467,int_stack+159439,int_stack+157871, 1.0, int_stack+157087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+502516,int_stack+488467,int_stack+2352, 1.0, int_stack+360556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+506044,int_stack+7308,int_stack+159439, 1.0, int_stack+6300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+509068,int_stack+506044,int_stack+488467, 1.0, int_stack+362320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+513772,int_stack+509068,int_stack+502516, 1.0, int_stack+370762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+370762,int_stack+11088,int_stack+310583,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+506044,int_stack+370762,int_stack+350413,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+360556,int_stack+506044,int_stack+352177,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+506044,int_stack+322231,int_stack+321790,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+507367,int_stack+322819,int_stack+322231,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+509131,int_stack+507367,int_stack+506044,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+370762,int_stack+323575,int_stack+322819,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4116,int_stack+370762,int_stack+507367,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+349090,int_stack+4116,int_stack+509131,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+4116,int_stack+198471,int_stack+197295,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+200039,int_stack+198471,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+370762,int_stack+5880,int_stack+4116,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+519652,int_stack+8568,int_stack+200039,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+522676,int_stack+519652,int_stack+5880,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+527380,int_stack+522676,int_stack+370762,28);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+353500,int_stack+331331,int_stack+330890,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+519652,int_stack+331919,int_stack+331331,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+521416,int_stack+519652,int_stack+353500,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+524062,int_stack+332675,int_stack+331919,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+533260,int_stack+524062,int_stack+519652,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+536788,int_stack+533260,int_stack+521416,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+533260,int_stack+245441,int_stack+244265,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+524062,int_stack+247009,int_stack+245441,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+541198,int_stack+524062,int_stack+533260,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+544726,int_stack+9828,int_stack+247009,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+547750,int_stack+544726,int_stack+524062,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+552454,int_stack+547750,int_stack+541198,28);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+544726,int_stack+340431,int_stack+339990,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+535024,int_stack+341019,int_stack+340431,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+546049,int_stack+535024,int_stack+544726,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+548695,int_stack+341775,int_stack+341019,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+8232,int_stack+548695,int_stack+535024,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+558334,int_stack+8232,int_stack+546049,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+8232,int_stack+316946,int_stack+315770,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+548695,int_stack+318514,int_stack+316946,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+562744,int_stack+548695,int_stack+8232,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+566272,int_stack+12033,int_stack+318514,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+569296,int_stack+566272,int_stack+548695,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+574000,int_stack+569296,int_stack+562744,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+566272,int_stack+13734,int_stack+13293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+263025,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+567595,int_stack+14322,int_stack+13734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+263466,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+569359,int_stack+567595,int_stack+566272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+354823,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+9996,int_stack+15078,int_stack+14322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+264054,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12264,int_stack+9996,int_stack+567595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+356146,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+579880,int_stack+12264,int_stack+569359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+357910,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9996,int_stack+16611,int_stack+16023, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+111573,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11760,int_stack+17395,int_stack+16611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+112749,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+566272,int_stack+11760,int_stack+9996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+374290,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+14112,int_stack+18403,int_stack+17395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+114317,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+584290,int_stack+14112,int_stack+11760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+376054,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+9996,int_stack+584290,int_stack+566272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+378406,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+566272,int_stack+20104,int_stack+19663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263025, 1.0, int_stack+272125,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+567595,int_stack+20692,int_stack+20104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263466, 1.0, int_stack+272566,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+569359,int_stack+567595,int_stack+566272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+354823, 1.0, int_stack+381934,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+584290,int_stack+21448,int_stack+20692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264054, 1.0, int_stack+273154,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+15876,int_stack+584290,int_stack+567595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356146, 1.0, int_stack+383257,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+584290,int_stack+15876,int_stack+569359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357910, 1.0, int_stack+385021,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15876,int_stack+22981,int_stack+22393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111573, 1.0, int_stack+120323,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+17640,int_stack+23765,int_stack+22981, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112749, 1.0, int_stack+121499,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+19992,int_stack+17640,int_stack+15876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+374290, 1.0, int_stack+395542,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+566272,int_stack+24773,int_stack+23765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114317, 1.0, int_stack+123067,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+569296,int_stack+566272,int_stack+17640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376054, 1.0, int_stack+397306,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+588700,int_stack+569296,int_stack+19992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+378406, 1.0, int_stack+405748,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+566272,int_stack+26474,int_stack+26033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+272125, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+567595,int_stack+27062,int_stack+26474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+272566, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+569359,int_stack+567595,int_stack+566272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+381934, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+15876,int_stack+27818,int_stack+27062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+273154, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+18144,int_stack+15876,int_stack+567595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+383257, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+21672,int_stack+18144,int_stack+569359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+385021, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15876,int_stack+29351,int_stack+28763, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+120323, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+17640,int_stack+30135,int_stack+29351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+121499, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+566272,int_stack+17640,int_stack+15876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+395542, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+569800,int_stack+31143,int_stack+30135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+123067, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+26082,int_stack+569800,int_stack+17640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+397306, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+594580,int_stack+26082,int_stack+566272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+405748, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+566272,int_stack+32844,int_stack+32403, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263025, 0.0, zero_stack, 1.0, int_stack+281225,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+567595,int_stack+33432,int_stack+32844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263466, 0.0, zero_stack, 1.0, int_stack+281666,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+569359,int_stack+567595,int_stack+566272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+354823, 0.0, zero_stack, 1.0, int_stack+409276,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+26082,int_stack+34188,int_stack+33432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264054, 0.0, zero_stack, 1.0, int_stack+282254,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+28350,int_stack+26082,int_stack+567595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356146, 0.0, zero_stack, 1.0, int_stack+410599,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+15876,int_stack+28350,int_stack+569359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357910, 0.0, zero_stack, 1.0, int_stack+412363,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26082,int_stack+35721,int_stack+35133, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111573, 0.0, zero_stack, 1.0, int_stack+129073,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+27846,int_stack+36505,int_stack+35721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112749, 0.0, zero_stack, 1.0, int_stack+130249,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30198,int_stack+27846,int_stack+26082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+374290, 0.0, zero_stack, 1.0, int_stack+422884,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+566272,int_stack+37513,int_stack+36505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114317, 0.0, zero_stack, 1.0, int_stack+131817,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+569296,int_stack+566272,int_stack+27846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376054, 0.0, zero_stack, 1.0, int_stack+0,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+600460,int_stack+569296,int_stack+30198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+378406, 0.0, zero_stack, 1.0, int_stack+430822,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+566272,int_stack+39214,int_stack+38773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+272125, 1.0, int_stack+281225, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+567595,int_stack+39802,int_stack+39214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+272566, 1.0, int_stack+281666, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+569359,int_stack+567595,int_stack+566272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+381934, 1.0, int_stack+409276, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+26082,int_stack+40558,int_stack+39802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+273154, 1.0, int_stack+282254, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+28350,int_stack+26082,int_stack+567595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+383257, 1.0, int_stack+410599, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+31878,int_stack+28350,int_stack+569359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385021, 1.0, int_stack+412363, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26082,int_stack+42091,int_stack+41503, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120323, 1.0, int_stack+129073, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+27846,int_stack+42875,int_stack+42091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121499, 1.0, int_stack+130249, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+566272,int_stack+27846,int_stack+26082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+395542, 1.0, int_stack+422884, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+569800,int_stack+43883,int_stack+42875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123067, 1.0, int_stack+131817, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+36288,int_stack+569800,int_stack+27846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397306, 1.0, int_stack+0, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+606340,int_stack+36288,int_stack+566272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+405748, 1.0, int_stack+430822, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+566272,int_stack+45584,int_stack+45143, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+281225, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+567595,int_stack+46172,int_stack+45584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+281666, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+569359,int_stack+567595,int_stack+566272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+409276, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+36288,int_stack+46928,int_stack+46172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+282254, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+38556,int_stack+36288,int_stack+567595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+410599, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+42084,int_stack+38556,int_stack+569359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+412363, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+36288,int_stack+48461,int_stack+47873, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+129073, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+38052,int_stack+49245,int_stack+48461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+130249, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+566272,int_stack+38052,int_stack+36288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+422884, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+569800,int_stack+50253,int_stack+49245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+131817, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+46494,int_stack+569800,int_stack+38052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+612220,int_stack+46494,int_stack+566272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+430822, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+566272,int_stack+51954,int_stack+51513, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263025, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290325,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+567595,int_stack+52542,int_stack+51954, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263466, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290766,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+569359,int_stack+567595,int_stack+566272, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+354823, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+434350,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+46494,int_stack+53298,int_stack+52542, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264054, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+291354,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+48762,int_stack+46494,int_stack+567595, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356146, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+424648,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+36288,int_stack+48762,int_stack+569359, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357910, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+435673,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+46494,int_stack+54831,int_stack+54243, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111573, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+137823,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+48258,int_stack+55615,int_stack+54831, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112749, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+138999,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+50610,int_stack+48258,int_stack+46494, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+374290, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+447958,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+566272,int_stack+56623,int_stack+55615, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114317, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+140567,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+569296,int_stack+566272,int_stack+48258, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376054, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+438319,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+618100,int_stack+569296,int_stack+50610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+378406, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+455896,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+566272,int_stack+58324,int_stack+57883, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+272125, 0.0, zero_stack, 1.0, int_stack+290325, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+567595,int_stack+58912,int_stack+58324, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+272566, 0.0, zero_stack, 1.0, int_stack+290766, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+569359,int_stack+567595,int_stack+566272, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+381934, 0.0, zero_stack, 1.0, int_stack+434350, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+46494,int_stack+59668,int_stack+58912, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+273154, 0.0, zero_stack, 1.0, int_stack+291354, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+48762,int_stack+46494,int_stack+567595, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+383257, 0.0, zero_stack, 1.0, int_stack+424648, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+52290,int_stack+48762,int_stack+569359, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385021, 0.0, zero_stack, 1.0, int_stack+435673, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+46494,int_stack+61201,int_stack+60613, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120323, 0.0, zero_stack, 1.0, int_stack+137823, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+48258,int_stack+61985,int_stack+61201, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+121499, 0.0, zero_stack, 1.0, int_stack+138999, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+566272,int_stack+48258,int_stack+46494, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+395542, 0.0, zero_stack, 1.0, int_stack+447958, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+569800,int_stack+62993,int_stack+61985, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123067, 0.0, zero_stack, 1.0, int_stack+140567, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+56700,int_stack+569800,int_stack+48258, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397306, 0.0, zero_stack, 1.0, int_stack+438319, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+623980,int_stack+56700,int_stack+566272, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+405748, 0.0, zero_stack, 1.0, int_stack+455896, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+566272,int_stack+64694,int_stack+64253, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281225, 1.0, int_stack+290325, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+567595,int_stack+65282,int_stack+64694, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281666, 1.0, int_stack+290766, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+569359,int_stack+567595,int_stack+566272, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409276, 1.0, int_stack+434350, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+56700,int_stack+66038,int_stack+65282, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282254, 1.0, int_stack+291354, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+58968,int_stack+56700,int_stack+567595, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410599, 1.0, int_stack+424648, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+62496,int_stack+58968,int_stack+569359, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412363, 1.0, int_stack+435673, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+56700,int_stack+67571,int_stack+66983, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129073, 1.0, int_stack+137823, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+58464,int_stack+68355,int_stack+67571, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+130249, 1.0, int_stack+138999, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+566272,int_stack+58464,int_stack+56700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+422884, 1.0, int_stack+447958, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+569800,int_stack+69363,int_stack+68355, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131817, 1.0, int_stack+140567, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+46494,int_stack+569800,int_stack+58464, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+438319, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+629860,int_stack+46494,int_stack+566272, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430822, 1.0, int_stack+455896, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+566272,int_stack+71064,int_stack+70623, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+290325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+567595,int_stack+71652,int_stack+71064, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+290766, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+569359,int_stack+567595,int_stack+566272, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+434350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+46494,int_stack+72408,int_stack+71652, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+291354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+48762,int_stack+46494,int_stack+567595, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+424648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+56700,int_stack+48762,int_stack+569359, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+435673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+46494,int_stack+73941,int_stack+73353, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+137823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+48258,int_stack+74725,int_stack+73941, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+138999, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+566272,int_stack+48258,int_stack+46494, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+447958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+569800,int_stack+75733,int_stack+74725, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+140567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+66906,int_stack+569800,int_stack+48258, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+438319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+635740,int_stack+66906,int_stack+566272, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+455896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+566272,int_stack+77434,int_stack+76993, 0.0, zero_stack, 1.0, int_stack+263025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+299425,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+567595,int_stack+78022,int_stack+77434, 0.0, zero_stack, 1.0, int_stack+263466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+299866,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+569359,int_stack+567595,int_stack+566272, 0.0, zero_stack, 1.0, int_stack+354823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459424,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+66906,int_stack+78778,int_stack+78022, 0.0, zero_stack, 1.0, int_stack+264054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+300454,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+69174,int_stack+66906,int_stack+567595, 0.0, zero_stack, 1.0, int_stack+356146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+449722,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+72702,int_stack+69174,int_stack+569359, 0.0, zero_stack, 1.0, int_stack+357910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460747,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+66906,int_stack+80311,int_stack+79723, 0.0, zero_stack, 1.0, int_stack+111573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146573,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+68670,int_stack+81095,int_stack+80311, 0.0, zero_stack, 1.0, int_stack+112749, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147749,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+566272,int_stack+68670,int_stack+66906, 0.0, zero_stack, 1.0, int_stack+374290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+473032,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+569800,int_stack+82103,int_stack+81095, 0.0, zero_stack, 1.0, int_stack+114317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149317,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+77112,int_stack+569800,int_stack+68670, 0.0, zero_stack, 1.0, int_stack+376054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+463393,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+641620,int_stack+77112,int_stack+566272, 0.0, zero_stack, 1.0, int_stack+378406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480970,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+566272,int_stack+83804,int_stack+83363, 0.0, zero_stack, 1.0, int_stack+272125, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+299425, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+567595,int_stack+84392,int_stack+83804, 0.0, zero_stack, 1.0, int_stack+272566, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+299866, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+569359,int_stack+567595,int_stack+566272, 0.0, zero_stack, 1.0, int_stack+381934, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459424, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+77112,int_stack+85148,int_stack+84392, 0.0, zero_stack, 1.0, int_stack+273154, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+300454, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+79380,int_stack+77112,int_stack+567595, 0.0, zero_stack, 1.0, int_stack+383257, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+449722, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+66906,int_stack+79380,int_stack+569359, 0.0, zero_stack, 1.0, int_stack+385021, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460747, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+77112,int_stack+86681,int_stack+86093, 0.0, zero_stack, 1.0, int_stack+120323, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146573, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+78876,int_stack+87465,int_stack+86681, 0.0, zero_stack, 1.0, int_stack+121499, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147749, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+81228,int_stack+78876,int_stack+77112, 0.0, zero_stack, 1.0, int_stack+395542, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+473032, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+566272,int_stack+88473,int_stack+87465, 0.0, zero_stack, 1.0, int_stack+123067, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+149317, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+569296,int_stack+566272,int_stack+78876, 0.0, zero_stack, 1.0, int_stack+397306, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+463393, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+647500,int_stack+569296,int_stack+81228, 0.0, zero_stack, 1.0, int_stack+405748, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480970, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+566272,int_stack+90174,int_stack+89733, 0.0, zero_stack, 1.0, int_stack+281225, 0.0, zero_stack, 1.0, int_stack+299425, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+567595,int_stack+90762,int_stack+90174, 0.0, zero_stack, 1.0, int_stack+281666, 0.0, zero_stack, 1.0, int_stack+299866, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+569359,int_stack+567595,int_stack+566272, 0.0, zero_stack, 1.0, int_stack+409276, 0.0, zero_stack, 1.0, int_stack+459424, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+77112,int_stack+91518,int_stack+90762, 0.0, zero_stack, 1.0, int_stack+282254, 0.0, zero_stack, 1.0, int_stack+300454, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+79380,int_stack+77112,int_stack+567595, 0.0, zero_stack, 1.0, int_stack+410599, 0.0, zero_stack, 1.0, int_stack+449722, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+82908,int_stack+79380,int_stack+569359, 0.0, zero_stack, 1.0, int_stack+412363, 0.0, zero_stack, 1.0, int_stack+460747, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+77112,int_stack+93051,int_stack+92463, 0.0, zero_stack, 1.0, int_stack+129073, 0.0, zero_stack, 1.0, int_stack+146573, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+78876,int_stack+93835,int_stack+93051, 0.0, zero_stack, 1.0, int_stack+130249, 0.0, zero_stack, 1.0, int_stack+147749, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+566272,int_stack+78876,int_stack+77112, 0.0, zero_stack, 1.0, int_stack+422884, 0.0, zero_stack, 1.0, int_stack+473032, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+569800,int_stack+94843,int_stack+93835, 0.0, zero_stack, 1.0, int_stack+131817, 0.0, zero_stack, 1.0, int_stack+149317, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+87318,int_stack+569800,int_stack+78876, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+463393, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+653380,int_stack+87318,int_stack+566272, 0.0, zero_stack, 1.0, int_stack+430822, 0.0, zero_stack, 1.0, int_stack+480970, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+566272,int_stack+96544,int_stack+96103, 0.0, zero_stack, 1.0, int_stack+290325, 1.0, int_stack+299425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+567595,int_stack+97132,int_stack+96544, 0.0, zero_stack, 1.0, int_stack+290766, 1.0, int_stack+299866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+569359,int_stack+567595,int_stack+566272, 0.0, zero_stack, 1.0, int_stack+434350, 1.0, int_stack+459424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+87318,int_stack+97888,int_stack+97132, 0.0, zero_stack, 1.0, int_stack+291354, 1.0, int_stack+300454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+89586,int_stack+87318,int_stack+567595, 0.0, zero_stack, 1.0, int_stack+424648, 1.0, int_stack+449722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+93114,int_stack+89586,int_stack+569359, 0.0, zero_stack, 1.0, int_stack+435673, 1.0, int_stack+460747, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+87318,int_stack+99421,int_stack+98833, 0.0, zero_stack, 1.0, int_stack+137823, 1.0, int_stack+146573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+89082,int_stack+100205,int_stack+99421, 0.0, zero_stack, 1.0, int_stack+138999, 1.0, int_stack+147749, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+566272,int_stack+89082,int_stack+87318, 0.0, zero_stack, 1.0, int_stack+447958, 1.0, int_stack+473032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+569800,int_stack+101213,int_stack+100205, 0.0, zero_stack, 1.0, int_stack+140567, 1.0, int_stack+149317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+97524,int_stack+569800,int_stack+89082, 0.0, zero_stack, 1.0, int_stack+438319, 1.0, int_stack+463393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+659260,int_stack+97524,int_stack+566272, 0.0, zero_stack, 1.0, int_stack+455896, 1.0, int_stack+480970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+566272,int_stack+102914,int_stack+102473, 0.0, zero_stack, 2.0, int_stack+299425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+567595,int_stack+103502,int_stack+102914, 0.0, zero_stack, 2.0, int_stack+299866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+569359,int_stack+567595,int_stack+566272, 0.0, zero_stack, 2.0, int_stack+459424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+97524,int_stack+104258,int_stack+103502, 0.0, zero_stack, 2.0, int_stack+300454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+99792,int_stack+97524,int_stack+567595, 0.0, zero_stack, 2.0, int_stack+449722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+87318,int_stack+99792,int_stack+569359, 0.0, zero_stack, 2.0, int_stack+460747, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+97524,int_stack+105791,int_stack+105203, 0.0, zero_stack, 2.0, int_stack+146573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+99288,int_stack+106575,int_stack+105791, 0.0, zero_stack, 2.0, int_stack+147749, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101640,int_stack+99288,int_stack+97524, 0.0, zero_stack, 2.0, int_stack+473032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+566272,int_stack+107583,int_stack+106575, 0.0, zero_stack, 2.0, int_stack+149317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+569296,int_stack+566272,int_stack+99288, 0.0, zero_stack, 2.0, int_stack+463393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+665140,int_stack+569296,int_stack+101640, 0.0, zero_stack, 2.0, int_stack+480970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+566272,int_stack+109284,int_stack+108843, 1.0, int_stack+263025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308966,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+567595,int_stack+109872,int_stack+109284, 1.0, int_stack+263466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+309995,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+569359,int_stack+567595,int_stack+566272, 1.0, int_stack+354823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484498,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+97524,int_stack+110628,int_stack+109872, 1.0, int_stack+264054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311339,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+99792,int_stack+97524,int_stack+567595, 1.0, int_stack+356146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+474796,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+103320,int_stack+99792,int_stack+569359, 1.0, int_stack+357910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+485821,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+97524,int_stack+113533,int_stack+112161, 1.0, int_stack+111573, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155911,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+99288,int_stack+115325,int_stack+113533, 1.0, int_stack+112749, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157871,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+354823,int_stack+99288,int_stack+97524, 1.0, int_stack+374290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2352,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+566272,int_stack+116333,int_stack+115325, 1.0, int_stack+114317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159439,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+569296,int_stack+566272,int_stack+99288, 1.0, int_stack+376054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+488467,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+107730,int_stack+569296,int_stack+354823, 1.0, int_stack+378406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+502516,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+354823,int_stack+118034,int_stack+117593, 1.0, int_stack+272125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308966, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+356146,int_stack+118622,int_stack+118034, 1.0, int_stack+272566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+309995, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+357910,int_stack+356146,int_stack+354823, 1.0, int_stack+381934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484498, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+566272,int_stack+119378,int_stack+118622, 1.0, int_stack+273154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311339, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+568540,int_stack+566272,int_stack+356146, 1.0, int_stack+383257, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+474796, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+374290,int_stack+568540,int_stack+357910, 1.0, int_stack+385021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+485821, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+566272,int_stack+122283,int_stack+120911, 1.0, int_stack+120323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155911, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+568036,int_stack+124075,int_stack+122283, 1.0, int_stack+121499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157871, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+570388,int_stack+568036,int_stack+566272, 1.0, int_stack+395542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2352, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+354823,int_stack+125083,int_stack+124075, 1.0, int_stack+123067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159439, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+378700,int_stack+354823,int_stack+568036, 1.0, int_stack+397306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+488467, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+383404,int_stack+378700,int_stack+570388, 1.0, int_stack+405748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+502516, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+405748,int_stack+126784,int_stack+126343, 1.0, int_stack+281225, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308966, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+407071,int_stack+127372,int_stack+126784, 1.0, int_stack+281666, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+309995, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+378700,int_stack+407071,int_stack+405748, 1.0, int_stack+409276, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484498, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+354823,int_stack+128128,int_stack+127372, 1.0, int_stack+282254, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311339, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+395542,int_stack+354823,int_stack+407071, 1.0, int_stack+410599, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+474796, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+354823,int_stack+395542,int_stack+378700, 1.0, int_stack+412363, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+485821, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+378700,int_stack+131033,int_stack+129661, 1.0, int_stack+129073, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155911, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+380464,int_stack+132825,int_stack+131033, 1.0, int_stack+130249, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157871, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+395542,int_stack+380464,int_stack+378700, 1.0, int_stack+422884, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2352, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+405748,int_stack+133833,int_stack+132825, 1.0, int_stack+131817, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+159439, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+408772,int_stack+405748,int_stack+380464, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+488467, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+566272,int_stack+408772,int_stack+395542, 1.0, int_stack+430822, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+502516, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359233,int_stack+135534,int_stack+135093, 1.0, int_stack+290325, 0.0, zero_stack, 1.0, int_stack+308966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+422884,int_stack+136122,int_stack+135534, 1.0, int_stack+290766, 0.0, zero_stack, 1.0, int_stack+309995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+430822,int_stack+422884,int_stack+359233, 1.0, int_stack+434350, 0.0, zero_stack, 1.0, int_stack+484498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+395542,int_stack+136878,int_stack+136122, 1.0, int_stack+291354, 0.0, zero_stack, 1.0, int_stack+311339, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+397810,int_stack+395542,int_stack+422884, 1.0, int_stack+424648, 0.0, zero_stack, 1.0, int_stack+474796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+405748,int_stack+397810,int_stack+430822, 1.0, int_stack+435673, 0.0, zero_stack, 1.0, int_stack+485821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+430822,int_stack+139783,int_stack+138411, 1.0, int_stack+137823, 0.0, zero_stack, 1.0, int_stack+155911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+141575,int_stack+139783, 1.0, int_stack+138999, 0.0, zero_stack, 1.0, int_stack+157871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+422884,int_stack+0,int_stack+430822, 1.0, int_stack+447958, 0.0, zero_stack, 1.0, int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+430822,int_stack+142583,int_stack+141575, 1.0, int_stack+140567, 0.0, zero_stack, 1.0, int_stack+159439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+378700,int_stack+430822,int_stack+0, 1.0, int_stack+438319, 0.0, zero_stack, 1.0, int_stack+488467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+430822,int_stack+378700,int_stack+422884, 1.0, int_stack+455896, 0.0, zero_stack, 1.0, int_stack+502516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359233,int_stack+144284,int_stack+143843, 1.0, int_stack+299425, 1.0, int_stack+308966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+447958,int_stack+144872,int_stack+144284, 1.0, int_stack+299866, 1.0, int_stack+309995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+455896,int_stack+447958,int_stack+359233, 1.0, int_stack+459424, 1.0, int_stack+484498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+422884,int_stack+145628,int_stack+144872, 1.0, int_stack+300454, 1.0, int_stack+311339, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+378700,int_stack+422884,int_stack+447958, 1.0, int_stack+449722, 1.0, int_stack+474796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+436702,int_stack+378700,int_stack+455896, 1.0, int_stack+460747, 1.0, int_stack+485821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+455896,int_stack+148533,int_stack+147161, 1.0, int_stack+146573, 1.0, int_stack+155911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+150325,int_stack+148533, 1.0, int_stack+147749, 1.0, int_stack+157871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+447958,int_stack+0,int_stack+455896, 1.0, int_stack+473032, 1.0, int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+455896,int_stack+151333,int_stack+150325, 1.0, int_stack+149317, 1.0, int_stack+159439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+378700,int_stack+455896,int_stack+0, 1.0, int_stack+463393, 1.0, int_stack+488467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+455896,int_stack+378700,int_stack+447958, 1.0, int_stack+480970, 1.0, int_stack+502516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359233,int_stack+153034,int_stack+152593, 2.0, int_stack+308966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+473032,int_stack+153622,int_stack+153034, 2.0, int_stack+309995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+480970,int_stack+473032,int_stack+359233, 2.0, int_stack+484498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+447958,int_stack+154378,int_stack+153622, 2.0, int_stack+311339, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+422884,int_stack+447958,int_stack+473032, 2.0, int_stack+474796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+378700,int_stack+422884,int_stack+480970, 2.0, int_stack+485821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+480970,int_stack+158655,int_stack+156499, 2.0, int_stack+155911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+160447,int_stack+158655, 2.0, int_stack+157871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+422884,int_stack+0,int_stack+480970, 2.0, int_stack+2352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+480970,int_stack+161455,int_stack+160447, 2.0, int_stack+159439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+461776,int_stack+480970,int_stack+0, 2.0, int_stack+488467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+480970,int_stack+461776,int_stack+422884, 2.0, int_stack+502516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359233,int_stack+163156,int_stack+162715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321790,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+502516,int_stack+163744,int_stack+163156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322231,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+422884,int_stack+502516,int_stack+359233, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+506044,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+461776,int_stack+164500,int_stack+163744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322819,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+473032,int_stack+461776,int_stack+502516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507367,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+461776,int_stack+473032,int_stack+422884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+509131,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+422884,int_stack+166033,int_stack+165445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197295,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+473032,int_stack+166817,int_stack+166033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198471,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+502516,int_stack+473032,int_stack+422884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4116,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+422884,int_stack+167825,int_stack+166817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200039,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+486850,int_stack+422884,int_stack+473032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+410158,int_stack+486850,int_stack+502516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370762,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359233,int_stack+169526,int_stack+169085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321790, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+502516,int_stack+170114,int_stack+169526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322231, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+486850,int_stack+502516,int_stack+359233, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+506044, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+489496,int_stack+170870,int_stack+170114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322819, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+473032,int_stack+489496,int_stack+502516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507367, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+395542,int_stack+473032,int_stack+486850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+509131, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+486850,int_stack+172403,int_stack+171815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197295, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+488614,int_stack+173187,int_stack+172403, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198471, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+473032,int_stack+488614,int_stack+486850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4116, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+502516,int_stack+174195,int_stack+173187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200039, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+97524,int_stack+502516,int_stack+488614, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+113610,int_stack+97524,int_stack+473032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370762, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359233,int_stack+175896,int_stack+175455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321790, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+473032,int_stack+176484,int_stack+175896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322231, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+97524,int_stack+473032,int_stack+359233, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+506044, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+100170,int_stack+177240,int_stack+176484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322819, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+502516,int_stack+100170,int_stack+473032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507367, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+486850,int_stack+502516,int_stack+97524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+509131, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+97524,int_stack+178773,int_stack+178185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197295, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+99288,int_stack+179557,int_stack+178773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198471, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+502516,int_stack+99288,int_stack+97524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4116, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+473032,int_stack+180565,int_stack+179557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200039, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+119490,int_stack+473032,int_stack+99288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+124194,int_stack+119490,int_stack+502516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370762, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359233,int_stack+182266,int_stack+181825, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+502516,int_stack+182854,int_stack+182266, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+119490,int_stack+502516,int_stack+359233, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+506044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+473032,int_stack+183610,int_stack+182854, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+422884,int_stack+473032,int_stack+502516, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+97524,int_stack+422884,int_stack+119490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+509131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+119490,int_stack+185143,int_stack+184555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+121254,int_stack+185927,int_stack+185143, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+198471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+422884,int_stack+121254,int_stack+119490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+502516,int_stack+186935,int_stack+185927, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+130074,int_stack+502516,int_stack+121254, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+134778,int_stack+130074,int_stack+422884, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359233,int_stack+188636,int_stack+188195, 0.0, zero_stack, 1.0, int_stack+321790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+422884,int_stack+189224,int_stack+188636, 0.0, zero_stack, 1.0, int_stack+322231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+130074,int_stack+422884,int_stack+359233, 0.0, zero_stack, 1.0, int_stack+506044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+502516,int_stack+189980,int_stack+189224, 0.0, zero_stack, 1.0, int_stack+322819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+473032,int_stack+502516,int_stack+422884, 0.0, zero_stack, 1.0, int_stack+507367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+119490,int_stack+473032,int_stack+130074, 0.0, zero_stack, 1.0, int_stack+509131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+130074,int_stack+191513,int_stack+190925, 0.0, zero_stack, 1.0, int_stack+197295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+131838,int_stack+192297,int_stack+191513, 0.0, zero_stack, 1.0, int_stack+198471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+473032,int_stack+131838,int_stack+130074, 0.0, zero_stack, 1.0, int_stack+4116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+422884,int_stack+193305,int_stack+192297, 0.0, zero_stack, 1.0, int_stack+200039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+140658,int_stack+422884,int_stack+131838, 0.0, zero_stack, 1.0, int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+145362,int_stack+140658,int_stack+473032, 0.0, zero_stack, 1.0, int_stack+370762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359233,int_stack+195006,int_stack+194565, 1.0, int_stack+321790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+473032,int_stack+195594,int_stack+195006, 1.0, int_stack+322231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+140658,int_stack+473032,int_stack+359233, 1.0, int_stack+506044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+422884,int_stack+196350,int_stack+195594, 1.0, int_stack+322819, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+447958,int_stack+422884,int_stack+473032, 1.0, int_stack+507367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+130074,int_stack+447958,int_stack+140658, 1.0, int_stack+509131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+140658,int_stack+199255,int_stack+197883, 1.0, int_stack+197295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+142422,int_stack+201047,int_stack+199255, 1.0, int_stack+198471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+447958,int_stack+142422,int_stack+140658, 1.0, int_stack+4116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+473032,int_stack+202055,int_stack+201047, 1.0, int_stack+200039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+502516,int_stack+473032,int_stack+142422, 1.0, int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+507220,int_stack+502516,int_stack+447958, 1.0, int_stack+370762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+359233,int_stack+203756,int_stack+203315,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+370762,int_stack+204344,int_stack+203756,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+447958,int_stack+370762,int_stack+359233,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+502516,int_stack+205100,int_stack+204344,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+473032,int_stack+502516,int_stack+370762,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+502516,int_stack+473032,int_stack+447958,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+447958,int_stack+206633,int_stack+206045,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+473032,int_stack+207417,int_stack+206633,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+370762,int_stack+473032,int_stack+447958,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+447958,int_stack+208425,int_stack+207417,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+140658,int_stack+447958,int_stack+473032,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+140658,int_stack+370762,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359233,int_stack+210126,int_stack+209685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330890,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+370762,int_stack+210714,int_stack+210126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331331,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+140658,int_stack+370762,int_stack+359233, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+353500,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+473032,int_stack+211470,int_stack+210714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331919,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+447958,int_stack+473032,int_stack+370762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519652,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+151242,int_stack+447958,int_stack+140658, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+521416,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+140658,int_stack+213003,int_stack+212415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244265,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+213787,int_stack+213003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245441,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+447958,int_stack+5880,int_stack+140658, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533260,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+140658,int_stack+214795,int_stack+213787, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247009,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+155652,int_stack+140658,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524062,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+160356,int_stack+155652,int_stack+447958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+541198,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359233,int_stack+216496,int_stack+216055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330890, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+447958,int_stack+217084,int_stack+216496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331331, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+155652,int_stack+447958,int_stack+359233, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+353500, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5880,int_stack+217840,int_stack+217084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331919, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+370762,int_stack+5880,int_stack+447958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519652, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+140658,int_stack+370762,int_stack+155652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+521416, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+155652,int_stack+219373,int_stack+218785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244265, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+220157,int_stack+219373, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245441, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+370762,int_stack+5880,int_stack+155652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533260, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+155652,int_stack+221165,int_stack+220157, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247009, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+166236,int_stack+155652,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524062, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+170940,int_stack+166236,int_stack+370762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+541198, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359233,int_stack+222866,int_stack+222425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330890, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+370762,int_stack+223454,int_stack+222866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331331, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+166236,int_stack+370762,int_stack+359233, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+353500, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5880,int_stack+224210,int_stack+223454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331919, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+447958,int_stack+5880,int_stack+370762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519652, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+155652,int_stack+447958,int_stack+166236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+521416, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+166236,int_stack+225743,int_stack+225155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244265, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+226527,int_stack+225743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245441, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+447958,int_stack+5880,int_stack+166236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533260, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+166236,int_stack+227535,int_stack+226527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247009, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+176820,int_stack+166236,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524062, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+181524,int_stack+176820,int_stack+447958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+541198, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359233,int_stack+229236,int_stack+228795, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+447958,int_stack+229824,int_stack+229236, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+176820,int_stack+447958,int_stack+359233, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+353500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5880,int_stack+230580,int_stack+229824, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+370762,int_stack+5880,int_stack+447958, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+166236,int_stack+370762,int_stack+176820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+521416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+176820,int_stack+232113,int_stack+231525, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+244265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+232897,int_stack+232113, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+370762,int_stack+5880,int_stack+176820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+176820,int_stack+233905,int_stack+232897, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+187404,int_stack+176820,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+192108,int_stack+187404,int_stack+370762, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+541198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359233,int_stack+235606,int_stack+235165, 0.0, zero_stack, 1.0, int_stack+330890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+370762,int_stack+236194,int_stack+235606, 0.0, zero_stack, 1.0, int_stack+331331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+187404,int_stack+370762,int_stack+359233, 0.0, zero_stack, 1.0, int_stack+353500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5880,int_stack+236950,int_stack+236194, 0.0, zero_stack, 1.0, int_stack+331919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+447958,int_stack+5880,int_stack+370762, 0.0, zero_stack, 1.0, int_stack+519652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+176820,int_stack+447958,int_stack+187404, 0.0, zero_stack, 1.0, int_stack+521416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+187404,int_stack+238483,int_stack+237895, 0.0, zero_stack, 1.0, int_stack+244265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+239267,int_stack+238483, 0.0, zero_stack, 1.0, int_stack+245441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+447958,int_stack+5880,int_stack+187404, 0.0, zero_stack, 1.0, int_stack+533260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+187404,int_stack+240275,int_stack+239267, 0.0, zero_stack, 1.0, int_stack+247009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+197988,int_stack+187404,int_stack+5880, 0.0, zero_stack, 1.0, int_stack+524062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+202692,int_stack+197988,int_stack+447958, 0.0, zero_stack, 1.0, int_stack+541198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+359233,int_stack+241976,int_stack+241535, 1.0, int_stack+330890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+447958,int_stack+242564,int_stack+241976, 1.0, int_stack+331331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+197988,int_stack+447958,int_stack+359233, 1.0, int_stack+353500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5880,int_stack+243320,int_stack+242564, 1.0, int_stack+331919, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+370762,int_stack+5880,int_stack+447958, 1.0, int_stack+519652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+187404,int_stack+370762,int_stack+197988, 1.0, int_stack+521416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+197988,int_stack+246225,int_stack+244853, 1.0, int_stack+244265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+248017,int_stack+246225, 1.0, int_stack+245441, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+370762,int_stack+5880,int_stack+197988, 1.0, int_stack+533260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+197988,int_stack+249025,int_stack+248017, 1.0, int_stack+247009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+208572,int_stack+197988,int_stack+5880, 1.0, int_stack+524062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+519652,int_stack+208572,int_stack+370762, 1.0, int_stack+541198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+353500,int_stack+250726,int_stack+250285,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+533260,int_stack+251314,int_stack+250726,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+541198,int_stack+533260,int_stack+353500,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+370762,int_stack+252070,int_stack+251314,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+447958,int_stack+370762,int_stack+533260,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+208572,int_stack+447958,int_stack+541198,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+533260,int_stack+253603,int_stack+253015,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+254387,int_stack+253603,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+541198,int_stack+5880,int_stack+533260,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+447958,int_stack+255395,int_stack+254387,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+197988,int_stack+447958,int_stack+5880,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+212982,int_stack+197988,int_stack+541198,28);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+353500,int_stack+257096,int_stack+256655,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+533260,int_stack+257684,int_stack+257096,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+541198,int_stack+533260,int_stack+353500,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+197988,int_stack+258440,int_stack+257684,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+447958,int_stack+197988,int_stack+533260,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+197988,int_stack+447958,int_stack+541198,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+533260,int_stack+259973,int_stack+259385,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+260757,int_stack+259973,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+541198,int_stack+5880,int_stack+533260,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+447958,int_stack+261765,int_stack+260757,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+218862,int_stack+447958,int_stack+5880,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+223566,int_stack+218862,int_stack+541198,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+353500,int_stack+266196,int_stack+265755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+339990,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+533260,int_stack+266784,int_stack+266196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+340431,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+541198,int_stack+533260,int_stack+353500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+544726,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+218862,int_stack+267540,int_stack+266784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+341019,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+447958,int_stack+218862,int_stack+533260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535024,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+218862,int_stack+447958,int_stack+541198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546049,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+533260,int_stack+269073,int_stack+268485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+315770,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+269857,int_stack+269073, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+316946,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+541198,int_stack+5880,int_stack+533260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8232,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+447958,int_stack+270865,int_stack+269857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+318514,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+229446,int_stack+447958,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+548695,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+234150,int_stack+229446,int_stack+541198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+562744,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+353500,int_stack+275296,int_stack+274855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+339990, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+533260,int_stack+275884,int_stack+275296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+340431, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+541198,int_stack+533260,int_stack+353500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+544726, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+229446,int_stack+276640,int_stack+275884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+341019, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+447958,int_stack+229446,int_stack+533260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535024, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+229446,int_stack+447958,int_stack+541198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546049, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+533260,int_stack+278173,int_stack+277585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+315770, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+278957,int_stack+278173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+316946, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+541198,int_stack+5880,int_stack+533260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8232, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+447958,int_stack+279965,int_stack+278957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+318514, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+240030,int_stack+447958,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+548695, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+244734,int_stack+240030,int_stack+541198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+562744, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+353500,int_stack+284396,int_stack+283955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+339990, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+533260,int_stack+284984,int_stack+284396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+340431, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+541198,int_stack+533260,int_stack+353500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+544726, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+240030,int_stack+285740,int_stack+284984, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+341019, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+447958,int_stack+240030,int_stack+533260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535024, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+240030,int_stack+447958,int_stack+541198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546049, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+533260,int_stack+287273,int_stack+286685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+315770, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+288057,int_stack+287273, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+316946, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+541198,int_stack+5880,int_stack+533260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8232, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+447958,int_stack+289065,int_stack+288057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+318514, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+250614,int_stack+447958,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+548695, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+255318,int_stack+250614,int_stack+541198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+562744, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+353500,int_stack+293496,int_stack+293055, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+339990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+533260,int_stack+294084,int_stack+293496, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+340431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+541198,int_stack+533260,int_stack+353500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+544726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+250614,int_stack+294840,int_stack+294084, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+341019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+447958,int_stack+250614,int_stack+533260, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+250614,int_stack+447958,int_stack+541198, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+533260,int_stack+296373,int_stack+295785, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+315770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+297157,int_stack+296373, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+316946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+541198,int_stack+5880,int_stack+533260, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+447958,int_stack+298165,int_stack+297157, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+318514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+261198,int_stack+447958,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+548695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+265902,int_stack+261198,int_stack+541198, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+562744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+353500,int_stack+302596,int_stack+302155, 0.0, zero_stack, 1.0, int_stack+339990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+533260,int_stack+303184,int_stack+302596, 0.0, zero_stack, 1.0, int_stack+340431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+541198,int_stack+533260,int_stack+353500, 0.0, zero_stack, 1.0, int_stack+544726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+261198,int_stack+303940,int_stack+303184, 0.0, zero_stack, 1.0, int_stack+341019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+447958,int_stack+261198,int_stack+533260, 0.0, zero_stack, 1.0, int_stack+535024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+261198,int_stack+447958,int_stack+541198, 0.0, zero_stack, 1.0, int_stack+546049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+533260,int_stack+305473,int_stack+304885, 0.0, zero_stack, 1.0, int_stack+315770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+306257,int_stack+305473, 0.0, zero_stack, 1.0, int_stack+316946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+541198,int_stack+5880,int_stack+533260, 0.0, zero_stack, 1.0, int_stack+8232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+447958,int_stack+307265,int_stack+306257, 0.0, zero_stack, 1.0, int_stack+318514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+271782,int_stack+447958,int_stack+5880, 0.0, zero_stack, 1.0, int_stack+548695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+276486,int_stack+271782,int_stack+541198, 0.0, zero_stack, 1.0, int_stack+562744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+353500,int_stack+313481,int_stack+313040, 1.0, int_stack+339990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+533260,int_stack+314069,int_stack+313481, 1.0, int_stack+340431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+541198,int_stack+533260,int_stack+353500, 1.0, int_stack+544726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+271782,int_stack+314825,int_stack+314069, 1.0, int_stack+341019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+447958,int_stack+271782,int_stack+533260, 1.0, int_stack+535024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+271782,int_stack+447958,int_stack+541198, 1.0, int_stack+546049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+541198,int_stack+317730,int_stack+316358, 1.0, int_stack+315770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5880,int_stack+319522,int_stack+317730, 1.0, int_stack+316946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+447958,int_stack+5880,int_stack+541198, 1.0, int_stack+8232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+541198,int_stack+320530,int_stack+319522, 1.0, int_stack+318514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+282366,int_stack+541198,int_stack+5880, 1.0, int_stack+548695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+541198,int_stack+282366,int_stack+447958, 1.0, int_stack+562744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+353500,int_stack+324961,int_stack+324520,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+562744,int_stack+325549,int_stack+324961,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+447958,int_stack+562744,int_stack+353500,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+282366,int_stack+326305,int_stack+325549,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+533260,int_stack+282366,int_stack+562744,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+282366,int_stack+533260,int_stack+447958,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+447958,int_stack+327838,int_stack+327250,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+533260,int_stack+328622,int_stack+327838,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+562744,int_stack+533260,int_stack+447958,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+447958,int_stack+329630,int_stack+328622,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+286776,int_stack+447958,int_stack+533260,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+291480,int_stack+286776,int_stack+562744,28);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+353500,int_stack+334061,int_stack+333620,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+562744,int_stack+334649,int_stack+334061,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+286776,int_stack+562744,int_stack+353500,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+533260,int_stack+335405,int_stack+334649,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+447958,int_stack+533260,int_stack+562744,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+297360,int_stack+447958,int_stack+286776,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+286776,int_stack+336938,int_stack+336350,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+288540,int_stack+337722,int_stack+336938,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+447958,int_stack+288540,int_stack+286776,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+562744,int_stack+338730,int_stack+337722,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+301770,int_stack+562744,int_stack+288540,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+306474,int_stack+301770,int_stack+447958,28);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+353500,int_stack+343161,int_stack+342720,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+447958,int_stack+343749,int_stack+343161,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+301770,int_stack+447958,int_stack+353500,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+562744,int_stack+344505,int_stack+343749,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+533260,int_stack+562744,int_stack+447958,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+286776,int_stack+533260,int_stack+301770,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+301770,int_stack+346038,int_stack+345450,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+303534,int_stack+346822,int_stack+346038,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+533260,int_stack+303534,int_stack+301770,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+447958,int_stack+347830,int_stack+346822,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+312354,int_stack+447958,int_stack+303534,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+317058,int_stack+312354,int_stack+533260,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+322938,int_stack+389662,int_stack+366352,210);
     Libderiv->ABCD[11] = int_stack + 322938;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+671020,int_stack+417004,int_stack+401338,210);
     Libderiv->ABCD[10] = int_stack + 671020;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+684250,int_stack+442078,int_stack+426412,210);
     Libderiv->ABCD[9] = int_stack + 684250;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+697480,int_stack+467152,int_stack+451486,210);
     Libderiv->ABCD[8] = int_stack + 697480;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+710710,int_stack+492226,int_stack+476560,210);
     Libderiv->ABCD[7] = int_stack + 710710;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+723940,int_stack+513772,int_stack+498106,210);
     Libderiv->ABCD[6] = int_stack + 723940;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+737170,int_stack+527380,int_stack+349090, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[2] = int_stack + 737170;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+750400,int_stack+552454,int_stack+536788, 0.0, zero_stack, 1.0, int_stack+360556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[1] = int_stack + 750400;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+763630,int_stack+574000,int_stack+558334, 1.0, int_stack+360556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[0] = int_stack + 763630;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+776860,int_stack+9996,int_stack+579880,210);
     Libderiv->ABCD[155] = int_stack + 776860;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+790090,int_stack+588700,int_stack+584290,210);
     Libderiv->ABCD[143] = int_stack + 790090;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+572152,int_stack+594580,int_stack+21672,210);
     Libderiv->ABCD[142] = int_stack + 572152;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+585382,int_stack+600460,int_stack+15876,210);
     Libderiv->ABCD[131] = int_stack + 585382;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+5880,int_stack+606340,int_stack+31878,210);
     Libderiv->ABCD[130] = int_stack + 5880;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+19110,int_stack+612220,int_stack+42084,210);
     Libderiv->ABCD[129] = int_stack + 19110;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+598612,int_stack+618100,int_stack+36288,210);
     Libderiv->ABCD[119] = int_stack + 598612;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+32340,int_stack+623980,int_stack+52290,210);
     Libderiv->ABCD[118] = int_stack + 32340;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+611842,int_stack+629860,int_stack+62496,210);
     Libderiv->ABCD[117] = int_stack + 611842;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+803320,int_stack+635740,int_stack+56700,210);
     Libderiv->ABCD[116] = int_stack + 803320;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+45570,int_stack+641620,int_stack+72702,210);
     Libderiv->ABCD[107] = int_stack + 45570;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+625072,int_stack+647500,int_stack+66906,210);
     Libderiv->ABCD[106] = int_stack + 625072;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+58800,int_stack+653380,int_stack+82908,210);
     Libderiv->ABCD[105] = int_stack + 58800;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+72030,int_stack+659260,int_stack+93114,210);
     Libderiv->ABCD[104] = int_stack + 72030;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+638302,int_stack+665140,int_stack+87318,210);
     Libderiv->ABCD[103] = int_stack + 638302;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+651532,int_stack+107730,int_stack+103320,210);
     Libderiv->ABCD[95] = int_stack + 651532;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+816550,int_stack+383404,int_stack+374290,210);
     Libderiv->ABCD[94] = int_stack + 816550;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+829780,int_stack+566272,int_stack+354823,210);
     Libderiv->ABCD[93] = int_stack + 829780;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+843010,int_stack+430822,int_stack+405748,210);
     Libderiv->ABCD[92] = int_stack + 843010;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+856240,int_stack+455896,int_stack+436702,210);
     Libderiv->ABCD[91] = int_stack + 856240;
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+430822,int_stack+480970,int_stack+378700,210);
     Libderiv->ABCD[90] = int_stack + 430822;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+370762,int_stack+410158,int_stack+461776, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[47] = int_stack + 370762;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+455896,int_stack+113610,int_stack+395542, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[46] = int_stack + 455896;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+405748,int_stack+124194,int_stack+486850, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[45] = int_stack + 405748;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+480970,int_stack+134778,int_stack+97524, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+451486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[44] = int_stack + 480970;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+85260,int_stack+145362,int_stack+119490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[43] = int_stack + 85260;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+98490,int_stack+507220,int_stack+130074, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[42] = int_stack + 98490;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+111720,int_stack+0,int_stack+502516, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+349090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[38] = int_stack + 111720;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+502516,int_stack+160356,int_stack+151242, 0.0, zero_stack, 1.0, int_stack+366352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[35] = int_stack + 502516;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+124950,int_stack+170940,int_stack+140658, 0.0, zero_stack, 1.0, int_stack+401338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[34] = int_stack + 124950;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+138180,int_stack+181524,int_stack+155652, 0.0, zero_stack, 1.0, int_stack+426412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[33] = int_stack + 138180;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+151410,int_stack+192108,int_stack+166236, 0.0, zero_stack, 1.0, int_stack+451486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[32] = int_stack + 151410;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+383992,int_stack+202692,int_stack+176820, 0.0, zero_stack, 1.0, int_stack+476560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[31] = int_stack + 383992;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+164640,int_stack+519652,int_stack+187404, 0.0, zero_stack, 1.0, int_stack+498106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[30] = int_stack + 164640;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+515746,int_stack+212982,int_stack+208572, 0.0, zero_stack, 1.0, int_stack+349090, 1.0, int_stack+536788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[26] = int_stack + 515746;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+177870,int_stack+223566,int_stack+197988, 0.0, zero_stack, 2.0, int_stack+536788, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[25] = int_stack + 177870;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+191100,int_stack+234150,int_stack+218862, 1.0, int_stack+366352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[23] = int_stack + 191100;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+353500,int_stack+244734,int_stack+229446, 1.0, int_stack+401338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[22] = int_stack + 353500;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+204330,int_stack+255318,int_stack+240030, 1.0, int_stack+426412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[21] = int_stack + 204330;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+217560,int_stack+265902,int_stack+250614, 1.0, int_stack+451486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[20] = int_stack + 217560;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+230790,int_stack+276486,int_stack+261198, 1.0, int_stack+476560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[19] = int_stack + 230790;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+244020,int_stack+541198,int_stack+271782, 1.0, int_stack+498106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[18] = int_stack + 244020;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+541198,int_stack+291480,int_stack+282366, 1.0, int_stack+349090, 0.0, zero_stack, 1.0, int_stack+558334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[14] = int_stack + 541198;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+336168,int_stack+306474,int_stack+297360, 1.0, int_stack+536788, 1.0, int_stack+558334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[13] = int_stack + 336168;
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+291186,int_stack+317058,int_stack+286776, 2.0, int_stack+558334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[12] = int_stack + 291186;

}
