/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (dd|gg) integrals */

void d12vrr_order_ddgg(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+3, dvrr_stack+0, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+0, dvrr_stack+12, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+21, dvrr_stack+6, dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+31, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+34, dvrr_stack+31, dvrr_stack+3, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+40, dvrr_stack+34, dvrr_stack+6, dvrr_stack+31, dvrr_stack+3, NULL);

 /* compute (1 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+50, dvrr_stack+40, dvrr_stack+21, NULL, NULL, dvrr_stack+6);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+80, dvrr_stack+40, dvrr_stack+21, dvrr_stack+34, dvrr_stack+6, NULL);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+95, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+98, dvrr_stack+95, dvrr_stack+31, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+104, dvrr_stack+98, dvrr_stack+34, dvrr_stack+95, dvrr_stack+31, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+114, dvrr_stack+104, dvrr_stack+40, dvrr_stack+98, dvrr_stack+34, NULL);

 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+95, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+129, dvrr_stack+12, dvrr_stack+95, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+135, dvrr_stack+15, dvrr_stack+129, dvrr_stack+0, dvrr_stack+12, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+145, dvrr_stack+21, dvrr_stack+135, dvrr_stack+6, dvrr_stack+15, NULL);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+160, dvrr_stack+80, dvrr_stack+145, NULL, NULL, dvrr_stack+21);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+205, dvrr_stack+114, dvrr_stack+80, NULL, NULL, dvrr_stack+40);

 /* compute (2 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+250, dvrr_stack+205, dvrr_stack+160, dvrr_stack+114, dvrr_stack+80, dvrr_stack+50);
 tmp = dvrr_stack + 250;
 target_ptr = Libderiv->dvrr_classes[2][4];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+340, dvrr_stack+80, dvrr_stack+145, dvrr_stack+40, dvrr_stack+21, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+361, dvrr_stack+114, dvrr_stack+80, dvrr_stack+104, dvrr_stack+40, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+382, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+385, dvrr_stack+95, dvrr_stack+382, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+391, dvrr_stack+129, dvrr_stack+385, dvrr_stack+12, dvrr_stack+95, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+401, dvrr_stack+135, dvrr_stack+391, dvrr_stack+15, dvrr_stack+129, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+416, dvrr_stack+145, dvrr_stack+401, dvrr_stack+21, dvrr_stack+135, NULL);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+437, dvrr_stack+340, dvrr_stack+416, NULL, NULL, dvrr_stack+145);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+500, dvrr_stack+361, dvrr_stack+340, NULL, NULL, dvrr_stack+80);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+563, dvrr_stack+500, dvrr_stack+437, dvrr_stack+361, dvrr_stack+340, dvrr_stack+160);
 tmp = dvrr_stack + 563;
 target_ptr = Libderiv->dvrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+689,dvrr_stack+563,dvrr_stack+250,6);


 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+959, dvrr_stack+340, dvrr_stack+416, dvrr_stack+80, dvrr_stack+145, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+987, dvrr_stack+361, dvrr_stack+340, dvrr_stack+114, dvrr_stack+80, NULL);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1015, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1018, dvrr_stack+382, dvrr_stack+1015, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1024, dvrr_stack+385, dvrr_stack+1018, dvrr_stack+95, dvrr_stack+382, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1034, dvrr_stack+391, dvrr_stack+1024, dvrr_stack+129, dvrr_stack+385, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1049, dvrr_stack+401, dvrr_stack+1034, dvrr_stack+135, dvrr_stack+391, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1070, dvrr_stack+416, dvrr_stack+1049, dvrr_stack+145, dvrr_stack+401, NULL);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1098, dvrr_stack+959, dvrr_stack+1070, NULL, NULL, dvrr_stack+416);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1182, dvrr_stack+987, dvrr_stack+959, NULL, NULL, dvrr_stack+340);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+1266, dvrr_stack+1182, dvrr_stack+1098, dvrr_stack+987, dvrr_stack+959, dvrr_stack+437);
 tmp = dvrr_stack + 1266;
 target_ptr = Libderiv->dvrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+1434,dvrr_stack+1266,dvrr_stack+563,6);


 /* compute (2 0 | 4 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gd(Libderiv->CD,dvrr_stack+1812,dvrr_stack+1434,dvrr_stack+689,6);


 /* compute (2 0 | 4 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,90,dvrr_stack+2352, dvrr_stack+1812, dvrr_stack+250);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2622, dvrr_stack+959, dvrr_stack+1070, dvrr_stack+340, dvrr_stack+416, NULL);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2658, dvrr_stack+987, dvrr_stack+959, dvrr_stack+361, dvrr_stack+340, NULL);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+2694, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+2697, dvrr_stack+1015, dvrr_stack+2694, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2703, dvrr_stack+1018, dvrr_stack+2697, dvrr_stack+382, dvrr_stack+1015, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2713, dvrr_stack+1024, dvrr_stack+2703, dvrr_stack+385, dvrr_stack+1018, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2728, dvrr_stack+1034, dvrr_stack+2713, dvrr_stack+391, dvrr_stack+1024, NULL);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2749, dvrr_stack+1049, dvrr_stack+2728, dvrr_stack+401, dvrr_stack+1034, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2777, dvrr_stack+1070, dvrr_stack+2749, dvrr_stack+416, dvrr_stack+1049, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2813, dvrr_stack+2622, dvrr_stack+2777, NULL, NULL, dvrr_stack+1070);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2921, dvrr_stack+2658, dvrr_stack+2622, NULL, NULL, dvrr_stack+959);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3029, dvrr_stack+2921, dvrr_stack+2813, dvrr_stack+2658, dvrr_stack+2622, dvrr_stack+1098);
 tmp = dvrr_stack + 3029;
 target_ptr = Libderiv->dvrr_classes[2][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+3245,dvrr_stack+3029,dvrr_stack+1266,6);


 /* compute (2 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+3749,dvrr_stack+3245,dvrr_stack+1434,6);


 /* compute (2 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,126,dvrr_stack+4505, dvrr_stack+3749, dvrr_stack+563);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4883, dvrr_stack+2622, dvrr_stack+2777, dvrr_stack+959, dvrr_stack+1070, NULL);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4928, dvrr_stack+2658, dvrr_stack+2622, dvrr_stack+987, dvrr_stack+959, NULL);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+4973, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+4976, dvrr_stack+2694, dvrr_stack+4973, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+4982, dvrr_stack+2697, dvrr_stack+4976, dvrr_stack+1015, dvrr_stack+2694, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+4992, dvrr_stack+2703, dvrr_stack+4982, dvrr_stack+1018, dvrr_stack+2697, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+5007, dvrr_stack+2713, dvrr_stack+4992, dvrr_stack+1024, dvrr_stack+2703, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+5028, dvrr_stack+2728, dvrr_stack+5007, dvrr_stack+1034, dvrr_stack+2713, NULL);

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5056, dvrr_stack+2749, dvrr_stack+5028, dvrr_stack+1049, dvrr_stack+2728, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+5092, dvrr_stack+2777, dvrr_stack+5056, dvrr_stack+1070, dvrr_stack+2749, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+5137, dvrr_stack+4883, dvrr_stack+5092, NULL, NULL, dvrr_stack+2777);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+5272, dvrr_stack+4928, dvrr_stack+4883, NULL, NULL, dvrr_stack+2622);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+5407, dvrr_stack+5272, dvrr_stack+5137, dvrr_stack+4928, dvrr_stack+4883, dvrr_stack+2813);
 tmp = dvrr_stack + 5407;
 target_ptr = Libderiv->dvrr_classes[2][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+5677,dvrr_stack+5407,dvrr_stack+3029,6);


 /* compute (2 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+6325,dvrr_stack+5677,dvrr_stack+3245,6);


 /* compute (2 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,168,dvrr_stack+7333, dvrr_stack+6325, dvrr_stack+1266);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+7837, dvrr_stack+4883, dvrr_stack+5092, dvrr_stack+2622, dvrr_stack+2777, NULL);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+7892, dvrr_stack+4928, dvrr_stack+4883, dvrr_stack+2658, dvrr_stack+2622, NULL);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1015, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+7947, dvrr_stack+4973, dvrr_stack+1015, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+7953, dvrr_stack+4976, dvrr_stack+7947, dvrr_stack+2694, dvrr_stack+4973, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+7963, dvrr_stack+4982, dvrr_stack+7953, dvrr_stack+2697, dvrr_stack+4976, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+7978, dvrr_stack+4992, dvrr_stack+7963, dvrr_stack+2703, dvrr_stack+4982, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+7999, dvrr_stack+5007, dvrr_stack+7978, dvrr_stack+2713, dvrr_stack+4992, NULL);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8027, dvrr_stack+5028, dvrr_stack+7999, dvrr_stack+2728, dvrr_stack+5007, NULL);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8063, dvrr_stack+5056, dvrr_stack+8027, dvrr_stack+2749, dvrr_stack+5028, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+8108, dvrr_stack+5092, dvrr_stack+8063, dvrr_stack+2777, dvrr_stack+5056, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+8163, dvrr_stack+7837, dvrr_stack+8108, NULL, NULL, dvrr_stack+5092);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+8328, dvrr_stack+7892, dvrr_stack+7837, NULL, NULL, dvrr_stack+4883);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+8493, dvrr_stack+8328, dvrr_stack+8163, dvrr_stack+7892, dvrr_stack+7837, dvrr_stack+5137);

 /* compute (2 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+8823,dvrr_stack+8493,dvrr_stack+5407,6);


 /* compute (2 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+9633,dvrr_stack+8823,dvrr_stack+5677,6);


 /* compute (2 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,216,dvrr_stack+10929, dvrr_stack+9633, dvrr_stack+3029);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+11577, dvrr_stack+7837, dvrr_stack+8108, dvrr_stack+4883, dvrr_stack+5092, NULL);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+11643, dvrr_stack+7892, dvrr_stack+7837, dvrr_stack+4928, dvrr_stack+4883, NULL);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+7892, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+7895, dvrr_stack+1015, dvrr_stack+7892, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+7901, dvrr_stack+7947, dvrr_stack+7895, dvrr_stack+4973, dvrr_stack+1015, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+7911, dvrr_stack+7953, dvrr_stack+7901, dvrr_stack+4976, dvrr_stack+7947, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+7926, dvrr_stack+7963, dvrr_stack+7911, dvrr_stack+4982, dvrr_stack+7953, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+11709, dvrr_stack+7978, dvrr_stack+7926, dvrr_stack+4992, dvrr_stack+7963, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11737, dvrr_stack+7999, dvrr_stack+11709, dvrr_stack+5007, dvrr_stack+7978, NULL);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11773, dvrr_stack+8027, dvrr_stack+11737, dvrr_stack+5028, dvrr_stack+7999, NULL);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11818, dvrr_stack+8063, dvrr_stack+11773, dvrr_stack+5056, dvrr_stack+8027, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+11873, dvrr_stack+8108, dvrr_stack+11818, dvrr_stack+5092, dvrr_stack+8063, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+11939, dvrr_stack+11577, dvrr_stack+11873, NULL, NULL, dvrr_stack+8108);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12137, dvrr_stack+11643, dvrr_stack+11577, NULL, NULL, dvrr_stack+7837);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12335, dvrr_stack+12137, dvrr_stack+11939, dvrr_stack+11643, dvrr_stack+11577, dvrr_stack+8163);

 /* compute (2 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+12731,dvrr_stack+12335,dvrr_stack+8493,6);


 /* compute (2 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+13721,dvrr_stack+12731,dvrr_stack+8823,6);


 /* compute (2 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,270,dvrr_stack+15341, dvrr_stack+13721, dvrr_stack+5407);

 /* compute (1 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+11643, dvrr_stack+6, dvrr_stack+15, NULL, NULL, dvrr_stack+0);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+11661, dvrr_stack+21, dvrr_stack+135, NULL, NULL, dvrr_stack+15);

 /* compute (2 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+16151, dvrr_stack+50, dvrr_stack+11661, dvrr_stack+40, dvrr_stack+21, dvrr_stack+11643);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+16211, dvrr_stack+145, dvrr_stack+401, NULL, NULL, dvrr_stack+135);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+16256, dvrr_stack+160, dvrr_stack+16211, dvrr_stack+80, dvrr_stack+145, dvrr_stack+11661);

 /* compute (3 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+16346, dvrr_stack+250, dvrr_stack+16256, dvrr_stack+205, dvrr_stack+160, dvrr_stack+16151);
 tmp = dvrr_stack + 16346;
 target_ptr = Libderiv->dvrr_classes[3][4];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+16496, dvrr_stack+416, dvrr_stack+1049, NULL, NULL, dvrr_stack+401);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+16559, dvrr_stack+437, dvrr_stack+16496, dvrr_stack+340, dvrr_stack+416, dvrr_stack+16211);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+16685, dvrr_stack+563, dvrr_stack+16559, dvrr_stack+500, dvrr_stack+437, dvrr_stack+16256);
 tmp = dvrr_stack + 16685;
 target_ptr = Libderiv->dvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+16895,dvrr_stack+16685,dvrr_stack+16346,10);


 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+17345, dvrr_stack+1070, dvrr_stack+2749, NULL, NULL, dvrr_stack+1049);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+17429, dvrr_stack+1098, dvrr_stack+17345, dvrr_stack+959, dvrr_stack+1070, dvrr_stack+16496);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+17597, dvrr_stack+1266, dvrr_stack+17429, dvrr_stack+1182, dvrr_stack+1098, dvrr_stack+16559);
 tmp = dvrr_stack + 17597;
 target_ptr = Libderiv->dvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+17877,dvrr_stack+17597,dvrr_stack+16685,10);


 /* compute (3 0 | 4 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gd(Libderiv->CD,dvrr_stack+18507,dvrr_stack+17877,dvrr_stack+16895,10);


 /* compute (3 0 | 4 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,150,dvrr_stack+19407, dvrr_stack+18507, dvrr_stack+16346);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+19857, dvrr_stack+2777, dvrr_stack+5056, NULL, NULL, dvrr_stack+2749);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+19965, dvrr_stack+2813, dvrr_stack+19857, dvrr_stack+2622, dvrr_stack+2777, dvrr_stack+17345);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+20181, dvrr_stack+3029, dvrr_stack+19965, dvrr_stack+2921, dvrr_stack+2813, dvrr_stack+17429);
 tmp = dvrr_stack + 20181;
 target_ptr = Libderiv->dvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+20541,dvrr_stack+20181,dvrr_stack+17597,10);


 /* compute (3 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+21381,dvrr_stack+20541,dvrr_stack+17877,10);


 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,210,dvrr_stack+22641, dvrr_stack+21381, dvrr_stack+16685);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+23271, dvrr_stack+5092, dvrr_stack+8063, NULL, NULL, dvrr_stack+5056);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+23406, dvrr_stack+5137, dvrr_stack+23271, dvrr_stack+4883, dvrr_stack+5092, dvrr_stack+19857);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+23676, dvrr_stack+5407, dvrr_stack+23406, dvrr_stack+5272, dvrr_stack+5137, dvrr_stack+19965);
 tmp = dvrr_stack + 23676;
 target_ptr = Libderiv->dvrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+24126,dvrr_stack+23676,dvrr_stack+20181,10);


 /* compute (3 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+25206,dvrr_stack+24126,dvrr_stack+20541,10);


 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,280,dvrr_stack+26886, dvrr_stack+25206, dvrr_stack+17597);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+27726, dvrr_stack+8108, dvrr_stack+11818, NULL, NULL, dvrr_stack+8063);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+27891, dvrr_stack+8163, dvrr_stack+27726, dvrr_stack+7837, dvrr_stack+8108, dvrr_stack+23271);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+28221, dvrr_stack+8493, dvrr_stack+27891, dvrr_stack+8328, dvrr_stack+8163, dvrr_stack+23406);

 /* compute (3 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+28771,dvrr_stack+28221,dvrr_stack+23676,10);


 /* compute (3 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+30121,dvrr_stack+28771,dvrr_stack+24126,10);


 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,360,dvrr_stack+32281, dvrr_stack+30121, dvrr_stack+20181);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+7837, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+7840, dvrr_stack+7892, dvrr_stack+7837, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+7846, dvrr_stack+7895, dvrr_stack+7840, dvrr_stack+1015, dvrr_stack+7892, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+80, dvrr_stack+7901, dvrr_stack+7846, dvrr_stack+7947, dvrr_stack+7895, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+340, dvrr_stack+7911, dvrr_stack+80, dvrr_stack+7953, dvrr_stack+7901, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+959, dvrr_stack+7926, dvrr_stack+340, dvrr_stack+7963, dvrr_stack+7911, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7856, dvrr_stack+11709, dvrr_stack+959, dvrr_stack+7978, dvrr_stack+7926, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4883, dvrr_stack+11737, dvrr_stack+7856, dvrr_stack+7999, dvrr_stack+11709, NULL);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+33361, dvrr_stack+11773, dvrr_stack+4883, dvrr_stack+8027, dvrr_stack+11737, NULL);

 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33416, dvrr_stack+11818, dvrr_stack+33361, dvrr_stack+8063, dvrr_stack+11773, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33482, dvrr_stack+11873, dvrr_stack+33416, NULL, NULL, dvrr_stack+11818);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33680, dvrr_stack+11939, dvrr_stack+33482, dvrr_stack+11577, dvrr_stack+11873, dvrr_stack+27726);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+34076, dvrr_stack+12335, dvrr_stack+33680, dvrr_stack+12137, dvrr_stack+11939, dvrr_stack+27891);

 /* compute (3 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+34736,dvrr_stack+34076,dvrr_stack+28221,10);


 /* compute (3 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+36386,dvrr_stack+34736,dvrr_stack+28771,10);


 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,450,dvrr_stack+39086, dvrr_stack+36386, dvrr_stack+23676);

 /* compute (1 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+2694, dvrr_stack+0, dvrr_stack+12, NULL, NULL, Data->F+4);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+11691, dvrr_stack+15, dvrr_stack+129, NULL, NULL, dvrr_stack+12);

 /* compute (2 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+2622, dvrr_stack+11643, dvrr_stack+11691, dvrr_stack+6, dvrr_stack+15, dvrr_stack+2694);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+12137, dvrr_stack+135, dvrr_stack+391, NULL, NULL, dvrr_stack+129);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+12167, dvrr_stack+11661, dvrr_stack+12137, dvrr_stack+21, dvrr_stack+135, dvrr_stack+11691);

 /* compute (3 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+12227, dvrr_stack+16151, dvrr_stack+12167, dvrr_stack+50, dvrr_stack+11661, dvrr_stack+2622);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+11577, dvrr_stack+401, dvrr_stack+1034, NULL, NULL, dvrr_stack+391);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+40436, dvrr_stack+16211, dvrr_stack+11577, dvrr_stack+145, dvrr_stack+401, dvrr_stack+12137);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+40526, dvrr_stack+16256, dvrr_stack+40436, dvrr_stack+160, dvrr_stack+16211, dvrr_stack+12167);

 /* compute (4 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+40676, dvrr_stack+16346, dvrr_stack+40526, dvrr_stack+250, dvrr_stack+16256, dvrr_stack+12227);
 tmp = dvrr_stack + 40676;
 target_ptr = Libderiv->dvrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+40901, dvrr_stack+1049, dvrr_stack+2728, NULL, NULL, dvrr_stack+1034);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+40964, dvrr_stack+16496, dvrr_stack+40901, dvrr_stack+416, dvrr_stack+1049, dvrr_stack+11577);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+41090, dvrr_stack+16559, dvrr_stack+40964, dvrr_stack+437, dvrr_stack+16496, dvrr_stack+40436);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+41300, dvrr_stack+16685, dvrr_stack+41090, dvrr_stack+563, dvrr_stack+16559, dvrr_stack+40526);
 tmp = dvrr_stack + 41300;
 target_ptr = Libderiv->dvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+41615,dvrr_stack+41300,dvrr_stack+40676,15);


 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+416, dvrr_stack+2749, dvrr_stack+5028, NULL, NULL, dvrr_stack+2728);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+42290, dvrr_stack+17345, dvrr_stack+416, dvrr_stack+1070, dvrr_stack+2749, dvrr_stack+40901);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+42458, dvrr_stack+17429, dvrr_stack+42290, dvrr_stack+1098, dvrr_stack+17345, dvrr_stack+40964);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+42738, dvrr_stack+17597, dvrr_stack+42458, dvrr_stack+1266, dvrr_stack+17429, dvrr_stack+41090);
 tmp = dvrr_stack + 42738;
 target_ptr = Libderiv->dvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+43158,dvrr_stack+42738,dvrr_stack+41300,15);


 /* compute (4 0 | 4 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gd(Libderiv->CD,dvrr_stack+44103,dvrr_stack+43158,dvrr_stack+41615,15);


 /* compute (4 0 | 4 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,225,dvrr_stack+45453, dvrr_stack+44103, dvrr_stack+40676);

 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1070, dvrr_stack+5056, dvrr_stack+8027, NULL, NULL, dvrr_stack+5028);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+46128, dvrr_stack+19857, dvrr_stack+1070, dvrr_stack+2777, dvrr_stack+5056, dvrr_stack+416);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+46344, dvrr_stack+19965, dvrr_stack+46128, dvrr_stack+2813, dvrr_stack+19857, dvrr_stack+42290);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+46704, dvrr_stack+20181, dvrr_stack+46344, dvrr_stack+3029, dvrr_stack+19965, dvrr_stack+42458);
 tmp = dvrr_stack + 46704;
 target_ptr = Libderiv->dvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+47244,dvrr_stack+46704,dvrr_stack+42738,15);


 /* compute (4 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+48504,dvrr_stack+47244,dvrr_stack+43158,15);


 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,315,dvrr_stack+50394, dvrr_stack+48504, dvrr_stack+41300);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2777, dvrr_stack+8063, dvrr_stack+11773, NULL, NULL, dvrr_stack+8027);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+51339, dvrr_stack+23271, dvrr_stack+2777, dvrr_stack+5092, dvrr_stack+8063, dvrr_stack+1070);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+51609, dvrr_stack+23406, dvrr_stack+51339, dvrr_stack+5137, dvrr_stack+23271, dvrr_stack+46128);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+52059, dvrr_stack+23676, dvrr_stack+51609, dvrr_stack+5407, dvrr_stack+23406, dvrr_stack+46344);

 /* compute (4 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+52734,dvrr_stack+52059,dvrr_stack+46704,15);


 /* compute (4 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+54354,dvrr_stack+52734,dvrr_stack+47244,15);


 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,420,dvrr_stack+56874, dvrr_stack+54354, dvrr_stack+42738);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+5092, dvrr_stack+11818, dvrr_stack+33361, NULL, NULL, dvrr_stack+11773);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+58134, dvrr_stack+27726, dvrr_stack+5092, dvrr_stack+8108, dvrr_stack+11818, dvrr_stack+2777);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+58464, dvrr_stack+27891, dvrr_stack+58134, dvrr_stack+8163, dvrr_stack+27726, dvrr_stack+51339);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+59014, dvrr_stack+28221, dvrr_stack+58464, dvrr_stack+8493, dvrr_stack+27891, dvrr_stack+51609);

 /* compute (4 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+59839,dvrr_stack+59014,dvrr_stack+52059,15);


 /* compute (4 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+61864,dvrr_stack+59839,dvrr_stack+52734,15);


 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,540,dvrr_stack+65104, dvrr_stack+61864, dvrr_stack+46704);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1015, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+8108, dvrr_stack+7837, dvrr_stack+1015, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+21, dvrr_stack+7840, dvrr_stack+8108, dvrr_stack+7892, dvrr_stack+7837, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+5257, dvrr_stack+7846, dvrr_stack+21, dvrr_stack+7895, dvrr_stack+7840, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+11622, dvrr_stack+80, dvrr_stack+5257, dvrr_stack+7901, dvrr_stack+7846, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+8108, dvrr_stack+340, dvrr_stack+11622, dvrr_stack+7911, dvrr_stack+80, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8136, dvrr_stack+959, dvrr_stack+8108, dvrr_stack+7926, dvrr_stack+340, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7892, dvrr_stack+7856, dvrr_stack+8136, dvrr_stack+11709, dvrr_stack+959, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+8108, dvrr_stack+4883, dvrr_stack+7892, dvrr_stack+11737, dvrr_stack+7856, NULL);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+8163, dvrr_stack+33361, dvrr_stack+8108, dvrr_stack+11773, dvrr_stack+4883, NULL);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+66724, dvrr_stack+33416, dvrr_stack+8163, NULL, NULL, dvrr_stack+33361);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+66922, dvrr_stack+33482, dvrr_stack+66724, dvrr_stack+11873, dvrr_stack+33416, dvrr_stack+5092);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+67318, dvrr_stack+33680, dvrr_stack+66922, dvrr_stack+11939, dvrr_stack+33482, dvrr_stack+58134);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+67978, dvrr_stack+34076, dvrr_stack+67318, dvrr_stack+12335, dvrr_stack+33680, dvrr_stack+58464);

 /* compute (4 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+68968,dvrr_stack+67978,dvrr_stack+59014,15);


 /* compute (4 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+71443,dvrr_stack+68968,dvrr_stack+59839,15);


 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,675,dvrr_stack+75493, dvrr_stack+71443, dvrr_stack+52059);

 /* compute (2 0 | 4 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,90,dvrr_stack+33416, dvrr_stack+1812, dvrr_stack+250);

 /* compute (2 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,126,dvrr_stack+33686, dvrr_stack+3749, dvrr_stack+563);

 /* compute (2 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,168,dvrr_stack+66724, dvrr_stack+6325, dvrr_stack+1266);

 /* compute (2 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,216,dvrr_stack+67228, dvrr_stack+9633, dvrr_stack+3029);

 /* compute (2 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,270,dvrr_stack+77518, dvrr_stack+13721, dvrr_stack+5407);

 /* compute (3 0 | 4 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,150,dvrr_stack+78328, dvrr_stack+18507, dvrr_stack+16346);

 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,210,dvrr_stack+78778, dvrr_stack+21381, dvrr_stack+16685);

 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,280,dvrr_stack+79408, dvrr_stack+25206, dvrr_stack+17597);

 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,360,dvrr_stack+80248, dvrr_stack+30121, dvrr_stack+20181);

 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,450,dvrr_stack+81328, dvrr_stack+36386, dvrr_stack+23676);

 /* compute (4 0 | 4 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,225,dvrr_stack+82678, dvrr_stack+44103, dvrr_stack+40676);

 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,315,dvrr_stack+83353, dvrr_stack+48504, dvrr_stack+41300);

 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,420,dvrr_stack+84298, dvrr_stack+54354, dvrr_stack+42738);

 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,540,dvrr_stack+85558, dvrr_stack+61864, dvrr_stack+46704);

 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,675,dvrr_stack+87178, dvrr_stack+71443, dvrr_stack+52059);

 /* compute (2 0 | 4 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,90,dvrr_stack+89203, dvrr_stack+1812, dvrr_stack+250);

 /* compute (2 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,126,dvrr_stack+1812, dvrr_stack+3749, dvrr_stack+563);

 /* compute (2 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,168,dvrr_stack+3749, dvrr_stack+6325, dvrr_stack+1266);

 /* compute (2 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,216,dvrr_stack+6325, dvrr_stack+9633, dvrr_stack+3029);

 /* compute (2 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,270,dvrr_stack+9633, dvrr_stack+13721, dvrr_stack+5407);

 /* compute (3 0 | 4 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,150,dvrr_stack+13721, dvrr_stack+18507, dvrr_stack+16346);

 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,210,dvrr_stack+18507, dvrr_stack+21381, dvrr_stack+16685);

 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,280,dvrr_stack+21381, dvrr_stack+25206, dvrr_stack+17597);

 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,360,dvrr_stack+25206, dvrr_stack+30121, dvrr_stack+20181);

 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,450,dvrr_stack+30121, dvrr_stack+36386, dvrr_stack+23676);

 /* compute (4 0 | 4 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,225,dvrr_stack+36386, dvrr_stack+44103, dvrr_stack+40676);

 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,315,dvrr_stack+44103, dvrr_stack+48504, dvrr_stack+41300);

 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,420,dvrr_stack+48504, dvrr_stack+54354, dvrr_stack+42738);

 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,540,dvrr_stack+54354, dvrr_stack+61864, dvrr_stack+46704);

 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,675,dvrr_stack+37061, dvrr_stack+71443, dvrr_stack+52059);

 /* compute (1 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+71443, dvrr_stack+34, dvrr_stack+6, NULL, NULL, dvrr_stack+3);

 /* compute (1 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+71461, dvrr_stack+104, dvrr_stack+40, NULL, NULL, dvrr_stack+34);

 /* compute (2 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+145, dvrr_stack+71461, dvrr_stack+50, dvrr_stack+104, dvrr_stack+40, dvrr_stack+71443);

 /* compute (2 0 | 3 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_fp(Libderiv->CD,dvrr_stack+71491,dvrr_stack+250,dvrr_stack+145,6);


 /* compute (2 0 | 3 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,60,dvrr_stack+71671, dvrr_stack+71491, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,126,dvrr_stack+71731, dvrr_stack+1434, NULL);
 tmp = dvrr_stack + 71731;
 target_ptr = Libderiv->deriv_classes[2][5][11];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,90,dvrr_stack+71857, dvrr_stack+689, NULL);
 tmp = dvrr_stack + 71857;
 target_ptr = Libderiv->deriv_classes[2][4][11];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,168,dvrr_stack+71947, dvrr_stack+3245, NULL);
 tmp = dvrr_stack + 71947;
 target_ptr = Libderiv->deriv_classes[2][6][11];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,216,dvrr_stack+72115, dvrr_stack+5677, NULL);
 tmp = dvrr_stack + 72115;
 target_ptr = Libderiv->deriv_classes[2][7][11];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,270,dvrr_stack+19137, dvrr_stack+8823, NULL);
 tmp = dvrr_stack + 19137;
 target_ptr = Libderiv->deriv_classes[2][8][11];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,330,dvrr_stack+72331, dvrr_stack+12731, NULL);

 /* compute (1 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+2912, dvrr_stack+3, dvrr_stack+0, NULL, NULL, Data->F+3);

 /* compute (2 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+72661, dvrr_stack+71443, dvrr_stack+11643, dvrr_stack+34, dvrr_stack+6, dvrr_stack+2912);

 /* compute (3 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+72697, dvrr_stack+145, dvrr_stack+16151, dvrr_stack+71461, dvrr_stack+50, dvrr_stack+72661);

 /* compute (3 0 | 3 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_fp(Libderiv->CD,dvrr_stack+72797,dvrr_stack+16346,dvrr_stack+72697,10);


 /* compute (3 0 | 3 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,100,dvrr_stack+73097, dvrr_stack+72797, NULL);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,210,dvrr_stack+73197, dvrr_stack+17877, NULL);
 tmp = dvrr_stack + 73197;
 target_ptr = Libderiv->deriv_classes[3][5][11];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,150,dvrr_stack+73407, dvrr_stack+16895, NULL);
 tmp = dvrr_stack + 73407;
 target_ptr = Libderiv->deriv_classes[3][4][11];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,280,dvrr_stack+73557, dvrr_stack+20541, NULL);
 tmp = dvrr_stack + 73557;
 target_ptr = Libderiv->deriv_classes[3][6][11];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,360,dvrr_stack+6973, dvrr_stack+24126, NULL);
 tmp = dvrr_stack + 6973;
 target_ptr = Libderiv->deriv_classes[3][7][11];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,450,dvrr_stack+73837, dvrr_stack+28771, NULL);
 tmp = dvrr_stack + 73837;
 target_ptr = Libderiv->deriv_classes[3][8][11];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,550,dvrr_stack+74287, dvrr_stack+34736, NULL);

 /* compute (1 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+1015, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (2 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+40, dvrr_stack+2912, dvrr_stack+2694, dvrr_stack+3, dvrr_stack+0, dvrr_stack+1015);

 /* compute (3 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+74837, dvrr_stack+72661, dvrr_stack+2622, dvrr_stack+71443, dvrr_stack+11643, dvrr_stack+40);

 /* compute (4 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+74897, dvrr_stack+72697, dvrr_stack+12227, dvrr_stack+145, dvrr_stack+16151, dvrr_stack+74837);

 /* compute (4 0 | 3 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_fp(Libderiv->CD,dvrr_stack+61864,dvrr_stack+40676,dvrr_stack+74897,15);


 /* compute (4 0 | 3 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,150,dvrr_stack+75047, dvrr_stack+61864, NULL);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+62314, dvrr_stack+43158, NULL);
 tmp = dvrr_stack + 62314;
 target_ptr = Libderiv->deriv_classes[4][5][11];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,225,dvrr_stack+75197, dvrr_stack+41615, NULL);
 tmp = dvrr_stack + 75197;
 target_ptr = Libderiv->deriv_classes[4][4][11];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+22221, dvrr_stack+47244, NULL);
 tmp = dvrr_stack + 22221;
 target_ptr = Libderiv->deriv_classes[4][6][11];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,540,dvrr_stack+62629, dvrr_stack+52734, NULL);
 tmp = dvrr_stack + 62629;
 target_ptr = Libderiv->deriv_classes[4][7][11];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,675,dvrr_stack+63169, dvrr_stack+59839, NULL);
 tmp = dvrr_stack + 63169;
 target_ptr = Libderiv->deriv_classes[4][8][11];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,825,dvrr_stack+63844, dvrr_stack+68968, NULL);

 /* compute (2 0 | 3 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,60,dvrr_stack+75422, dvrr_stack+71491, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,126,dvrr_stack+64669, dvrr_stack+1434, NULL);
 tmp = dvrr_stack + 64669;
 target_ptr = Libderiv->deriv_classes[2][5][10];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,90,dvrr_stack+64795, dvrr_stack+689, NULL);
 tmp = dvrr_stack + 64795;
 target_ptr = Libderiv->deriv_classes[2][4][10];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+64885, dvrr_stack+3245, NULL);
 tmp = dvrr_stack + 64885;
 target_ptr = Libderiv->deriv_classes[2][6][10];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+55974, dvrr_stack+5677, NULL);
 tmp = dvrr_stack + 55974;
 target_ptr = Libderiv->deriv_classes[2][7][10];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+56190, dvrr_stack+8823, NULL);
 tmp = dvrr_stack + 56190;
 target_ptr = Libderiv->deriv_classes[2][8][10];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,330,dvrr_stack+56460, dvrr_stack+12731, NULL);

 /* compute (3 0 | 3 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,100,dvrr_stack+49764, dvrr_stack+72797, NULL);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,210,dvrr_stack+49864, dvrr_stack+17877, NULL);
 tmp = dvrr_stack + 49864;
 target_ptr = Libderiv->deriv_classes[3][5][10];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,150,dvrr_stack+50074, dvrr_stack+16895, NULL);
 tmp = dvrr_stack + 50074;
 target_ptr = Libderiv->deriv_classes[3][4][10];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+45048, dvrr_stack+20541, NULL);
 tmp = dvrr_stack + 45048;
 target_ptr = Libderiv->deriv_classes[3][6][10];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+31471, dvrr_stack+24126, NULL);
 tmp = dvrr_stack + 31471;
 target_ptr = Libderiv->deriv_classes[3][7][10];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+31831, dvrr_stack+28771, NULL);
 tmp = dvrr_stack + 31831;
 target_ptr = Libderiv->deriv_classes[3][8][10];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,550,dvrr_stack+26286, dvrr_stack+34736, NULL);

 /* compute (4 0 | 3 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,150,dvrr_stack+50224, dvrr_stack+61864, NULL);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+14171, dvrr_stack+43158, NULL);
 tmp = dvrr_stack + 14171;
 target_ptr = Libderiv->deriv_classes[4][5][10];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,225,dvrr_stack+14486, dvrr_stack+41615, NULL);
 tmp = dvrr_stack + 14486;
 target_ptr = Libderiv->deriv_classes[4][4][10];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+14711, dvrr_stack+47244, NULL);
 tmp = dvrr_stack + 14711;
 target_ptr = Libderiv->deriv_classes[4][6][10];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+89473, dvrr_stack+52734, NULL);
 tmp = dvrr_stack + 89473;
 target_ptr = Libderiv->deriv_classes[4][7][10];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+90013, dvrr_stack+59839, NULL);
 tmp = dvrr_stack + 90013;
 target_ptr = Libderiv->deriv_classes[4][8][10];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+90688, dvrr_stack+68968, NULL);

 /* compute (2 0 | 3 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,60,dvrr_stack+56790, dvrr_stack+71491, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+71491, dvrr_stack+1434, NULL);
 tmp = dvrr_stack + 71491;
 target_ptr = Libderiv->deriv_classes[2][5][9];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,90,dvrr_stack+1434, dvrr_stack+689, NULL);
 tmp = dvrr_stack + 1434;
 target_ptr = Libderiv->deriv_classes[2][4][9];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+689, dvrr_stack+3245, NULL);
 tmp = dvrr_stack + 689;
 target_ptr = Libderiv->deriv_classes[2][6][9];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+3245, dvrr_stack+5677, NULL);
 tmp = dvrr_stack + 3245;
 target_ptr = Libderiv->deriv_classes[2][7][9];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+5677, dvrr_stack+8823, NULL);
 tmp = dvrr_stack + 5677;
 target_ptr = Libderiv->deriv_classes[2][8][9];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+8823, dvrr_stack+12731, NULL);

 /* compute (3 0 | 3 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,100,dvrr_stack+12731, dvrr_stack+72797, NULL);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+15131, dvrr_stack+17877, NULL);
 tmp = dvrr_stack + 15131;
 target_ptr = Libderiv->deriv_classes[3][5][9];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,150,dvrr_stack+17877, dvrr_stack+16895, NULL);
 tmp = dvrr_stack + 17877;
 target_ptr = Libderiv->deriv_classes[3][4][9];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+16895, dvrr_stack+20541, NULL);
 tmp = dvrr_stack + 16895;
 target_ptr = Libderiv->deriv_classes[3][6][9];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+20541, dvrr_stack+24126, NULL);
 tmp = dvrr_stack + 20541;
 target_ptr = Libderiv->deriv_classes[3][7][9];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+24126, dvrr_stack+28771, NULL);
 tmp = dvrr_stack + 24126;
 target_ptr = Libderiv->deriv_classes[3][8][9];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+28771, dvrr_stack+34736, NULL);

 /* compute (4 0 | 3 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,150,dvrr_stack+34736, dvrr_stack+61864, NULL);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+61864, dvrr_stack+43158, NULL);
 tmp = dvrr_stack + 61864;
 target_ptr = Libderiv->deriv_classes[4][5][9];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,225,dvrr_stack+43158, dvrr_stack+41615, NULL);
 tmp = dvrr_stack + 43158;
 target_ptr = Libderiv->deriv_classes[4][4][9];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+41615, dvrr_stack+47244, NULL);
 tmp = dvrr_stack + 41615;
 target_ptr = Libderiv->deriv_classes[4][6][9];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+47244, dvrr_stack+52734, NULL);
 tmp = dvrr_stack + 47244;
 target_ptr = Libderiv->deriv_classes[4][7][9];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+52734, dvrr_stack+59839, NULL);
 tmp = dvrr_stack + 52734;
 target_ptr = Libderiv->deriv_classes[4][8][9];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+59839, dvrr_stack+68968, NULL);

 /* compute (1 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+68968, dvrr_stack+31, dvrr_stack+3, NULL, NULL, Data->F+2);

 /* compute (1 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+68977, dvrr_stack+98, dvrr_stack+34, NULL, NULL, dvrr_stack+31);

 /* compute (2 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+68995, dvrr_stack+68977, dvrr_stack+71443, dvrr_stack+98, dvrr_stack+34, dvrr_stack+68968);

 /* compute (2 0 | 3 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_f(Data,6,1,dvrr_stack+69031, dvrr_stack+250, dvrr_stack+68995);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+69091, dvrr_stack+1266, dvrr_stack+250);
 tmp = dvrr_stack + 69091;
 target_ptr = Libderiv->deriv_classes[2][5][8];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,6,1,dvrr_stack+69217, dvrr_stack+563, dvrr_stack+145);
 tmp = dvrr_stack + 69217;
 target_ptr = Libderiv->deriv_classes[2][4][8];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+69307, dvrr_stack+3029, dvrr_stack+563);
 tmp = dvrr_stack + 69307;
 target_ptr = Libderiv->deriv_classes[2][6][8];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+69475, dvrr_stack+5407, dvrr_stack+1266);
 tmp = dvrr_stack + 69475;
 target_ptr = Libderiv->deriv_classes[2][7][8];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+69691, dvrr_stack+8493, dvrr_stack+3029);
 tmp = dvrr_stack + 69691;
 target_ptr = Libderiv->deriv_classes[2][8][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+69961, dvrr_stack+12335, dvrr_stack+5407);

 /* compute (1 0 | 0 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+34, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (2 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+70291, dvrr_stack+68968, dvrr_stack+2912, dvrr_stack+31, dvrr_stack+3, dvrr_stack+34);

 /* compute (3 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+70309, dvrr_stack+68995, dvrr_stack+72661, dvrr_stack+68977, dvrr_stack+71443, dvrr_stack+70291);

 /* compute (3 0 | 3 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_f(Data,10,1,dvrr_stack+70369, dvrr_stack+16346, dvrr_stack+70309);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+70469, dvrr_stack+17597, dvrr_stack+16346);
 tmp = dvrr_stack + 70469;
 target_ptr = Libderiv->deriv_classes[3][5][8];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,10,1,dvrr_stack+70679, dvrr_stack+16685, dvrr_stack+72697);
 tmp = dvrr_stack + 70679;
 target_ptr = Libderiv->deriv_classes[3][4][8];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+70829, dvrr_stack+20181, dvrr_stack+16685);
 tmp = dvrr_stack + 70829;
 target_ptr = Libderiv->deriv_classes[3][6][8];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+60664, dvrr_stack+23676, dvrr_stack+17597);
 tmp = dvrr_stack + 60664;
 target_ptr = Libderiv->deriv_classes[3][7][8];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+61024, dvrr_stack+28221, dvrr_stack+20181);
 tmp = dvrr_stack + 61024;
 target_ptr = Libderiv->deriv_classes[3][8][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+53409, dvrr_stack+34076, dvrr_stack+23676);

 /* compute (2 0 | 0 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+68977, dvrr_stack+34, dvrr_stack+1015, Data->F+2, Data->F+3, NULL);

 /* compute (3 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+71109, dvrr_stack+70291, dvrr_stack+40, dvrr_stack+68968, dvrr_stack+2912, dvrr_stack+68977);

 /* compute (4 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+71139, dvrr_stack+70309, dvrr_stack+74837, dvrr_stack+68995, dvrr_stack+72661, dvrr_stack+71109);

 /* compute (4 0 | 3 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_f(Data,15,1,dvrr_stack+71229, dvrr_stack+40676, dvrr_stack+71139);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+61474, dvrr_stack+42738, dvrr_stack+40676);
 tmp = dvrr_stack + 61474;
 target_ptr = Libderiv->deriv_classes[4][5][8];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,15,1,dvrr_stack+53959, dvrr_stack+41300, dvrr_stack+74897);
 tmp = dvrr_stack + 53959;
 target_ptr = Libderiv->deriv_classes[4][4][8];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+47784, dvrr_stack+46704, dvrr_stack+41300);
 tmp = dvrr_stack + 47784;
 target_ptr = Libderiv->deriv_classes[4][6][8];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+43383, dvrr_stack+52059, dvrr_stack+42738);
 tmp = dvrr_stack + 43383;
 target_ptr = Libderiv->deriv_classes[4][7][8];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+34886, dvrr_stack+59014, dvrr_stack+46704);
 tmp = dvrr_stack + 34886;
 target_ptr = Libderiv->deriv_classes[4][8][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+35561, dvrr_stack+67978, dvrr_stack+52059);

 /* compute (2 0 | 3 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_f(Data,6,1,dvrr_stack+71379, dvrr_stack+250, dvrr_stack+68995);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+54184, dvrr_stack+1266, dvrr_stack+250);
 tmp = dvrr_stack + 54184;
 target_ptr = Libderiv->deriv_classes[2][5][7];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,6,1,dvrr_stack+48204, dvrr_stack+563, dvrr_stack+145);
 tmp = dvrr_stack + 48204;
 target_ptr = Libderiv->deriv_classes[2][4][7];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+48294, dvrr_stack+3029, dvrr_stack+563);
 tmp = dvrr_stack + 48294;
 target_ptr = Libderiv->deriv_classes[2][6][7];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+42035, dvrr_stack+5407, dvrr_stack+1266);
 tmp = dvrr_stack + 42035;
 target_ptr = Libderiv->deriv_classes[2][7][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+29321, dvrr_stack+8493, dvrr_stack+3029);
 tmp = dvrr_stack + 29321;
 target_ptr = Libderiv->deriv_classes[2][8][7];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+29591, dvrr_stack+12335, dvrr_stack+5407);

 /* compute (3 0 | 3 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_f(Data,10,1,dvrr_stack+43923, dvrr_stack+16346, dvrr_stack+70309);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+24576, dvrr_stack+17597, dvrr_stack+16346);
 tmp = dvrr_stack + 24576;
 target_ptr = Libderiv->deriv_classes[3][5][7];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,10,1,dvrr_stack+29921, dvrr_stack+16685, dvrr_stack+72697);
 tmp = dvrr_stack + 29921;
 target_ptr = Libderiv->deriv_classes[3][4][7];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+24786, dvrr_stack+20181, dvrr_stack+16685);
 tmp = dvrr_stack + 24786;
 target_ptr = Libderiv->deriv_classes[3][6][7];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+20901, dvrr_stack+23676, dvrr_stack+17597);
 tmp = dvrr_stack + 20901;
 target_ptr = Libderiv->deriv_classes[3][7][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+18027, dvrr_stack+28221, dvrr_stack+20181);
 tmp = dvrr_stack + 18027;
 target_ptr = Libderiv->deriv_classes[3][8][7];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+12831, dvrr_stack+34076, dvrr_stack+23676);

 /* compute (4 0 | 3 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_f(Data,15,1,dvrr_stack+17175, dvrr_stack+40676, dvrr_stack+71139);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+13381, dvrr_stack+42738, dvrr_stack+40676);
 tmp = dvrr_stack + 13381;
 target_ptr = Libderiv->deriv_classes[4][5][7];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,15,1,dvrr_stack+72797, dvrr_stack+41300, dvrr_stack+74897);
 tmp = dvrr_stack + 72797;
 target_ptr = Libderiv->deriv_classes[4][4][7];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+9153, dvrr_stack+46704, dvrr_stack+41300);
 tmp = dvrr_stack + 9153;
 target_ptr = Libderiv->deriv_classes[4][6][7];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+91513, dvrr_stack+52059, dvrr_stack+42738);
 tmp = dvrr_stack + 91513;
 target_ptr = Libderiv->deriv_classes[4][7][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+92053, dvrr_stack+59014, dvrr_stack+46704);
 tmp = dvrr_stack + 92053;
 target_ptr = Libderiv->deriv_classes[4][8][7];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+92728, dvrr_stack+67978, dvrr_stack+52059);

 /* compute (2 0 | 3 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_f(Data,6,1,dvrr_stack+9573, dvrr_stack+250, dvrr_stack+68995);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+62179, dvrr_stack+1266, dvrr_stack+250);
 tmp = dvrr_stack + 62179;
 target_ptr = Libderiv->deriv_classes[2][5][6];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,6,1,dvrr_stack+25066, dvrr_stack+563, dvrr_stack+145);
 tmp = dvrr_stack + 25066;
 target_ptr = Libderiv->deriv_classes[2][4][6];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+5947, dvrr_stack+3029, dvrr_stack+563);
 tmp = dvrr_stack + 5947;
 target_ptr = Libderiv->deriv_classes[2][6][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+3461, dvrr_stack+5407, dvrr_stack+1266);
 tmp = dvrr_stack + 3461;
 target_ptr = Libderiv->deriv_classes[2][7][6];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+1524, dvrr_stack+8493, dvrr_stack+3029);
 tmp = dvrr_stack + 1524;
 target_ptr = Libderiv->deriv_classes[2][8][6];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+8493, dvrr_stack+12335, dvrr_stack+5407);

 /* compute (3 0 | 3 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_f(Data,10,1,dvrr_stack+21261, dvrr_stack+16346, dvrr_stack+70309);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+6115, dvrr_stack+17597, dvrr_stack+16346);
 tmp = dvrr_stack + 6115;
 target_ptr = Libderiv->deriv_classes[3][5][6];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,10,1,dvrr_stack+10443, dvrr_stack+16685, dvrr_stack+72697);
 tmp = dvrr_stack + 10443;
 target_ptr = Libderiv->deriv_classes[3][4][6];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+10593, dvrr_stack+20181, dvrr_stack+16685);
 tmp = dvrr_stack + 10593;
 target_ptr = Libderiv->deriv_classes[3][6][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+12327, dvrr_stack+23676, dvrr_stack+17597);
 tmp = dvrr_stack + 12327;
 target_ptr = Libderiv->deriv_classes[3][7][6];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+93553, dvrr_stack+28221, dvrr_stack+20181);
 tmp = dvrr_stack + 93553;
 target_ptr = Libderiv->deriv_classes[3][8][6];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+94003, dvrr_stack+34076, dvrr_stack+23676);

 /* compute (4 0 | 3 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_f(Data,15,1,dvrr_stack+4253, dvrr_stack+40676, dvrr_stack+71139);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+34064, dvrr_stack+42738, dvrr_stack+40676);
 tmp = dvrr_stack + 34064;
 target_ptr = Libderiv->deriv_classes[4][5][6];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,15,1,dvrr_stack+34379, dvrr_stack+41300, dvrr_stack+74897);
 tmp = dvrr_stack + 34379;
 target_ptr = Libderiv->deriv_classes[4][4][6];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+94553, dvrr_stack+46704, dvrr_stack+41300);
 tmp = dvrr_stack + 94553;
 target_ptr = Libderiv->deriv_classes[4][6][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+94973, dvrr_stack+52059, dvrr_stack+42738);
 tmp = dvrr_stack + 94973;
 target_ptr = Libderiv->deriv_classes[4][7][6];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+95513, dvrr_stack+59014, dvrr_stack+46704);
 tmp = dvrr_stack + 95513;
 target_ptr = Libderiv->deriv_classes[4][8][6];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+96188, dvrr_stack+67978, dvrr_stack+52059);

 /* compute (1 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+2190,dvrr_stack+500,dvrr_stack+205,3);


 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,45,dvrr_stack+145, dvrr_stack+2190, NULL);

 /* compute (1 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+11873,dvrr_stack+1182,dvrr_stack+500,3);


 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,63,dvrr_stack+71109, dvrr_stack+11873, NULL);

 /* compute (1 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+67876,dvrr_stack+2921,dvrr_stack+1182,3);


 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,84,dvrr_stack+857, dvrr_stack+67876, NULL);

 /* compute (1 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+68128,dvrr_stack+5272,dvrr_stack+2921,3);


 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,108,dvrr_stack+45328, dvrr_stack+68128, NULL);

 /* compute (1 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+68452,dvrr_stack+8328,dvrr_stack+5272,3);


 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,135,dvrr_stack+68857, dvrr_stack+68452, NULL);

 /* compute (1 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+190, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+3, dvrr_stack+12, dvrr_stack+95, NULL, NULL, Data->F+5);

 /* compute (2 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+1794, dvrr_stack+2694, dvrr_stack+3, dvrr_stack+0, dvrr_stack+12, dvrr_stack+190);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+71172, dvrr_stack+129, dvrr_stack+385, NULL, NULL, dvrr_stack+95);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+71190, dvrr_stack+11691, dvrr_stack+71172, dvrr_stack+15, dvrr_stack+129, dvrr_stack+3);

 /* compute (3 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+70291, dvrr_stack+2622, dvrr_stack+71190, dvrr_stack+11643, dvrr_stack+11691, dvrr_stack+1794);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+18477, dvrr_stack+391, dvrr_stack+1024, NULL, NULL, dvrr_stack+385);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+61789, dvrr_stack+12137, dvrr_stack+18477, dvrr_stack+135, dvrr_stack+391, dvrr_stack+71172);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+4403, dvrr_stack+12167, dvrr_stack+61789, dvrr_stack+11661, dvrr_stack+12137, dvrr_stack+71190);

 /* compute (4 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+8163, dvrr_stack+12227, dvrr_stack+4403, dvrr_stack+16151, dvrr_stack+12167, dvrr_stack+70291);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+16151, dvrr_stack+1034, dvrr_stack+2713, NULL, NULL, dvrr_stack+1024);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+34604, dvrr_stack+11577, dvrr_stack+16151, dvrr_stack+401, dvrr_stack+1034, dvrr_stack+18477);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+97013, dvrr_stack+40436, dvrr_stack+34604, dvrr_stack+16211, dvrr_stack+11577, dvrr_stack+61789);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+97163, dvrr_stack+40526, dvrr_stack+97013, dvrr_stack+16256, dvrr_stack+40436, dvrr_stack+4403);

 /* compute (5 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+97388, dvrr_stack+40676, dvrr_stack+97163, dvrr_stack+16346, dvrr_stack+40526, dvrr_stack+8163);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+16196, dvrr_stack+2728, dvrr_stack+5007, NULL, NULL, dvrr_stack+2713);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+97703, dvrr_stack+40901, dvrr_stack+16196, dvrr_stack+1049, dvrr_stack+2728, dvrr_stack+16151);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+97829, dvrr_stack+40964, dvrr_stack+97703, dvrr_stack+16496, dvrr_stack+40901, dvrr_stack+34604);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+98039, dvrr_stack+41090, dvrr_stack+97829, dvrr_stack+16559, dvrr_stack+40964, dvrr_stack+97013);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+98354, dvrr_stack+41300, dvrr_stack+98039, dvrr_stack+16685, dvrr_stack+41090, dvrr_stack+97163);

 /* compute (5 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+98795,dvrr_stack+98354,dvrr_stack+97388,21);


 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+99740, dvrr_stack+98795, NULL);

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+16496, dvrr_stack+5028, dvrr_stack+7999, NULL, NULL, dvrr_stack+5007);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+100055, dvrr_stack+416, dvrr_stack+16496, dvrr_stack+2749, dvrr_stack+5028, dvrr_stack+16196);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+100223, dvrr_stack+42290, dvrr_stack+100055, dvrr_stack+17345, dvrr_stack+416, dvrr_stack+97703);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+100503, dvrr_stack+42458, dvrr_stack+100223, dvrr_stack+17429, dvrr_stack+42290, dvrr_stack+97829);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+100923, dvrr_stack+42738, dvrr_stack+100503, dvrr_stack+17597, dvrr_stack+42458, dvrr_stack+98039);

 /* compute (5 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+101511,dvrr_stack+100923,dvrr_stack+98354,21);


 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,441,dvrr_stack+102834, dvrr_stack+101511, NULL);

 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+17325, dvrr_stack+8027, dvrr_stack+11737, NULL, NULL, dvrr_stack+7999);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+103275, dvrr_stack+1070, dvrr_stack+17325, dvrr_stack+5056, dvrr_stack+8027, dvrr_stack+16496);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+103491, dvrr_stack+46128, dvrr_stack+103275, dvrr_stack+19857, dvrr_stack+1070, dvrr_stack+100055);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+103851, dvrr_stack+46344, dvrr_stack+103491, dvrr_stack+19965, dvrr_stack+46128, dvrr_stack+100223);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+104391, dvrr_stack+46704, dvrr_stack+103851, dvrr_stack+20181, dvrr_stack+46344, dvrr_stack+100503);

 /* compute (5 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+105147,dvrr_stack+104391,dvrr_stack+100923,21);


 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+106911, dvrr_stack+105147, NULL);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19857, dvrr_stack+11773, dvrr_stack+4883, NULL, NULL, dvrr_stack+11737);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+107499, dvrr_stack+2777, dvrr_stack+19857, dvrr_stack+8063, dvrr_stack+11773, dvrr_stack+17325);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+107769, dvrr_stack+51339, dvrr_stack+107499, dvrr_stack+23271, dvrr_stack+2777, dvrr_stack+103275);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+108219, dvrr_stack+51609, dvrr_stack+107769, dvrr_stack+23406, dvrr_stack+51339, dvrr_stack+103491);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+108894, dvrr_stack+52059, dvrr_stack+108219, dvrr_stack+23676, dvrr_stack+51609, dvrr_stack+103851);

 /* compute (5 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+109839,dvrr_stack+108894,dvrr_stack+104391,21);


 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+112107, dvrr_stack+109839, NULL);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+23271, dvrr_stack+33361, dvrr_stack+8108, NULL, NULL, dvrr_stack+4883);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+112863, dvrr_stack+5092, dvrr_stack+23271, dvrr_stack+11818, dvrr_stack+33361, dvrr_stack+19857);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+113193, dvrr_stack+58134, dvrr_stack+112863, dvrr_stack+27726, dvrr_stack+5092, dvrr_stack+107499);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+113743, dvrr_stack+58464, dvrr_stack+113193, dvrr_stack+27891, dvrr_stack+58134, dvrr_stack+107769);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+114568, dvrr_stack+59014, dvrr_stack+113743, dvrr_stack+28221, dvrr_stack+58464, dvrr_stack+108219);

 /* compute (5 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+115723,dvrr_stack+114568,dvrr_stack+108894,21);


 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+58134, dvrr_stack+115723, NULL);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,45,dvrr_stack+59079, dvrr_stack+2190, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,63,dvrr_stack+59124, dvrr_stack+11873, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,84,dvrr_stack+59187, dvrr_stack+67876, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,108,dvrr_stack+59271, dvrr_stack+68128, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,135,dvrr_stack+59379, dvrr_stack+68452, NULL);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+59514, dvrr_stack+98795, NULL);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+27726, dvrr_stack+101511, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+28167, dvrr_stack+105147, NULL);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+112863, dvrr_stack+109839, NULL);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+113619, dvrr_stack+115723, NULL);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,45,dvrr_stack+33361, dvrr_stack+2190, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,63,dvrr_stack+2190, dvrr_stack+11873, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+2253, dvrr_stack+67876, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+67876, dvrr_stack+68128, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+67984, dvrr_stack+68452, NULL);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+68119, dvrr_stack+98795, NULL);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+98795, dvrr_stack+101511, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+101511, dvrr_stack+105147, NULL);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+105147, dvrr_stack+109839, NULL);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+109839, dvrr_stack+115723, NULL);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,3,1,dvrr_stack+115723, dvrr_stack+500, dvrr_stack+71461);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+115768, dvrr_stack+1182, dvrr_stack+205);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+115831, dvrr_stack+2921, dvrr_stack+500);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+115915, dvrr_stack+5272, dvrr_stack+1182);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+116023, dvrr_stack+8328, dvrr_stack+2921);

 /* compute (2 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+116158, dvrr_stack+1015, dvrr_stack+190, Data->F+3, Data->F+4, NULL);

 /* compute (3 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+116164, dvrr_stack+40, dvrr_stack+1794, dvrr_stack+2912, dvrr_stack+2694, dvrr_stack+116158);

 /* compute (4 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+116194, dvrr_stack+74837, dvrr_stack+70291, dvrr_stack+72661, dvrr_stack+2622, dvrr_stack+116164);

 /* compute (5 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+116284, dvrr_stack+74897, dvrr_stack+8163, dvrr_stack+72697, dvrr_stack+12227, dvrr_stack+116194);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,21,1,dvrr_stack+116494, dvrr_stack+98354, dvrr_stack+116284);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+116809, dvrr_stack+100923, dvrr_stack+97388);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+117250, dvrr_stack+104391, dvrr_stack+98354);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+117838, dvrr_stack+108894, dvrr_stack+100923);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+110784, dvrr_stack+114568, dvrr_stack+104391);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,3,1,dvrr_stack+72661, dvrr_stack+500, dvrr_stack+71461);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+72706, dvrr_stack+1182, dvrr_stack+205);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+74837, dvrr_stack+2921, dvrr_stack+500);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+74921, dvrr_stack+5272, dvrr_stack+1182);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+118594, dvrr_stack+8328, dvrr_stack+2921);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,21,1,dvrr_stack+111729, dvrr_stack+98354, dvrr_stack+116284);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+105903, dvrr_stack+100923, dvrr_stack+97388);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+102099, dvrr_stack+104391, dvrr_stack+98354);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+118729, dvrr_stack+108894, dvrr_stack+100923);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+119485, dvrr_stack+114568, dvrr_stack+104391);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,3,1,dvrr_stack+116158, dvrr_stack+500, dvrr_stack+71461);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+112044, dvrr_stack+1182, dvrr_stack+205);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+120430, dvrr_stack+2921, dvrr_stack+500);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+120514, dvrr_stack+5272, dvrr_stack+1182);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+120622, dvrr_stack+8328, dvrr_stack+2921);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,21,1,dvrr_stack+106344, dvrr_stack+98354, dvrr_stack+116284);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+99236, dvrr_stack+100923, dvrr_stack+97388);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+120757, dvrr_stack+104391, dvrr_stack+98354);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+121345, dvrr_stack+108894, dvrr_stack+100923);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+122101, dvrr_stack+114568, dvrr_stack+104391);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,15,dvrr_stack+116203, dvrr_stack+250, dvrr_stack+114);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,15,dvrr_stack+116248, dvrr_stack+40676, dvrr_stack+250);
 tmp = dvrr_stack + 116248;
 target_ptr = Libderiv->deriv_classes[3][4][2];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+99677, dvrr_stack+563, dvrr_stack+361);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+123046, dvrr_stack+41300, dvrr_stack+563);
 tmp = dvrr_stack + 123046;
 target_ptr = Libderiv->deriv_classes[3][5][2];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+116398, dvrr_stack+1266, dvrr_stack+987);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+123256, dvrr_stack+42738, dvrr_stack+1266);
 tmp = dvrr_stack + 123256;
 target_ptr = Libderiv->deriv_classes[3][6][2];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+123536, dvrr_stack+3029, dvrr_stack+2658);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+68434, dvrr_stack+46704, dvrr_stack+3029);
 tmp = dvrr_stack + 68434;
 target_ptr = Libderiv->deriv_classes[3][7][2];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+123644, dvrr_stack+5407, dvrr_stack+4928);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+114564, dvrr_stack+52059, dvrr_stack+5407);
 tmp = dvrr_stack + 114564;
 target_ptr = Libderiv->deriv_classes[3][8][2];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,15,dvrr_stack+123779, dvrr_stack+16346, dvrr_stack+205);
 tmp = dvrr_stack + 123779;
 target_ptr = Libderiv->deriv_classes[2][4][2];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,15,dvrr_stack+106659, dvrr_stack+97388, dvrr_stack+16346);
 tmp = dvrr_stack + 106659;
 target_ptr = Libderiv->deriv_classes[4][4][2];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+123869, dvrr_stack+16685, dvrr_stack+500);
 tmp = dvrr_stack + 123869;
 target_ptr = Libderiv->deriv_classes[2][5][2];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+115014, dvrr_stack+98354, dvrr_stack+16685);
 tmp = dvrr_stack + 115014;
 target_ptr = Libderiv->deriv_classes[4][5][2];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+115329, dvrr_stack+17597, dvrr_stack+1182);
 tmp = dvrr_stack + 115329;
 target_ptr = Libderiv->deriv_classes[2][6][2];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+123995, dvrr_stack+100923, dvrr_stack+17597);
 tmp = dvrr_stack + 123995;
 target_ptr = Libderiv->deriv_classes[4][6][2];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+5056, dvrr_stack+20181, dvrr_stack+2921);
 tmp = dvrr_stack + 5056;
 target_ptr = Libderiv->deriv_classes[2][7][2];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+124415, dvrr_stack+104391, dvrr_stack+20181);
 tmp = dvrr_stack + 124415;
 target_ptr = Libderiv->deriv_classes[4][7][2];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+11818, dvrr_stack+23676, dvrr_stack+5272);
 tmp = dvrr_stack + 11818;
 target_ptr = Libderiv->deriv_classes[2][8][2];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+124955, dvrr_stack+108894, dvrr_stack+23676);
 tmp = dvrr_stack + 124955;
 target_ptr = Libderiv->deriv_classes[4][8][2];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+1015, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+72769, dvrr_stack+190, dvrr_stack+1015, Data->F+4, Data->F+5, NULL);

 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+2912, dvrr_stack+95, dvrr_stack+382, NULL, NULL, Data->F+6);

 /* compute (2 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+75029, dvrr_stack+3, dvrr_stack+2912, dvrr_stack+12, dvrr_stack+95, dvrr_stack+1015);

 /* compute (3 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+12, dvrr_stack+1794, dvrr_stack+75029, dvrr_stack+2694, dvrr_stack+3, dvrr_stack+72769);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+1794, dvrr_stack+385, dvrr_stack+1018, NULL, NULL, dvrr_stack+382);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+42, dvrr_stack+71172, dvrr_stack+1794, dvrr_stack+129, dvrr_stack+385, dvrr_stack+2912);

 /* compute (3 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+125630, dvrr_stack+71190, dvrr_stack+42, dvrr_stack+11691, dvrr_stack+71172, dvrr_stack+75029);

 /* compute (4 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+125690, dvrr_stack+70291, dvrr_stack+125630, dvrr_stack+2622, dvrr_stack+71190, dvrr_stack+12);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+2622, dvrr_stack+1024, dvrr_stack+2703, NULL, NULL, dvrr_stack+1018);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+70291, dvrr_stack+18477, dvrr_stack+2622, dvrr_stack+391, dvrr_stack+1024, dvrr_stack+1794);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+8063, dvrr_stack+61789, dvrr_stack+70291, dvrr_stack+12137, dvrr_stack+18477, dvrr_stack+42);

 /* compute (4 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+125780, dvrr_stack+4403, dvrr_stack+8063, dvrr_stack+12167, dvrr_stack+61789, dvrr_stack+125630);

 /* compute (5 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+115497, dvrr_stack+8163, dvrr_stack+125780, dvrr_stack+12227, dvrr_stack+4403, dvrr_stack+125690);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+4403, dvrr_stack+2713, dvrr_stack+4992, NULL, NULL, dvrr_stack+2703);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+8163, dvrr_stack+16151, dvrr_stack+4403, dvrr_stack+1034, dvrr_stack+2713, dvrr_stack+2622);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+125630, dvrr_stack+34604, dvrr_stack+8163, dvrr_stack+11577, dvrr_stack+16151, dvrr_stack+70291);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+8253, dvrr_stack+97013, dvrr_stack+125630, dvrr_stack+40436, dvrr_stack+34604, dvrr_stack+8063);

 /* compute (5 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+23271, dvrr_stack+97163, dvrr_stack+8253, dvrr_stack+40526, dvrr_stack+97013, dvrr_stack+125780);

 /* compute (6 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+125780, dvrr_stack+97388, dvrr_stack+23271, dvrr_stack+40676, dvrr_stack+97163, dvrr_stack+115497);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,15,dvrr_stack+126200, dvrr_stack+125780, dvrr_stack+40676);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+68794, dvrr_stack+5007, dvrr_stack+7978, NULL, NULL, dvrr_stack+4992);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+115497, dvrr_stack+16196, dvrr_stack+68794, dvrr_stack+2728, dvrr_stack+5007, dvrr_stack+4403);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+126515, dvrr_stack+97703, dvrr_stack+115497, dvrr_stack+40901, dvrr_stack+16196, dvrr_stack+8163);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+97013, dvrr_stack+97829, dvrr_stack+126515, dvrr_stack+40964, dvrr_stack+97703, dvrr_stack+125630);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+126725, dvrr_stack+98039, dvrr_stack+97013, dvrr_stack+41090, dvrr_stack+97829, dvrr_stack+8253);

 /* compute (6 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+127166, dvrr_stack+98354, dvrr_stack+126725, dvrr_stack+41300, dvrr_stack+98039, dvrr_stack+23271);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+97703, dvrr_stack+127166, dvrr_stack+41300);

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+23271, dvrr_stack+7999, dvrr_stack+11709, NULL, NULL, dvrr_stack+7978);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+23355, dvrr_stack+16496, dvrr_stack+23271, dvrr_stack+5028, dvrr_stack+7999, dvrr_stack+68794);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+40901, dvrr_stack+100055, dvrr_stack+23355, dvrr_stack+416, dvrr_stack+16496, dvrr_stack+115497);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+8063, dvrr_stack+100223, dvrr_stack+40901, dvrr_stack+42290, dvrr_stack+100055, dvrr_stack+126515);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+127754, dvrr_stack+100503, dvrr_stack+8063, dvrr_stack+42458, dvrr_stack+100223, dvrr_stack+97013);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+128342, dvrr_stack+100923, dvrr_stack+127754, dvrr_stack+42738, dvrr_stack+100503, dvrr_stack+126725);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+126515, dvrr_stack+128342, dvrr_stack+42738);

 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+97013, dvrr_stack+11737, dvrr_stack+7856, NULL, NULL, dvrr_stack+11709);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+97121, dvrr_stack+17325, dvrr_stack+97013, dvrr_stack+8027, dvrr_stack+11737, dvrr_stack+23271);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+100055, dvrr_stack+103275, dvrr_stack+97121, dvrr_stack+1070, dvrr_stack+17325, dvrr_stack+23355);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+129126, dvrr_stack+103491, dvrr_stack+100055, dvrr_stack+46128, dvrr_stack+103275, dvrr_stack+40901);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+129666, dvrr_stack+103851, dvrr_stack+129126, dvrr_stack+46344, dvrr_stack+103491, dvrr_stack+8063);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+130422, dvrr_stack+104391, dvrr_stack+129666, dvrr_stack+46704, dvrr_stack+103851, dvrr_stack+127754);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+103275, dvrr_stack+130422, dvrr_stack+46704);

 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+127754, dvrr_stack+4883, dvrr_stack+7892, NULL, NULL, dvrr_stack+7856);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+127889, dvrr_stack+19857, dvrr_stack+127754, dvrr_stack+11773, dvrr_stack+4883, dvrr_stack+97013);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+46128, dvrr_stack+107499, dvrr_stack+127889, dvrr_stack+2777, dvrr_stack+19857, dvrr_stack+97121);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+131430, dvrr_stack+107769, dvrr_stack+46128, dvrr_stack+51339, dvrr_stack+107499, dvrr_stack+100055);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+132105, dvrr_stack+108219, dvrr_stack+131430, dvrr_stack+51609, dvrr_stack+107769, dvrr_stack+129126);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+133050, dvrr_stack+108894, dvrr_stack+132105, dvrr_stack+52059, dvrr_stack+108219, dvrr_stack+129666);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+129126, dvrr_stack+133050, dvrr_stack+52059);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,15,dvrr_stack+4883, dvrr_stack+250, dvrr_stack+114);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,15,dvrr_stack+125630, dvrr_stack+40676, dvrr_stack+250);
 tmp = dvrr_stack + 125630;
 target_ptr = Libderiv->deriv_classes[3][4][1];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+127103, dvrr_stack+563, dvrr_stack+361);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+98144, dvrr_stack+41300, dvrr_stack+563);
 tmp = dvrr_stack + 98144;
 target_ptr = Libderiv->deriv_classes[3][5][1];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+130071, dvrr_stack+1266, dvrr_stack+987);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+131430, dvrr_stack+42738, dvrr_stack+1266);
 tmp = dvrr_stack + 131430;
 target_ptr = Libderiv->deriv_classes[3][6][1];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+130155, dvrr_stack+3029, dvrr_stack+2658);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+104031, dvrr_stack+46704, dvrr_stack+3029);
 tmp = dvrr_stack + 104031;
 target_ptr = Libderiv->deriv_classes[3][7][1];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+130263, dvrr_stack+5407, dvrr_stack+4928);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+131710, dvrr_stack+52059, dvrr_stack+5407);
 tmp = dvrr_stack + 131710;
 target_ptr = Libderiv->deriv_classes[3][8][1];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,15,dvrr_stack+132160, dvrr_stack+16346, dvrr_stack+205);
 tmp = dvrr_stack + 132160;
 target_ptr = Libderiv->deriv_classes[2][4][1];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,15,dvrr_stack+132250, dvrr_stack+97388, dvrr_stack+16346);
 tmp = dvrr_stack + 132250;
 target_ptr = Libderiv->deriv_classes[4][4][1];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+132475, dvrr_stack+16685, dvrr_stack+500);
 tmp = dvrr_stack + 132475;
 target_ptr = Libderiv->deriv_classes[2][5][1];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+132601, dvrr_stack+98354, dvrr_stack+16685);
 tmp = dvrr_stack + 132601;
 target_ptr = Libderiv->deriv_classes[4][5][1];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+100055, dvrr_stack+17597, dvrr_stack+1182);
 tmp = dvrr_stack + 100055;
 target_ptr = Libderiv->deriv_classes[2][6][1];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+100223, dvrr_stack+100923, dvrr_stack+17597);
 tmp = dvrr_stack + 100223;
 target_ptr = Libderiv->deriv_classes[4][6][1];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+100643, dvrr_stack+20181, dvrr_stack+2921);
 tmp = dvrr_stack + 100643;
 target_ptr = Libderiv->deriv_classes[2][7][1];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+107499, dvrr_stack+104391, dvrr_stack+20181);
 tmp = dvrr_stack + 107499;
 target_ptr = Libderiv->deriv_classes[4][7][1];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+108039, dvrr_stack+23676, dvrr_stack+5272);
 tmp = dvrr_stack + 108039;
 target_ptr = Libderiv->deriv_classes[2][8][1];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+51339, dvrr_stack+108894, dvrr_stack+23676);
 tmp = dvrr_stack + 51339;
 target_ptr = Libderiv->deriv_classes[4][8][1];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,15,dvrr_stack+108309, dvrr_stack+125780, dvrr_stack+40676);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+46128, dvrr_stack+127166, dvrr_stack+41300);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+127754, dvrr_stack+128342, dvrr_stack+42738);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+134310, dvrr_stack+130422, dvrr_stack+46704);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+135066, dvrr_stack+133050, dvrr_stack+52059);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,15,dvrr_stack+52014, dvrr_stack+250, dvrr_stack+114);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,15,dvrr_stack+108624, dvrr_stack+40676, dvrr_stack+250);
 tmp = dvrr_stack + 108624;
 target_ptr = Libderiv->deriv_classes[3][4][0];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+68794, dvrr_stack+563, dvrr_stack+361);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+250, dvrr_stack+41300, dvrr_stack+563);
 tmp = dvrr_stack + 250;
 target_ptr = Libderiv->deriv_classes[3][5][0];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+563, dvrr_stack+1266, dvrr_stack+987);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+19857, dvrr_stack+42738, dvrr_stack+1266);
 tmp = dvrr_stack + 19857;
 target_ptr = Libderiv->deriv_classes[3][6][0];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+1266, dvrr_stack+3029, dvrr_stack+2658);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+97013, dvrr_stack+46704, dvrr_stack+3029);
 tmp = dvrr_stack + 97013;
 target_ptr = Libderiv->deriv_classes[3][7][0];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+46569, dvrr_stack+5407, dvrr_stack+4928);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+136011, dvrr_stack+52059, dvrr_stack+5407);
 tmp = dvrr_stack + 136011;
 target_ptr = Libderiv->deriv_classes[3][8][0];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,15,dvrr_stack+5407, dvrr_stack+16346, dvrr_stack+205);
 tmp = dvrr_stack + 5407;
 target_ptr = Libderiv->deriv_classes[2][4][0];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,15,dvrr_stack+40901, dvrr_stack+97388, dvrr_stack+16346);
 tmp = dvrr_stack + 40901;
 target_ptr = Libderiv->deriv_classes[4][4][0];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+5497, dvrr_stack+16685, dvrr_stack+500);
 tmp = dvrr_stack + 5497;
 target_ptr = Libderiv->deriv_classes[2][5][0];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+97373, dvrr_stack+98354, dvrr_stack+16685);
 tmp = dvrr_stack + 97373;
 target_ptr = Libderiv->deriv_classes[4][5][0];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+98354, dvrr_stack+17597, dvrr_stack+1182);
 tmp = dvrr_stack + 98354;
 target_ptr = Libderiv->deriv_classes[2][6][0];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+136461, dvrr_stack+100923, dvrr_stack+17597);
 tmp = dvrr_stack + 136461;
 target_ptr = Libderiv->deriv_classes[4][6][0];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+3029, dvrr_stack+20181, dvrr_stack+2921);
 tmp = dvrr_stack + 3029;
 target_ptr = Libderiv->deriv_classes[2][7][0];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+100859, dvrr_stack+104391, dvrr_stack+20181);
 tmp = dvrr_stack + 100859;
 target_ptr = Libderiv->deriv_classes[4][7][0];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+104391, dvrr_stack+23676, dvrr_stack+5272);
 tmp = dvrr_stack + 104391;
 target_ptr = Libderiv->deriv_classes[2][8][0];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+16151, dvrr_stack+108894, dvrr_stack+23676);
 tmp = dvrr_stack + 16151;
 target_ptr = Libderiv->deriv_classes[4][8][0];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,15,dvrr_stack+104661, dvrr_stack+125780, dvrr_stack+40676);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+108774, dvrr_stack+127166, dvrr_stack+41300);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+127166, dvrr_stack+128342, dvrr_stack+42738);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+128342, dvrr_stack+130422, dvrr_stack+46704);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+130398, dvrr_stack+133050, dvrr_stack+52059);

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,90,dvrr_stack+52059, dvrr_stack+2352, NULL);
 tmp = dvrr_stack + 52059;
 target_ptr = Libderiv->deriv2_classes[2][4][143];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,126,dvrr_stack+52149, dvrr_stack+4505, NULL);
 tmp = dvrr_stack + 52149;
 target_ptr = Libderiv->deriv2_classes[2][5][143];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,168,dvrr_stack+52275, dvrr_stack+7333, NULL);
 tmp = dvrr_stack + 52275;
 target_ptr = Libderiv->deriv2_classes[2][6][143];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,216,dvrr_stack+52443, dvrr_stack+10929, NULL);
 tmp = dvrr_stack + 52443;
 target_ptr = Libderiv->deriv2_classes[2][7][143];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,270,dvrr_stack+46704, dvrr_stack+15341, NULL);
 tmp = dvrr_stack + 46704;
 target_ptr = Libderiv->deriv2_classes[2][8][143];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,150,dvrr_stack+46974, dvrr_stack+19407, NULL);
 tmp = dvrr_stack + 46974;
 target_ptr = Libderiv->deriv2_classes[3][4][143];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,210,dvrr_stack+125780, dvrr_stack+22641, NULL);
 tmp = dvrr_stack + 125780;
 target_ptr = Libderiv->deriv2_classes[3][5][143];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,280,dvrr_stack+132916, dvrr_stack+26886, NULL);
 tmp = dvrr_stack + 132916;
 target_ptr = Libderiv->deriv2_classes[3][6][143];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,360,dvrr_stack+133196, dvrr_stack+32281, NULL);
 tmp = dvrr_stack + 133196;
 target_ptr = Libderiv->deriv2_classes[3][7][143];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,450,dvrr_stack+133556, dvrr_stack+39086, NULL);
 tmp = dvrr_stack + 133556;
 target_ptr = Libderiv->deriv2_classes[3][8][143];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,225,dvrr_stack+98522, dvrr_stack+45453, NULL);
 tmp = dvrr_stack + 98522;
 target_ptr = Libderiv->deriv2_classes[4][4][143];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,315,dvrr_stack+109215, dvrr_stack+50394, NULL);
 tmp = dvrr_stack + 109215;
 target_ptr = Libderiv->deriv2_classes[4][5][143];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,420,dvrr_stack+41126, dvrr_stack+56874, NULL);
 tmp = dvrr_stack + 41126;
 target_ptr = Libderiv->deriv2_classes[4][6][143];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,540,dvrr_stack+17325, dvrr_stack+65104, NULL);
 tmp = dvrr_stack + 17325;
 target_ptr = Libderiv->deriv2_classes[4][7][143];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,675,dvrr_stack+23271, dvrr_stack+75493, NULL);
 tmp = dvrr_stack + 23271;
 target_ptr = Libderiv->deriv2_classes[4][8][143];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,90,dvrr_stack+47124, dvrr_stack+2352, NULL);
 tmp = dvrr_stack + 47124;
 target_ptr = Libderiv->deriv2_classes[2][4][131];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,126,dvrr_stack+125990, dvrr_stack+4505, NULL);
 tmp = dvrr_stack + 125990;
 target_ptr = Libderiv->deriv2_classes[2][5][131];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,168,dvrr_stack+104976, dvrr_stack+7333, NULL);
 tmp = dvrr_stack + 104976;
 target_ptr = Libderiv->deriv2_classes[2][6][131];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,216,dvrr_stack+134006, dvrr_stack+10929, NULL);
 tmp = dvrr_stack + 134006;
 target_ptr = Libderiv->deriv2_classes[2][7][131];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,270,dvrr_stack+109530, dvrr_stack+15341, NULL);
 tmp = dvrr_stack + 109530;
 target_ptr = Libderiv->deriv2_classes[2][8][131];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,150,dvrr_stack+20137, dvrr_stack+19407, NULL);
 tmp = dvrr_stack + 20137;
 target_ptr = Libderiv->deriv2_classes[3][4][131];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,210,dvrr_stack+20287, dvrr_stack+22641, NULL);
 tmp = dvrr_stack + 20287;
 target_ptr = Libderiv->deriv2_classes[3][5][131];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,280,dvrr_stack+40436, dvrr_stack+26886, NULL);
 tmp = dvrr_stack + 40436;
 target_ptr = Libderiv->deriv2_classes[3][6][131];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,360,dvrr_stack+2622, dvrr_stack+32281, NULL);
 tmp = dvrr_stack + 2622;
 target_ptr = Libderiv->deriv2_classes[3][7][131];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,450,dvrr_stack+42251, dvrr_stack+39086, NULL);
 tmp = dvrr_stack + 42251;
 target_ptr = Libderiv->deriv2_classes[3][8][131];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,225,dvrr_stack+115497, dvrr_stack+45453, NULL);
 tmp = dvrr_stack + 115497;
 target_ptr = Libderiv->deriv2_classes[4][4][131];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,315,dvrr_stack+42701, dvrr_stack+50394, NULL);
 tmp = dvrr_stack + 42701;
 target_ptr = Libderiv->deriv2_classes[4][5][131];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,420,dvrr_stack+7837, dvrr_stack+56874, NULL);
 tmp = dvrr_stack + 7837;
 target_ptr = Libderiv->deriv2_classes[4][6][131];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,540,dvrr_stack+136881, dvrr_stack+65104, NULL);
 tmp = dvrr_stack + 136881;
 target_ptr = Libderiv->deriv2_classes[4][7][131];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,675,dvrr_stack+137421, dvrr_stack+75493, NULL);
 tmp = dvrr_stack + 137421;
 target_ptr = Libderiv->deriv2_classes[4][8][131];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,90,dvrr_stack+5272, dvrr_stack+33416, NULL);
 tmp = dvrr_stack + 5272;
 target_ptr = Libderiv->deriv2_classes[2][4][130];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,126,dvrr_stack+4928, dvrr_stack+33686, NULL);
 tmp = dvrr_stack + 4928;
 target_ptr = Libderiv->deriv2_classes[2][5][130];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+23946, dvrr_stack+66724, NULL);
 tmp = dvrr_stack + 23946;
 target_ptr = Libderiv->deriv2_classes[2][6][130];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+138096, dvrr_stack+67228, NULL);
 tmp = dvrr_stack + 138096;
 target_ptr = Libderiv->deriv2_classes[2][7][130];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+138312, dvrr_stack+77518, NULL);
 tmp = dvrr_stack + 138312;
 target_ptr = Libderiv->deriv2_classes[2][8][130];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,150,dvrr_stack+138582, dvrr_stack+78328, NULL);
 tmp = dvrr_stack + 138582;
 target_ptr = Libderiv->deriv2_classes[3][4][130];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,210,dvrr_stack+138732, dvrr_stack+78778, NULL);
 tmp = dvrr_stack + 138732;
 target_ptr = Libderiv->deriv2_classes[3][5][130];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+941, dvrr_stack+79408, NULL);
 tmp = dvrr_stack + 941;
 target_ptr = Libderiv->deriv2_classes[3][6][130];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+138942, dvrr_stack+80248, NULL);
 tmp = dvrr_stack + 138942;
 target_ptr = Libderiv->deriv2_classes[3][7][130];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+139302, dvrr_stack+81328, NULL);
 tmp = dvrr_stack + 139302;
 target_ptr = Libderiv->deriv2_classes[3][8][130];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,225,dvrr_stack+139752, dvrr_stack+82678, NULL);
 tmp = dvrr_stack + 139752;
 target_ptr = Libderiv->deriv2_classes[4][4][130];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+139977, dvrr_stack+83353, NULL);
 tmp = dvrr_stack + 139977;
 target_ptr = Libderiv->deriv2_classes[4][5][130];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+140292, dvrr_stack+84298, NULL);
 tmp = dvrr_stack + 140292;
 target_ptr = Libderiv->deriv2_classes[4][6][130];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+140712, dvrr_stack+85558, NULL);
 tmp = dvrr_stack + 140712;
 target_ptr = Libderiv->deriv2_classes[4][7][130];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+141252, dvrr_stack+87178, NULL);
 tmp = dvrr_stack + 141252;
 target_ptr = Libderiv->deriv2_classes[4][8][130];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,90,dvrr_stack+460, dvrr_stack+2352, NULL);
 tmp = dvrr_stack + 460;
 target_ptr = Libderiv->deriv2_classes[2][4][119];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,126,dvrr_stack+34604, dvrr_stack+4505, NULL);
 tmp = dvrr_stack + 34604;
 target_ptr = Libderiv->deriv2_classes[2][5][119];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,168,dvrr_stack+4403, dvrr_stack+7333, NULL);
 tmp = dvrr_stack + 4403;
 target_ptr = Libderiv->deriv2_classes[2][6][119];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,216,dvrr_stack+7333, dvrr_stack+10929, NULL);
 tmp = dvrr_stack + 7333;
 target_ptr = Libderiv->deriv2_classes[2][7][119];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,270,dvrr_stack+7549, dvrr_stack+15341, NULL);
 tmp = dvrr_stack + 7549;
 target_ptr = Libderiv->deriv2_classes[2][8][119];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,150,dvrr_stack+15341, dvrr_stack+19407, NULL);
 tmp = dvrr_stack + 15341;
 target_ptr = Libderiv->deriv2_classes[3][4][119];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,210,dvrr_stack+19407, dvrr_stack+22641, NULL);
 tmp = dvrr_stack + 19407;
 target_ptr = Libderiv->deriv2_classes[3][5][119];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,280,dvrr_stack+22641, dvrr_stack+26886, NULL);
 tmp = dvrr_stack + 22641;
 target_ptr = Libderiv->deriv2_classes[3][6][119];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,360,dvrr_stack+15491, dvrr_stack+32281, NULL);
 tmp = dvrr_stack + 15491;
 target_ptr = Libderiv->deriv2_classes[3][7][119];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,450,dvrr_stack+32281, dvrr_stack+39086, NULL);
 tmp = dvrr_stack + 32281;
 target_ptr = Libderiv->deriv2_classes[3][8][119];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,225,dvrr_stack+39086, dvrr_stack+45453, NULL);
 tmp = dvrr_stack + 39086;
 target_ptr = Libderiv->deriv2_classes[4][4][119];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,315,dvrr_stack+39311, dvrr_stack+50394, NULL);
 tmp = dvrr_stack + 39311;
 target_ptr = Libderiv->deriv2_classes[4][5][119];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,420,dvrr_stack+39626, dvrr_stack+56874, NULL);
 tmp = dvrr_stack + 39626;
 target_ptr = Libderiv->deriv2_classes[4][6][119];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,540,dvrr_stack+32731, dvrr_stack+65104, NULL);
 tmp = dvrr_stack + 32731;
 target_ptr = Libderiv->deriv2_classes[4][7][119];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,675,dvrr_stack+65053, dvrr_stack+75493, NULL);
 tmp = dvrr_stack + 65053;
 target_ptr = Libderiv->deriv2_classes[4][8][119];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,90,dvrr_stack+33271, dvrr_stack+33416, NULL);
 tmp = dvrr_stack + 33271;
 target_ptr = Libderiv->deriv2_classes[2][4][118];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+40046, dvrr_stack+33686, NULL);
 tmp = dvrr_stack + 40046;
 target_ptr = Libderiv->deriv2_classes[2][5][118];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+40172, dvrr_stack+66724, NULL);
 tmp = dvrr_stack + 40172;
 target_ptr = Libderiv->deriv2_classes[2][6][118];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+22921, dvrr_stack+67228, NULL);
 tmp = dvrr_stack + 22921;
 target_ptr = Libderiv->deriv2_classes[2][7][118];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+15851, dvrr_stack+77518, NULL);
 tmp = dvrr_stack + 15851;
 target_ptr = Libderiv->deriv2_classes[2][8][118];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,150,dvrr_stack+19617, dvrr_stack+78328, NULL);
 tmp = dvrr_stack + 19617;
 target_ptr = Libderiv->deriv2_classes[3][4][118];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+4571, dvrr_stack+78778, NULL);
 tmp = dvrr_stack + 4571;
 target_ptr = Libderiv->deriv2_classes[3][5][118];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+2337, dvrr_stack+79408, NULL);
 tmp = dvrr_stack + 2337;
 target_ptr = Libderiv->deriv2_classes[3][6][118];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+33406, dvrr_stack+80248, NULL);
 tmp = dvrr_stack + 33406;
 target_ptr = Libderiv->deriv2_classes[3][7][118];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+75482, dvrr_stack+81328, NULL);
 tmp = dvrr_stack + 75482;
 target_ptr = Libderiv->deriv2_classes[3][8][118];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,225,dvrr_stack+33766, dvrr_stack+82678, NULL);
 tmp = dvrr_stack + 33766;
 target_ptr = Libderiv->deriv2_classes[4][4][118];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+75932, dvrr_stack+83353, NULL);
 tmp = dvrr_stack + 75932;
 target_ptr = Libderiv->deriv2_classes[4][5][118];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+76247, dvrr_stack+84298, NULL);
 tmp = dvrr_stack + 76247;
 target_ptr = Libderiv->deriv2_classes[4][6][118];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+76667, dvrr_stack+85558, NULL);
 tmp = dvrr_stack + 76667;
 target_ptr = Libderiv->deriv2_classes[4][7][118];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+77207, dvrr_stack+87178, NULL);
 tmp = dvrr_stack + 77207;
 target_ptr = Libderiv->deriv2_classes[4][8][118];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,90,dvrr_stack+19767, dvrr_stack+89203, NULL);
 tmp = dvrr_stack + 19767;
 target_ptr = Libderiv->deriv2_classes[2][4][117];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+23137, dvrr_stack+1812, NULL);
 tmp = dvrr_stack + 23137;
 target_ptr = Libderiv->deriv2_classes[2][5][117];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+40716, dvrr_stack+3749, NULL);
 tmp = dvrr_stack + 40716;
 target_ptr = Libderiv->deriv2_classes[2][6][117];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+1794, dvrr_stack+6325, NULL);
 tmp = dvrr_stack + 1794;
 target_ptr = Libderiv->deriv2_classes[2][7][117];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+6325, dvrr_stack+9633, NULL);
 tmp = dvrr_stack + 6325;
 target_ptr = Libderiv->deriv2_classes[2][8][117];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,150,dvrr_stack+9633, dvrr_stack+13721, NULL);
 tmp = dvrr_stack + 9633;
 target_ptr = Libderiv->deriv2_classes[3][4][117];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+9783, dvrr_stack+18507, NULL);
 tmp = dvrr_stack + 9783;
 target_ptr = Libderiv->deriv2_classes[3][5][117];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+9993, dvrr_stack+21381, NULL);
 tmp = dvrr_stack + 9993;
 target_ptr = Libderiv->deriv2_classes[3][6][117];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+6595, dvrr_stack+25206, NULL);
 tmp = dvrr_stack + 6595;
 target_ptr = Libderiv->deriv2_classes[3][7][117];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+18477, dvrr_stack+30121, NULL);
 tmp = dvrr_stack + 18477;
 target_ptr = Libderiv->deriv2_classes[3][8][117];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,225,dvrr_stack+12088, dvrr_stack+36386, NULL);
 tmp = dvrr_stack + 12088;
 target_ptr = Libderiv->deriv2_classes[4][4][117];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+36386, dvrr_stack+44103, NULL);
 tmp = dvrr_stack + 36386;
 target_ptr = Libderiv->deriv2_classes[4][5][117];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+44023, dvrr_stack+48504, NULL);
 tmp = dvrr_stack + 44023;
 target_ptr = Libderiv->deriv2_classes[4][6][117];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+48462, dvrr_stack+54354, NULL);
 tmp = dvrr_stack + 48462;
 target_ptr = Libderiv->deriv2_classes[4][7][117];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+54310, dvrr_stack+37061, NULL);
 tmp = dvrr_stack + 54310;
 target_ptr = Libderiv->deriv2_classes[4][8][117];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_g(Data,6,1,dvrr_stack+36701, dvrr_stack+71731, dvrr_stack+71671);
 tmp = dvrr_stack + 36701;
 target_ptr = Libderiv->deriv2_classes[2][4][107];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+36791, dvrr_stack+71947, dvrr_stack+71857);
 tmp = dvrr_stack + 36791;
 target_ptr = Libderiv->deriv2_classes[2][5][107];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+36917, dvrr_stack+72115, dvrr_stack+71731);
 tmp = dvrr_stack + 36917;
 target_ptr = Libderiv->deriv2_classes[2][6][107];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+37085, dvrr_stack+19137, dvrr_stack+71947);
 tmp = dvrr_stack + 37085;
 target_ptr = Libderiv->deriv2_classes[2][7][107];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+37301, dvrr_stack+72331, dvrr_stack+72115);
 tmp = dvrr_stack + 37301;
 target_ptr = Libderiv->deriv2_classes[2][8][107];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_g(Data,10,1,dvrr_stack+37571, dvrr_stack+73197, dvrr_stack+73097);
 tmp = dvrr_stack + 37571;
 target_ptr = Libderiv->deriv2_classes[3][4][107];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+18927, dvrr_stack+73557, dvrr_stack+73407);
 tmp = dvrr_stack + 18927;
 target_ptr = Libderiv->deriv2_classes[3][5][107];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+37721, dvrr_stack+6973, dvrr_stack+73197);
 tmp = dvrr_stack + 37721;
 target_ptr = Libderiv->deriv2_classes[3][6][107];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+38001, dvrr_stack+73837, dvrr_stack+73557);
 tmp = dvrr_stack + 38001;
 target_ptr = Libderiv->deriv2_classes[3][7][107];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+38361, dvrr_stack+74287, dvrr_stack+6973);
 tmp = dvrr_stack + 38361;
 target_ptr = Libderiv->deriv2_classes[3][8][107];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_g(Data,15,1,dvrr_stack+38811, dvrr_stack+62314, dvrr_stack+75047);
 tmp = dvrr_stack + 38811;
 target_ptr = Libderiv->deriv2_classes[4][4][107];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+54985, dvrr_stack+22221, dvrr_stack+75197);
 tmp = dvrr_stack + 54985;
 target_ptr = Libderiv->deriv2_classes[4][5][107];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+55300, dvrr_stack+62629, dvrr_stack+62314);
 tmp = dvrr_stack + 55300;
 target_ptr = Libderiv->deriv2_classes[4][6][107];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+49002, dvrr_stack+63169, dvrr_stack+22221);
 tmp = dvrr_stack + 49002;
 target_ptr = Libderiv->deriv2_classes[4][7][107];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+30071, dvrr_stack+63844, dvrr_stack+62629);
 tmp = dvrr_stack + 30071;
 target_ptr = Libderiv->deriv2_classes[4][8][107];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_g(Data,6,1,dvrr_stack+10273, dvrr_stack+64669, dvrr_stack+75422);
 tmp = dvrr_stack + 10273;
 target_ptr = Libderiv->deriv2_classes[2][4][106];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+2010, dvrr_stack+64885, dvrr_stack+64795);
 tmp = dvrr_stack + 2010;
 target_ptr = Libderiv->deriv2_classes[2][5][106];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+55720, dvrr_stack+55974, dvrr_stack+64669);
 tmp = dvrr_stack + 55720;
 target_ptr = Libderiv->deriv2_classes[2][6][106];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+49542, dvrr_stack+56190, dvrr_stack+64885);
 tmp = dvrr_stack + 49542;
 target_ptr = Libderiv->deriv2_classes[2][7][106];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+44443, dvrr_stack+56460, dvrr_stack+55974);
 tmp = dvrr_stack + 44443;
 target_ptr = Libderiv->deriv2_classes[2][8][106];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_g(Data,10,1,dvrr_stack+44713, dvrr_stack+49864, dvrr_stack+49764);
 tmp = dvrr_stack + 44713;
 target_ptr = Libderiv->deriv2_classes[3][4][106];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+30746, dvrr_stack+45048, dvrr_stack+50074);
 tmp = dvrr_stack + 30746;
 target_ptr = Libderiv->deriv2_classes[3][5][106];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+30956, dvrr_stack+31471, dvrr_stack+49864);
 tmp = dvrr_stack + 30956;
 target_ptr = Libderiv->deriv2_classes[3][6][106];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+25156, dvrr_stack+31831, dvrr_stack+45048);
 tmp = dvrr_stack + 25156;
 target_ptr = Libderiv->deriv2_classes[3][7][106];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+25516, dvrr_stack+26286, dvrr_stack+31471);
 tmp = dvrr_stack + 25516;
 target_ptr = Libderiv->deriv2_classes[3][8][106];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_g(Data,15,1,dvrr_stack+31236, dvrr_stack+14171, dvrr_stack+50224);
 tmp = dvrr_stack + 31236;
 target_ptr = Libderiv->deriv2_classes[4][4][106];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+25966, dvrr_stack+14711, dvrr_stack+14486);
 tmp = dvrr_stack + 25966;
 target_ptr = Libderiv->deriv2_classes[4][5][106];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+21361, dvrr_stack+89473, dvrr_stack+14171);
 tmp = dvrr_stack + 21361;
 target_ptr = Libderiv->deriv2_classes[4][6][106];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+3677, dvrr_stack+90013, dvrr_stack+14711);
 tmp = dvrr_stack + 3677;
 target_ptr = Libderiv->deriv2_classes[4][7][106];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+77882, dvrr_stack+90688, dvrr_stack+89473);
 tmp = dvrr_stack + 77882;
 target_ptr = Libderiv->deriv2_classes[4][8][106];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_g(Data,6,1,dvrr_stack+40340, dvrr_stack+71491, dvrr_stack+56790);
 tmp = dvrr_stack + 40340;
 target_ptr = Libderiv->deriv2_classes[2][4][105];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+102687, dvrr_stack+689, dvrr_stack+1434);
 tmp = dvrr_stack + 102687;
 target_ptr = Libderiv->deriv2_classes[2][5][105];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+44863, dvrr_stack+3245, dvrr_stack+71491);
 tmp = dvrr_stack + 44863;
 target_ptr = Libderiv->deriv2_classes[2][6][105];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+21781, dvrr_stack+5677, dvrr_stack+689);
 tmp = dvrr_stack + 21781;
 target_ptr = Libderiv->deriv2_classes[2][7][105];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+13696, dvrr_stack+8823, dvrr_stack+3245);
 tmp = dvrr_stack + 13696;
 target_ptr = Libderiv->deriv2_classes[2][8][105];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_g(Data,10,1,dvrr_stack+21997, dvrr_stack+15131, dvrr_stack+12731);
 tmp = dvrr_stack + 21997;
 target_ptr = Libderiv->deriv2_classes[3][4][105];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+78557, dvrr_stack+16895, dvrr_stack+17877);
 tmp = dvrr_stack + 78557;
 target_ptr = Libderiv->deriv2_classes[3][5][105];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+78767, dvrr_stack+20541, dvrr_stack+15131);
 tmp = dvrr_stack + 78767;
 target_ptr = Libderiv->deriv2_classes[3][6][105];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+79047, dvrr_stack+24126, dvrr_stack+16895);
 tmp = dvrr_stack + 79047;
 target_ptr = Libderiv->deriv2_classes[3][7][105];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+79407, dvrr_stack+28771, dvrr_stack+20541);
 tmp = dvrr_stack + 79407;
 target_ptr = Libderiv->deriv2_classes[3][8][105];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_g(Data,15,1,dvrr_stack+79857, dvrr_stack+61864, dvrr_stack+34736);
 tmp = dvrr_stack + 79857;
 target_ptr = Libderiv->deriv2_classes[4][4][105];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+80082, dvrr_stack+41615, dvrr_stack+43158);
 tmp = dvrr_stack + 80082;
 target_ptr = Libderiv->deriv2_classes[4][5][105];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+80397, dvrr_stack+47244, dvrr_stack+61864);
 tmp = dvrr_stack + 80397;
 target_ptr = Libderiv->deriv2_classes[4][6][105];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+80817, dvrr_stack+52734, dvrr_stack+41615);
 tmp = dvrr_stack + 80817;
 target_ptr = Libderiv->deriv2_classes[4][7][105];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+81357, dvrr_stack+59839, dvrr_stack+47244);
 tmp = dvrr_stack + 81357;
 target_ptr = Libderiv->deriv2_classes[4][8][105];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_g(Data,6,1,dvrr_stack+101399, dvrr_stack+69091, dvrr_stack+69031);
 tmp = dvrr_stack + 101399;
 target_ptr = Libderiv->deriv2_classes[2][4][104];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+0, dvrr_stack+69307, dvrr_stack+69217);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv2_classes[2][5][104];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+13966, dvrr_stack+69475, dvrr_stack+69091);
 tmp = dvrr_stack + 13966;
 target_ptr = Libderiv->deriv2_classes[2][6][104];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+82032, dvrr_stack+69691, dvrr_stack+69307);
 tmp = dvrr_stack + 82032;
 target_ptr = Libderiv->deriv2_classes[2][7][104];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+82248, dvrr_stack+69961, dvrr_stack+69475);
 tmp = dvrr_stack + 82248;
 target_ptr = Libderiv->deriv2_classes[2][8][104];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_g(Data,10,1,dvrr_stack+82518, dvrr_stack+70469, dvrr_stack+70369);
 tmp = dvrr_stack + 82518;
 target_ptr = Libderiv->deriv2_classes[3][4][104];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+82668, dvrr_stack+70829, dvrr_stack+70679);
 tmp = dvrr_stack + 82668;
 target_ptr = Libderiv->deriv2_classes[3][5][104];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+82878, dvrr_stack+60664, dvrr_stack+70469);
 tmp = dvrr_stack + 82878;
 target_ptr = Libderiv->deriv2_classes[3][6][104];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+83158, dvrr_stack+61024, dvrr_stack+70829);
 tmp = dvrr_stack + 83158;
 target_ptr = Libderiv->deriv2_classes[3][7][104];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+83518, dvrr_stack+53409, dvrr_stack+60664);
 tmp = dvrr_stack + 83518;
 target_ptr = Libderiv->deriv2_classes[3][8][104];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_g(Data,15,1,dvrr_stack+83968, dvrr_stack+61474, dvrr_stack+71229);
 tmp = dvrr_stack + 83968;
 target_ptr = Libderiv->deriv2_classes[4][4][104];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+84193, dvrr_stack+47784, dvrr_stack+53959);
 tmp = dvrr_stack + 84193;
 target_ptr = Libderiv->deriv2_classes[4][5][104];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+84508, dvrr_stack+43383, dvrr_stack+61474);
 tmp = dvrr_stack + 84508;
 target_ptr = Libderiv->deriv2_classes[4][6][104];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+84928, dvrr_stack+34886, dvrr_stack+47784);
 tmp = dvrr_stack + 84928;
 target_ptr = Libderiv->deriv2_classes[4][7][104];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+85468, dvrr_stack+35561, dvrr_stack+43383);
 tmp = dvrr_stack + 85468;
 target_ptr = Libderiv->deriv2_classes[4][8][104];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_g(Data,6,1,dvrr_stack+4781, dvrr_stack+71731, dvrr_stack+71671);
 tmp = dvrr_stack + 4781;
 target_ptr = Libderiv->deriv2_classes[2][4][95];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+43016, dvrr_stack+71947, dvrr_stack+71857);
 tmp = dvrr_stack + 43016;
 target_ptr = Libderiv->deriv2_classes[2][5][95];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+86143, dvrr_stack+72115, dvrr_stack+71731);
 tmp = dvrr_stack + 86143;
 target_ptr = Libderiv->deriv2_classes[2][6][95];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+86311, dvrr_stack+19137, dvrr_stack+71947);
 tmp = dvrr_stack + 86311;
 target_ptr = Libderiv->deriv2_classes[2][7][95];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+86527, dvrr_stack+72331, dvrr_stack+72115);
 tmp = dvrr_stack + 86527;
 target_ptr = Libderiv->deriv2_classes[2][8][95];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_g(Data,10,1,dvrr_stack+86797, dvrr_stack+73197, dvrr_stack+73097);
 tmp = dvrr_stack + 86797;
 target_ptr = Libderiv->deriv2_classes[3][4][95];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+86947, dvrr_stack+73557, dvrr_stack+73407);
 tmp = dvrr_stack + 86947;
 target_ptr = Libderiv->deriv2_classes[3][5][95];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+87157, dvrr_stack+6973, dvrr_stack+73197);
 tmp = dvrr_stack + 87157;
 target_ptr = Libderiv->deriv2_classes[3][6][95];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+87437, dvrr_stack+73837, dvrr_stack+73557);
 tmp = dvrr_stack + 87437;
 target_ptr = Libderiv->deriv2_classes[3][7][95];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+87797, dvrr_stack+74287, dvrr_stack+6973);
 tmp = dvrr_stack + 87797;
 target_ptr = Libderiv->deriv2_classes[3][8][95];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_g(Data,15,1,dvrr_stack+88247, dvrr_stack+62314, dvrr_stack+75047);
 tmp = dvrr_stack + 88247;
 target_ptr = Libderiv->deriv2_classes[4][4][95];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+88472, dvrr_stack+22221, dvrr_stack+75197);
 tmp = dvrr_stack + 88472;
 target_ptr = Libderiv->deriv2_classes[4][5][95];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+88787, dvrr_stack+62629, dvrr_stack+62314);
 tmp = dvrr_stack + 88787;
 target_ptr = Libderiv->deriv2_classes[4][6][95];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+65728, dvrr_stack+63169, dvrr_stack+22221);
 tmp = dvrr_stack + 65728;
 target_ptr = Libderiv->deriv2_classes[4][7][95];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+66268, dvrr_stack+63844, dvrr_stack+62629);
 tmp = dvrr_stack + 66268;
 target_ptr = Libderiv->deriv2_classes[4][8][95];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_g(Data,6,1,dvrr_stack+89207, dvrr_stack+64669, dvrr_stack+75422);
 tmp = dvrr_stack + 89207;
 target_ptr = Libderiv->deriv2_classes[2][4][94];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+89297, dvrr_stack+64885, dvrr_stack+64795);
 tmp = dvrr_stack + 89297;
 target_ptr = Libderiv->deriv2_classes[2][5][94];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+66943, dvrr_stack+55974, dvrr_stack+64669);
 tmp = dvrr_stack + 66943;
 target_ptr = Libderiv->deriv2_classes[2][6][94];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+67111, dvrr_stack+56190, dvrr_stack+64885);
 tmp = dvrr_stack + 67111;
 target_ptr = Libderiv->deriv2_classes[2][7][94];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+67327, dvrr_stack+56460, dvrr_stack+55974);
 tmp = dvrr_stack + 67327;
 target_ptr = Libderiv->deriv2_classes[2][8][94];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_g(Data,10,1,dvrr_stack+67597, dvrr_stack+49864, dvrr_stack+49764);
 tmp = dvrr_stack + 67597;
 target_ptr = Libderiv->deriv2_classes[3][4][94];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+56850, dvrr_stack+45048, dvrr_stack+50074);
 tmp = dvrr_stack + 56850;
 target_ptr = Libderiv->deriv2_classes[3][5][94];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+57060, dvrr_stack+31471, dvrr_stack+49864);
 tmp = dvrr_stack + 57060;
 target_ptr = Libderiv->deriv2_classes[3][6][94];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+57340, dvrr_stack+31831, dvrr_stack+45048);
 tmp = dvrr_stack + 57340;
 target_ptr = Libderiv->deriv2_classes[3][7][94];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+50374, dvrr_stack+26286, dvrr_stack+31471);
 tmp = dvrr_stack + 50374;
 target_ptr = Libderiv->deriv2_classes[3][8][94];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_g(Data,15,1,dvrr_stack+57700, dvrr_stack+14171, dvrr_stack+50224);
 tmp = dvrr_stack + 57700;
 target_ptr = Libderiv->deriv2_classes[4][4][94];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+50824, dvrr_stack+14711, dvrr_stack+14486);
 tmp = dvrr_stack + 50824;
 target_ptr = Libderiv->deriv2_classes[4][5][94];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+45436, dvrr_stack+89473, dvrr_stack+14171);
 tmp = dvrr_stack + 45436;
 target_ptr = Libderiv->deriv2_classes[4][6][94];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+26836, dvrr_stack+90013, dvrr_stack+14711);
 tmp = dvrr_stack + 26836;
 target_ptr = Libderiv->deriv2_classes[4][7][94];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+10873, dvrr_stack+90688, dvrr_stack+89473);
 tmp = dvrr_stack + 10873;
 target_ptr = Libderiv->deriv2_classes[4][8][94];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_g(Data,6,1,dvrr_stack+67747, dvrr_stack+71491, dvrr_stack+56790);
 tmp = dvrr_stack + 67747;
 target_ptr = Libderiv->deriv2_classes[2][4][93];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+57925, dvrr_stack+689, dvrr_stack+1434);
 tmp = dvrr_stack + 57925;
 target_ptr = Libderiv->deriv2_classes[2][5][93];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+51139, dvrr_stack+3245, dvrr_stack+71491);
 tmp = dvrr_stack + 51139;
 target_ptr = Libderiv->deriv2_classes[2][6][93];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+45856, dvrr_stack+5677, dvrr_stack+689);
 tmp = dvrr_stack + 45856;
 target_ptr = Libderiv->deriv2_classes[2][7][93];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+11548, dvrr_stack+8823, dvrr_stack+3245);
 tmp = dvrr_stack + 11548;
 target_ptr = Libderiv->deriv2_classes[2][8][93];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_g(Data,10,1,dvrr_stack+27376, dvrr_stack+15131, dvrr_stack+12731);
 tmp = dvrr_stack + 27376;
 target_ptr = Libderiv->deriv2_classes[3][4][93];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+8257, dvrr_stack+16895, dvrr_stack+17877);
 tmp = dvrr_stack + 8257;
 target_ptr = Libderiv->deriv2_classes[3][5][93];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+141927, dvrr_stack+20541, dvrr_stack+15131);
 tmp = dvrr_stack + 141927;
 target_ptr = Libderiv->deriv2_classes[3][6][93];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+142207, dvrr_stack+24126, dvrr_stack+16895);
 tmp = dvrr_stack + 142207;
 target_ptr = Libderiv->deriv2_classes[3][7][93];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+142567, dvrr_stack+28771, dvrr_stack+20541);
 tmp = dvrr_stack + 142567;
 target_ptr = Libderiv->deriv2_classes[3][8][93];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_g(Data,15,1,dvrr_stack+143017, dvrr_stack+61864, dvrr_stack+34736);
 tmp = dvrr_stack + 143017;
 target_ptr = Libderiv->deriv2_classes[4][4][93];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+143242, dvrr_stack+41615, dvrr_stack+43158);
 tmp = dvrr_stack + 143242;
 target_ptr = Libderiv->deriv2_classes[4][5][93];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+143557, dvrr_stack+47244, dvrr_stack+61864);
 tmp = dvrr_stack + 143557;
 target_ptr = Libderiv->deriv2_classes[4][6][93];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+143977, dvrr_stack+52734, dvrr_stack+41615);
 tmp = dvrr_stack + 143977;
 target_ptr = Libderiv->deriv2_classes[4][7][93];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+144517, dvrr_stack+59839, dvrr_stack+47244);
 tmp = dvrr_stack + 144517;
 target_ptr = Libderiv->deriv2_classes[4][8][93];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_g(Data,6,1,dvrr_stack+145192, dvrr_stack+69091, dvrr_stack+69031);
 tmp = dvrr_stack + 145192;
 target_ptr = Libderiv->deriv2_classes[2][4][92];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+145282, dvrr_stack+69307, dvrr_stack+69217);
 tmp = dvrr_stack + 145282;
 target_ptr = Libderiv->deriv2_classes[2][5][92];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+145408, dvrr_stack+69475, dvrr_stack+69091);
 tmp = dvrr_stack + 145408;
 target_ptr = Libderiv->deriv2_classes[2][6][92];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+145576, dvrr_stack+69691, dvrr_stack+69307);
 tmp = dvrr_stack + 145576;
 target_ptr = Libderiv->deriv2_classes[2][7][92];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+145792, dvrr_stack+69961, dvrr_stack+69475);
 tmp = dvrr_stack + 145792;
 target_ptr = Libderiv->deriv2_classes[2][8][92];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_g(Data,10,1,dvrr_stack+146062, dvrr_stack+70469, dvrr_stack+70369);
 tmp = dvrr_stack + 146062;
 target_ptr = Libderiv->deriv2_classes[3][4][92];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+146212, dvrr_stack+70829, dvrr_stack+70679);
 tmp = dvrr_stack + 146212;
 target_ptr = Libderiv->deriv2_classes[3][5][92];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+146422, dvrr_stack+60664, dvrr_stack+70469);
 tmp = dvrr_stack + 146422;
 target_ptr = Libderiv->deriv2_classes[3][6][92];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+146702, dvrr_stack+61024, dvrr_stack+70829);
 tmp = dvrr_stack + 146702;
 target_ptr = Libderiv->deriv2_classes[3][7][92];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+147062, dvrr_stack+53409, dvrr_stack+60664);
 tmp = dvrr_stack + 147062;
 target_ptr = Libderiv->deriv2_classes[3][8][92];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_g(Data,15,1,dvrr_stack+147512, dvrr_stack+61474, dvrr_stack+71229);
 tmp = dvrr_stack + 147512;
 target_ptr = Libderiv->deriv2_classes[4][4][92];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+147737, dvrr_stack+47784, dvrr_stack+53959);
 tmp = dvrr_stack + 147737;
 target_ptr = Libderiv->deriv2_classes[4][5][92];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+148052, dvrr_stack+43383, dvrr_stack+61474);
 tmp = dvrr_stack + 148052;
 target_ptr = Libderiv->deriv2_classes[4][6][92];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+148472, dvrr_stack+34886, dvrr_stack+47784);
 tmp = dvrr_stack + 148472;
 target_ptr = Libderiv->deriv2_classes[4][7][92];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+149012, dvrr_stack+35561, dvrr_stack+43383);
 tmp = dvrr_stack + 149012;
 target_ptr = Libderiv->deriv2_classes[4][8][92];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_g(Data,6,1,dvrr_stack+149687, dvrr_stack+54184, dvrr_stack+71379);
 tmp = dvrr_stack + 149687;
 target_ptr = Libderiv->deriv2_classes[2][4][91];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+149777, dvrr_stack+48294, dvrr_stack+48204);
 tmp = dvrr_stack + 149777;
 target_ptr = Libderiv->deriv2_classes[2][5][91];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+27526, dvrr_stack+42035, dvrr_stack+54184);
 tmp = dvrr_stack + 27526;
 target_ptr = Libderiv->deriv2_classes[2][6][91];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+149903, dvrr_stack+29321, dvrr_stack+48294);
 tmp = dvrr_stack + 149903;
 target_ptr = Libderiv->deriv2_classes[2][7][91];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+150119, dvrr_stack+29591, dvrr_stack+42035);
 tmp = dvrr_stack + 150119;
 target_ptr = Libderiv->deriv2_classes[2][8][91];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_g(Data,10,1,dvrr_stack+150389, dvrr_stack+24576, dvrr_stack+43923);
 tmp = dvrr_stack + 150389;
 target_ptr = Libderiv->deriv2_classes[3][4][91];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+150539, dvrr_stack+24786, dvrr_stack+29921);
 tmp = dvrr_stack + 150539;
 target_ptr = Libderiv->deriv2_classes[3][5][91];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+150749, dvrr_stack+20901, dvrr_stack+24576);
 tmp = dvrr_stack + 150749;
 target_ptr = Libderiv->deriv2_classes[3][6][91];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+151029, dvrr_stack+18027, dvrr_stack+24786);
 tmp = dvrr_stack + 151029;
 target_ptr = Libderiv->deriv2_classes[3][7][91];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+151389, dvrr_stack+12831, dvrr_stack+20901);
 tmp = dvrr_stack + 151389;
 target_ptr = Libderiv->deriv2_classes[3][8][91];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_g(Data,15,1,dvrr_stack+151839, dvrr_stack+13381, dvrr_stack+17175);
 tmp = dvrr_stack + 151839;
 target_ptr = Libderiv->deriv2_classes[4][4][91];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+152064, dvrr_stack+9153, dvrr_stack+72797);
 tmp = dvrr_stack + 152064;
 target_ptr = Libderiv->deriv2_classes[4][5][91];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+152379, dvrr_stack+91513, dvrr_stack+13381);
 tmp = dvrr_stack + 152379;
 target_ptr = Libderiv->deriv2_classes[4][6][91];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+152799, dvrr_stack+92053, dvrr_stack+9153);
 tmp = dvrr_stack + 152799;
 target_ptr = Libderiv->deriv2_classes[4][7][91];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+153339, dvrr_stack+92728, dvrr_stack+91513);
 tmp = dvrr_stack + 153339;
 target_ptr = Libderiv->deriv2_classes[4][8][91];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_g(Data,6,1,dvrr_stack+154014, dvrr_stack+71731, dvrr_stack+71671);
 tmp = dvrr_stack + 154014;
 target_ptr = Libderiv->deriv2_classes[2][4][83];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+154104, dvrr_stack+71947, dvrr_stack+71857);
 tmp = dvrr_stack + 154104;
 target_ptr = Libderiv->deriv2_classes[2][5][83];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+154230, dvrr_stack+72115, dvrr_stack+71731);
 tmp = dvrr_stack + 154230;
 target_ptr = Libderiv->deriv2_classes[2][6][83];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+154398, dvrr_stack+19137, dvrr_stack+71947);
 tmp = dvrr_stack + 154398;
 target_ptr = Libderiv->deriv2_classes[2][7][83];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+154614, dvrr_stack+72331, dvrr_stack+72115);
 tmp = dvrr_stack + 154614;
 target_ptr = Libderiv->deriv2_classes[2][8][83];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_g(Data,10,1,dvrr_stack+72331, dvrr_stack+73197, dvrr_stack+73097);
 tmp = dvrr_stack + 72331;
 target_ptr = Libderiv->deriv2_classes[3][4][83];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+154884, dvrr_stack+73557, dvrr_stack+73407);
 tmp = dvrr_stack + 154884;
 target_ptr = Libderiv->deriv2_classes[3][5][83];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+155094, dvrr_stack+6973, dvrr_stack+73197);
 tmp = dvrr_stack + 155094;
 target_ptr = Libderiv->deriv2_classes[3][6][83];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+155374, dvrr_stack+73837, dvrr_stack+73557);
 tmp = dvrr_stack + 155374;
 target_ptr = Libderiv->deriv2_classes[3][7][83];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+155734, dvrr_stack+74287, dvrr_stack+6973);
 tmp = dvrr_stack + 155734;
 target_ptr = Libderiv->deriv2_classes[3][8][83];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_g(Data,15,1,dvrr_stack+74287, dvrr_stack+62314, dvrr_stack+75047);
 tmp = dvrr_stack + 74287;
 target_ptr = Libderiv->deriv2_classes[4][4][83];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+74512, dvrr_stack+22221, dvrr_stack+75197);
 tmp = dvrr_stack + 74512;
 target_ptr = Libderiv->deriv2_classes[4][5][83];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+156184, dvrr_stack+62629, dvrr_stack+62314);
 tmp = dvrr_stack + 156184;
 target_ptr = Libderiv->deriv2_classes[4][6][83];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+156604, dvrr_stack+63169, dvrr_stack+22221);
 tmp = dvrr_stack + 156604;
 target_ptr = Libderiv->deriv2_classes[4][7][83];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+157144, dvrr_stack+63844, dvrr_stack+62629);
 tmp = dvrr_stack + 157144;
 target_ptr = Libderiv->deriv2_classes[4][8][83];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_g(Data,6,1,dvrr_stack+63844, dvrr_stack+64669, dvrr_stack+75422);
 tmp = dvrr_stack + 63844;
 target_ptr = Libderiv->deriv2_classes[2][4][82];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+63934, dvrr_stack+64885, dvrr_stack+64795);
 tmp = dvrr_stack + 63934;
 target_ptr = Libderiv->deriv2_classes[2][5][82];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+75029, dvrr_stack+55974, dvrr_stack+64669);
 tmp = dvrr_stack + 75029;
 target_ptr = Libderiv->deriv2_classes[2][6][82];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+64060, dvrr_stack+56190, dvrr_stack+64885);
 tmp = dvrr_stack + 64060;
 target_ptr = Libderiv->deriv2_classes[2][7][82];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+64276, dvrr_stack+56460, dvrr_stack+55974);
 tmp = dvrr_stack + 64276;
 target_ptr = Libderiv->deriv2_classes[2][8][82];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_g(Data,10,1,dvrr_stack+56460, dvrr_stack+49864, dvrr_stack+49764);
 tmp = dvrr_stack + 56460;
 target_ptr = Libderiv->deriv2_classes[3][4][82];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+157819, dvrr_stack+45048, dvrr_stack+50074);
 tmp = dvrr_stack + 157819;
 target_ptr = Libderiv->deriv2_classes[3][5][82];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+158029, dvrr_stack+31471, dvrr_stack+49864);
 tmp = dvrr_stack + 158029;
 target_ptr = Libderiv->deriv2_classes[3][6][82];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+158309, dvrr_stack+31831, dvrr_stack+45048);
 tmp = dvrr_stack + 158309;
 target_ptr = Libderiv->deriv2_classes[3][7][82];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+158669, dvrr_stack+26286, dvrr_stack+31471);
 tmp = dvrr_stack + 158669;
 target_ptr = Libderiv->deriv2_classes[3][8][82];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_g(Data,15,1,dvrr_stack+159119, dvrr_stack+14171, dvrr_stack+50224);
 tmp = dvrr_stack + 159119;
 target_ptr = Libderiv->deriv2_classes[4][4][82];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+159344, dvrr_stack+14711, dvrr_stack+14486);
 tmp = dvrr_stack + 159344;
 target_ptr = Libderiv->deriv2_classes[4][5][82];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+26281, dvrr_stack+89473, dvrr_stack+14171);
 tmp = dvrr_stack + 26281;
 target_ptr = Libderiv->deriv2_classes[4][6][82];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+159659, dvrr_stack+90013, dvrr_stack+14711);
 tmp = dvrr_stack + 159659;
 target_ptr = Libderiv->deriv2_classes[4][7][82];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+160199, dvrr_stack+90688, dvrr_stack+89473);
 tmp = dvrr_stack + 160199;
 target_ptr = Libderiv->deriv2_classes[4][8][82];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_g(Data,6,1,dvrr_stack+90688, dvrr_stack+71491, dvrr_stack+56790);
 tmp = dvrr_stack + 90688;
 target_ptr = Libderiv->deriv2_classes[2][4][81];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+90778, dvrr_stack+689, dvrr_stack+1434);
 tmp = dvrr_stack + 90778;
 target_ptr = Libderiv->deriv2_classes[2][5][81];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+90904, dvrr_stack+3245, dvrr_stack+71491);
 tmp = dvrr_stack + 90904;
 target_ptr = Libderiv->deriv2_classes[2][6][81];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+91072, dvrr_stack+5677, dvrr_stack+689);
 tmp = dvrr_stack + 91072;
 target_ptr = Libderiv->deriv2_classes[2][7][81];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+160874, dvrr_stack+8823, dvrr_stack+3245);
 tmp = dvrr_stack + 160874;
 target_ptr = Libderiv->deriv2_classes[2][8][81];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_g(Data,10,1,dvrr_stack+50224, dvrr_stack+15131, dvrr_stack+12731);
 tmp = dvrr_stack + 50224;
 target_ptr = Libderiv->deriv2_classes[3][4][81];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+8823, dvrr_stack+16895, dvrr_stack+17877);
 tmp = dvrr_stack + 8823;
 target_ptr = Libderiv->deriv2_classes[3][5][81];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+161144, dvrr_stack+20541, dvrr_stack+15131);
 tmp = dvrr_stack + 161144;
 target_ptr = Libderiv->deriv2_classes[3][6][81];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+161424, dvrr_stack+24126, dvrr_stack+16895);
 tmp = dvrr_stack + 161424;
 target_ptr = Libderiv->deriv2_classes[3][7][81];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+161784, dvrr_stack+28771, dvrr_stack+20541);
 tmp = dvrr_stack + 161784;
 target_ptr = Libderiv->deriv2_classes[3][8][81];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_g(Data,15,1,dvrr_stack+91288, dvrr_stack+61864, dvrr_stack+34736);
 tmp = dvrr_stack + 91288;
 target_ptr = Libderiv->deriv2_classes[4][4][81];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+162234, dvrr_stack+41615, dvrr_stack+43158);
 tmp = dvrr_stack + 162234;
 target_ptr = Libderiv->deriv2_classes[4][5][81];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+162549, dvrr_stack+47244, dvrr_stack+61864);
 tmp = dvrr_stack + 162549;
 target_ptr = Libderiv->deriv2_classes[4][6][81];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+28755, dvrr_stack+52734, dvrr_stack+41615);
 tmp = dvrr_stack + 28755;
 target_ptr = Libderiv->deriv2_classes[4][7][81];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+162969, dvrr_stack+59839, dvrr_stack+47244);
 tmp = dvrr_stack + 162969;
 target_ptr = Libderiv->deriv2_classes[4][8][81];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_g(Data,6,1,dvrr_stack+9033, dvrr_stack+69091, dvrr_stack+69031);
 tmp = dvrr_stack + 9033;
 target_ptr = Libderiv->deriv2_classes[2][4][80];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+56610, dvrr_stack+69307, dvrr_stack+69217);
 tmp = dvrr_stack + 56610;
 target_ptr = Libderiv->deriv2_classes[2][5][80];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+72481, dvrr_stack+69475, dvrr_stack+69091);
 tmp = dvrr_stack + 72481;
 target_ptr = Libderiv->deriv2_classes[2][6][80];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+163644, dvrr_stack+69691, dvrr_stack+69307);
 tmp = dvrr_stack + 163644;
 target_ptr = Libderiv->deriv2_classes[2][7][80];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+59829, dvrr_stack+69961, dvrr_stack+69475);
 tmp = dvrr_stack + 59829;
 target_ptr = Libderiv->deriv2_classes[2][8][80];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_g(Data,10,1,dvrr_stack+69961, dvrr_stack+70469, dvrr_stack+70369);
 tmp = dvrr_stack + 69961;
 target_ptr = Libderiv->deriv2_classes[3][4][80];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+70111, dvrr_stack+70829, dvrr_stack+70679);
 tmp = dvrr_stack + 70111;
 target_ptr = Libderiv->deriv2_classes[3][5][80];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+60099, dvrr_stack+60664, dvrr_stack+70469);
 tmp = dvrr_stack + 60099;
 target_ptr = Libderiv->deriv2_classes[3][6][80];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+163860, dvrr_stack+61024, dvrr_stack+70829);
 tmp = dvrr_stack + 163860;
 target_ptr = Libderiv->deriv2_classes[3][7][80];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+164220, dvrr_stack+53409, dvrr_stack+60664);
 tmp = dvrr_stack + 164220;
 target_ptr = Libderiv->deriv2_classes[3][8][80];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_g(Data,15,1,dvrr_stack+53409, dvrr_stack+61474, dvrr_stack+71229);
 tmp = dvrr_stack + 53409;
 target_ptr = Libderiv->deriv2_classes[4][4][80];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+53634, dvrr_stack+47784, dvrr_stack+53959);
 tmp = dvrr_stack + 53634;
 target_ptr = Libderiv->deriv2_classes[4][5][80];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+164670, dvrr_stack+43383, dvrr_stack+61474);
 tmp = dvrr_stack + 164670;
 target_ptr = Libderiv->deriv2_classes[4][6][80];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+165090, dvrr_stack+34886, dvrr_stack+47784);
 tmp = dvrr_stack + 165090;
 target_ptr = Libderiv->deriv2_classes[4][7][80];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+165630, dvrr_stack+35561, dvrr_stack+43383);
 tmp = dvrr_stack + 165630;
 target_ptr = Libderiv->deriv2_classes[4][8][80];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_g(Data,6,1,dvrr_stack+35561, dvrr_stack+54184, dvrr_stack+71379);
 tmp = dvrr_stack + 35561;
 target_ptr = Libderiv->deriv2_classes[2][4][79];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+35651, dvrr_stack+48294, dvrr_stack+48204);
 tmp = dvrr_stack + 35651;
 target_ptr = Libderiv->deriv2_classes[2][5][79];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+35777, dvrr_stack+42035, dvrr_stack+54184);
 tmp = dvrr_stack + 35777;
 target_ptr = Libderiv->deriv2_classes[2][6][79];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+35945, dvrr_stack+29321, dvrr_stack+48294);
 tmp = dvrr_stack + 35945;
 target_ptr = Libderiv->deriv2_classes[2][7][79];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+166305, dvrr_stack+29591, dvrr_stack+42035);
 tmp = dvrr_stack + 166305;
 target_ptr = Libderiv->deriv2_classes[2][8][79];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_g(Data,10,1,dvrr_stack+29591, dvrr_stack+24576, dvrr_stack+43923);
 tmp = dvrr_stack + 29591;
 target_ptr = Libderiv->deriv2_classes[3][4][79];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+36161, dvrr_stack+24786, dvrr_stack+29921);
 tmp = dvrr_stack + 36161;
 target_ptr = Libderiv->deriv2_classes[3][5][79];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+166575, dvrr_stack+20901, dvrr_stack+24576);
 tmp = dvrr_stack + 166575;
 target_ptr = Libderiv->deriv2_classes[3][6][79];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+166855, dvrr_stack+18027, dvrr_stack+24786);
 tmp = dvrr_stack + 166855;
 target_ptr = Libderiv->deriv2_classes[3][7][79];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+167215, dvrr_stack+12831, dvrr_stack+20901);
 tmp = dvrr_stack + 167215;
 target_ptr = Libderiv->deriv2_classes[3][8][79];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_g(Data,15,1,dvrr_stack+167665, dvrr_stack+13381, dvrr_stack+17175);
 tmp = dvrr_stack + 167665;
 target_ptr = Libderiv->deriv2_classes[4][4][79];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+71172, dvrr_stack+9153, dvrr_stack+72797);
 tmp = dvrr_stack + 71172;
 target_ptr = Libderiv->deriv2_classes[4][5][79];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+12687, dvrr_stack+91513, dvrr_stack+13381);
 tmp = dvrr_stack + 12687;
 target_ptr = Libderiv->deriv2_classes[4][6][79];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+167890, dvrr_stack+92053, dvrr_stack+9153);
 tmp = dvrr_stack + 167890;
 target_ptr = Libderiv->deriv2_classes[4][7][79];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+168430, dvrr_stack+92728, dvrr_stack+91513);
 tmp = dvrr_stack + 168430;
 target_ptr = Libderiv->deriv2_classes[4][8][79];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_g(Data,6,1,dvrr_stack+92728, dvrr_stack+62179, dvrr_stack+9573);
 tmp = dvrr_stack + 92728;
 target_ptr = Libderiv->deriv2_classes[2][4][78];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+92818, dvrr_stack+5947, dvrr_stack+25066);
 tmp = dvrr_stack + 92818;
 target_ptr = Libderiv->deriv2_classes[2][5][78];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+92944, dvrr_stack+3461, dvrr_stack+62179);
 tmp = dvrr_stack + 92944;
 target_ptr = Libderiv->deriv2_classes[2][6][78];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+93112, dvrr_stack+1524, dvrr_stack+5947);
 tmp = dvrr_stack + 93112;
 target_ptr = Libderiv->deriv2_classes[2][7][78];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+169105, dvrr_stack+8493, dvrr_stack+3461);
 tmp = dvrr_stack + 169105;
 target_ptr = Libderiv->deriv2_classes[2][8][78];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_g(Data,10,1,dvrr_stack+17175, dvrr_stack+6115, dvrr_stack+21261);
 tmp = dvrr_stack + 17175;
 target_ptr = Libderiv->deriv2_classes[3][4][78];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+93328, dvrr_stack+10593, dvrr_stack+10443);
 tmp = dvrr_stack + 93328;
 target_ptr = Libderiv->deriv2_classes[3][5][78];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+169375, dvrr_stack+12327, dvrr_stack+6115);
 tmp = dvrr_stack + 169375;
 target_ptr = Libderiv->deriv2_classes[3][6][78];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+169655, dvrr_stack+93553, dvrr_stack+10593);
 tmp = dvrr_stack + 169655;
 target_ptr = Libderiv->deriv2_classes[3][7][78];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+170015, dvrr_stack+94003, dvrr_stack+12327);
 tmp = dvrr_stack + 170015;
 target_ptr = Libderiv->deriv2_classes[3][8][78];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_g(Data,15,1,dvrr_stack+94003, dvrr_stack+34064, dvrr_stack+4253);
 tmp = dvrr_stack + 94003;
 target_ptr = Libderiv->deriv2_classes[4][4][78];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+94228, dvrr_stack+94553, dvrr_stack+34379);
 tmp = dvrr_stack + 94228;
 target_ptr = Libderiv->deriv2_classes[4][5][78];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+170465, dvrr_stack+94973, dvrr_stack+34064);
 tmp = dvrr_stack + 170465;
 target_ptr = Libderiv->deriv2_classes[4][6][78];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+170885, dvrr_stack+95513, dvrr_stack+94553);
 tmp = dvrr_stack + 170885;
 target_ptr = Libderiv->deriv2_classes[4][7][78];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+171425, dvrr_stack+96188, dvrr_stack+94973);
 tmp = dvrr_stack + 171425;
 target_ptr = Libderiv->deriv2_classes[4][8][78];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,15,dvrr_stack+96188, dvrr_stack+73407, dvrr_stack+145);
 tmp = dvrr_stack + 96188;
 target_ptr = Libderiv->deriv2_classes[2][4][35];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,21,dvrr_stack+96278, dvrr_stack+73197, dvrr_stack+71109);
 tmp = dvrr_stack + 96278;
 target_ptr = Libderiv->deriv2_classes[2][5][35];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,28,dvrr_stack+96404, dvrr_stack+73557, dvrr_stack+857);
 tmp = dvrr_stack + 96404;
 target_ptr = Libderiv->deriv2_classes[2][6][35];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,36,dvrr_stack+96572, dvrr_stack+6973, dvrr_stack+45328);
 tmp = dvrr_stack + 96572;
 target_ptr = Libderiv->deriv2_classes[2][7][35];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,45,dvrr_stack+172100, dvrr_stack+73837, dvrr_stack+68857);
 tmp = dvrr_stack + 172100;
 target_ptr = Libderiv->deriv2_classes[2][8][35];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,15,dvrr_stack+96788, dvrr_stack+75197, dvrr_stack+71857);
 tmp = dvrr_stack + 96788;
 target_ptr = Libderiv->deriv2_classes[3][4][35];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,21,dvrr_stack+172370, dvrr_stack+62314, dvrr_stack+71731);
 tmp = dvrr_stack + 172370;
 target_ptr = Libderiv->deriv2_classes[3][5][35];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,28,dvrr_stack+172580, dvrr_stack+22221, dvrr_stack+71947);
 tmp = dvrr_stack + 172580;
 target_ptr = Libderiv->deriv2_classes[3][6][35];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,36,dvrr_stack+172860, dvrr_stack+62629, dvrr_stack+72115);
 tmp = dvrr_stack + 172860;
 target_ptr = Libderiv->deriv2_classes[3][7][35];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,45,dvrr_stack+173220, dvrr_stack+63169, dvrr_stack+19137);
 tmp = dvrr_stack + 173220;
 target_ptr = Libderiv->deriv2_classes[3][8][35];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,15,dvrr_stack+173670, dvrr_stack+99740, dvrr_stack+73407);
 tmp = dvrr_stack + 173670;
 target_ptr = Libderiv->deriv2_classes[4][4][35];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,21,dvrr_stack+8467, dvrr_stack+102834, dvrr_stack+73197);
 tmp = dvrr_stack + 8467;
 target_ptr = Libderiv->deriv2_classes[4][5][35];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,28,dvrr_stack+173895, dvrr_stack+106911, dvrr_stack+73557);
 tmp = dvrr_stack + 173895;
 target_ptr = Libderiv->deriv2_classes[4][6][35];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,36,dvrr_stack+174315, dvrr_stack+112107, dvrr_stack+6973);
 tmp = dvrr_stack + 174315;
 target_ptr = Libderiv->deriv2_classes[4][7][35];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,45,dvrr_stack+174855, dvrr_stack+58134, dvrr_stack+73837);
 tmp = dvrr_stack + 174855;
 target_ptr = Libderiv->deriv2_classes[4][8][35];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,15,dvrr_stack+21261, dvrr_stack+50074, dvrr_stack+59079);
 tmp = dvrr_stack + 21261;
 target_ptr = Libderiv->deriv2_classes[2][4][34];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+29741, dvrr_stack+49864, dvrr_stack+59124);
 tmp = dvrr_stack + 29741;
 target_ptr = Libderiv->deriv2_classes[2][5][34];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+175530, dvrr_stack+45048, dvrr_stack+59187);
 tmp = dvrr_stack + 175530;
 target_ptr = Libderiv->deriv2_classes[2][6][34];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+175698, dvrr_stack+31471, dvrr_stack+59271);
 tmp = dvrr_stack + 175698;
 target_ptr = Libderiv->deriv2_classes[2][7][34];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+60379, dvrr_stack+31831, dvrr_stack+59379);
 tmp = dvrr_stack + 60379;
 target_ptr = Libderiv->deriv2_classes[2][8][34];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,15,dvrr_stack+34730, dvrr_stack+14486, dvrr_stack+64795);
 tmp = dvrr_stack + 34730;
 target_ptr = Libderiv->deriv2_classes[3][4][34];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+13107, dvrr_stack+14171, dvrr_stack+64669);
 tmp = dvrr_stack + 13107;
 target_ptr = Libderiv->deriv2_classes[3][5][34];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+175914, dvrr_stack+14711, dvrr_stack+64885);
 tmp = dvrr_stack + 175914;
 target_ptr = Libderiv->deriv2_classes[3][6][34];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+176194, dvrr_stack+89473, dvrr_stack+55974);
 tmp = dvrr_stack + 176194;
 target_ptr = Libderiv->deriv2_classes[3][7][34];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+176554, dvrr_stack+90013, dvrr_stack+56190);
 tmp = dvrr_stack + 176554;
 target_ptr = Libderiv->deriv2_classes[3][8][34];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,15,dvrr_stack+177004, dvrr_stack+59514, dvrr_stack+50074);
 tmp = dvrr_stack + 177004;
 target_ptr = Libderiv->deriv2_classes[4][4][34];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+177229, dvrr_stack+27726, dvrr_stack+49864);
 tmp = dvrr_stack + 177229;
 target_ptr = Libderiv->deriv2_classes[4][5][34];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+177544, dvrr_stack+28167, dvrr_stack+45048);
 tmp = dvrr_stack + 177544;
 target_ptr = Libderiv->deriv2_classes[4][6][34];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+177964, dvrr_stack+112863, dvrr_stack+31471);
 tmp = dvrr_stack + 177964;
 target_ptr = Libderiv->deriv2_classes[4][7][34];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+178504, dvrr_stack+113619, dvrr_stack+31831);
 tmp = dvrr_stack + 178504;
 target_ptr = Libderiv->deriv2_classes[4][8][34];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,15,dvrr_stack+43923, dvrr_stack+17877, dvrr_stack+33361);
 tmp = dvrr_stack + 43923;
 target_ptr = Libderiv->deriv2_classes[2][4][33];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+70321, dvrr_stack+15131, dvrr_stack+2190);
 tmp = dvrr_stack + 70321;
 target_ptr = Libderiv->deriv2_classes[2][5][33];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+179179, dvrr_stack+16895, dvrr_stack+2253);
 tmp = dvrr_stack + 179179;
 target_ptr = Libderiv->deriv2_classes[2][6][33];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+179347, dvrr_stack+20541, dvrr_stack+67876);
 tmp = dvrr_stack + 179347;
 target_ptr = Libderiv->deriv2_classes[2][7][33];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+179563, dvrr_stack+24126, dvrr_stack+67984);
 tmp = dvrr_stack + 179563;
 target_ptr = Libderiv->deriv2_classes[2][8][33];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,15,dvrr_stack+179833, dvrr_stack+43158, dvrr_stack+1434);
 tmp = dvrr_stack + 179833;
 target_ptr = Libderiv->deriv2_classes[3][4][33];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+179983, dvrr_stack+61864, dvrr_stack+71491);
 tmp = dvrr_stack + 179983;
 target_ptr = Libderiv->deriv2_classes[3][5][33];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+180193, dvrr_stack+41615, dvrr_stack+689);
 tmp = dvrr_stack + 180193;
 target_ptr = Libderiv->deriv2_classes[3][6][33];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+180473, dvrr_stack+47244, dvrr_stack+3245);
 tmp = dvrr_stack + 180473;
 target_ptr = Libderiv->deriv2_classes[3][7][33];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+180833, dvrr_stack+52734, dvrr_stack+5677);
 tmp = dvrr_stack + 180833;
 target_ptr = Libderiv->deriv2_classes[3][8][33];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,15,dvrr_stack+181283, dvrr_stack+68119, dvrr_stack+17877);
 tmp = dvrr_stack + 181283;
 target_ptr = Libderiv->deriv2_classes[4][4][33];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+181508, dvrr_stack+98795, dvrr_stack+15131);
 tmp = dvrr_stack + 181508;
 target_ptr = Libderiv->deriv2_classes[4][5][33];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+181823, dvrr_stack+101511, dvrr_stack+16895);
 tmp = dvrr_stack + 181823;
 target_ptr = Libderiv->deriv2_classes[4][6][33];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+182243, dvrr_stack+105147, dvrr_stack+20541);
 tmp = dvrr_stack + 182243;
 target_ptr = Libderiv->deriv2_classes[4][7][33];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+182783, dvrr_stack+109839, dvrr_stack+24126);
 tmp = dvrr_stack + 182783;
 target_ptr = Libderiv->deriv2_classes[4][8][33];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,15,dvrr_stack+56736, dvrr_stack+70679, dvrr_stack+115723);
 tmp = dvrr_stack + 56736;
 target_ptr = Libderiv->deriv2_classes[2][4][32];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+183458, dvrr_stack+70469, dvrr_stack+115768);
 tmp = dvrr_stack + 183458;
 target_ptr = Libderiv->deriv2_classes[2][5][32];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+183584, dvrr_stack+70829, dvrr_stack+115831);
 tmp = dvrr_stack + 183584;
 target_ptr = Libderiv->deriv2_classes[2][6][32];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+183752, dvrr_stack+60664, dvrr_stack+115915);
 tmp = dvrr_stack + 183752;
 target_ptr = Libderiv->deriv2_classes[2][7][32];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+183968, dvrr_stack+61024, dvrr_stack+116023);
 tmp = dvrr_stack + 183968;
 target_ptr = Libderiv->deriv2_classes[2][8][32];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,15,dvrr_stack+184238, dvrr_stack+53959, dvrr_stack+69217);
 tmp = dvrr_stack + 184238;
 target_ptr = Libderiv->deriv2_classes[3][4][32];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+184388, dvrr_stack+61474, dvrr_stack+69091);
 tmp = dvrr_stack + 184388;
 target_ptr = Libderiv->deriv2_classes[3][5][32];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+184598, dvrr_stack+47784, dvrr_stack+69307);
 tmp = dvrr_stack + 184598;
 target_ptr = Libderiv->deriv2_classes[3][6][32];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+184878, dvrr_stack+43383, dvrr_stack+69475);
 tmp = dvrr_stack + 184878;
 target_ptr = Libderiv->deriv2_classes[3][7][32];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+185238, dvrr_stack+34886, dvrr_stack+69691);
 tmp = dvrr_stack + 185238;
 target_ptr = Libderiv->deriv2_classes[3][8][32];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,15,dvrr_stack+185688, dvrr_stack+116494, dvrr_stack+70679);
 tmp = dvrr_stack + 185688;
 target_ptr = Libderiv->deriv2_classes[4][4][32];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+185913, dvrr_stack+116809, dvrr_stack+70469);
 tmp = dvrr_stack + 185913;
 target_ptr = Libderiv->deriv2_classes[4][5][32];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+186228, dvrr_stack+117250, dvrr_stack+70829);
 tmp = dvrr_stack + 186228;
 target_ptr = Libderiv->deriv2_classes[4][6][32];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+186648, dvrr_stack+117838, dvrr_stack+60664);
 tmp = dvrr_stack + 186648;
 target_ptr = Libderiv->deriv2_classes[4][7][32];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+187188, dvrr_stack+110784, dvrr_stack+61024);
 tmp = dvrr_stack + 187188;
 target_ptr = Libderiv->deriv2_classes[4][8][32];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,15,dvrr_stack+64546, dvrr_stack+29921, dvrr_stack+72661);
 tmp = dvrr_stack + 64546;
 target_ptr = Libderiv->deriv2_classes[2][4][31];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+187863, dvrr_stack+24576, dvrr_stack+72706);
 tmp = dvrr_stack + 187863;
 target_ptr = Libderiv->deriv2_classes[2][5][31];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+73022, dvrr_stack+24786, dvrr_stack+74837);
 tmp = dvrr_stack + 73022;
 target_ptr = Libderiv->deriv2_classes[2][6][31];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+187989, dvrr_stack+20901, dvrr_stack+74921);
 tmp = dvrr_stack + 187989;
 target_ptr = Libderiv->deriv2_classes[2][7][31];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+188205, dvrr_stack+18027, dvrr_stack+118594);
 tmp = dvrr_stack + 188205;
 target_ptr = Libderiv->deriv2_classes[2][8][31];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,15,dvrr_stack+188475, dvrr_stack+72797, dvrr_stack+48204);
 tmp = dvrr_stack + 188475;
 target_ptr = Libderiv->deriv2_classes[3][4][31];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+188625, dvrr_stack+13381, dvrr_stack+54184);
 tmp = dvrr_stack + 188625;
 target_ptr = Libderiv->deriv2_classes[3][5][31];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+188835, dvrr_stack+9153, dvrr_stack+48294);
 tmp = dvrr_stack + 188835;
 target_ptr = Libderiv->deriv2_classes[3][6][31];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+189115, dvrr_stack+91513, dvrr_stack+42035);
 tmp = dvrr_stack + 189115;
 target_ptr = Libderiv->deriv2_classes[3][7][31];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+189475, dvrr_stack+92053, dvrr_stack+29321);
 tmp = dvrr_stack + 189475;
 target_ptr = Libderiv->deriv2_classes[3][8][31];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,15,dvrr_stack+189925, dvrr_stack+111729, dvrr_stack+29921);
 tmp = dvrr_stack + 189925;
 target_ptr = Libderiv->deriv2_classes[4][4][31];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+190150, dvrr_stack+105903, dvrr_stack+24576);
 tmp = dvrr_stack + 190150;
 target_ptr = Libderiv->deriv2_classes[4][5][31];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+190465, dvrr_stack+102099, dvrr_stack+24786);
 tmp = dvrr_stack + 190465;
 target_ptr = Libderiv->deriv2_classes[4][6][31];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+190885, dvrr_stack+118729, dvrr_stack+20901);
 tmp = dvrr_stack + 190885;
 target_ptr = Libderiv->deriv2_classes[4][7][31];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+191425, dvrr_stack+119485, dvrr_stack+18027);
 tmp = dvrr_stack + 191425;
 target_ptr = Libderiv->deriv2_classes[4][8][31];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,15,dvrr_stack+192100, dvrr_stack+10443, dvrr_stack+116158);
 tmp = dvrr_stack + 192100;
 target_ptr = Libderiv->deriv2_classes[2][4][30];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+192190, dvrr_stack+6115, dvrr_stack+112044);
 tmp = dvrr_stack + 192190;
 target_ptr = Libderiv->deriv2_classes[2][5][30];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+192316, dvrr_stack+10593, dvrr_stack+120430);
 tmp = dvrr_stack + 192316;
 target_ptr = Libderiv->deriv2_classes[2][6][30];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+192484, dvrr_stack+12327, dvrr_stack+120514);
 tmp = dvrr_stack + 192484;
 target_ptr = Libderiv->deriv2_classes[2][7][30];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+192700, dvrr_stack+93553, dvrr_stack+120622);
 tmp = dvrr_stack + 192700;
 target_ptr = Libderiv->deriv2_classes[2][8][30];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,15,dvrr_stack+4217, dvrr_stack+34379, dvrr_stack+25066);
 tmp = dvrr_stack + 4217;
 target_ptr = Libderiv->deriv2_classes[3][4][30];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+192970, dvrr_stack+34064, dvrr_stack+62179);
 tmp = dvrr_stack + 192970;
 target_ptr = Libderiv->deriv2_classes[3][5][30];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+193180, dvrr_stack+94553, dvrr_stack+5947);
 tmp = dvrr_stack + 193180;
 target_ptr = Libderiv->deriv2_classes[3][6][30];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+193460, dvrr_stack+94973, dvrr_stack+3461);
 tmp = dvrr_stack + 193460;
 target_ptr = Libderiv->deriv2_classes[3][7][30];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+193820, dvrr_stack+95513, dvrr_stack+1524);
 tmp = dvrr_stack + 193820;
 target_ptr = Libderiv->deriv2_classes[3][8][30];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,15,dvrr_stack+194270, dvrr_stack+106344, dvrr_stack+10443);
 tmp = dvrr_stack + 194270;
 target_ptr = Libderiv->deriv2_classes[4][4][30];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+194495, dvrr_stack+99236, dvrr_stack+6115);
 tmp = dvrr_stack + 194495;
 target_ptr = Libderiv->deriv2_classes[4][5][30];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+194810, dvrr_stack+120757, dvrr_stack+10593);
 tmp = dvrr_stack + 194810;
 target_ptr = Libderiv->deriv2_classes[4][6][30];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+195230, dvrr_stack+121345, dvrr_stack+12327);
 tmp = dvrr_stack + 195230;
 target_ptr = Libderiv->deriv2_classes[4][7][30];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+195770, dvrr_stack+122101, dvrr_stack+93553);
 tmp = dvrr_stack + 195770;
 target_ptr = Libderiv->deriv2_classes[4][8][30];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,15,dvrr_stack+196445, dvrr_stack+116248, dvrr_stack+116203);
 tmp = dvrr_stack + 196445;
 target_ptr = Libderiv->deriv2_classes[2][4][26];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+196535, dvrr_stack+123046, dvrr_stack+99677);
 tmp = dvrr_stack + 196535;
 target_ptr = Libderiv->deriv2_classes[2][5][26];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+196661, dvrr_stack+123256, dvrr_stack+116398);
 tmp = dvrr_stack + 196661;
 target_ptr = Libderiv->deriv2_classes[2][6][26];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+196829, dvrr_stack+68434, dvrr_stack+123536);
 tmp = dvrr_stack + 196829;
 target_ptr = Libderiv->deriv2_classes[2][7][26];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+197045, dvrr_stack+114564, dvrr_stack+123644);
 tmp = dvrr_stack + 197045;
 target_ptr = Libderiv->deriv2_classes[2][8][26];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,15,dvrr_stack+197315, dvrr_stack+106659, dvrr_stack+123779);
 tmp = dvrr_stack + 197315;
 target_ptr = Libderiv->deriv2_classes[3][4][26];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+197465, dvrr_stack+115014, dvrr_stack+123869);
 tmp = dvrr_stack + 197465;
 target_ptr = Libderiv->deriv2_classes[3][5][26];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+197675, dvrr_stack+123995, dvrr_stack+115329);
 tmp = dvrr_stack + 197675;
 target_ptr = Libderiv->deriv2_classes[3][6][26];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+197955, dvrr_stack+124415, dvrr_stack+5056);
 tmp = dvrr_stack + 197955;
 target_ptr = Libderiv->deriv2_classes[3][7][26];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+198315, dvrr_stack+124955, dvrr_stack+11818);
 tmp = dvrr_stack + 198315;
 target_ptr = Libderiv->deriv2_classes[3][8][26];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,15,dvrr_stack+198765, dvrr_stack+126200, dvrr_stack+116248);
 tmp = dvrr_stack + 198765;
 target_ptr = Libderiv->deriv2_classes[4][4][26];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+198990, dvrr_stack+97703, dvrr_stack+123046);
 tmp = dvrr_stack + 198990;
 target_ptr = Libderiv->deriv2_classes[4][5][26];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+199305, dvrr_stack+126515, dvrr_stack+123256);
 tmp = dvrr_stack + 199305;
 target_ptr = Libderiv->deriv2_classes[4][6][26];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+199725, dvrr_stack+103275, dvrr_stack+68434);
 tmp = dvrr_stack + 199725;
 target_ptr = Libderiv->deriv2_classes[4][7][26];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+200265, dvrr_stack+129126, dvrr_stack+114564);
 tmp = dvrr_stack + 200265;
 target_ptr = Libderiv->deriv2_classes[4][8][26];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,15,dvrr_stack+49758, dvrr_stack+73407, dvrr_stack+145);
 tmp = dvrr_stack + 49758;
 target_ptr = Libderiv->deriv2_classes[2][4][23];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,21,dvrr_stack+26701, dvrr_stack+73197, dvrr_stack+71109);
 tmp = dvrr_stack + 26701;
 target_ptr = Libderiv->deriv2_classes[2][5][23];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,28,dvrr_stack+200940, dvrr_stack+73557, dvrr_stack+857);
 tmp = dvrr_stack + 200940;
 target_ptr = Libderiv->deriv2_classes[2][6][23];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,36,dvrr_stack+201108, dvrr_stack+6973, dvrr_stack+45328);
 tmp = dvrr_stack + 201108;
 target_ptr = Libderiv->deriv2_classes[2][7][23];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,45,dvrr_stack+201324, dvrr_stack+73837, dvrr_stack+68857);
 tmp = dvrr_stack + 201324;
 target_ptr = Libderiv->deriv2_classes[2][8][23];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,15,dvrr_stack+201594, dvrr_stack+75197, dvrr_stack+71857);
 tmp = dvrr_stack + 201594;
 target_ptr = Libderiv->deriv2_classes[3][4][23];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,21,dvrr_stack+201744, dvrr_stack+62314, dvrr_stack+71731);
 tmp = dvrr_stack + 201744;
 target_ptr = Libderiv->deriv2_classes[3][5][23];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,28,dvrr_stack+201954, dvrr_stack+22221, dvrr_stack+71947);
 tmp = dvrr_stack + 201954;
 target_ptr = Libderiv->deriv2_classes[3][6][23];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,36,dvrr_stack+202234, dvrr_stack+62629, dvrr_stack+72115);
 tmp = dvrr_stack + 202234;
 target_ptr = Libderiv->deriv2_classes[3][7][23];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,45,dvrr_stack+202594, dvrr_stack+63169, dvrr_stack+19137);
 tmp = dvrr_stack + 202594;
 target_ptr = Libderiv->deriv2_classes[3][8][23];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,15,dvrr_stack+203044, dvrr_stack+99740, dvrr_stack+73407);
 tmp = dvrr_stack + 203044;
 target_ptr = Libderiv->deriv2_classes[4][4][23];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,21,dvrr_stack+203269, dvrr_stack+102834, dvrr_stack+73197);
 tmp = dvrr_stack + 203269;
 target_ptr = Libderiv->deriv2_classes[4][5][23];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,28,dvrr_stack+203584, dvrr_stack+106911, dvrr_stack+73557);
 tmp = dvrr_stack + 203584;
 target_ptr = Libderiv->deriv2_classes[4][6][23];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,36,dvrr_stack+204004, dvrr_stack+112107, dvrr_stack+6973);
 tmp = dvrr_stack + 204004;
 target_ptr = Libderiv->deriv2_classes[4][7][23];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,45,dvrr_stack+204544, dvrr_stack+58134, dvrr_stack+73837);
 tmp = dvrr_stack + 204544;
 target_ptr = Libderiv->deriv2_classes[4][8][23];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,15,dvrr_stack+205219, dvrr_stack+50074, dvrr_stack+59079);
 tmp = dvrr_stack + 205219;
 target_ptr = Libderiv->deriv2_classes[2][4][22];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+205309, dvrr_stack+49864, dvrr_stack+59124);
 tmp = dvrr_stack + 205309;
 target_ptr = Libderiv->deriv2_classes[2][5][22];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+205435, dvrr_stack+45048, dvrr_stack+59187);
 tmp = dvrr_stack + 205435;
 target_ptr = Libderiv->deriv2_classes[2][6][22];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+205603, dvrr_stack+31471, dvrr_stack+59271);
 tmp = dvrr_stack + 205603;
 target_ptr = Libderiv->deriv2_classes[2][7][22];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+205819, dvrr_stack+31831, dvrr_stack+59379);
 tmp = dvrr_stack + 205819;
 target_ptr = Libderiv->deriv2_classes[2][8][22];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,15,dvrr_stack+206089, dvrr_stack+14486, dvrr_stack+64795);
 tmp = dvrr_stack + 206089;
 target_ptr = Libderiv->deriv2_classes[3][4][22];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+206239, dvrr_stack+14171, dvrr_stack+64669);
 tmp = dvrr_stack + 206239;
 target_ptr = Libderiv->deriv2_classes[3][5][22];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+206449, dvrr_stack+14711, dvrr_stack+64885);
 tmp = dvrr_stack + 206449;
 target_ptr = Libderiv->deriv2_classes[3][6][22];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+206729, dvrr_stack+89473, dvrr_stack+55974);
 tmp = dvrr_stack + 206729;
 target_ptr = Libderiv->deriv2_classes[3][7][22];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+207089, dvrr_stack+90013, dvrr_stack+56190);
 tmp = dvrr_stack + 207089;
 target_ptr = Libderiv->deriv2_classes[3][8][22];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,15,dvrr_stack+207539, dvrr_stack+59514, dvrr_stack+50074);
 tmp = dvrr_stack + 207539;
 target_ptr = Libderiv->deriv2_classes[4][4][22];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+207764, dvrr_stack+27726, dvrr_stack+49864);
 tmp = dvrr_stack + 207764;
 target_ptr = Libderiv->deriv2_classes[4][5][22];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+208079, dvrr_stack+28167, dvrr_stack+45048);
 tmp = dvrr_stack + 208079;
 target_ptr = Libderiv->deriv2_classes[4][6][22];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+208499, dvrr_stack+112863, dvrr_stack+31471);
 tmp = dvrr_stack + 208499;
 target_ptr = Libderiv->deriv2_classes[4][7][22];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+209039, dvrr_stack+113619, dvrr_stack+31831);
 tmp = dvrr_stack + 209039;
 target_ptr = Libderiv->deriv2_classes[4][8][22];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,15,dvrr_stack+209714, dvrr_stack+17877, dvrr_stack+33361);
 tmp = dvrr_stack + 209714;
 target_ptr = Libderiv->deriv2_classes[2][4][21];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+209804, dvrr_stack+15131, dvrr_stack+2190);
 tmp = dvrr_stack + 209804;
 target_ptr = Libderiv->deriv2_classes[2][5][21];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+209930, dvrr_stack+16895, dvrr_stack+2253);
 tmp = dvrr_stack + 209930;
 target_ptr = Libderiv->deriv2_classes[2][6][21];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+210098, dvrr_stack+20541, dvrr_stack+67876);
 tmp = dvrr_stack + 210098;
 target_ptr = Libderiv->deriv2_classes[2][7][21];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+210314, dvrr_stack+24126, dvrr_stack+67984);
 tmp = dvrr_stack + 210314;
 target_ptr = Libderiv->deriv2_classes[2][8][21];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,15,dvrr_stack+210584, dvrr_stack+43158, dvrr_stack+1434);
 tmp = dvrr_stack + 210584;
 target_ptr = Libderiv->deriv2_classes[3][4][21];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+210734, dvrr_stack+61864, dvrr_stack+71491);
 tmp = dvrr_stack + 210734;
 target_ptr = Libderiv->deriv2_classes[3][5][21];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+210944, dvrr_stack+41615, dvrr_stack+689);
 tmp = dvrr_stack + 210944;
 target_ptr = Libderiv->deriv2_classes[3][6][21];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+211224, dvrr_stack+47244, dvrr_stack+3245);
 tmp = dvrr_stack + 211224;
 target_ptr = Libderiv->deriv2_classes[3][7][21];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+211584, dvrr_stack+52734, dvrr_stack+5677);
 tmp = dvrr_stack + 211584;
 target_ptr = Libderiv->deriv2_classes[3][8][21];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,15,dvrr_stack+212034, dvrr_stack+68119, dvrr_stack+17877);
 tmp = dvrr_stack + 212034;
 target_ptr = Libderiv->deriv2_classes[4][4][21];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+212259, dvrr_stack+98795, dvrr_stack+15131);
 tmp = dvrr_stack + 212259;
 target_ptr = Libderiv->deriv2_classes[4][5][21];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+212574, dvrr_stack+101511, dvrr_stack+16895);
 tmp = dvrr_stack + 212574;
 target_ptr = Libderiv->deriv2_classes[4][6][21];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+212994, dvrr_stack+105147, dvrr_stack+20541);
 tmp = dvrr_stack + 212994;
 target_ptr = Libderiv->deriv2_classes[4][7][21];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+213534, dvrr_stack+109839, dvrr_stack+24126);
 tmp = dvrr_stack + 213534;
 target_ptr = Libderiv->deriv2_classes[4][8][21];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,15,dvrr_stack+214209, dvrr_stack+70679, dvrr_stack+115723);
 tmp = dvrr_stack + 214209;
 target_ptr = Libderiv->deriv2_classes[2][4][20];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+214299, dvrr_stack+70469, dvrr_stack+115768);
 tmp = dvrr_stack + 214299;
 target_ptr = Libderiv->deriv2_classes[2][5][20];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+214425, dvrr_stack+70829, dvrr_stack+115831);
 tmp = dvrr_stack + 214425;
 target_ptr = Libderiv->deriv2_classes[2][6][20];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+214593, dvrr_stack+60664, dvrr_stack+115915);
 tmp = dvrr_stack + 214593;
 target_ptr = Libderiv->deriv2_classes[2][7][20];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+214809, dvrr_stack+61024, dvrr_stack+116023);
 tmp = dvrr_stack + 214809;
 target_ptr = Libderiv->deriv2_classes[2][8][20];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,15,dvrr_stack+215079, dvrr_stack+53959, dvrr_stack+69217);
 tmp = dvrr_stack + 215079;
 target_ptr = Libderiv->deriv2_classes[3][4][20];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+215229, dvrr_stack+61474, dvrr_stack+69091);
 tmp = dvrr_stack + 215229;
 target_ptr = Libderiv->deriv2_classes[3][5][20];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+215439, dvrr_stack+47784, dvrr_stack+69307);
 tmp = dvrr_stack + 215439;
 target_ptr = Libderiv->deriv2_classes[3][6][20];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+215719, dvrr_stack+43383, dvrr_stack+69475);
 tmp = dvrr_stack + 215719;
 target_ptr = Libderiv->deriv2_classes[3][7][20];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+216079, dvrr_stack+34886, dvrr_stack+69691);
 tmp = dvrr_stack + 216079;
 target_ptr = Libderiv->deriv2_classes[3][8][20];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,15,dvrr_stack+216529, dvrr_stack+116494, dvrr_stack+70679);
 tmp = dvrr_stack + 216529;
 target_ptr = Libderiv->deriv2_classes[4][4][20];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+216754, dvrr_stack+116809, dvrr_stack+70469);
 tmp = dvrr_stack + 216754;
 target_ptr = Libderiv->deriv2_classes[4][5][20];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+217069, dvrr_stack+117250, dvrr_stack+70829);
 tmp = dvrr_stack + 217069;
 target_ptr = Libderiv->deriv2_classes[4][6][20];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+217489, dvrr_stack+117838, dvrr_stack+60664);
 tmp = dvrr_stack + 217489;
 target_ptr = Libderiv->deriv2_classes[4][7][20];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+218029, dvrr_stack+110784, dvrr_stack+61024);
 tmp = dvrr_stack + 218029;
 target_ptr = Libderiv->deriv2_classes[4][8][20];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,15,dvrr_stack+218704, dvrr_stack+29921, dvrr_stack+72661);
 tmp = dvrr_stack + 218704;
 target_ptr = Libderiv->deriv2_classes[2][4][19];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+218794, dvrr_stack+24576, dvrr_stack+72706);
 tmp = dvrr_stack + 218794;
 target_ptr = Libderiv->deriv2_classes[2][5][19];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+218920, dvrr_stack+24786, dvrr_stack+74837);
 tmp = dvrr_stack + 218920;
 target_ptr = Libderiv->deriv2_classes[2][6][19];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+219088, dvrr_stack+20901, dvrr_stack+74921);
 tmp = dvrr_stack + 219088;
 target_ptr = Libderiv->deriv2_classes[2][7][19];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+219304, dvrr_stack+18027, dvrr_stack+118594);
 tmp = dvrr_stack + 219304;
 target_ptr = Libderiv->deriv2_classes[2][8][19];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,15,dvrr_stack+219574, dvrr_stack+72797, dvrr_stack+48204);
 tmp = dvrr_stack + 219574;
 target_ptr = Libderiv->deriv2_classes[3][4][19];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+219724, dvrr_stack+13381, dvrr_stack+54184);
 tmp = dvrr_stack + 219724;
 target_ptr = Libderiv->deriv2_classes[3][5][19];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+219934, dvrr_stack+9153, dvrr_stack+48294);
 tmp = dvrr_stack + 219934;
 target_ptr = Libderiv->deriv2_classes[3][6][19];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+220214, dvrr_stack+91513, dvrr_stack+42035);
 tmp = dvrr_stack + 220214;
 target_ptr = Libderiv->deriv2_classes[3][7][19];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+220574, dvrr_stack+92053, dvrr_stack+29321);
 tmp = dvrr_stack + 220574;
 target_ptr = Libderiv->deriv2_classes[3][8][19];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,15,dvrr_stack+221024, dvrr_stack+111729, dvrr_stack+29921);
 tmp = dvrr_stack + 221024;
 target_ptr = Libderiv->deriv2_classes[4][4][19];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+221249, dvrr_stack+105903, dvrr_stack+24576);
 tmp = dvrr_stack + 221249;
 target_ptr = Libderiv->deriv2_classes[4][5][19];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+221564, dvrr_stack+102099, dvrr_stack+24786);
 tmp = dvrr_stack + 221564;
 target_ptr = Libderiv->deriv2_classes[4][6][19];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+221984, dvrr_stack+118729, dvrr_stack+20901);
 tmp = dvrr_stack + 221984;
 target_ptr = Libderiv->deriv2_classes[4][7][19];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+222524, dvrr_stack+119485, dvrr_stack+18027);
 tmp = dvrr_stack + 222524;
 target_ptr = Libderiv->deriv2_classes[4][8][19];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,15,dvrr_stack+223199, dvrr_stack+10443, dvrr_stack+116158);
 tmp = dvrr_stack + 223199;
 target_ptr = Libderiv->deriv2_classes[2][4][18];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+223289, dvrr_stack+6115, dvrr_stack+112044);
 tmp = dvrr_stack + 223289;
 target_ptr = Libderiv->deriv2_classes[2][5][18];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+223415, dvrr_stack+10593, dvrr_stack+120430);
 tmp = dvrr_stack + 223415;
 target_ptr = Libderiv->deriv2_classes[2][6][18];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+223583, dvrr_stack+12327, dvrr_stack+120514);
 tmp = dvrr_stack + 223583;
 target_ptr = Libderiv->deriv2_classes[2][7][18];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+223799, dvrr_stack+93553, dvrr_stack+120622);
 tmp = dvrr_stack + 223799;
 target_ptr = Libderiv->deriv2_classes[2][8][18];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,15,dvrr_stack+224069, dvrr_stack+34379, dvrr_stack+25066);
 tmp = dvrr_stack + 224069;
 target_ptr = Libderiv->deriv2_classes[3][4][18];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+224219, dvrr_stack+34064, dvrr_stack+62179);
 tmp = dvrr_stack + 224219;
 target_ptr = Libderiv->deriv2_classes[3][5][18];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+224429, dvrr_stack+94553, dvrr_stack+5947);
 tmp = dvrr_stack + 224429;
 target_ptr = Libderiv->deriv2_classes[3][6][18];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+224709, dvrr_stack+94973, dvrr_stack+3461);
 tmp = dvrr_stack + 224709;
 target_ptr = Libderiv->deriv2_classes[3][7][18];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+225069, dvrr_stack+95513, dvrr_stack+1524);
 tmp = dvrr_stack + 225069;
 target_ptr = Libderiv->deriv2_classes[3][8][18];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,15,dvrr_stack+225519, dvrr_stack+106344, dvrr_stack+10443);
 tmp = dvrr_stack + 225519;
 target_ptr = Libderiv->deriv2_classes[4][4][18];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+225744, dvrr_stack+99236, dvrr_stack+6115);
 tmp = dvrr_stack + 225744;
 target_ptr = Libderiv->deriv2_classes[4][5][18];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+226059, dvrr_stack+120757, dvrr_stack+10593);
 tmp = dvrr_stack + 226059;
 target_ptr = Libderiv->deriv2_classes[4][6][18];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+226479, dvrr_stack+121345, dvrr_stack+12327);
 tmp = dvrr_stack + 226479;
 target_ptr = Libderiv->deriv2_classes[4][7][18];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+227019, dvrr_stack+122101, dvrr_stack+93553);
 tmp = dvrr_stack + 227019;
 target_ptr = Libderiv->deriv2_classes[4][8][18];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,15,dvrr_stack+227694, dvrr_stack+116248, dvrr_stack+116203);
 tmp = dvrr_stack + 227694;
 target_ptr = Libderiv->deriv2_classes[2][4][14];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+227784, dvrr_stack+123046, dvrr_stack+99677);
 tmp = dvrr_stack + 227784;
 target_ptr = Libderiv->deriv2_classes[2][5][14];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+227910, dvrr_stack+123256, dvrr_stack+116398);
 tmp = dvrr_stack + 227910;
 target_ptr = Libderiv->deriv2_classes[2][6][14];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+228078, dvrr_stack+68434, dvrr_stack+123536);
 tmp = dvrr_stack + 228078;
 target_ptr = Libderiv->deriv2_classes[2][7][14];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+228294, dvrr_stack+114564, dvrr_stack+123644);
 tmp = dvrr_stack + 228294;
 target_ptr = Libderiv->deriv2_classes[2][8][14];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,15,dvrr_stack+228564, dvrr_stack+106659, dvrr_stack+123779);
 tmp = dvrr_stack + 228564;
 target_ptr = Libderiv->deriv2_classes[3][4][14];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+228714, dvrr_stack+115014, dvrr_stack+123869);
 tmp = dvrr_stack + 228714;
 target_ptr = Libderiv->deriv2_classes[3][5][14];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+228924, dvrr_stack+123995, dvrr_stack+115329);
 tmp = dvrr_stack + 228924;
 target_ptr = Libderiv->deriv2_classes[3][6][14];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+229204, dvrr_stack+124415, dvrr_stack+5056);
 tmp = dvrr_stack + 229204;
 target_ptr = Libderiv->deriv2_classes[3][7][14];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+229564, dvrr_stack+124955, dvrr_stack+11818);
 tmp = dvrr_stack + 229564;
 target_ptr = Libderiv->deriv2_classes[3][8][14];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,15,dvrr_stack+230014, dvrr_stack+126200, dvrr_stack+116248);
 tmp = dvrr_stack + 230014;
 target_ptr = Libderiv->deriv2_classes[4][4][14];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+230239, dvrr_stack+97703, dvrr_stack+123046);
 tmp = dvrr_stack + 230239;
 target_ptr = Libderiv->deriv2_classes[4][5][14];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+230554, dvrr_stack+126515, dvrr_stack+123256);
 tmp = dvrr_stack + 230554;
 target_ptr = Libderiv->deriv2_classes[4][6][14];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+230974, dvrr_stack+103275, dvrr_stack+68434);
 tmp = dvrr_stack + 230974;
 target_ptr = Libderiv->deriv2_classes[4][7][14];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+231514, dvrr_stack+129126, dvrr_stack+114564);
 tmp = dvrr_stack + 231514;
 target_ptr = Libderiv->deriv2_classes[4][8][14];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,15,dvrr_stack+232189, dvrr_stack+125630, dvrr_stack+4883);
 tmp = dvrr_stack + 232189;
 target_ptr = Libderiv->deriv2_classes[2][4][13];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+232279, dvrr_stack+98144, dvrr_stack+127103);
 tmp = dvrr_stack + 232279;
 target_ptr = Libderiv->deriv2_classes[2][5][13];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+232405, dvrr_stack+131430, dvrr_stack+130071);
 tmp = dvrr_stack + 232405;
 target_ptr = Libderiv->deriv2_classes[2][6][13];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+232573, dvrr_stack+104031, dvrr_stack+130155);
 tmp = dvrr_stack + 232573;
 target_ptr = Libderiv->deriv2_classes[2][7][13];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+232789, dvrr_stack+131710, dvrr_stack+130263);
 tmp = dvrr_stack + 232789;
 target_ptr = Libderiv->deriv2_classes[2][8][13];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,15,dvrr_stack+233059, dvrr_stack+132250, dvrr_stack+132160);
 tmp = dvrr_stack + 233059;
 target_ptr = Libderiv->deriv2_classes[3][4][13];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+233209, dvrr_stack+132601, dvrr_stack+132475);
 tmp = dvrr_stack + 233209;
 target_ptr = Libderiv->deriv2_classes[3][5][13];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+233419, dvrr_stack+100223, dvrr_stack+100055);
 tmp = dvrr_stack + 233419;
 target_ptr = Libderiv->deriv2_classes[3][6][13];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+233699, dvrr_stack+107499, dvrr_stack+100643);
 tmp = dvrr_stack + 233699;
 target_ptr = Libderiv->deriv2_classes[3][7][13];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+234059, dvrr_stack+51339, dvrr_stack+108039);
 tmp = dvrr_stack + 234059;
 target_ptr = Libderiv->deriv2_classes[3][8][13];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,15,dvrr_stack+234509, dvrr_stack+108309, dvrr_stack+125630);
 tmp = dvrr_stack + 234509;
 target_ptr = Libderiv->deriv2_classes[4][4][13];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+234734, dvrr_stack+46128, dvrr_stack+98144);
 tmp = dvrr_stack + 234734;
 target_ptr = Libderiv->deriv2_classes[4][5][13];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+235049, dvrr_stack+127754, dvrr_stack+131430);
 tmp = dvrr_stack + 235049;
 target_ptr = Libderiv->deriv2_classes[4][6][13];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+235469, dvrr_stack+134310, dvrr_stack+104031);
 tmp = dvrr_stack + 235469;
 target_ptr = Libderiv->deriv2_classes[4][7][13];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+236009, dvrr_stack+135066, dvrr_stack+131710);
 tmp = dvrr_stack + 236009;
 target_ptr = Libderiv->deriv2_classes[4][8][13];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,15,dvrr_stack+236684, dvrr_stack+73407, dvrr_stack+145);
 tmp = dvrr_stack + 236684;
 target_ptr = Libderiv->deriv2_classes[2][4][11];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,21,dvrr_stack+236774, dvrr_stack+73197, dvrr_stack+71109);
 tmp = dvrr_stack + 236774;
 target_ptr = Libderiv->deriv2_classes[2][5][11];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,28,dvrr_stack+236900, dvrr_stack+73557, dvrr_stack+857);
 tmp = dvrr_stack + 236900;
 target_ptr = Libderiv->deriv2_classes[2][6][11];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,36,dvrr_stack+237068, dvrr_stack+6973, dvrr_stack+45328);
 tmp = dvrr_stack + 237068;
 target_ptr = Libderiv->deriv2_classes[2][7][11];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,45,dvrr_stack+237284, dvrr_stack+73837, dvrr_stack+68857);
 tmp = dvrr_stack + 237284;
 target_ptr = Libderiv->deriv2_classes[2][8][11];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,15,dvrr_stack+68857, dvrr_stack+75197, dvrr_stack+71857);
 tmp = dvrr_stack + 68857;
 target_ptr = Libderiv->deriv2_classes[3][4][11];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,21,dvrr_stack+75197, dvrr_stack+62314, dvrr_stack+71731);
 tmp = dvrr_stack + 75197;
 target_ptr = Libderiv->deriv2_classes[3][5][11];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,28,dvrr_stack+237554, dvrr_stack+22221, dvrr_stack+71947);
 tmp = dvrr_stack + 237554;
 target_ptr = Libderiv->deriv2_classes[3][6][11];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,36,dvrr_stack+22147, dvrr_stack+62629, dvrr_stack+72115);
 tmp = dvrr_stack + 22147;
 target_ptr = Libderiv->deriv2_classes[3][7][11];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,45,dvrr_stack+62305, dvrr_stack+63169, dvrr_stack+19137);
 tmp = dvrr_stack + 62305;
 target_ptr = Libderiv->deriv2_classes[3][8][11];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,15,dvrr_stack+19137, dvrr_stack+99740, dvrr_stack+73407);
 tmp = dvrr_stack + 19137;
 target_ptr = Libderiv->deriv2_classes[4][4][11];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,21,dvrr_stack+99740, dvrr_stack+102834, dvrr_stack+73197);
 tmp = dvrr_stack + 99740;
 target_ptr = Libderiv->deriv2_classes[4][5][11];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,28,dvrr_stack+102813, dvrr_stack+106911, dvrr_stack+73557);
 tmp = dvrr_stack + 102813;
 target_ptr = Libderiv->deriv2_classes[4][6][11];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,36,dvrr_stack+106884, dvrr_stack+112107, dvrr_stack+6973);
 tmp = dvrr_stack + 106884;
 target_ptr = Libderiv->deriv2_classes[4][7][11];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,45,dvrr_stack+112107, dvrr_stack+58134, dvrr_stack+73837);
 tmp = dvrr_stack + 112107;
 target_ptr = Libderiv->deriv2_classes[4][8][11];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,15,dvrr_stack+45328, dvrr_stack+50074, dvrr_stack+59079);
 tmp = dvrr_stack + 45328;
 target_ptr = Libderiv->deriv2_classes[2][4][10];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+6955, dvrr_stack+49864, dvrr_stack+59124);
 tmp = dvrr_stack + 6955;
 target_ptr = Libderiv->deriv2_classes[2][5][10];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+7081, dvrr_stack+45048, dvrr_stack+59187);
 tmp = dvrr_stack + 7081;
 target_ptr = Libderiv->deriv2_classes[2][6][10];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+62755, dvrr_stack+31471, dvrr_stack+59271);
 tmp = dvrr_stack + 62755;
 target_ptr = Libderiv->deriv2_classes[2][7][10];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+62971, dvrr_stack+31831, dvrr_stack+59379);
 tmp = dvrr_stack + 62971;
 target_ptr = Libderiv->deriv2_classes[2][8][10];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,15,dvrr_stack+237834, dvrr_stack+14486, dvrr_stack+64795);
 tmp = dvrr_stack + 237834;
 target_ptr = Libderiv->deriv2_classes[3][4][10];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+14486, dvrr_stack+14171, dvrr_stack+64669);
 tmp = dvrr_stack + 14486;
 target_ptr = Libderiv->deriv2_classes[3][5][10];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+63241, dvrr_stack+14711, dvrr_stack+64885);
 tmp = dvrr_stack + 63241;
 target_ptr = Libderiv->deriv2_classes[3][6][10];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+14696, dvrr_stack+89473, dvrr_stack+55974);
 tmp = dvrr_stack + 14696;
 target_ptr = Libderiv->deriv2_classes[3][7][10];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+73190, dvrr_stack+90013, dvrr_stack+56190);
 tmp = dvrr_stack + 73190;
 target_ptr = Libderiv->deriv2_classes[3][8][10];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,15,dvrr_stack+64636, dvrr_stack+59514, dvrr_stack+50074);
 tmp = dvrr_stack + 64636;
 target_ptr = Libderiv->deriv2_classes[4][4][10];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+55888, dvrr_stack+27726, dvrr_stack+49864);
 tmp = dvrr_stack + 55888;
 target_ptr = Libderiv->deriv2_classes[4][5][10];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+73640, dvrr_stack+28167, dvrr_stack+45048);
 tmp = dvrr_stack + 73640;
 target_ptr = Libderiv->deriv2_classes[4][6][10];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+71617, dvrr_stack+112863, dvrr_stack+31471);
 tmp = dvrr_stack + 71617;
 target_ptr = Libderiv->deriv2_classes[4][7][10];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+112782, dvrr_stack+113619, dvrr_stack+31831);
 tmp = dvrr_stack + 112782;
 target_ptr = Libderiv->deriv2_classes[4][8][10];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,15,dvrr_stack+113457, dvrr_stack+17877, dvrr_stack+33361);
 tmp = dvrr_stack + 113457;
 target_ptr = Libderiv->deriv2_classes[2][4][9];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+113547, dvrr_stack+15131, dvrr_stack+2190);
 tmp = dvrr_stack + 113547;
 target_ptr = Libderiv->deriv2_classes[2][5][9];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+113673, dvrr_stack+16895, dvrr_stack+2253);
 tmp = dvrr_stack + 113673;
 target_ptr = Libderiv->deriv2_classes[2][6][9];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+113841, dvrr_stack+20541, dvrr_stack+67876);
 tmp = dvrr_stack + 113841;
 target_ptr = Libderiv->deriv2_classes[2][7][9];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+114057, dvrr_stack+24126, dvrr_stack+67984);
 tmp = dvrr_stack + 114057;
 target_ptr = Libderiv->deriv2_classes[2][8][9];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,15,dvrr_stack+114327, dvrr_stack+43158, dvrr_stack+1434);
 tmp = dvrr_stack + 114327;
 target_ptr = Libderiv->deriv2_classes[3][4][9];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+56203, dvrr_stack+61864, dvrr_stack+71491);
 tmp = dvrr_stack + 56203;
 target_ptr = Libderiv->deriv2_classes[3][5][9];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+61789, dvrr_stack+41615, dvrr_stack+689);
 tmp = dvrr_stack + 61789;
 target_ptr = Libderiv->deriv2_classes[3][6][9];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+41546, dvrr_stack+47244, dvrr_stack+3245);
 tmp = dvrr_stack + 41546;
 target_ptr = Libderiv->deriv2_classes[3][7][9];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+47214, dvrr_stack+52734, dvrr_stack+5677);
 tmp = dvrr_stack + 47214;
 target_ptr = Libderiv->deriv2_classes[3][8][9];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,15,dvrr_stack+52659, dvrr_stack+68119, dvrr_stack+17877);
 tmp = dvrr_stack + 52659;
 target_ptr = Libderiv->deriv2_classes[4][4][9];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+52884, dvrr_stack+98795, dvrr_stack+15131);
 tmp = dvrr_stack + 52884;
 target_ptr = Libderiv->deriv2_classes[4][5][9];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+98747, dvrr_stack+101511, dvrr_stack+16895);
 tmp = dvrr_stack + 98747;
 target_ptr = Libderiv->deriv2_classes[4][6][9];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+101489, dvrr_stack+105147, dvrr_stack+20541);
 tmp = dvrr_stack + 101489;
 target_ptr = Libderiv->deriv2_classes[4][7][9];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+105144, dvrr_stack+109839, dvrr_stack+24126);
 tmp = dvrr_stack + 105144;
 target_ptr = Libderiv->deriv2_classes[4][8][9];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,15,dvrr_stack+3245, dvrr_stack+70679, dvrr_stack+115723);
 tmp = dvrr_stack + 3245;
 target_ptr = Libderiv->deriv2_classes[2][4][8];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+3335, dvrr_stack+70469, dvrr_stack+115768);
 tmp = dvrr_stack + 3335;
 target_ptr = Libderiv->deriv2_classes[2][5][8];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+15056, dvrr_stack+70829, dvrr_stack+115831);
 tmp = dvrr_stack + 15056;
 target_ptr = Libderiv->deriv2_classes[2][6][8];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+5623, dvrr_stack+60664, dvrr_stack+115915);
 tmp = dvrr_stack + 5623;
 target_ptr = Libderiv->deriv2_classes[2][7][8];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+647, dvrr_stack+61024, dvrr_stack+116023);
 tmp = dvrr_stack + 647;
 target_ptr = Libderiv->deriv2_classes[2][8][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,15,dvrr_stack+1374, dvrr_stack+53959, dvrr_stack+69217);
 tmp = dvrr_stack + 1374;
 target_ptr = Libderiv->deriv2_classes[3][4][8];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+53199, dvrr_stack+61474, dvrr_stack+69091);
 tmp = dvrr_stack + 53199;
 target_ptr = Libderiv->deriv2_classes[3][5][8];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+61474, dvrr_stack+47784, dvrr_stack+69307);
 tmp = dvrr_stack + 61474;
 target_ptr = Libderiv->deriv2_classes[3][6][8];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+69007, dvrr_stack+43383, dvrr_stack+69475);
 tmp = dvrr_stack + 69007;
 target_ptr = Libderiv->deriv2_classes[3][7][8];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+47664, dvrr_stack+34886, dvrr_stack+69691);
 tmp = dvrr_stack + 47664;
 target_ptr = Libderiv->deriv2_classes[3][8][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,15,dvrr_stack+69367, dvrr_stack+116494, dvrr_stack+70679);
 tmp = dvrr_stack + 69367;
 target_ptr = Libderiv->deriv2_classes[4][4][8];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+69592, dvrr_stack+116809, dvrr_stack+70469);
 tmp = dvrr_stack + 69592;
 target_ptr = Libderiv->deriv2_classes[4][5][8];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+109800, dvrr_stack+117250, dvrr_stack+70829);
 tmp = dvrr_stack + 109800;
 target_ptr = Libderiv->deriv2_classes[4][6][8];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+70447, dvrr_stack+117838, dvrr_stack+60664);
 tmp = dvrr_stack + 70447;
 target_ptr = Libderiv->deriv2_classes[4][7][8];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+34880, dvrr_stack+110784, dvrr_stack+61024);
 tmp = dvrr_stack + 34880;
 target_ptr = Libderiv->deriv2_classes[4][8][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,15,dvrr_stack+48114, dvrr_stack+29921, dvrr_stack+72661);
 tmp = dvrr_stack + 48114;
 target_ptr = Libderiv->deriv2_classes[2][4][7];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+53949, dvrr_stack+24576, dvrr_stack+72706);
 tmp = dvrr_stack + 53949;
 target_ptr = Libderiv->deriv2_classes[2][5][7];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+70987, dvrr_stack+24786, dvrr_stack+74837);
 tmp = dvrr_stack + 70987;
 target_ptr = Libderiv->deriv2_classes[2][6][7];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+110220, dvrr_stack+20901, dvrr_stack+74921);
 tmp = dvrr_stack + 110220;
 target_ptr = Libderiv->deriv2_classes[2][7][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+110436, dvrr_stack+18027, dvrr_stack+118594);
 tmp = dvrr_stack + 110436;
 target_ptr = Libderiv->deriv2_classes[2][8][7];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,15,dvrr_stack+64861, dvrr_stack+72797, dvrr_stack+48204);
 tmp = dvrr_stack + 64861;
 target_ptr = Libderiv->deriv2_classes[3][4][7];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+72649, dvrr_stack+13381, dvrr_stack+54184);
 tmp = dvrr_stack + 72649;
 target_ptr = Libderiv->deriv2_classes[3][5][7];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+110706, dvrr_stack+9153, dvrr_stack+48294);
 tmp = dvrr_stack + 110706;
 target_ptr = Libderiv->deriv2_classes[3][6][7];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+9123, dvrr_stack+91513, dvrr_stack+42035);
 tmp = dvrr_stack + 9123;
 target_ptr = Libderiv->deriv2_classes[3][7][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+91513, dvrr_stack+92053, dvrr_stack+29321);
 tmp = dvrr_stack + 91513;
 target_ptr = Libderiv->deriv2_classes[3][8][7];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,15,dvrr_stack+91963, dvrr_stack+111729, dvrr_stack+29921);
 tmp = dvrr_stack + 91963;
 target_ptr = Libderiv->deriv2_classes[4][4][7];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+92188, dvrr_stack+105903, dvrr_stack+24576);
 tmp = dvrr_stack + 92188;
 target_ptr = Libderiv->deriv2_classes[4][5][7];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+105819, dvrr_stack+102099, dvrr_stack+24786);
 tmp = dvrr_stack + 105819;
 target_ptr = Libderiv->deriv2_classes[4][6][7];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+102029, dvrr_stack+118729, dvrr_stack+20901);
 tmp = dvrr_stack + 102029;
 target_ptr = Libderiv->deriv2_classes[4][7][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+110986, dvrr_stack+119485, dvrr_stack+18027);
 tmp = dvrr_stack + 110986;
 target_ptr = Libderiv->deriv2_classes[4][8][7];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,15,dvrr_stack+92503, dvrr_stack+10443, dvrr_stack+116158);
 tmp = dvrr_stack + 92503;
 target_ptr = Libderiv->deriv2_classes[2][4][6];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+92593, dvrr_stack+6115, dvrr_stack+112044);
 tmp = dvrr_stack + 92593;
 target_ptr = Libderiv->deriv2_classes[2][5][6];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+48204, dvrr_stack+10593, dvrr_stack+120430);
 tmp = dvrr_stack + 48204;
 target_ptr = Libderiv->deriv2_classes[2][6][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+54075, dvrr_stack+12327, dvrr_stack+120514);
 tmp = dvrr_stack + 54075;
 target_ptr = Libderiv->deriv2_classes[2][7][6];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+111661, dvrr_stack+93553, dvrr_stack+120622);
 tmp = dvrr_stack + 111661;
 target_ptr = Libderiv->deriv2_classes[2][8][6];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,15,dvrr_stack+9483, dvrr_stack+34379, dvrr_stack+25066);
 tmp = dvrr_stack + 9483;
 target_ptr = Libderiv->deriv2_classes[3][4][6];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+34379, dvrr_stack+34064, dvrr_stack+62179);
 tmp = dvrr_stack + 34379;
 target_ptr = Libderiv->deriv2_classes[3][5][6];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+20497, dvrr_stack+94553, dvrr_stack+5947);
 tmp = dvrr_stack + 20497;
 target_ptr = Libderiv->deriv2_classes[3][6][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+94543, dvrr_stack+94973, dvrr_stack+3461);
 tmp = dvrr_stack + 94543;
 target_ptr = Libderiv->deriv2_classes[3][7][6];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+94903, dvrr_stack+95513, dvrr_stack+1524);
 tmp = dvrr_stack + 94903;
 target_ptr = Libderiv->deriv2_classes[3][8][6];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,15,dvrr_stack+1524, dvrr_stack+106344, dvrr_stack+10443);
 tmp = dvrr_stack + 1524;
 target_ptr = Libderiv->deriv2_classes[4][4][6];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+95353, dvrr_stack+99236, dvrr_stack+6115);
 tmp = dvrr_stack + 95353;
 target_ptr = Libderiv->deriv2_classes[4][5][6];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+106239, dvrr_stack+120757, dvrr_stack+10593);
 tmp = dvrr_stack + 106239;
 target_ptr = Libderiv->deriv2_classes[4][6][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+17865, dvrr_stack+121345, dvrr_stack+12327);
 tmp = dvrr_stack + 17865;
 target_ptr = Libderiv->deriv2_classes[4][7][6];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+24114, dvrr_stack+122101, dvrr_stack+93553);
 tmp = dvrr_stack + 24114;
 target_ptr = Libderiv->deriv2_classes[4][8][6];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,15,dvrr_stack+48372, dvrr_stack+116248, dvrr_stack+116203);
 tmp = dvrr_stack + 48372;
 target_ptr = Libderiv->deriv2_classes[2][4][2];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+3461, dvrr_stack+123046, dvrr_stack+99677);
 tmp = dvrr_stack + 3461;
 target_ptr = Libderiv->deriv2_classes[2][5][2];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+95668, dvrr_stack+123256, dvrr_stack+116398);
 tmp = dvrr_stack + 95668;
 target_ptr = Libderiv->deriv2_classes[2][6][2];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+116398, dvrr_stack+68434, dvrr_stack+123536);
 tmp = dvrr_stack + 116398;
 target_ptr = Libderiv->deriv2_classes[2][7][2];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+116614, dvrr_stack+114564, dvrr_stack+123644);
 tmp = dvrr_stack + 116614;
 target_ptr = Libderiv->deriv2_classes[2][8][2];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,15,dvrr_stack+123536, dvrr_stack+106659, dvrr_stack+123779);
 tmp = dvrr_stack + 123536;
 target_ptr = Libderiv->deriv2_classes[3][4][2];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+106659, dvrr_stack+115014, dvrr_stack+123869);
 tmp = dvrr_stack + 106659;
 target_ptr = Libderiv->deriv2_classes[3][5][2];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+115014, dvrr_stack+123995, dvrr_stack+115329);
 tmp = dvrr_stack + 115014;
 target_ptr = Libderiv->deriv2_classes[3][6][2];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+123686, dvrr_stack+124415, dvrr_stack+5056);
 tmp = dvrr_stack + 123686;
 target_ptr = Libderiv->deriv2_classes[3][7][2];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+124046, dvrr_stack+124955, dvrr_stack+11818);
 tmp = dvrr_stack + 124046;
 target_ptr = Libderiv->deriv2_classes[3][8][2];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,15,dvrr_stack+11818, dvrr_stack+126200, dvrr_stack+116248);
 tmp = dvrr_stack + 11818;
 target_ptr = Libderiv->deriv2_classes[4][4][2];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+124496, dvrr_stack+97703, dvrr_stack+123046);
 tmp = dvrr_stack + 124496;
 target_ptr = Libderiv->deriv2_classes[4][5][2];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+124811, dvrr_stack+126515, dvrr_stack+123256);
 tmp = dvrr_stack + 124811;
 target_ptr = Libderiv->deriv2_classes[4][6][2];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+116884, dvrr_stack+103275, dvrr_stack+68434);
 tmp = dvrr_stack + 116884;
 target_ptr = Libderiv->deriv2_classes[4][7][2];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+117424, dvrr_stack+129126, dvrr_stack+114564);
 tmp = dvrr_stack + 117424;
 target_ptr = Libderiv->deriv2_classes[4][8][2];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,15,dvrr_stack+3587, dvrr_stack+125630, dvrr_stack+4883);
 tmp = dvrr_stack + 3587;
 target_ptr = Libderiv->deriv2_classes[2][4][1];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+115294, dvrr_stack+98144, dvrr_stack+127103);
 tmp = dvrr_stack + 115294;
 target_ptr = Libderiv->deriv2_classes[2][5][1];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+125231, dvrr_stack+131430, dvrr_stack+130071);
 tmp = dvrr_stack + 125231;
 target_ptr = Libderiv->deriv2_classes[2][6][1];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+125399, dvrr_stack+104031, dvrr_stack+130155);
 tmp = dvrr_stack + 125399;
 target_ptr = Libderiv->deriv2_classes[2][7][1];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+118099, dvrr_stack+131710, dvrr_stack+130263);
 tmp = dvrr_stack + 118099;
 target_ptr = Libderiv->deriv2_classes[2][8][1];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,15,dvrr_stack+118369, dvrr_stack+132250, dvrr_stack+132160);
 tmp = dvrr_stack + 118369;
 target_ptr = Libderiv->deriv2_classes[3][4][1];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+132160, dvrr_stack+132601, dvrr_stack+132475);
 tmp = dvrr_stack + 132160;
 target_ptr = Libderiv->deriv2_classes[3][5][1];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+132370, dvrr_stack+100223, dvrr_stack+100055);
 tmp = dvrr_stack + 132370;
 target_ptr = Libderiv->deriv2_classes[3][6][1];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+100055, dvrr_stack+107499, dvrr_stack+100643);
 tmp = dvrr_stack + 100055;
 target_ptr = Libderiv->deriv2_classes[3][7][1];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+118519, dvrr_stack+51339, dvrr_stack+108039);
 tmp = dvrr_stack + 118519;
 target_ptr = Libderiv->deriv2_classes[3][8][1];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,15,dvrr_stack+100415, dvrr_stack+108309, dvrr_stack+125630);
 tmp = dvrr_stack + 100415;
 target_ptr = Libderiv->deriv2_classes[4][4][1];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+118969, dvrr_stack+46128, dvrr_stack+98144);
 tmp = dvrr_stack + 118969;
 target_ptr = Libderiv->deriv2_classes[4][5][1];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+119284, dvrr_stack+127754, dvrr_stack+131430);
 tmp = dvrr_stack + 119284;
 target_ptr = Libderiv->deriv2_classes[4][6][1];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+127754, dvrr_stack+134310, dvrr_stack+104031);
 tmp = dvrr_stack + 127754;
 target_ptr = Libderiv->deriv2_classes[4][7][1];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+119704, dvrr_stack+135066, dvrr_stack+131710);
 tmp = dvrr_stack + 119704;
 target_ptr = Libderiv->deriv2_classes[4][8][1];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,15,dvrr_stack+100640, dvrr_stack+108624, dvrr_stack+52014);
 tmp = dvrr_stack + 100640;
 target_ptr = Libderiv->deriv2_classes[2][4][0];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+100730, dvrr_stack+250, dvrr_stack+68794);
 tmp = dvrr_stack + 100730;
 target_ptr = Libderiv->deriv2_classes[2][5][0];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+132650, dvrr_stack+19857, dvrr_stack+563);
 tmp = dvrr_stack + 132650;
 target_ptr = Libderiv->deriv2_classes[2][6][0];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+120379, dvrr_stack+97013, dvrr_stack+1266);
 tmp = dvrr_stack + 120379;
 target_ptr = Libderiv->deriv2_classes[2][7][0];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+120595, dvrr_stack+136011, dvrr_stack+46569);
 tmp = dvrr_stack + 120595;
 target_ptr = Libderiv->deriv2_classes[2][8][0];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,15,dvrr_stack+125615, dvrr_stack+40901, dvrr_stack+5407);
 tmp = dvrr_stack + 125615;
 target_ptr = Libderiv->deriv2_classes[3][4][0];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+120865, dvrr_stack+97373, dvrr_stack+5497);
 tmp = dvrr_stack + 120865;
 target_ptr = Libderiv->deriv2_classes[3][5][0];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+97373, dvrr_stack+136461, dvrr_stack+98354);
 tmp = dvrr_stack + 97373;
 target_ptr = Libderiv->deriv2_classes[3][6][0];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+136461, dvrr_stack+100859, dvrr_stack+3029);
 tmp = dvrr_stack + 136461;
 target_ptr = Libderiv->deriv2_classes[3][7][0];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+97653, dvrr_stack+16151, dvrr_stack+104391);
 tmp = dvrr_stack + 97653;
 target_ptr = Libderiv->deriv2_classes[3][8][0];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 4 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,15,dvrr_stack+98103, dvrr_stack+104661, dvrr_stack+108624);
 tmp = dvrr_stack + 98103;
 target_ptr = Libderiv->deriv2_classes[4][4][0];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+100856, dvrr_stack+108774, dvrr_stack+250);
 tmp = dvrr_stack + 100856;
 target_ptr = Libderiv->deriv2_classes[4][5][0];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+121075, dvrr_stack+127166, dvrr_stack+19857);
 tmp = dvrr_stack + 121075;
 target_ptr = Libderiv->deriv2_classes[4][6][0];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+121495, dvrr_stack+128342, dvrr_stack+97013);
 tmp = dvrr_stack + 121495;
 target_ptr = Libderiv->deriv2_classes[4][7][0];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+128294, dvrr_stack+130398, dvrr_stack+136011);
 tmp = dvrr_stack + 128294;
 target_ptr = Libderiv->deriv2_classes[4][8][0];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];


}

