/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (ff|hg) integrals */

void d12vrr_order_ffhg(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+3, dvrr_stack+0, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+0, dvrr_stack+12, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+21, dvrr_stack+6, dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+31, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+34, dvrr_stack+31, dvrr_stack+3, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+40, dvrr_stack+34, dvrr_stack+6, dvrr_stack+31, dvrr_stack+3, NULL);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+50, dvrr_stack+40, dvrr_stack+21, NULL, NULL, dvrr_stack+6);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+80, dvrr_stack+40, dvrr_stack+21, dvrr_stack+34, dvrr_stack+6, NULL);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+95, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+98, dvrr_stack+95, dvrr_stack+31, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+104, dvrr_stack+98, dvrr_stack+34, dvrr_stack+95, dvrr_stack+31, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+114, dvrr_stack+104, dvrr_stack+40, dvrr_stack+98, dvrr_stack+34, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+129, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+132, dvrr_stack+12, dvrr_stack+129, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+138, dvrr_stack+15, dvrr_stack+132, dvrr_stack+0, dvrr_stack+12, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+148, dvrr_stack+21, dvrr_stack+138, dvrr_stack+6, dvrr_stack+15, NULL);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+163, dvrr_stack+80, dvrr_stack+148, NULL, NULL, dvrr_stack+21);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+208, dvrr_stack+114, dvrr_stack+80, NULL, NULL, dvrr_stack+40);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+253, dvrr_stack+208, dvrr_stack+163, dvrr_stack+114, dvrr_stack+80, dvrr_stack+50);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+343, dvrr_stack+80, dvrr_stack+148, dvrr_stack+40, dvrr_stack+21, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+364, dvrr_stack+114, dvrr_stack+80, dvrr_stack+104, dvrr_stack+40, NULL);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+385, dvrr_stack+364, dvrr_stack+343, NULL, NULL, dvrr_stack+80);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+448, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+451, dvrr_stack+448, dvrr_stack+95, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+457, dvrr_stack+451, dvrr_stack+98, dvrr_stack+448, dvrr_stack+95, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+467, dvrr_stack+457, dvrr_stack+104, dvrr_stack+451, dvrr_stack+98, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+482, dvrr_stack+467, dvrr_stack+114, dvrr_stack+457, dvrr_stack+104, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+503, dvrr_stack+482, dvrr_stack+364, NULL, NULL, dvrr_stack+114);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+95, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+448, dvrr_stack+129, dvrr_stack+95, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+566, dvrr_stack+132, dvrr_stack+448, dvrr_stack+12, dvrr_stack+129, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+576, dvrr_stack+138, dvrr_stack+566, dvrr_stack+15, dvrr_stack+132, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+591, dvrr_stack+148, dvrr_stack+576, dvrr_stack+21, dvrr_stack+138, NULL);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+612, dvrr_stack+343, dvrr_stack+591, NULL, NULL, dvrr_stack+148);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+675, dvrr_stack+385, dvrr_stack+612, dvrr_stack+364, dvrr_stack+343, dvrr_stack+163);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+801, dvrr_stack+503, dvrr_stack+385, dvrr_stack+482, dvrr_stack+364, dvrr_stack+208);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+927, dvrr_stack+801, dvrr_stack+675, dvrr_stack+503, dvrr_stack+385, dvrr_stack+253);
 tmp = dvrr_stack + 927;
 target_ptr = Libderiv->dvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1137, dvrr_stack+343, dvrr_stack+591, dvrr_stack+80, dvrr_stack+148, NULL);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1165, dvrr_stack+364, dvrr_stack+343, dvrr_stack+114, dvrr_stack+80, NULL);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1193, dvrr_stack+1165, dvrr_stack+1137, NULL, NULL, dvrr_stack+343);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1277, dvrr_stack+482, dvrr_stack+364, dvrr_stack+467, dvrr_stack+114, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1305, dvrr_stack+1277, dvrr_stack+1165, NULL, NULL, dvrr_stack+364);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+454, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1389, dvrr_stack+95, dvrr_stack+454, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1395, dvrr_stack+448, dvrr_stack+1389, dvrr_stack+129, dvrr_stack+95, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1405, dvrr_stack+566, dvrr_stack+1395, dvrr_stack+132, dvrr_stack+448, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1420, dvrr_stack+576, dvrr_stack+1405, dvrr_stack+138, dvrr_stack+566, NULL);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1441, dvrr_stack+591, dvrr_stack+1420, dvrr_stack+148, dvrr_stack+576, NULL);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1469, dvrr_stack+1137, dvrr_stack+1441, NULL, NULL, dvrr_stack+591);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+1553, dvrr_stack+1193, dvrr_stack+1469, dvrr_stack+1165, dvrr_stack+1137, dvrr_stack+612);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+1721, dvrr_stack+1305, dvrr_stack+1193, dvrr_stack+1277, dvrr_stack+1165, dvrr_stack+385);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+1889, dvrr_stack+1721, dvrr_stack+1553, dvrr_stack+1305, dvrr_stack+1193, dvrr_stack+675);
 tmp = dvrr_stack + 1889;
 target_ptr = Libderiv->dvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+2169,dvrr_stack+1889,dvrr_stack+927,10);


 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2799, dvrr_stack+1137, dvrr_stack+1441, dvrr_stack+343, dvrr_stack+591, NULL);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2835, dvrr_stack+1165, dvrr_stack+1137, dvrr_stack+364, dvrr_stack+343, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2871, dvrr_stack+2835, dvrr_stack+2799, NULL, NULL, dvrr_stack+1137);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2979, dvrr_stack+1277, dvrr_stack+1165, dvrr_stack+482, dvrr_stack+364, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3015, dvrr_stack+2979, dvrr_stack+2835, NULL, NULL, dvrr_stack+1165);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+364, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+367, dvrr_stack+454, dvrr_stack+364, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+373, dvrr_stack+1389, dvrr_stack+367, dvrr_stack+95, dvrr_stack+454, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+482, dvrr_stack+1395, dvrr_stack+373, dvrr_stack+448, dvrr_stack+1389, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+3123, dvrr_stack+1405, dvrr_stack+482, dvrr_stack+566, dvrr_stack+1395, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3144, dvrr_stack+1420, dvrr_stack+3123, dvrr_stack+576, dvrr_stack+1405, NULL);

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3172, dvrr_stack+1441, dvrr_stack+3144, dvrr_stack+591, dvrr_stack+1420, NULL);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3208, dvrr_stack+2799, dvrr_stack+3172, NULL, NULL, dvrr_stack+1441);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3316, dvrr_stack+2871, dvrr_stack+3208, dvrr_stack+2835, dvrr_stack+2799, dvrr_stack+1469);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3532, dvrr_stack+3015, dvrr_stack+2871, dvrr_stack+2979, dvrr_stack+2835, dvrr_stack+1193);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3748, dvrr_stack+3532, dvrr_stack+3316, dvrr_stack+3015, dvrr_stack+2871, dvrr_stack+1553);
 tmp = dvrr_stack + 3748;
 target_ptr = Libderiv->dvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+4108,dvrr_stack+3748,dvrr_stack+1889,10);


 /* compute (3 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+4948,dvrr_stack+4108,dvrr_stack+2169,10);


 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,210,dvrr_stack+6208, dvrr_stack+4948, dvrr_stack+927);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6838, dvrr_stack+2799, dvrr_stack+3172, dvrr_stack+1137, dvrr_stack+1441, NULL);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6883, dvrr_stack+2835, dvrr_stack+2799, dvrr_stack+1165, dvrr_stack+1137, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6928, dvrr_stack+6883, dvrr_stack+6838, NULL, NULL, dvrr_stack+2799);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7063, dvrr_stack+2979, dvrr_stack+2835, dvrr_stack+1277, dvrr_stack+1165, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7108, dvrr_stack+7063, dvrr_stack+6883, NULL, NULL, dvrr_stack+2835);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1165, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+497, dvrr_stack+364, dvrr_stack+1165, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1168, dvrr_stack+367, dvrr_stack+497, dvrr_stack+454, dvrr_stack+364, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1178, dvrr_stack+373, dvrr_stack+1168, dvrr_stack+1389, dvrr_stack+367, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1277, dvrr_stack+482, dvrr_stack+1178, dvrr_stack+1395, dvrr_stack+373, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+7243, dvrr_stack+3123, dvrr_stack+1277, dvrr_stack+1405, dvrr_stack+482, NULL);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7271, dvrr_stack+3144, dvrr_stack+7243, dvrr_stack+1420, dvrr_stack+3123, NULL);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7307, dvrr_stack+3172, dvrr_stack+7271, dvrr_stack+1441, dvrr_stack+3144, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7352, dvrr_stack+6838, dvrr_stack+7307, NULL, NULL, dvrr_stack+3172);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7487, dvrr_stack+6928, dvrr_stack+7352, dvrr_stack+6883, dvrr_stack+6838, dvrr_stack+3208);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7757, dvrr_stack+7108, dvrr_stack+6928, dvrr_stack+7063, dvrr_stack+6883, dvrr_stack+2871);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8027, dvrr_stack+7757, dvrr_stack+7487, dvrr_stack+7108, dvrr_stack+6928, dvrr_stack+3316);
 tmp = dvrr_stack + 8027;
 target_ptr = Libderiv->dvrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+8477,dvrr_stack+8027,dvrr_stack+3748,10);


 /* compute (3 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+9557,dvrr_stack+8477,dvrr_stack+4108,10);


 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,280,dvrr_stack+11237, dvrr_stack+9557, dvrr_stack+1889);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12077, dvrr_stack+6838, dvrr_stack+7307, dvrr_stack+2799, dvrr_stack+3172, NULL);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12132, dvrr_stack+6883, dvrr_stack+6838, dvrr_stack+2835, dvrr_stack+2799, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12187, dvrr_stack+12132, dvrr_stack+12077, NULL, NULL, dvrr_stack+6838);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12352, dvrr_stack+7063, dvrr_stack+6883, dvrr_stack+2979, dvrr_stack+2835, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12407, dvrr_stack+12352, dvrr_stack+12132, NULL, NULL, dvrr_stack+6883);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+2835, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+2838, dvrr_stack+1165, dvrr_stack+2835, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2844, dvrr_stack+497, dvrr_stack+2838, dvrr_stack+364, dvrr_stack+1165, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2854, dvrr_stack+1168, dvrr_stack+2844, dvrr_stack+367, dvrr_stack+497, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2979, dvrr_stack+1178, dvrr_stack+2854, dvrr_stack+373, dvrr_stack+1168, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+12572, dvrr_stack+1277, dvrr_stack+2979, dvrr_stack+482, dvrr_stack+1178, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+12600, dvrr_stack+7243, dvrr_stack+12572, dvrr_stack+3123, dvrr_stack+1277, NULL);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12636, dvrr_stack+7271, dvrr_stack+12600, dvrr_stack+3144, dvrr_stack+7243, NULL);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12681, dvrr_stack+7307, dvrr_stack+12636, dvrr_stack+3172, dvrr_stack+7271, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12736, dvrr_stack+12077, dvrr_stack+12681, NULL, NULL, dvrr_stack+7307);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12901, dvrr_stack+12187, dvrr_stack+12736, dvrr_stack+12132, dvrr_stack+12077, dvrr_stack+7352);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+13231, dvrr_stack+12407, dvrr_stack+12187, dvrr_stack+12352, dvrr_stack+12132, dvrr_stack+6928);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+13561, dvrr_stack+13231, dvrr_stack+12901, dvrr_stack+12407, dvrr_stack+12187, dvrr_stack+7487);
 tmp = dvrr_stack + 13561;
 target_ptr = Libderiv->dvrr_classes[3][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+14111,dvrr_stack+13561,dvrr_stack+8027,10);


 /* compute (3 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+15461,dvrr_stack+14111,dvrr_stack+8477,10);


 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,360,dvrr_stack+17621, dvrr_stack+15461, dvrr_stack+3748);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18701, dvrr_stack+12077, dvrr_stack+12681, dvrr_stack+6838, dvrr_stack+7307, NULL);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18767, dvrr_stack+12132, dvrr_stack+12077, dvrr_stack+6883, dvrr_stack+6838, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18833, dvrr_stack+18767, dvrr_stack+18701, NULL, NULL, dvrr_stack+12077);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19031, dvrr_stack+12352, dvrr_stack+12132, dvrr_stack+7063, dvrr_stack+6883, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19097, dvrr_stack+19031, dvrr_stack+18767, NULL, NULL, dvrr_stack+12132);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+364, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6883, dvrr_stack+2835, dvrr_stack+364, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+6889, dvrr_stack+2838, dvrr_stack+6883, dvrr_stack+1165, dvrr_stack+2835, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+3000, dvrr_stack+2844, dvrr_stack+6889, dvrr_stack+497, dvrr_stack+2838, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+6899, dvrr_stack+2854, dvrr_stack+3000, dvrr_stack+1168, dvrr_stack+2844, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+7063, dvrr_stack+2979, dvrr_stack+6899, dvrr_stack+1178, dvrr_stack+2854, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+19295, dvrr_stack+12572, dvrr_stack+7063, dvrr_stack+1277, dvrr_stack+2979, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19331, dvrr_stack+12600, dvrr_stack+19295, dvrr_stack+7243, dvrr_stack+12572, NULL);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19376, dvrr_stack+12636, dvrr_stack+19331, dvrr_stack+7271, dvrr_stack+12600, NULL);

 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19431, dvrr_stack+12681, dvrr_stack+19376, dvrr_stack+7307, dvrr_stack+12636, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19497, dvrr_stack+18701, dvrr_stack+19431, NULL, NULL, dvrr_stack+12681);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19695, dvrr_stack+18833, dvrr_stack+19497, dvrr_stack+18767, dvrr_stack+18701, dvrr_stack+12736);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20091, dvrr_stack+19097, dvrr_stack+18833, dvrr_stack+19031, dvrr_stack+18767, dvrr_stack+12187);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20487, dvrr_stack+20091, dvrr_stack+19695, dvrr_stack+19097, dvrr_stack+18833, dvrr_stack+12901);

 /* compute (3 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+21147,dvrr_stack+20487,dvrr_stack+13561,10);


 /* compute (3 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+22797,dvrr_stack+21147,dvrr_stack+14111,10);


 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,450,dvrr_stack+25497, dvrr_stack+22797, dvrr_stack+8027);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+19097, dvrr_stack+18701, dvrr_stack+19431, dvrr_stack+12077, dvrr_stack+12681, NULL);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+19175, dvrr_stack+18767, dvrr_stack+18701, dvrr_stack+12132, dvrr_stack+12077, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+26847, dvrr_stack+19175, dvrr_stack+19097, NULL, NULL, dvrr_stack+18701);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27081, dvrr_stack+19031, dvrr_stack+18767, dvrr_stack+12352, dvrr_stack+12132, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27159, dvrr_stack+27081, dvrr_stack+19175, NULL, NULL, dvrr_stack+18767);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1165, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+497, dvrr_stack+364, dvrr_stack+1165, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+18767, dvrr_stack+6883, dvrr_stack+497, dvrr_stack+2835, dvrr_stack+364, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+18777, dvrr_stack+6889, dvrr_stack+18767, dvrr_stack+2838, dvrr_stack+6883, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+18792, dvrr_stack+3000, dvrr_stack+18777, dvrr_stack+2844, dvrr_stack+6889, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+12132, dvrr_stack+6899, dvrr_stack+18792, dvrr_stack+2854, dvrr_stack+3000, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+12352, dvrr_stack+7063, dvrr_stack+12132, dvrr_stack+2979, dvrr_stack+6899, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19031, dvrr_stack+19295, dvrr_stack+12352, dvrr_stack+12572, dvrr_stack+7063, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+27393, dvrr_stack+19331, dvrr_stack+19031, dvrr_stack+12600, dvrr_stack+19295, NULL);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27448, dvrr_stack+19376, dvrr_stack+27393, dvrr_stack+12636, dvrr_stack+19331, NULL);

 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27514, dvrr_stack+19431, dvrr_stack+27448, dvrr_stack+12681, dvrr_stack+19376, NULL);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27592, dvrr_stack+19097, dvrr_stack+27514, NULL, NULL, dvrr_stack+19431);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27826, dvrr_stack+26847, dvrr_stack+27592, dvrr_stack+19175, dvrr_stack+19097, dvrr_stack+19497);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28294, dvrr_stack+27159, dvrr_stack+26847, dvrr_stack+27081, dvrr_stack+19175, dvrr_stack+18833);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28762, dvrr_stack+28294, dvrr_stack+27826, dvrr_stack+27159, dvrr_stack+26847, dvrr_stack+19695);

 /* compute (3 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+29542,dvrr_stack+28762,dvrr_stack+20487,10);


 /* compute (3 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+31522,dvrr_stack+29542,dvrr_stack+21147,10);


 /* compute (3 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,550,dvrr_stack+34822, dvrr_stack+31522, dvrr_stack+13561);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+19175, dvrr_stack+6, dvrr_stack+15, NULL, NULL, dvrr_stack+0);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+19193, dvrr_stack+21, dvrr_stack+138, NULL, NULL, dvrr_stack+15);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+19223, dvrr_stack+50, dvrr_stack+19193, dvrr_stack+40, dvrr_stack+21, dvrr_stack+19175);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+27081, dvrr_stack+148, dvrr_stack+576, NULL, NULL, dvrr_stack+138);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+27126, dvrr_stack+163, dvrr_stack+27081, dvrr_stack+80, dvrr_stack+148, dvrr_stack+19193);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+27216, dvrr_stack+253, dvrr_stack+27126, dvrr_stack+208, dvrr_stack+163, dvrr_stack+19223);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+36472, dvrr_stack+591, dvrr_stack+1420, NULL, NULL, dvrr_stack+576);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+36535, dvrr_stack+612, dvrr_stack+36472, dvrr_stack+343, dvrr_stack+591, dvrr_stack+27081);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+36661, dvrr_stack+675, dvrr_stack+36535, dvrr_stack+385, dvrr_stack+612, dvrr_stack+27126);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+36871, dvrr_stack+927, dvrr_stack+36661, dvrr_stack+801, dvrr_stack+675, dvrr_stack+27216);
 tmp = dvrr_stack + 36871;
 target_ptr = Libderiv->dvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+37186, dvrr_stack+1441, dvrr_stack+3144, NULL, NULL, dvrr_stack+1420);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+37270, dvrr_stack+1469, dvrr_stack+37186, dvrr_stack+1137, dvrr_stack+1441, dvrr_stack+36472);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+37438, dvrr_stack+1553, dvrr_stack+37270, dvrr_stack+1193, dvrr_stack+1469, dvrr_stack+36535);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+37718, dvrr_stack+1889, dvrr_stack+37438, dvrr_stack+1721, dvrr_stack+1553, dvrr_stack+36661);
 tmp = dvrr_stack + 37718;
 target_ptr = Libderiv->dvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+38138,dvrr_stack+37718,dvrr_stack+36871,15);


 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+39083, dvrr_stack+3172, dvrr_stack+7271, NULL, NULL, dvrr_stack+3144);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+39191, dvrr_stack+3208, dvrr_stack+39083, dvrr_stack+2799, dvrr_stack+3172, dvrr_stack+37186);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+39407, dvrr_stack+3316, dvrr_stack+39191, dvrr_stack+2871, dvrr_stack+3208, dvrr_stack+37270);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+39767, dvrr_stack+3748, dvrr_stack+39407, dvrr_stack+3532, dvrr_stack+3316, dvrr_stack+37438);
 tmp = dvrr_stack + 39767;
 target_ptr = Libderiv->dvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+40307,dvrr_stack+39767,dvrr_stack+37718,15);


 /* compute (4 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+41567,dvrr_stack+40307,dvrr_stack+38138,15);


 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,315,dvrr_stack+43457, dvrr_stack+41567, dvrr_stack+36871);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+44402, dvrr_stack+7307, dvrr_stack+12636, NULL, NULL, dvrr_stack+7271);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+44537, dvrr_stack+7352, dvrr_stack+44402, dvrr_stack+6838, dvrr_stack+7307, dvrr_stack+39083);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+44807, dvrr_stack+7487, dvrr_stack+44537, dvrr_stack+6928, dvrr_stack+7352, dvrr_stack+39191);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+45257, dvrr_stack+8027, dvrr_stack+44807, dvrr_stack+7757, dvrr_stack+7487, dvrr_stack+39407);
 tmp = dvrr_stack + 45257;
 target_ptr = Libderiv->dvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+45932,dvrr_stack+45257,dvrr_stack+39767,15);


 /* compute (4 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+47552,dvrr_stack+45932,dvrr_stack+40307,15);


 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,420,dvrr_stack+50072, dvrr_stack+47552, dvrr_stack+37718);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+51332, dvrr_stack+12681, dvrr_stack+19376, NULL, NULL, dvrr_stack+12636);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+51497, dvrr_stack+12736, dvrr_stack+51332, dvrr_stack+12077, dvrr_stack+12681, dvrr_stack+44402);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+51827, dvrr_stack+12901, dvrr_stack+51497, dvrr_stack+12187, dvrr_stack+12736, dvrr_stack+44537);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+52377, dvrr_stack+13561, dvrr_stack+51827, dvrr_stack+13231, dvrr_stack+12901, dvrr_stack+44807);
 tmp = dvrr_stack + 52377;
 target_ptr = Libderiv->dvrr_classes[4][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+53202,dvrr_stack+52377,dvrr_stack+45257,15);


 /* compute (4 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+55227,dvrr_stack+53202,dvrr_stack+45932,15);


 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,540,dvrr_stack+58467, dvrr_stack+55227, dvrr_stack+39767);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+60087, dvrr_stack+19431, dvrr_stack+27448, NULL, NULL, dvrr_stack+19376);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+60285, dvrr_stack+19497, dvrr_stack+60087, dvrr_stack+18701, dvrr_stack+19431, dvrr_stack+51332);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+60681, dvrr_stack+19695, dvrr_stack+60285, dvrr_stack+18833, dvrr_stack+19497, dvrr_stack+51497);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+61341, dvrr_stack+20487, dvrr_stack+60681, dvrr_stack+20091, dvrr_stack+19695, dvrr_stack+51827);

 /* compute (4 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+62331,dvrr_stack+61341,dvrr_stack+52377,15);


 /* compute (4 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+64806,dvrr_stack+62331,dvrr_stack+53202,15);


 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,675,dvrr_stack+68856, dvrr_stack+64806, dvrr_stack+45257);

 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+18701, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+18704, dvrr_stack+1165, dvrr_stack+18701, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+18710, dvrr_stack+497, dvrr_stack+18704, dvrr_stack+364, dvrr_stack+1165, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+80, dvrr_stack+18767, dvrr_stack+18710, dvrr_stack+6883, dvrr_stack+497, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+19076, dvrr_stack+18777, dvrr_stack+80, dvrr_stack+6889, dvrr_stack+18767, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1137, dvrr_stack+18792, dvrr_stack+19076, dvrr_stack+3000, dvrr_stack+18777, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+18720, dvrr_stack+12132, dvrr_stack+1137, dvrr_stack+6899, dvrr_stack+18792, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12077, dvrr_stack+12352, dvrr_stack+18720, dvrr_stack+7063, dvrr_stack+12132, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2799, dvrr_stack+19031, dvrr_stack+12077, dvrr_stack+19295, dvrr_stack+12352, NULL);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1193, dvrr_stack+27393, dvrr_stack+2799, dvrr_stack+19331, dvrr_stack+19031, NULL);

 /* compute (0 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+18813, dvrr_stack+27448, dvrr_stack+1193, dvrr_stack+19376, dvrr_stack+27393, NULL);

 /* compute (1 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+70881, dvrr_stack+27514, dvrr_stack+18813, NULL, NULL, dvrr_stack+27448);

 /* compute (2 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+71115, dvrr_stack+27592, dvrr_stack+70881, dvrr_stack+19097, dvrr_stack+27514, dvrr_stack+60087);

 /* compute (3 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+71583, dvrr_stack+27826, dvrr_stack+71115, dvrr_stack+26847, dvrr_stack+27592, dvrr_stack+60285);

 /* compute (4 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+72363, dvrr_stack+28762, dvrr_stack+71583, dvrr_stack+28294, dvrr_stack+27826, dvrr_stack+60681);

 /* compute (4 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+73533,dvrr_stack+72363,dvrr_stack+61341,15);


 /* compute (4 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+76503,dvrr_stack+73533,dvrr_stack+62331,15);


 /* compute (4 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,825,dvrr_stack+81453, dvrr_stack+76503, dvrr_stack+52377);

 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+28294, dvrr_stack+0, dvrr_stack+12, NULL, NULL, Data->F+5);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+1259, dvrr_stack+15, dvrr_stack+132, NULL, NULL, dvrr_stack+12);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+28303, dvrr_stack+19175, dvrr_stack+1259, dvrr_stack+6, dvrr_stack+15, dvrr_stack+28294);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+28339, dvrr_stack+138, dvrr_stack+566, NULL, NULL, dvrr_stack+132);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+28369, dvrr_stack+19193, dvrr_stack+28339, dvrr_stack+21, dvrr_stack+138, dvrr_stack+1259);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+28429, dvrr_stack+19223, dvrr_stack+28369, dvrr_stack+50, dvrr_stack+19193, dvrr_stack+28303);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+28529, dvrr_stack+576, dvrr_stack+1405, NULL, NULL, dvrr_stack+566);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+28574, dvrr_stack+27081, dvrr_stack+28529, dvrr_stack+148, dvrr_stack+576, dvrr_stack+28339);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+26847, dvrr_stack+27126, dvrr_stack+28574, dvrr_stack+163, dvrr_stack+27081, dvrr_stack+28369);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+83928, dvrr_stack+27216, dvrr_stack+26847, dvrr_stack+253, dvrr_stack+27126, dvrr_stack+28429);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+28664, dvrr_stack+1420, dvrr_stack+3123, NULL, NULL, dvrr_stack+1405);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+18891, dvrr_stack+36472, dvrr_stack+28664, dvrr_stack+591, dvrr_stack+1420, dvrr_stack+28529);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+84153, dvrr_stack+36535, dvrr_stack+18891, dvrr_stack+612, dvrr_stack+36472, dvrr_stack+28574);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+84363, dvrr_stack+36661, dvrr_stack+84153, dvrr_stack+675, dvrr_stack+36535, dvrr_stack+26847);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+84678, dvrr_stack+36871, dvrr_stack+84363, dvrr_stack+927, dvrr_stack+36661, dvrr_stack+83928);
 tmp = dvrr_stack + 84678;
 target_ptr = Libderiv->dvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+26997, dvrr_stack+3144, dvrr_stack+7243, NULL, NULL, dvrr_stack+3123);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+591, dvrr_stack+37186, dvrr_stack+26997, dvrr_stack+1441, dvrr_stack+3144, dvrr_stack+28664);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+85119, dvrr_stack+37270, dvrr_stack+591, dvrr_stack+1469, dvrr_stack+37186, dvrr_stack+18891);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+85399, dvrr_stack+37438, dvrr_stack+85119, dvrr_stack+1553, dvrr_stack+37270, dvrr_stack+84153);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+85819, dvrr_stack+37718, dvrr_stack+85399, dvrr_stack+1889, dvrr_stack+37438, dvrr_stack+84363);
 tmp = dvrr_stack + 85819;
 target_ptr = Libderiv->dvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+86407,dvrr_stack+85819,dvrr_stack+84678,21);


 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1441, dvrr_stack+7271, dvrr_stack+12600, NULL, NULL, dvrr_stack+7243);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+87730, dvrr_stack+39083, dvrr_stack+1441, dvrr_stack+3172, dvrr_stack+7271, dvrr_stack+26997);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+87946, dvrr_stack+39191, dvrr_stack+87730, dvrr_stack+3208, dvrr_stack+39083, dvrr_stack+591);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+88306, dvrr_stack+39407, dvrr_stack+87946, dvrr_stack+3316, dvrr_stack+39191, dvrr_stack+85119);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+88846, dvrr_stack+39767, dvrr_stack+88306, dvrr_stack+3748, dvrr_stack+39407, dvrr_stack+85399);
 tmp = dvrr_stack + 88846;
 target_ptr = Libderiv->dvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+89602,dvrr_stack+88846,dvrr_stack+85819,21);


 /* compute (5 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+91366,dvrr_stack+89602,dvrr_stack+86407,21);


 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,441,dvrr_stack+94012, dvrr_stack+91366, dvrr_stack+84678);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3172, dvrr_stack+12636, dvrr_stack+19331, NULL, NULL, dvrr_stack+12600);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+95335, dvrr_stack+44402, dvrr_stack+3172, dvrr_stack+7307, dvrr_stack+12636, dvrr_stack+1441);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+95605, dvrr_stack+44537, dvrr_stack+95335, dvrr_stack+7352, dvrr_stack+44402, dvrr_stack+87730);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+96055, dvrr_stack+44807, dvrr_stack+95605, dvrr_stack+7487, dvrr_stack+44537, dvrr_stack+87946);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+96730, dvrr_stack+45257, dvrr_stack+96055, dvrr_stack+8027, dvrr_stack+44807, dvrr_stack+88306);
 tmp = dvrr_stack + 96730;
 target_ptr = Libderiv->dvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+97675,dvrr_stack+96730,dvrr_stack+88846,21);


 /* compute (5 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+99943,dvrr_stack+97675,dvrr_stack+89602,21);


 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,588,dvrr_stack+103471, dvrr_stack+99943, dvrr_stack+85819);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+7307, dvrr_stack+19376, dvrr_stack+27393, NULL, NULL, dvrr_stack+19331);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+105235, dvrr_stack+51332, dvrr_stack+7307, dvrr_stack+12681, dvrr_stack+19376, dvrr_stack+3172);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+105565, dvrr_stack+51497, dvrr_stack+105235, dvrr_stack+12736, dvrr_stack+51332, dvrr_stack+95335);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+106115, dvrr_stack+51827, dvrr_stack+105565, dvrr_stack+12901, dvrr_stack+51497, dvrr_stack+95605);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+106940, dvrr_stack+52377, dvrr_stack+106115, dvrr_stack+13561, dvrr_stack+51827, dvrr_stack+96055);
 tmp = dvrr_stack + 106940;
 target_ptr = Libderiv->dvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+108095,dvrr_stack+106940,dvrr_stack+96730,21);


 /* compute (5 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+110930,dvrr_stack+108095,dvrr_stack+97675,21);


 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,756,dvrr_stack+115466, dvrr_stack+110930, dvrr_stack+88846);

 /* compute (1 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12681, dvrr_stack+27448, dvrr_stack+1193, NULL, NULL, dvrr_stack+27393);

 /* compute (2 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+117734, dvrr_stack+60087, dvrr_stack+12681, dvrr_stack+19431, dvrr_stack+27448, dvrr_stack+7307);

 /* compute (3 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+118130, dvrr_stack+60285, dvrr_stack+117734, dvrr_stack+19497, dvrr_stack+60087, dvrr_stack+105235);

 /* compute (4 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+118790, dvrr_stack+60681, dvrr_stack+118130, dvrr_stack+19695, dvrr_stack+60285, dvrr_stack+105565);

 /* compute (5 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+119780, dvrr_stack+61341, dvrr_stack+118790, dvrr_stack+20487, dvrr_stack+60681, dvrr_stack+106115);

 /* compute (5 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+121166,dvrr_stack+119780,dvrr_stack+106940,21);


 /* compute (5 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+124631,dvrr_stack+121166,dvrr_stack+108095,21);


 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,945,dvrr_stack+130301, dvrr_stack+124631, dvrr_stack+96730);

 /* compute (0 0 | 1 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+19431, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+19434, dvrr_stack+18701, dvrr_stack+19431, Data->F+14, Data->F+15, NULL);

 /* compute (0 0 | 3 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+21, dvrr_stack+18704, dvrr_stack+19434, dvrr_stack+1165, dvrr_stack+18701, NULL);

 /* compute (0 0 | 4 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+3000, dvrr_stack+18710, dvrr_stack+21, dvrr_stack+497, dvrr_stack+18704, NULL);

 /* compute (0 0 | 5 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+19440, dvrr_stack+80, dvrr_stack+3000, dvrr_stack+18767, dvrr_stack+18710, NULL);

 /* compute (0 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+19461, dvrr_stack+19076, dvrr_stack+19440, dvrr_stack+18777, dvrr_stack+80, NULL);

 /* compute (0 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+18756, dvrr_stack+1137, dvrr_stack+19461, dvrr_stack+18792, dvrr_stack+19076, NULL);

 /* compute (0 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19489, dvrr_stack+18720, dvrr_stack+18756, dvrr_stack+12132, dvrr_stack+1137, NULL);

 /* compute (0 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19534, dvrr_stack+12077, dvrr_stack+19489, dvrr_stack+12352, dvrr_stack+18720, NULL);

 /* compute (0 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19589, dvrr_stack+2799, dvrr_stack+19534, dvrr_stack+19031, dvrr_stack+12077, NULL);

 /* compute (0 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+19097, dvrr_stack+1193, dvrr_stack+19589, dvrr_stack+27393, dvrr_stack+2799, NULL);

 /* compute (1 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+19655, dvrr_stack+18813, dvrr_stack+19097, NULL, NULL, dvrr_stack+1193);

 /* compute (2 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+133136, dvrr_stack+70881, dvrr_stack+19655, dvrr_stack+27514, dvrr_stack+18813, dvrr_stack+12681);

 /* compute (3 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+133604, dvrr_stack+71115, dvrr_stack+133136, dvrr_stack+27592, dvrr_stack+70881, dvrr_stack+117734);

 /* compute (4 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+134384, dvrr_stack+71583, dvrr_stack+133604, dvrr_stack+27826, dvrr_stack+71115, dvrr_stack+118130);

 /* compute (5 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+135554, dvrr_stack+72363, dvrr_stack+134384, dvrr_stack+28762, dvrr_stack+71583, dvrr_stack+118790);

 /* compute (5 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+137192,dvrr_stack+135554,dvrr_stack+119780,21);


 /* compute (5 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+141350,dvrr_stack+137192,dvrr_stack+121166,21);


 /* compute (5 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1155,dvrr_stack+148280, dvrr_stack+141350, dvrr_stack+106940);

 /* compute (1 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+1165, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+27514, dvrr_stack+12, dvrr_stack+129, NULL, NULL, Data->F+6);

 /* compute (2 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+27523, dvrr_stack+28294, dvrr_stack+27514, dvrr_stack+0, dvrr_stack+12, dvrr_stack+1165);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+27541, dvrr_stack+132, dvrr_stack+448, NULL, NULL, dvrr_stack+129);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+27559, dvrr_stack+1259, dvrr_stack+27541, dvrr_stack+15, dvrr_stack+132, dvrr_stack+27514);

 /* compute (3 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+148, dvrr_stack+28303, dvrr_stack+27559, dvrr_stack+19175, dvrr_stack+1259, dvrr_stack+27523);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+27595, dvrr_stack+566, dvrr_stack+1395, NULL, NULL, dvrr_stack+448);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+27625, dvrr_stack+28339, dvrr_stack+27595, dvrr_stack+138, dvrr_stack+566, dvrr_stack+27541);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+27685, dvrr_stack+28369, dvrr_stack+27625, dvrr_stack+19193, dvrr_stack+28339, dvrr_stack+27559);

 /* compute (4 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+27785, dvrr_stack+28429, dvrr_stack+27685, dvrr_stack+19223, dvrr_stack+28369, dvrr_stack+148);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+27935, dvrr_stack+1405, dvrr_stack+482, NULL, NULL, dvrr_stack+1395);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+27980, dvrr_stack+28529, dvrr_stack+27935, dvrr_stack+576, dvrr_stack+1405, dvrr_stack+27595);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+28070, dvrr_stack+28574, dvrr_stack+27980, dvrr_stack+27081, dvrr_stack+28529, dvrr_stack+27625);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+3307, dvrr_stack+26847, dvrr_stack+28070, dvrr_stack+27126, dvrr_stack+28574, dvrr_stack+27685);

 /* compute (5 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+12879, dvrr_stack+83928, dvrr_stack+3307, dvrr_stack+27216, dvrr_stack+26847, dvrr_stack+27785);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+27081, dvrr_stack+3123, dvrr_stack+1277, NULL, NULL, dvrr_stack+482);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+19889, dvrr_stack+28664, dvrr_stack+27081, dvrr_stack+1420, dvrr_stack+3123, dvrr_stack+27935);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+7472, dvrr_stack+18891, dvrr_stack+19889, dvrr_stack+36472, dvrr_stack+28664, dvrr_stack+27980);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+151745, dvrr_stack+84153, dvrr_stack+7472, dvrr_stack+36535, dvrr_stack+18891, dvrr_stack+28070);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+152060, dvrr_stack+84363, dvrr_stack+151745, dvrr_stack+36661, dvrr_stack+84153, dvrr_stack+3307);

 /* compute (6 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+152501, dvrr_stack+84678, dvrr_stack+152060, dvrr_stack+36871, dvrr_stack+84363, dvrr_stack+12879);
 tmp = dvrr_stack + 152501;
 target_ptr = Libderiv->dvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+36472, dvrr_stack+7243, dvrr_stack+12572, NULL, NULL, dvrr_stack+1277);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+36556, dvrr_stack+26997, dvrr_stack+36472, dvrr_stack+3144, dvrr_stack+7243, dvrr_stack+27081);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+153089, dvrr_stack+591, dvrr_stack+36556, dvrr_stack+37186, dvrr_stack+26997, dvrr_stack+19889);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+153369, dvrr_stack+85119, dvrr_stack+153089, dvrr_stack+37270, dvrr_stack+591, dvrr_stack+7472);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+153789, dvrr_stack+85399, dvrr_stack+153369, dvrr_stack+37438, dvrr_stack+85119, dvrr_stack+151745);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+154377, dvrr_stack+85819, dvrr_stack+153789, dvrr_stack+37718, dvrr_stack+85399, dvrr_stack+152060);
 tmp = dvrr_stack + 154377;
 target_ptr = Libderiv->dvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+155161,dvrr_stack+154377,dvrr_stack+152501,28);


 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+37186, dvrr_stack+12600, dvrr_stack+19295, NULL, NULL, dvrr_stack+12572);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+37294, dvrr_stack+1441, dvrr_stack+37186, dvrr_stack+7271, dvrr_stack+12600, dvrr_stack+36472);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+156925, dvrr_stack+87730, dvrr_stack+37294, dvrr_stack+39083, dvrr_stack+1441, dvrr_stack+36556);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+157285, dvrr_stack+87946, dvrr_stack+156925, dvrr_stack+39191, dvrr_stack+87730, dvrr_stack+153089);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+157825, dvrr_stack+88306, dvrr_stack+157285, dvrr_stack+39407, dvrr_stack+87946, dvrr_stack+153369);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+158581, dvrr_stack+88846, dvrr_stack+157825, dvrr_stack+39767, dvrr_stack+88306, dvrr_stack+153789);
 tmp = dvrr_stack + 158581;
 target_ptr = Libderiv->dvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+159589,dvrr_stack+158581,dvrr_stack+154377,28);


 /* compute (6 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+161941,dvrr_stack+159589,dvrr_stack+155161,28);


 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,588,dvrr_stack+165469, dvrr_stack+161941, dvrr_stack+152501);

 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+39083, dvrr_stack+19331, dvrr_stack+19031, NULL, NULL, dvrr_stack+19295);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+39218, dvrr_stack+3172, dvrr_stack+39083, dvrr_stack+12636, dvrr_stack+19331, dvrr_stack+37186);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+167233, dvrr_stack+95335, dvrr_stack+39218, dvrr_stack+44402, dvrr_stack+3172, dvrr_stack+37294);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+167683, dvrr_stack+95605, dvrr_stack+167233, dvrr_stack+44537, dvrr_stack+95335, dvrr_stack+156925);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+168358, dvrr_stack+96055, dvrr_stack+167683, dvrr_stack+44807, dvrr_stack+95605, dvrr_stack+157285);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+169303, dvrr_stack+96730, dvrr_stack+168358, dvrr_stack+45257, dvrr_stack+96055, dvrr_stack+157825);
 tmp = dvrr_stack + 169303;
 target_ptr = Libderiv->dvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+170563,dvrr_stack+169303,dvrr_stack+158581,28);


 /* compute (6 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+173587,dvrr_stack+170563,dvrr_stack+159589,28);


 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,784,dvrr_stack+178291, dvrr_stack+173587, dvrr_stack+154377);

 /* compute (1 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+44402, dvrr_stack+27393, dvrr_stack+2799, NULL, NULL, dvrr_stack+19031);

 /* compute (2 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+44567, dvrr_stack+7307, dvrr_stack+44402, dvrr_stack+19376, dvrr_stack+27393, dvrr_stack+39083);

 /* compute (3 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+180643, dvrr_stack+105235, dvrr_stack+44567, dvrr_stack+51332, dvrr_stack+7307, dvrr_stack+39218);

 /* compute (4 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+181193, dvrr_stack+105565, dvrr_stack+180643, dvrr_stack+51497, dvrr_stack+105235, dvrr_stack+167233);

 /* compute (5 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+182018, dvrr_stack+106115, dvrr_stack+181193, dvrr_stack+51827, dvrr_stack+105565, dvrr_stack+167683);

 /* compute (6 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+183173, dvrr_stack+106940, dvrr_stack+182018, dvrr_stack+52377, dvrr_stack+106115, dvrr_stack+168358);

 /* compute (6 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+184713,dvrr_stack+183173,dvrr_stack+169303,28);


 /* compute (6 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+188493,dvrr_stack+184713,dvrr_stack+170563,28);


 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1008,dvrr_stack+194541, dvrr_stack+188493, dvrr_stack+158581);

 /* compute (1 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+51332, dvrr_stack+1193, dvrr_stack+19589, NULL, NULL, dvrr_stack+2799);

 /* compute (2 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+51530, dvrr_stack+12681, dvrr_stack+51332, dvrr_stack+27448, dvrr_stack+1193, dvrr_stack+44402);

 /* compute (3 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+197565, dvrr_stack+117734, dvrr_stack+51530, dvrr_stack+60087, dvrr_stack+12681, dvrr_stack+44567);

 /* compute (4 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+198225, dvrr_stack+118130, dvrr_stack+197565, dvrr_stack+60285, dvrr_stack+117734, dvrr_stack+180643);

 /* compute (5 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+199215, dvrr_stack+118790, dvrr_stack+198225, dvrr_stack+60681, dvrr_stack+118130, dvrr_stack+181193);

 /* compute (6 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+200601, dvrr_stack+119780, dvrr_stack+199215, dvrr_stack+61341, dvrr_stack+118790, dvrr_stack+182018);

 /* compute (6 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+202449,dvrr_stack+200601,dvrr_stack+183173,28);


 /* compute (6 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+207069,dvrr_stack+202449,dvrr_stack+184713,28);


 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1260,dvrr_stack+214629, dvrr_stack+207069, dvrr_stack+169303);

 /* compute (0 0 | 1 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+60087, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+19431, dvrr_stack+60087, Data->F+15, Data->F+16, NULL);

 /* compute (0 0 | 3 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+138, dvrr_stack+19434, dvrr_stack+15, dvrr_stack+18701, dvrr_stack+19431, NULL);

 /* compute (0 0 | 4 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+576, dvrr_stack+21, dvrr_stack+138, dvrr_stack+18704, dvrr_stack+19434, NULL);

 /* compute (0 0 | 5 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1420, dvrr_stack+3000, dvrr_stack+576, dvrr_stack+18710, dvrr_stack+21, NULL);

 /* compute (0 0 | 6 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3144, dvrr_stack+19440, dvrr_stack+1420, dvrr_stack+80, dvrr_stack+3000, NULL);

 /* compute (0 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7271, dvrr_stack+19461, dvrr_stack+3144, dvrr_stack+19076, dvrr_stack+19440, NULL);

 /* compute (0 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12636, dvrr_stack+18756, dvrr_stack+7271, dvrr_stack+1137, dvrr_stack+19461, NULL);

 /* compute (0 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+60087, dvrr_stack+19489, dvrr_stack+12636, dvrr_stack+18720, dvrr_stack+18756, NULL);

 /* compute (0 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27448, dvrr_stack+19534, dvrr_stack+60087, dvrr_stack+12077, dvrr_stack+19489, NULL);

 /* compute (0 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+60142, dvrr_stack+19589, dvrr_stack+27448, dvrr_stack+2799, dvrr_stack+19534, NULL);

 /* compute (1 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+60220, dvrr_stack+19097, dvrr_stack+60142, NULL, NULL, dvrr_stack+19589);

 /* compute (2 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+60454, dvrr_stack+19655, dvrr_stack+60220, dvrr_stack+18813, dvrr_stack+19097, dvrr_stack+51332);

 /* compute (3 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+218409, dvrr_stack+133136, dvrr_stack+60454, dvrr_stack+70881, dvrr_stack+19655, dvrr_stack+51530);

 /* compute (4 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+60142, dvrr_stack+133604, dvrr_stack+218409, dvrr_stack+71115, dvrr_stack+133136, dvrr_stack+197565);

 /* compute (5 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+218409, dvrr_stack+134384, dvrr_stack+60142, dvrr_stack+71583, dvrr_stack+133604, dvrr_stack+198225);

 /* compute (6 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+220047, dvrr_stack+135554, dvrr_stack+218409, dvrr_stack+72363, dvrr_stack+134384, dvrr_stack+199215);

 /* compute (6 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+222231,dvrr_stack+220047,dvrr_stack+200601,28);


 /* compute (6 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+227775,dvrr_stack+222231,dvrr_stack+202449,28);


 /* compute (6 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1540,dvrr_stack+237015, dvrr_stack+227775, dvrr_stack+183173);

 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,210,dvrr_stack+218409, dvrr_stack+4948, dvrr_stack+927);

 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,280,dvrr_stack+219039, dvrr_stack+9557, dvrr_stack+1889);

 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,360,dvrr_stack+60142, dvrr_stack+15461, dvrr_stack+3748);

 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,450,dvrr_stack+133136, dvrr_stack+22797, dvrr_stack+8027);

 /* compute (3 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,550,dvrr_stack+241635, dvrr_stack+31522, dvrr_stack+13561);

 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,315,dvrr_stack+134486, dvrr_stack+41567, dvrr_stack+36871);

 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,420,dvrr_stack+70881, dvrr_stack+47552, dvrr_stack+37718);

 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,540,dvrr_stack+243285, dvrr_stack+55227, dvrr_stack+39767);

 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,675,dvrr_stack+244905, dvrr_stack+64806, dvrr_stack+45257);

 /* compute (4 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,825,dvrr_stack+246930, dvrr_stack+76503, dvrr_stack+52377);

 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,441,dvrr_stack+249405, dvrr_stack+91366, dvrr_stack+84678);

 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,588,dvrr_stack+250728, dvrr_stack+99943, dvrr_stack+85819);

 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,756,dvrr_stack+252492, dvrr_stack+110930, dvrr_stack+88846);

 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,945,dvrr_stack+254760, dvrr_stack+124631, dvrr_stack+96730);

 /* compute (5 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1155,dvrr_stack+257595, dvrr_stack+141350, dvrr_stack+106940);

 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,588,dvrr_stack+261060, dvrr_stack+161941, dvrr_stack+152501);

 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,784,dvrr_stack+262824, dvrr_stack+173587, dvrr_stack+154377);

 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1008,dvrr_stack+265176, dvrr_stack+188493, dvrr_stack+158581);

 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1260,dvrr_stack+268200, dvrr_stack+207069, dvrr_stack+169303);

 /* compute (6 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1540,dvrr_stack+271980, dvrr_stack+227775, dvrr_stack+183173);

 /* compute (3 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,210,dvrr_stack+276600, dvrr_stack+4948, dvrr_stack+927);

 /* compute (3 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,280,dvrr_stack+4948, dvrr_stack+9557, dvrr_stack+1889);

 /* compute (3 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,360,dvrr_stack+9557, dvrr_stack+15461, dvrr_stack+3748);

 /* compute (3 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,450,dvrr_stack+15461, dvrr_stack+22797, dvrr_stack+8027);

 /* compute (3 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,550,dvrr_stack+22797, dvrr_stack+31522, dvrr_stack+13561);

 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,315,dvrr_stack+31522, dvrr_stack+41567, dvrr_stack+36871);

 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,420,dvrr_stack+41567, dvrr_stack+47552, dvrr_stack+37718);

 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,540,dvrr_stack+47552, dvrr_stack+55227, dvrr_stack+39767);

 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,675,dvrr_stack+55227, dvrr_stack+64806, dvrr_stack+45257);

 /* compute (4 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,825,dvrr_stack+64806, dvrr_stack+76503, dvrr_stack+52377);

 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,441,dvrr_stack+76503, dvrr_stack+91366, dvrr_stack+84678);

 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,588,dvrr_stack+91366, dvrr_stack+99943, dvrr_stack+85819);

 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,756,dvrr_stack+99943, dvrr_stack+110930, dvrr_stack+88846);

 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,945,dvrr_stack+110930, dvrr_stack+124631, dvrr_stack+96730);

 /* compute (5 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1155,dvrr_stack+124631, dvrr_stack+141350, dvrr_stack+106940);

 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,588,dvrr_stack+141350, dvrr_stack+161941, dvrr_stack+152501);

 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,784,dvrr_stack+161941, dvrr_stack+173587, dvrr_stack+154377);

 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1008,dvrr_stack+173587, dvrr_stack+188493, dvrr_stack+158581);

 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1260,dvrr_stack+188493, dvrr_stack+207069, dvrr_stack+169303);

 /* compute (6 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1540,dvrr_stack+207069, dvrr_stack+227775, dvrr_stack+183173);

 /* compute (1 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+227775, dvrr_stack+34, dvrr_stack+6, NULL, NULL, dvrr_stack+3);

 /* compute (1 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+19193, dvrr_stack+104, dvrr_stack+40, NULL, NULL, dvrr_stack+34);

 /* compute (2 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+227793, dvrr_stack+19193, dvrr_stack+50, dvrr_stack+104, dvrr_stack+40, dvrr_stack+227775);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+12636, dvrr_stack+467, dvrr_stack+114, NULL, NULL, dvrr_stack+104);

 /* compute (2 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+227853, dvrr_stack+12636, dvrr_stack+208, dvrr_stack+467, dvrr_stack+114, dvrr_stack+19193);

 /* compute (3 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+227943, dvrr_stack+227853, dvrr_stack+253, dvrr_stack+12636, dvrr_stack+208, dvrr_stack+227793);

 /* compute (3 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+228093,dvrr_stack+927,dvrr_stack+227943,10);


 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,150,dvrr_stack+228543, dvrr_stack+228093, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,280,dvrr_stack+228693, dvrr_stack+4108, NULL);
 tmp = dvrr_stack + 228693;
 target_ptr = Libderiv->deriv_classes[3][6][11];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,210,dvrr_stack+228973, dvrr_stack+2169, NULL);
 tmp = dvrr_stack + 228973;
 target_ptr = Libderiv->deriv_classes[3][5][11];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,360,dvrr_stack+44897, dvrr_stack+8477, NULL);
 tmp = dvrr_stack + 44897;
 target_ptr = Libderiv->deriv_classes[3][7][11];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,450,dvrr_stack+229183, dvrr_stack+14111, NULL);
 tmp = dvrr_stack + 229183;
 target_ptr = Libderiv->deriv_classes[3][8][11];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,550,dvrr_stack+229633, dvrr_stack+21147, NULL);
 tmp = dvrr_stack + 229633;
 target_ptr = Libderiv->deriv_classes[3][9][11];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,660,dvrr_stack+230183, dvrr_stack+29542, NULL);

 /* compute (1 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+208, dvrr_stack+3, dvrr_stack+0, NULL, NULL, Data->F+4);

 /* compute (2 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+217, dvrr_stack+227775, dvrr_stack+19175, dvrr_stack+34, dvrr_stack+6, dvrr_stack+208);

 /* compute (3 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+230843, dvrr_stack+227793, dvrr_stack+19223, dvrr_stack+19193, dvrr_stack+50, dvrr_stack+217);

 /* compute (4 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+230943, dvrr_stack+227943, dvrr_stack+27216, dvrr_stack+227853, dvrr_stack+253, dvrr_stack+230843);

 /* compute (4 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+231168,dvrr_stack+36871,dvrr_stack+230943,15);


 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,225,dvrr_stack+231843, dvrr_stack+231168, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+5788, dvrr_stack+40307, NULL);
 tmp = dvrr_stack + 5788;
 target_ptr = Libderiv->deriv_classes[4][6][11];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+232068, dvrr_stack+38138, NULL);
 tmp = dvrr_stack + 232068;
 target_ptr = Libderiv->deriv_classes[4][5][11];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,540,dvrr_stack+232383, dvrr_stack+45932, NULL);
 tmp = dvrr_stack + 232383;
 target_ptr = Libderiv->deriv_classes[4][7][11];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,675,dvrr_stack+232923, dvrr_stack+53202, NULL);
 tmp = dvrr_stack + 232923;
 target_ptr = Libderiv->deriv_classes[4][8][11];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,825,dvrr_stack+233598, dvrr_stack+62331, NULL);
 tmp = dvrr_stack + 233598;
 target_ptr = Libderiv->deriv_classes[4][9][11];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,990,dvrr_stack+234423, dvrr_stack+73533, NULL);

 /* compute (1 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+253, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (2 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+256, dvrr_stack+208, dvrr_stack+28294, dvrr_stack+3, dvrr_stack+0, dvrr_stack+253);

 /* compute (3 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+274, dvrr_stack+217, dvrr_stack+28303, dvrr_stack+227775, dvrr_stack+19175, dvrr_stack+256);

 /* compute (4 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+235413, dvrr_stack+230843, dvrr_stack+28429, dvrr_stack+227793, dvrr_stack+19223, dvrr_stack+274);

 /* compute (5 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+235563, dvrr_stack+230943, dvrr_stack+83928, dvrr_stack+227943, dvrr_stack+27216, dvrr_stack+235413);

 /* compute (5 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+235878,dvrr_stack+84678,dvrr_stack+235563,21);


 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+211689, dvrr_stack+235878, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+212004, dvrr_stack+89602, NULL);
 tmp = dvrr_stack + 212004;
 target_ptr = Libderiv->deriv_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,441,dvrr_stack+212592, dvrr_stack+86407, NULL);
 tmp = dvrr_stack + 212592;
 target_ptr = Libderiv->deriv_classes[5][5][11];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+213033, dvrr_stack+97675, NULL);
 tmp = dvrr_stack + 213033;
 target_ptr = Libderiv->deriv_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+192273, dvrr_stack+108095, NULL);
 tmp = dvrr_stack + 192273;
 target_ptr = Libderiv->deriv_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+193218, dvrr_stack+121166, NULL);
 tmp = dvrr_stack + 193218;
 target_ptr = Libderiv->deriv_classes[5][9][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+176611, dvrr_stack+137192, NULL);

 /* compute (2 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+6, dvrr_stack+253, dvrr_stack+1165, Data->F+4, Data->F+5, NULL);

 /* compute (3 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+19223, dvrr_stack+256, dvrr_stack+27523, dvrr_stack+208, dvrr_stack+28294, dvrr_stack+6);

 /* compute (4 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+236823, dvrr_stack+274, dvrr_stack+148, dvrr_stack+217, dvrr_stack+28303, dvrr_stack+19223);

 /* compute (5 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+213789, dvrr_stack+235413, dvrr_stack+27785, dvrr_stack+230843, dvrr_stack+28429, dvrr_stack+236823);

 /* compute (6 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+213999, dvrr_stack+235563, dvrr_stack+12879, dvrr_stack+230943, dvrr_stack+83928, dvrr_stack+213789);

 /* compute (6 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+102211,dvrr_stack+152501,dvrr_stack+213999,28);


 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+164293, dvrr_stack+102211, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,784,dvrr_stack+143114, dvrr_stack+159589, NULL);
 tmp = dvrr_stack + 143114;
 target_ptr = Libderiv->deriv_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+164713, dvrr_stack+155161, NULL);
 tmp = dvrr_stack + 164713;
 target_ptr = Libderiv->deriv_classes[6][5][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+143898, dvrr_stack+170563, NULL);
 tmp = dvrr_stack + 143898;
 target_ptr = Libderiv->deriv_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+144906, dvrr_stack+184713, NULL);
 tmp = dvrr_stack + 144906;
 target_ptr = Libderiv->deriv_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+146166, dvrr_stack+202449, NULL);
 tmp = dvrr_stack + 146166;
 target_ptr = Libderiv->deriv_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+128096, dvrr_stack+222231, NULL);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,150,dvrr_stack+214419, dvrr_stack+228093, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+177997, dvrr_stack+4108, NULL);
 tmp = dvrr_stack + 177997;
 target_ptr = Libderiv->deriv_classes[3][6][10];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,210,dvrr_stack+147706, dvrr_stack+2169, NULL);
 tmp = dvrr_stack + 147706;
 target_ptr = Libderiv->deriv_classes[3][5][10];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+147916, dvrr_stack+8477, NULL);
 tmp = dvrr_stack + 147916;
 target_ptr = Libderiv->deriv_classes[3][7][10];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+113765, dvrr_stack+14111, NULL);
 tmp = dvrr_stack + 113765;
 target_ptr = Libderiv->deriv_classes[3][8][10];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,550,dvrr_stack+114215, dvrr_stack+21147, NULL);
 tmp = dvrr_stack + 114215;
 target_ptr = Libderiv->deriv_classes[3][9][10];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,660,dvrr_stack+114765, dvrr_stack+29542, NULL);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,225,dvrr_stack+129944, dvrr_stack+231168, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+93130, dvrr_stack+40307, NULL);
 tmp = dvrr_stack + 93130;
 target_ptr = Libderiv->deriv_classes[4][6][10];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+93550, dvrr_stack+38138, NULL);
 tmp = dvrr_stack + 93550;
 target_ptr = Libderiv->deriv_classes[4][5][10];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+77826, dvrr_stack+45932, NULL);
 tmp = dvrr_stack + 77826;
 target_ptr = Libderiv->deriv_classes[4][7][10];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+78366, dvrr_stack+53202, NULL);
 tmp = dvrr_stack + 78366;
 target_ptr = Libderiv->deriv_classes[4][8][10];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+79041, dvrr_stack+62331, NULL);
 tmp = dvrr_stack + 79041;
 target_ptr = Libderiv->deriv_classes[4][9][10];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,990,dvrr_stack+79866, dvrr_stack+73533, NULL);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+80856, dvrr_stack+235878, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+67281, dvrr_stack+89602, NULL);
 tmp = dvrr_stack + 67281;
 target_ptr = Libderiv->deriv_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+67869, dvrr_stack+86407, NULL);
 tmp = dvrr_stack + 67869;
 target_ptr = Libderiv->deriv_classes[5][5][10];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+57252, dvrr_stack+97675, NULL);
 tmp = dvrr_stack + 57252;
 target_ptr = Libderiv->deriv_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+32467, dvrr_stack+108095, NULL);
 tmp = dvrr_stack + 32467;
 target_ptr = Libderiv->deriv_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+33412, dvrr_stack+121166, NULL);
 tmp = dvrr_stack + 33412;
 target_ptr = Libderiv->deriv_classes[5][9][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+277230, dvrr_stack+137192, NULL);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+68310, dvrr_stack+102211, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+49172, dvrr_stack+159589, NULL);
 tmp = dvrr_stack + 49172;
 target_ptr = Libderiv->deriv_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+42827, dvrr_stack+155161, NULL);
 tmp = dvrr_stack + 42827;
 target_ptr = Libderiv->deriv_classes[6][5][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+24447, dvrr_stack+170563, NULL);
 tmp = dvrr_stack + 24447;
 target_ptr = Libderiv->deriv_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+278616, dvrr_stack+184713, NULL);
 tmp = dvrr_stack + 278616;
 target_ptr = Libderiv->deriv_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+279876, dvrr_stack+202449, NULL);
 tmp = dvrr_stack + 279876;
 target_ptr = Libderiv->deriv_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+281416, dvrr_stack+222231, NULL);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,150,dvrr_stack+194373, dvrr_stack+228093, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+228093, dvrr_stack+4108, NULL);
 tmp = dvrr_stack + 228093;
 target_ptr = Libderiv->deriv_classes[3][6][9];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+4108, dvrr_stack+2169, NULL);
 tmp = dvrr_stack + 4108;
 target_ptr = Libderiv->deriv_classes[3][5][9];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+2169, dvrr_stack+8477, NULL);
 tmp = dvrr_stack + 2169;
 target_ptr = Libderiv->deriv_classes[3][7][9];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+8477, dvrr_stack+14111, NULL);
 tmp = dvrr_stack + 8477;
 target_ptr = Libderiv->deriv_classes[3][8][9];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+14111, dvrr_stack+21147, NULL);
 tmp = dvrr_stack + 14111;
 target_ptr = Libderiv->deriv_classes[3][9][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,660,dvrr_stack+21147, dvrr_stack+29542, NULL);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,225,dvrr_stack+29542, dvrr_stack+231168, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+231168, dvrr_stack+40307, NULL);
 tmp = dvrr_stack + 231168;
 target_ptr = Libderiv->deriv_classes[4][6][9];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+40307, dvrr_stack+38138, NULL);
 tmp = dvrr_stack + 40307;
 target_ptr = Libderiv->deriv_classes[4][5][9];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+38138, dvrr_stack+45932, NULL);
 tmp = dvrr_stack + 38138;
 target_ptr = Libderiv->deriv_classes[4][7][9];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+45932, dvrr_stack+53202, NULL);
 tmp = dvrr_stack + 45932;
 target_ptr = Libderiv->deriv_classes[4][8][9];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+53202, dvrr_stack+62331, NULL);
 tmp = dvrr_stack + 53202;
 target_ptr = Libderiv->deriv_classes[4][9][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,990,dvrr_stack+21807, dvrr_stack+73533, NULL);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+73533, dvrr_stack+235878, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+235878, dvrr_stack+89602, NULL);
 tmp = dvrr_stack + 235878;
 target_ptr = Libderiv->deriv_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+89602, dvrr_stack+86407, NULL);
 tmp = dvrr_stack + 89602;
 target_ptr = Libderiv->deriv_classes[5][5][9];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+86407, dvrr_stack+97675, NULL);
 tmp = dvrr_stack + 86407;
 target_ptr = Libderiv->deriv_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+46607, dvrr_stack+108095, NULL);
 tmp = dvrr_stack + 46607;
 target_ptr = Libderiv->deriv_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+108095, dvrr_stack+121166, NULL);
 tmp = dvrr_stack + 108095;
 target_ptr = Libderiv->deriv_classes[5][9][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+121166, dvrr_stack+137192, NULL);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+137192, dvrr_stack+102211, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+102211, dvrr_stack+159589, NULL);
 tmp = dvrr_stack + 102211;
 target_ptr = Libderiv->deriv_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+159589, dvrr_stack+155161, NULL);
 tmp = dvrr_stack + 159589;
 target_ptr = Libderiv->deriv_classes[6][5][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+155161, dvrr_stack+170563, NULL);
 tmp = dvrr_stack + 155161;
 target_ptr = Libderiv->deriv_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+170563, dvrr_stack+184713, NULL);
 tmp = dvrr_stack + 170563;
 target_ptr = Libderiv->deriv_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+184713, dvrr_stack+202449, NULL);
 tmp = dvrr_stack + 184713;
 target_ptr = Libderiv->deriv_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+202449, dvrr_stack+222231, NULL);

 /* compute (1 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+222231, dvrr_stack+31, dvrr_stack+3, NULL, NULL, Data->F+3);

 /* compute (1 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+194523, dvrr_stack+98, dvrr_stack+34, NULL, NULL, dvrr_stack+31);

 /* compute (2 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+7271, dvrr_stack+194523, dvrr_stack+227775, dvrr_stack+98, dvrr_stack+34, dvrr_stack+222231);

 /* compute (1 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+34, dvrr_stack+457, dvrr_stack+104, NULL, NULL, dvrr_stack+98);

 /* compute (2 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+214569, dvrr_stack+34, dvrr_stack+19193, dvrr_stack+457, dvrr_stack+104, dvrr_stack+194523);

 /* compute (3 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+222240, dvrr_stack+214569, dvrr_stack+227793, dvrr_stack+34, dvrr_stack+19193, dvrr_stack+7271);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,10,1,dvrr_stack+222340, dvrr_stack+927, dvrr_stack+222240);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+222490, dvrr_stack+3748, dvrr_stack+927);
 tmp = dvrr_stack + 222490;
 target_ptr = Libderiv->deriv_classes[3][6][8];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+222770, dvrr_stack+1889, dvrr_stack+227943);
 tmp = dvrr_stack + 222770;
 target_ptr = Libderiv->deriv_classes[3][5][8];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+222980, dvrr_stack+8027, dvrr_stack+1889);
 tmp = dvrr_stack + 222980;
 target_ptr = Libderiv->deriv_classes[3][7][8];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+223340, dvrr_stack+13561, dvrr_stack+3748);
 tmp = dvrr_stack + 223340;
 target_ptr = Libderiv->deriv_classes[3][8][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+223790, dvrr_stack+20487, dvrr_stack+8027);
 tmp = dvrr_stack + 223790;
 target_ptr = Libderiv->deriv_classes[3][9][8];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,10,1,dvrr_stack+224340, dvrr_stack+28762, dvrr_stack+13561);

 /* compute (1 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (2 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+34, dvrr_stack+222231, dvrr_stack+208, dvrr_stack+31, dvrr_stack+3, dvrr_stack+0);

 /* compute (3 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+225000, dvrr_stack+7271, dvrr_stack+217, dvrr_stack+194523, dvrr_stack+227775, dvrr_stack+34);

 /* compute (4 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+225060, dvrr_stack+222240, dvrr_stack+230843, dvrr_stack+214569, dvrr_stack+227793, dvrr_stack+225000);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,15,1,dvrr_stack+225210, dvrr_stack+36871, dvrr_stack+225060);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+225435, dvrr_stack+39767, dvrr_stack+36871);
 tmp = dvrr_stack + 225435;
 target_ptr = Libderiv->deriv_classes[4][6][8];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+225855, dvrr_stack+37718, dvrr_stack+230943);
 tmp = dvrr_stack + 225855;
 target_ptr = Libderiv->deriv_classes[4][5][8];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+226170, dvrr_stack+45257, dvrr_stack+37718);
 tmp = dvrr_stack + 226170;
 target_ptr = Libderiv->deriv_classes[4][7][8];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+226710, dvrr_stack+52377, dvrr_stack+39767);
 tmp = dvrr_stack + 226710;
 target_ptr = Libderiv->deriv_classes[4][8][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+204297, dvrr_stack+61341, dvrr_stack+45257);
 tmp = dvrr_stack + 204297;
 target_ptr = Libderiv->deriv_classes[4][9][8];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,15,1,dvrr_stack+205122, dvrr_stack+72363, dvrr_stack+52377);

 /* compute (2 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+497, dvrr_stack+0, dvrr_stack+253, Data->F+3, Data->F+4, NULL);

 /* compute (3 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+214569, dvrr_stack+34, dvrr_stack+256, dvrr_stack+222231, dvrr_stack+208, dvrr_stack+497);

 /* compute (4 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+227385, dvrr_stack+225000, dvrr_stack+274, dvrr_stack+7271, dvrr_stack+217, dvrr_stack+214569);

 /* compute (5 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+227475, dvrr_stack+225060, dvrr_stack+235413, dvrr_stack+222240, dvrr_stack+230843, dvrr_stack+227385);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,21,1,dvrr_stack+206112, dvrr_stack+84678, dvrr_stack+227475);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+206427, dvrr_stack+88846, dvrr_stack+84678);
 tmp = dvrr_stack + 206427;
 target_ptr = Libderiv->deriv_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+186253, dvrr_stack+85819, dvrr_stack+235563);
 tmp = dvrr_stack + 186253;
 target_ptr = Libderiv->deriv_classes[5][5][8];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+156169, dvrr_stack+96730, dvrr_stack+85819);
 tmp = dvrr_stack + 156169;
 target_ptr = Libderiv->deriv_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+40622, dvrr_stack+106940, dvrr_stack+88846);
 tmp = dvrr_stack + 40622;
 target_ptr = Libderiv->deriv_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+186694, dvrr_stack+119780, dvrr_stack+96730);
 tmp = dvrr_stack + 186694;
 target_ptr = Libderiv->deriv_classes[5][9][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+171823, dvrr_stack+135554, dvrr_stack+106940);

 /* compute (3 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+138, dvrr_stack+497, dvrr_stack+6, dvrr_stack+0, dvrr_stack+253, NULL);

 /* compute (4 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+208, dvrr_stack+214569, dvrr_stack+19223, dvrr_stack+34, dvrr_stack+256, dvrr_stack+138);

 /* compute (5 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+68730, dvrr_stack+227385, dvrr_stack+236823, dvrr_stack+225000, dvrr_stack+274, dvrr_stack+208);

 /* compute (6 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+187849, dvrr_stack+227475, dvrr_stack+213789, dvrr_stack+225060, dvrr_stack+235413, dvrr_stack+68730);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,28,1,dvrr_stack+160177, dvrr_stack+152501, dvrr_stack+187849);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+160597, dvrr_stack+158581, dvrr_stack+152501);
 tmp = dvrr_stack + 160597;
 target_ptr = Libderiv->deriv_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+137612, dvrr_stack+154377, dvrr_stack+213999);
 tmp = dvrr_stack + 137612;
 target_ptr = Libderiv->deriv_classes[6][5][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+138200, dvrr_stack+169303, dvrr_stack+154377);
 tmp = dvrr_stack + 138200;
 target_ptr = Libderiv->deriv_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+139208, dvrr_stack+183173, dvrr_stack+158581);
 tmp = dvrr_stack + 139208;
 target_ptr = Libderiv->deriv_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+122552, dvrr_stack+200601, dvrr_stack+169303);
 tmp = dvrr_stack + 122552;
 target_ptr = Libderiv->deriv_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+97675, dvrr_stack+220047, dvrr_stack+183173);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,10,1,dvrr_stack+227685, dvrr_stack+927, dvrr_stack+222240);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+188129, dvrr_stack+3748, dvrr_stack+927);
 tmp = dvrr_stack + 188129;
 target_ptr = Libderiv->deriv_classes[3][6][7];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+173209, dvrr_stack+1889, dvrr_stack+227943);
 tmp = dvrr_stack + 173209;
 target_ptr = Libderiv->deriv_classes[3][5][7];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+161381, dvrr_stack+8027, dvrr_stack+1889);
 tmp = dvrr_stack + 161381;
 target_ptr = Libderiv->deriv_classes[3][7][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+102995, dvrr_stack+13561, dvrr_stack+3748);
 tmp = dvrr_stack + 102995;
 target_ptr = Libderiv->deriv_classes[3][8][7];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+140468, dvrr_stack+20487, dvrr_stack+8027);
 tmp = dvrr_stack + 140468;
 target_ptr = Libderiv->deriv_classes[3][9][7];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,10,1,dvrr_stack+109250, dvrr_stack+28762, dvrr_stack+13561);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,15,1,dvrr_stack+141018, dvrr_stack+36871, dvrr_stack+225060);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+99523, dvrr_stack+39767, dvrr_stack+36871);
 tmp = dvrr_stack + 99523;
 target_ptr = Libderiv->deriv_classes[4][6][7];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+124092, dvrr_stack+37718, dvrr_stack+230943);
 tmp = dvrr_stack + 124092;
 target_ptr = Libderiv->deriv_classes[4][5][7];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+109910, dvrr_stack+45257, dvrr_stack+37718);
 tmp = dvrr_stack + 109910;
 target_ptr = Libderiv->deriv_classes[4][7][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+90043, dvrr_stack+52377, dvrr_stack+39767);
 tmp = dvrr_stack + 90043;
 target_ptr = Libderiv->deriv_classes[4][8][7];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+73848, dvrr_stack+61341, dvrr_stack+45257);
 tmp = dvrr_stack + 73848;
 target_ptr = Libderiv->deriv_classes[4][9][7];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,15,1,dvrr_stack+74673, dvrr_stack+72363, dvrr_stack+52377);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,21,1,dvrr_stack+110450, dvrr_stack+84678, dvrr_stack+227475);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+90718, dvrr_stack+88846, dvrr_stack+84678);
 tmp = dvrr_stack + 90718;
 target_ptr = Libderiv->deriv_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+87163, dvrr_stack+85819, dvrr_stack+235563);
 tmp = dvrr_stack + 87163;
 target_ptr = Libderiv->deriv_classes[5][5][7];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+75663, dvrr_stack+96730, dvrr_stack+85819);
 tmp = dvrr_stack + 75663;
 target_ptr = Libderiv->deriv_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+62331, dvrr_stack+106940, dvrr_stack+88846);
 tmp = dvrr_stack + 62331;
 target_ptr = Libderiv->deriv_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+63276, dvrr_stack+119780, dvrr_stack+96730);
 tmp = dvrr_stack + 63276;
 target_ptr = Libderiv->deriv_classes[5][9][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+29767, dvrr_stack+135554, dvrr_stack+106940);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,28,1,dvrr_stack+54027, dvrr_stack+152501, dvrr_stack+187849);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+14661, dvrr_stack+158581, dvrr_stack+152501);
 tmp = dvrr_stack + 14661;
 target_ptr = Libderiv->deriv_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+54447, dvrr_stack+154377, dvrr_stack+213999);
 tmp = dvrr_stack + 54447;
 target_ptr = Libderiv->deriv_classes[6][5][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+283264, dvrr_stack+169303, dvrr_stack+154377);
 tmp = dvrr_stack + 283264;
 target_ptr = Libderiv->deriv_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+284272, dvrr_stack+183173, dvrr_stack+158581);
 tmp = dvrr_stack + 284272;
 target_ptr = Libderiv->deriv_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+285532, dvrr_stack+200601, dvrr_stack+169303);
 tmp = dvrr_stack + 285532;
 target_ptr = Libderiv->deriv_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+287072, dvrr_stack+220047, dvrr_stack+183173);

 /* compute (3 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,10,1,dvrr_stack+173419, dvrr_stack+927, dvrr_stack+222240);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+236466, dvrr_stack+3748, dvrr_stack+927);
 tmp = dvrr_stack + 236466;
 target_ptr = Libderiv->deriv_classes[3][6][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+124407, dvrr_stack+1889, dvrr_stack+227943);
 tmp = dvrr_stack + 124407;
 target_ptr = Libderiv->deriv_classes[3][5][6];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+64431, dvrr_stack+8027, dvrr_stack+1889);
 tmp = dvrr_stack + 64431;
 target_ptr = Libderiv->deriv_classes[3][7][6];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+8927, dvrr_stack+13561, dvrr_stack+3748);
 tmp = dvrr_stack + 8927;
 target_ptr = Libderiv->deriv_classes[3][8][6];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+4318, dvrr_stack+20487, dvrr_stack+8027);
 tmp = dvrr_stack + 4318;
 target_ptr = Libderiv->deriv_classes[3][9][6];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,10,1,dvrr_stack+20487, dvrr_stack+28762, dvrr_stack+13561);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,15,1,dvrr_stack+38678, dvrr_stack+36871, dvrr_stack+225060);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+58008, dvrr_stack+39767, dvrr_stack+36871);
 tmp = dvrr_stack + 58008;
 target_ptr = Libderiv->deriv_classes[4][6][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+31153, dvrr_stack+37718, dvrr_stack+230943);
 tmp = dvrr_stack + 31153;
 target_ptr = Libderiv->deriv_classes[4][5][6];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+16811, dvrr_stack+45257, dvrr_stack+37718);
 tmp = dvrr_stack + 16811;
 target_ptr = Libderiv->deriv_classes[4][7][6];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+28727, dvrr_stack+52377, dvrr_stack+39767);
 tmp = dvrr_stack + 28727;
 target_ptr = Libderiv->deriv_classes[4][8][6];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+288920, dvrr_stack+61341, dvrr_stack+45257);
 tmp = dvrr_stack + 288920;
 target_ptr = Libderiv->deriv_classes[4][9][6];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,15,1,dvrr_stack+61222, dvrr_stack+72363, dvrr_stack+52377);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,21,1,dvrr_stack+230843, dvrr_stack+84678, dvrr_stack+227475);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+10637, dvrr_stack+88846, dvrr_stack+84678);
 tmp = dvrr_stack + 10637;
 target_ptr = Libderiv->deriv_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+72141, dvrr_stack+85819, dvrr_stack+235563);
 tmp = dvrr_stack + 72141;
 target_ptr = Libderiv->deriv_classes[5][5][6];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+72582, dvrr_stack+96730, dvrr_stack+85819);
 tmp = dvrr_stack + 72582;
 target_ptr = Libderiv->deriv_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+289745, dvrr_stack+106940, dvrr_stack+88846);
 tmp = dvrr_stack + 289745;
 target_ptr = Libderiv->deriv_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+290690, dvrr_stack+119780, dvrr_stack+96730);
 tmp = dvrr_stack + 290690;
 target_ptr = Libderiv->deriv_classes[5][9][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+291845, dvrr_stack+135554, dvrr_stack+106940);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,28,1,dvrr_stack+135431, dvrr_stack+152501, dvrr_stack+187849);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+135851, dvrr_stack+158581, dvrr_stack+152501);
 tmp = dvrr_stack + 135851;
 target_ptr = Libderiv->deriv_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+293231, dvrr_stack+154377, dvrr_stack+213999);
 tmp = dvrr_stack + 293231;
 target_ptr = Libderiv->deriv_classes[6][5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+293819, dvrr_stack+169303, dvrr_stack+154377);
 tmp = dvrr_stack + 293819;
 target_ptr = Libderiv->deriv_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+294827, dvrr_stack+183173, dvrr_stack+158581);
 tmp = dvrr_stack + 294827;
 target_ptr = Libderiv->deriv_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+296087, dvrr_stack+200601, dvrr_stack+169303);
 tmp = dvrr_stack + 296087;
 target_ptr = Libderiv->deriv_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+297627, dvrr_stack+220047, dvrr_stack+183173);

 /* compute (2 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+219879,dvrr_stack+1721,dvrr_stack+801,6);


 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,126,dvrr_stack+68730, dvrr_stack+219879, NULL);

 /* compute (2 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+220257,dvrr_stack+3532,dvrr_stack+1721,6);


 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,168,dvrr_stack+165301, dvrr_stack+220257, NULL);

 /* compute (2 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+220761,dvrr_stack+7757,dvrr_stack+3532,6);


 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,216,dvrr_stack+187849, dvrr_stack+220761, NULL);

 /* compute (2 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+221409,dvrr_stack+13231,dvrr_stack+7757,6);


 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,270,dvrr_stack+2529, dvrr_stack+221409, NULL);

 /* compute (2 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+299475,dvrr_stack+20091,dvrr_stack+13231,6);


 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,330,dvrr_stack+136635, dvrr_stack+299475, NULL);

 /* compute (1 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+188065, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+0, dvrr_stack+1165, dvrr_stack+188065, Data->F+5, Data->F+6, NULL);

 /* compute (1 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+188068, dvrr_stack+129, dvrr_stack+95, NULL, NULL, Data->F+7);

 /* compute (2 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+194523, dvrr_stack+27514, dvrr_stack+188068, dvrr_stack+12, dvrr_stack+129, dvrr_stack+188065);

 /* compute (3 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+12, dvrr_stack+27523, dvrr_stack+194523, dvrr_stack+28294, dvrr_stack+27514, dvrr_stack+0);

 /* compute (1 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+227835, dvrr_stack+448, dvrr_stack+1389, NULL, NULL, dvrr_stack+95);

 /* compute (2 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+7271, dvrr_stack+27541, dvrr_stack+227835, dvrr_stack+132, dvrr_stack+448, dvrr_stack+188068);

 /* compute (3 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+214569, dvrr_stack+27559, dvrr_stack+7271, dvrr_stack+1259, dvrr_stack+27541, dvrr_stack+194523);

 /* compute (4 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+227943, dvrr_stack+148, dvrr_stack+214569, dvrr_stack+28303, dvrr_stack+27559, dvrr_stack+12);

 /* compute (1 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+42, dvrr_stack+1395, dvrr_stack+373, NULL, NULL, dvrr_stack+1389);

 /* compute (2 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+228033, dvrr_stack+27595, dvrr_stack+42, dvrr_stack+566, dvrr_stack+1395, dvrr_stack+227835);

 /* compute (3 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+225000, dvrr_stack+27625, dvrr_stack+228033, dvrr_stack+28339, dvrr_stack+27595, dvrr_stack+7271);

 /* compute (4 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+227385, dvrr_stack+27685, dvrr_stack+225000, dvrr_stack+28369, dvrr_stack+27625, dvrr_stack+214569);

 /* compute (5 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+231588, dvrr_stack+27785, dvrr_stack+227385, dvrr_stack+28429, dvrr_stack+27685, dvrr_stack+227943);

 /* compute (1 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+208, dvrr_stack+482, dvrr_stack+1178, NULL, NULL, dvrr_stack+373);

 /* compute (2 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+225100, dvrr_stack+27935, dvrr_stack+208, dvrr_stack+1405, dvrr_stack+482, dvrr_stack+42);

 /* compute (3 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+227535, dvrr_stack+27980, dvrr_stack+225100, dvrr_stack+28529, dvrr_stack+27935, dvrr_stack+228033);

 /* compute (4 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+81171, dvrr_stack+28070, dvrr_stack+227535, dvrr_stack+28574, dvrr_stack+27980, dvrr_stack+225000);

 /* compute (5 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+300465, dvrr_stack+3307, dvrr_stack+81171, dvrr_stack+26847, dvrr_stack+28070, dvrr_stack+227385);

 /* compute (6 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+51926, dvrr_stack+12879, dvrr_stack+300465, dvrr_stack+83928, dvrr_stack+3307, dvrr_stack+231588);

 /* compute (1 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+83928, dvrr_stack+1277, dvrr_stack+2979, NULL, NULL, dvrr_stack+1178);

 /* compute (2 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+87604, dvrr_stack+27081, dvrr_stack+83928, dvrr_stack+3123, dvrr_stack+1277, dvrr_stack+208);

 /* compute (3 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+34567, dvrr_stack+19889, dvrr_stack+87604, dvrr_stack+28664, dvrr_stack+27081, dvrr_stack+225100);

 /* compute (4 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+28220, dvrr_stack+7472, dvrr_stack+34567, dvrr_stack+18891, dvrr_stack+19889, dvrr_stack+227535);

 /* compute (5 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+300780, dvrr_stack+151745, dvrr_stack+28220, dvrr_stack+84153, dvrr_stack+7472, dvrr_stack+81171);

 /* compute (6 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+301221, dvrr_stack+152060, dvrr_stack+300780, dvrr_stack+84363, dvrr_stack+151745, dvrr_stack+300465);

 /* compute (7 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+301809, dvrr_stack+152501, dvrr_stack+301221, dvrr_stack+84678, dvrr_stack+152060, dvrr_stack+51926);

 /* compute (1 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+188409, dvrr_stack+12572, dvrr_stack+7063, NULL, NULL, dvrr_stack+2979);

 /* compute (2 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+83991, dvrr_stack+36472, dvrr_stack+188409, dvrr_stack+7243, dvrr_stack+12572, dvrr_stack+83928);

 /* compute (3 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+84159, dvrr_stack+36556, dvrr_stack+83991, dvrr_stack+26997, dvrr_stack+36472, dvrr_stack+87604);

 /* compute (4 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+302565, dvrr_stack+153089, dvrr_stack+84159, dvrr_stack+591, dvrr_stack+36556, dvrr_stack+34567);

 /* compute (5 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+302985, dvrr_stack+153369, dvrr_stack+302565, dvrr_stack+85119, dvrr_stack+153089, dvrr_stack+28220);

 /* compute (6 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+303573, dvrr_stack+153789, dvrr_stack+302985, dvrr_stack+85399, dvrr_stack+153369, dvrr_stack+300780);

 /* compute (7 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+304357, dvrr_stack+154377, dvrr_stack+303573, dvrr_stack+85819, dvrr_stack+153789, dvrr_stack+301221);

 /* compute (7 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+305365,dvrr_stack+304357,dvrr_stack+301809,36);


 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+307633, dvrr_stack+305365, NULL);

 /* compute (1 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+85119, dvrr_stack+19295, dvrr_stack+12352, NULL, NULL, dvrr_stack+7063);

 /* compute (2 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+85227, dvrr_stack+37186, dvrr_stack+85119, dvrr_stack+12600, dvrr_stack+19295, dvrr_stack+188409);

 /* compute (3 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+85443, dvrr_stack+37294, dvrr_stack+85227, dvrr_stack+1441, dvrr_stack+37186, dvrr_stack+83991);

 /* compute (4 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+308389, dvrr_stack+156925, dvrr_stack+85443, dvrr_stack+87730, dvrr_stack+37294, dvrr_stack+84159);

 /* compute (5 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+308929, dvrr_stack+157285, dvrr_stack+308389, dvrr_stack+87946, dvrr_stack+156925, dvrr_stack+302565);

 /* compute (6 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+309685, dvrr_stack+157825, dvrr_stack+308929, dvrr_stack+88306, dvrr_stack+157285, dvrr_stack+302985);

 /* compute (7 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+310693, dvrr_stack+158581, dvrr_stack+309685, dvrr_stack+88846, dvrr_stack+157825, dvrr_stack+303573);

 /* compute (7 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+311989,dvrr_stack+310693,dvrr_stack+304357,36);


 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+87730, dvrr_stack+311989, NULL);

 /* compute (1 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+84439, dvrr_stack+19031, dvrr_stack+12077, NULL, NULL, dvrr_stack+12352);

 /* compute (2 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+17351, dvrr_stack+39083, dvrr_stack+84439, dvrr_stack+19331, dvrr_stack+19031, dvrr_stack+85119);

 /* compute (3 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+315013, dvrr_stack+39218, dvrr_stack+17351, dvrr_stack+3172, dvrr_stack+39083, dvrr_stack+85227);

 /* compute (4 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+315463, dvrr_stack+167233, dvrr_stack+315013, dvrr_stack+95335, dvrr_stack+39218, dvrr_stack+85443);

 /* compute (5 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+316138, dvrr_stack+167683, dvrr_stack+315463, dvrr_stack+95605, dvrr_stack+167233, dvrr_stack+308389);

 /* compute (6 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+317083, dvrr_stack+168358, dvrr_stack+316138, dvrr_stack+96055, dvrr_stack+167683, dvrr_stack+308929);

 /* compute (7 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+318343, dvrr_stack+169303, dvrr_stack+317083, dvrr_stack+96730, dvrr_stack+168358, dvrr_stack+309685);

 /* compute (7 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+319963,dvrr_stack+318343,dvrr_stack+310693,36);


 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+95335, dvrr_stack+319963, NULL);

 /* compute (1 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+110765, dvrr_stack+2799, dvrr_stack+19534, NULL, NULL, dvrr_stack+12077);

 /* compute (2 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+323851, dvrr_stack+44402, dvrr_stack+110765, dvrr_stack+27393, dvrr_stack+2799, dvrr_stack+84439);

 /* compute (3 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+324181, dvrr_stack+44567, dvrr_stack+323851, dvrr_stack+7307, dvrr_stack+44402, dvrr_stack+17351);

 /* compute (4 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+324731, dvrr_stack+180643, dvrr_stack+324181, dvrr_stack+105235, dvrr_stack+44567, dvrr_stack+315013);

 /* compute (5 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+325556, dvrr_stack+181193, dvrr_stack+324731, dvrr_stack+105565, dvrr_stack+180643, dvrr_stack+315463);

 /* compute (6 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+326711, dvrr_stack+182018, dvrr_stack+325556, dvrr_stack+106115, dvrr_stack+181193, dvrr_stack+316138);

 /* compute (7 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+328251, dvrr_stack+183173, dvrr_stack+326711, dvrr_stack+106940, dvrr_stack+182018, dvrr_stack+317083);

 /* compute (7 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+330231,dvrr_stack+328251,dvrr_stack+318343,36);


 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+105235, dvrr_stack+330231, NULL);

 /* compute (1 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+26847, dvrr_stack+19589, dvrr_stack+27448, NULL, NULL, dvrr_stack+19534);

 /* compute (2 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+335091, dvrr_stack+51332, dvrr_stack+26847, dvrr_stack+1193, dvrr_stack+19589, dvrr_stack+110765);

 /* compute (3 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+335487, dvrr_stack+51530, dvrr_stack+335091, dvrr_stack+12681, dvrr_stack+51332, dvrr_stack+323851);

 /* compute (4 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+336147, dvrr_stack+197565, dvrr_stack+335487, dvrr_stack+117734, dvrr_stack+51530, dvrr_stack+324181);

 /* compute (5 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+337137, dvrr_stack+198225, dvrr_stack+336147, dvrr_stack+118130, dvrr_stack+197565, dvrr_stack+324731);

 /* compute (6 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+335091, dvrr_stack+199215, dvrr_stack+337137, dvrr_stack+118790, dvrr_stack+198225, dvrr_stack+325556);

 /* compute (7 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+336939, dvrr_stack+200601, dvrr_stack+335091, dvrr_stack+119780, dvrr_stack+199215, dvrr_stack+326711);

 /* compute (7 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+339315,dvrr_stack+336939,dvrr_stack+328251,36);


 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+197565, dvrr_stack+339315, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,126,dvrr_stack+335091, dvrr_stack+219879, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+335217, dvrr_stack+220257, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+335385, dvrr_stack+220761, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+335601, dvrr_stack+221409, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,330,dvrr_stack+335871, dvrr_stack+299475, NULL);

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+199545, dvrr_stack+305365, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+200301, dvrr_stack+311989, NULL);

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+117734, dvrr_stack+319963, NULL);

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+119030, dvrr_stack+330231, NULL);

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+345255, dvrr_stack+339315, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+336201, dvrr_stack+219879, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+219879, dvrr_stack+220257, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+220047, dvrr_stack+220761, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+220263, dvrr_stack+221409, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+220533, dvrr_stack+299475, NULL);

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+299475, dvrr_stack+305365, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+305365, dvrr_stack+311989, NULL);

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+311989, dvrr_stack+319963, NULL);

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+319963, dvrr_stack+330231, NULL);

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+330231, dvrr_stack+339315, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+339315, dvrr_stack+1721, dvrr_stack+227853);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+339441, dvrr_stack+3532, dvrr_stack+801);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+339609, dvrr_stack+7757, dvrr_stack+1721);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+339825, dvrr_stack+13231, dvrr_stack+3532);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+340095, dvrr_stack+20091, dvrr_stack+7757);

 /* compute (3 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+231158, dvrr_stack+6, dvrr_stack+0, dvrr_stack+253, dvrr_stack+1165, NULL);

 /* compute (4 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+231798, dvrr_stack+19223, dvrr_stack+12, dvrr_stack+256, dvrr_stack+27523, dvrr_stack+231158);

 /* compute (5 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+340425, dvrr_stack+236823, dvrr_stack+227943, dvrr_stack+274, dvrr_stack+148, dvrr_stack+231798);

 /* compute (6 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+340551, dvrr_stack+213789, dvrr_stack+231588, dvrr_stack+235413, dvrr_stack+27785, dvrr_stack+340425);

 /* compute (7 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+340831, dvrr_stack+213999, dvrr_stack+51926, dvrr_stack+235563, dvrr_stack+12879, dvrr_stack+340551);

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+341371, dvrr_stack+304357, dvrr_stack+340831);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+342127, dvrr_stack+310693, dvrr_stack+301809);

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+343135, dvrr_stack+318343, dvrr_stack+304357);

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+332211, dvrr_stack+328251, dvrr_stack+310693);

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+321583, dvrr_stack+336939, dvrr_stack+318343);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+340425, dvrr_stack+1721, dvrr_stack+227853);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+340551, dvrr_stack+3532, dvrr_stack+801);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+235413, dvrr_stack+7757, dvrr_stack+1721);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+213789, dvrr_stack+13231, dvrr_stack+3532);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+214059, dvrr_stack+20091, dvrr_stack+7757);

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+344431, dvrr_stack+304357, dvrr_stack+340831);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+333831, dvrr_stack+310693, dvrr_stack+301809);

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+313285, dvrr_stack+318343, dvrr_stack+304357);

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+347235, dvrr_stack+328251, dvrr_stack+310693);

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+348855, dvrr_stack+336939, dvrr_stack+318343);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+235629, dvrr_stack+1721, dvrr_stack+227853);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+334839, dvrr_stack+3532, dvrr_stack+801);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+323563, dvrr_stack+7757, dvrr_stack+1721);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+314581, dvrr_stack+13231, dvrr_stack+3532);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+306373, dvrr_stack+20091, dvrr_stack+7757);

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+306703, dvrr_stack+304357, dvrr_stack+340831);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+220863, dvrr_stack+310693, dvrr_stack+301809);

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+350835, dvrr_stack+318343, dvrr_stack+304357);

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+352131, dvrr_stack+328251, dvrr_stack+310693);

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+353751, dvrr_stack+336939, dvrr_stack+318343);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+340719, dvrr_stack+927, dvrr_stack+503);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+340845, dvrr_stack+84678, dvrr_stack+927);
 tmp = dvrr_stack + 340845;
 target_ptr = Libderiv->deriv_classes[4][5][2];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+341160, dvrr_stack+1889, dvrr_stack+1305);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+221871, dvrr_stack+85819, dvrr_stack+1889);
 tmp = dvrr_stack + 221871;
 target_ptr = Libderiv->deriv_classes[4][6][2];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+300231, dvrr_stack+3748, dvrr_stack+3015);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+336327, dvrr_stack+88846, dvrr_stack+3748);
 tmp = dvrr_stack + 336327;
 target_ptr = Libderiv->deriv_classes[4][7][2];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+355731, dvrr_stack+8027, dvrr_stack+7108);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+336867, dvrr_stack+96730, dvrr_stack+8027);
 tmp = dvrr_stack + 336867;
 target_ptr = Libderiv->deriv_classes[4][8][2];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+337542, dvrr_stack+13561, dvrr_stack+12407);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+337872, dvrr_stack+106940, dvrr_stack+13561);
 tmp = dvrr_stack + 337872;
 target_ptr = Libderiv->deriv_classes[4][9][2];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+338697, dvrr_stack+36871, dvrr_stack+801);
 tmp = dvrr_stack + 338697;
 target_ptr = Libderiv->deriv_classes[3][5][2];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+201309, dvrr_stack+152501, dvrr_stack+36871);
 tmp = dvrr_stack + 201309;
 target_ptr = Libderiv->deriv_classes[5][5][2];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+338907, dvrr_stack+37718, dvrr_stack+1721);
 tmp = dvrr_stack + 338907;
 target_ptr = Libderiv->deriv_classes[3][6][2];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+201750, dvrr_stack+154377, dvrr_stack+37718);
 tmp = dvrr_stack + 201750;
 target_ptr = Libderiv->deriv_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+120650, dvrr_stack+39767, dvrr_stack+3532);
 tmp = dvrr_stack + 120650;
 target_ptr = Libderiv->deriv_classes[3][7][2];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+356001, dvrr_stack+158581, dvrr_stack+39767);
 tmp = dvrr_stack + 356001;
 target_ptr = Libderiv->deriv_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+51332, dvrr_stack+45257, dvrr_stack+7757);
 tmp = dvrr_stack + 51332;
 target_ptr = Libderiv->deriv_classes[3][8][2];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+356757, dvrr_stack+169303, dvrr_stack+45257);
 tmp = dvrr_stack + 356757;
 target_ptr = Libderiv->deriv_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+357702, dvrr_stack+52377, dvrr_stack+13231);
 tmp = dvrr_stack + 357702;
 target_ptr = Libderiv->deriv_classes[3][9][2];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+358252, dvrr_stack+183173, dvrr_stack+52377);
 tmp = dvrr_stack + 358252;
 target_ptr = Libderiv->deriv_classes[5][9][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+359407, dvrr_stack+301809, dvrr_stack+84678);
 tmp = dvrr_stack + 359407;
 target_ptr = Libderiv->deriv_classes[6][5][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+359995, dvrr_stack+304357, dvrr_stack+85819);
 tmp = dvrr_stack + 359995;
 target_ptr = Libderiv->deriv_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+360779, dvrr_stack+310693, dvrr_stack+88846);
 tmp = dvrr_stack + 360779;
 target_ptr = Libderiv->deriv_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+361787, dvrr_stack+318343, dvrr_stack+96730);
 tmp = dvrr_stack + 361787;
 target_ptr = Libderiv->deriv_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+363047, dvrr_stack+328251, dvrr_stack+106940);
 tmp = dvrr_stack + 363047;
 target_ptr = Libderiv->deriv_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+227853, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+6, dvrr_stack+188065, dvrr_stack+227853, Data->F+6, Data->F+7, NULL);

 /* compute (3 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+231158, dvrr_stack+0, dvrr_stack+6, dvrr_stack+1165, dvrr_stack+188065, NULL);

 /* compute (1 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+227856, dvrr_stack+95, dvrr_stack+454, NULL, NULL, Data->F+8);

 /* compute (2 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+300447, dvrr_stack+188068, dvrr_stack+227856, dvrr_stack+129, dvrr_stack+95, dvrr_stack+227853);

 /* compute (3 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+214389, dvrr_stack+194523, dvrr_stack+300447, dvrr_stack+27514, dvrr_stack+188068, dvrr_stack+6);

 /* compute (4 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+231798, dvrr_stack+12, dvrr_stack+214389, dvrr_stack+27523, dvrr_stack+194523, dvrr_stack+231158);

 /* compute (1 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+194523, dvrr_stack+1389, dvrr_stack+367, NULL, NULL, dvrr_stack+454);

 /* compute (2 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+188065, dvrr_stack+227835, dvrr_stack+194523, dvrr_stack+448, dvrr_stack+1389, dvrr_stack+227856);

 /* compute (3 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+91306, dvrr_stack+7271, dvrr_stack+188065, dvrr_stack+27541, dvrr_stack+227835, dvrr_stack+300447);

 /* compute (4 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+227835, dvrr_stack+214569, dvrr_stack+91306, dvrr_stack+27559, dvrr_stack+7271, dvrr_stack+214389);

 /* compute (5 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+314851, dvrr_stack+227943, dvrr_stack+227835, dvrr_stack+148, dvrr_stack+214569, dvrr_stack+231798);

 /* compute (1 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+214389, dvrr_stack+373, dvrr_stack+1168, NULL, NULL, dvrr_stack+367);

 /* compute (2 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+214569, dvrr_stack+42, dvrr_stack+214389, dvrr_stack+1395, dvrr_stack+373, dvrr_stack+194523);

 /* compute (3 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+227925, dvrr_stack+228033, dvrr_stack+214569, dvrr_stack+27595, dvrr_stack+42, dvrr_stack+188065);

 /* compute (4 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+1389, dvrr_stack+225000, dvrr_stack+227925, dvrr_stack+27625, dvrr_stack+228033, dvrr_stack+91306);

 /* compute (5 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+253, dvrr_stack+227385, dvrr_stack+1389, dvrr_stack+27685, dvrr_stack+225000, dvrr_stack+227835);

 /* compute (6 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+364587, dvrr_stack+231588, dvrr_stack+253, dvrr_stack+27785, dvrr_stack+227385, dvrr_stack+314851);

 /* compute (1 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+34777, dvrr_stack+1178, dvrr_stack+2854, NULL, NULL, dvrr_stack+1168);

 /* compute (2 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+227835, dvrr_stack+208, dvrr_stack+34777, dvrr_stack+482, dvrr_stack+1178, dvrr_stack+214389);

 /* compute (3 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+227385, dvrr_stack+225100, dvrr_stack+227835, dvrr_stack+27935, dvrr_stack+208, dvrr_stack+214569);

 /* compute (4 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+231588, dvrr_stack+227535, dvrr_stack+227385, dvrr_stack+27980, dvrr_stack+225100, dvrr_stack+227925);

 /* compute (5 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+364867, dvrr_stack+81171, dvrr_stack+231588, dvrr_stack+28070, dvrr_stack+227535, dvrr_stack+1389);

 /* compute (6 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+27144, dvrr_stack+300465, dvrr_stack+364867, dvrr_stack+3307, dvrr_stack+81171, dvrr_stack+253);

 /* compute (7 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+27564, dvrr_stack+51926, dvrr_stack+27144, dvrr_stack+12879, dvrr_stack+300465, dvrr_stack+364587);

 /* compute (1 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+364587, dvrr_stack+2979, dvrr_stack+6899, NULL, NULL, dvrr_stack+2854);

 /* compute (2 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+364650, dvrr_stack+83928, dvrr_stack+364587, dvrr_stack+1277, dvrr_stack+2979, dvrr_stack+34777);

 /* compute (3 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+225000, dvrr_stack+87604, dvrr_stack+364650, dvrr_stack+27081, dvrr_stack+83928, dvrr_stack+227835);

 /* compute (4 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+1389, dvrr_stack+34567, dvrr_stack+225000, dvrr_stack+19889, dvrr_stack+87604, dvrr_stack+227385);

 /* compute (5 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+0, dvrr_stack+28220, dvrr_stack+1389, dvrr_stack+7472, dvrr_stack+34567, dvrr_stack+231588);

 /* compute (6 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+51782, dvrr_stack+300780, dvrr_stack+0, dvrr_stack+151745, dvrr_stack+28220, dvrr_stack+364867);

 /* compute (7 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+19589, dvrr_stack+301221, dvrr_stack+51782, dvrr_stack+152060, dvrr_stack+300780, dvrr_stack+27144);

 /* compute (8 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+364776, dvrr_stack+301809, dvrr_stack+19589, dvrr_stack+152501, dvrr_stack+301221, dvrr_stack+27564);

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+151745, dvrr_stack+364776, dvrr_stack+152501);

 /* compute (1 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+335007, dvrr_stack+7063, dvrr_stack+12132, NULL, NULL, dvrr_stack+6899);

 /* compute (2 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+1137, dvrr_stack+188409, dvrr_stack+335007, dvrr_stack+12572, dvrr_stack+7063, dvrr_stack+364587);

 /* compute (3 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+12572, dvrr_stack+83991, dvrr_stack+1137, dvrr_stack+36472, dvrr_stack+188409, dvrr_stack+364650);

 /* compute (4 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+365721, dvrr_stack+84159, dvrr_stack+12572, dvrr_stack+36556, dvrr_stack+83991, dvrr_stack+225000);

 /* compute (5 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+300447, dvrr_stack+302565, dvrr_stack+365721, dvrr_stack+153089, dvrr_stack+84159, dvrr_stack+1389);

 /* compute (6 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+26847, dvrr_stack+302985, dvrr_stack+300447, dvrr_stack+153369, dvrr_stack+302565, dvrr_stack+0);

 /* compute (7 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+27631, dvrr_stack+303573, dvrr_stack+26847, dvrr_stack+153789, dvrr_stack+302985, dvrr_stack+51782);

 /* compute (8 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+153089, dvrr_stack+304357, dvrr_stack+27631, dvrr_stack+154377, dvrr_stack+303573, dvrr_stack+19589);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+302565, dvrr_stack+153089, dvrr_stack+154377);

 /* compute (1 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+88738, dvrr_stack+12352, dvrr_stack+18720, NULL, NULL, dvrr_stack+12132);

 /* compute (2 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+19589, dvrr_stack+85119, dvrr_stack+88738, dvrr_stack+19295, dvrr_stack+12352, dvrr_stack+335007);

 /* compute (3 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+366141, dvrr_stack+85227, dvrr_stack+19589, dvrr_stack+37186, dvrr_stack+85119, dvrr_stack+1137);

 /* compute (4 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+19805, dvrr_stack+85443, dvrr_stack+366141, dvrr_stack+37294, dvrr_stack+85227, dvrr_stack+12572);

 /* compute (5 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+303573, dvrr_stack+308389, dvrr_stack+19805, dvrr_stack+156925, dvrr_stack+85443, dvrr_stack+365721);

 /* compute (6 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+366501, dvrr_stack+308929, dvrr_stack+303573, dvrr_stack+157285, dvrr_stack+308389, dvrr_stack+300447);

 /* compute (7 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+300447, dvrr_stack+309685, dvrr_stack+366501, dvrr_stack+157825, dvrr_stack+308929, dvrr_stack+26847);

 /* compute (8 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+156925, dvrr_stack+310693, dvrr_stack+300447, dvrr_stack+158581, dvrr_stack+309685, dvrr_stack+27631);

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+26847, dvrr_stack+156925, dvrr_stack+158581);

 /* compute (1 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+28143, dvrr_stack+12077, dvrr_stack+19489, NULL, NULL, dvrr_stack+18720);

 /* compute (2 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6838, dvrr_stack+84439, dvrr_stack+28143, dvrr_stack+19031, dvrr_stack+12077, dvrr_stack+88738);

 /* compute (3 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+308389, dvrr_stack+17351, dvrr_stack+6838, dvrr_stack+39083, dvrr_stack+84439, dvrr_stack+19589);

 /* compute (4 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+308839, dvrr_stack+315013, dvrr_stack+308389, dvrr_stack+39218, dvrr_stack+17351, dvrr_stack+366141);

 /* compute (5 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+309514, dvrr_stack+315463, dvrr_stack+308839, dvrr_stack+167233, dvrr_stack+315013, dvrr_stack+19805);

 /* compute (6 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+367509, dvrr_stack+316138, dvrr_stack+309514, dvrr_stack+167683, dvrr_stack+315463, dvrr_stack+303573);

 /* compute (7 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+368769, dvrr_stack+317083, dvrr_stack+367509, dvrr_stack+168358, dvrr_stack+316138, dvrr_stack+366501);

 /* compute (8 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+167233, dvrr_stack+318343, dvrr_stack+368769, dvrr_stack+169303, dvrr_stack+317083, dvrr_stack+300447);

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+365721, dvrr_stack+167233, dvrr_stack+169303);

 /* compute (1 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+300447, dvrr_stack+19534, dvrr_stack+60087, NULL, NULL, dvrr_stack+19489);

 /* compute (2 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12077, dvrr_stack+110765, dvrr_stack+300447, dvrr_stack+2799, dvrr_stack+19534, dvrr_stack+28143);

 /* compute (3 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+28143, dvrr_stack+323851, dvrr_stack+12077, dvrr_stack+44402, dvrr_stack+110765, dvrr_stack+6838);

 /* compute (4 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+300447, dvrr_stack+324181, dvrr_stack+28143, dvrr_stack+44567, dvrr_stack+323851, dvrr_stack+308389);

 /* compute (5 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+314851, dvrr_stack+324731, dvrr_stack+300447, dvrr_stack+180643, dvrr_stack+324181, dvrr_stack+308839);

 /* compute (6 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+316006, dvrr_stack+325556, dvrr_stack+314851, dvrr_stack+181193, dvrr_stack+324731, dvrr_stack+309514);

 /* compute (7 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+308389, dvrr_stack+326711, dvrr_stack+316006, dvrr_stack+182018, dvrr_stack+325556, dvrr_stack+367509);

 /* compute (8 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+314851, dvrr_stack+328251, dvrr_stack+308389, dvrr_stack+183173, dvrr_stack+326711, dvrr_stack+368769);

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+308389, dvrr_stack+314851, dvrr_stack+183173);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+87604, dvrr_stack+927, dvrr_stack+503);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+310369, dvrr_stack+84678, dvrr_stack+927);
 tmp = dvrr_stack + 310369;
 target_ptr = Libderiv->deriv_classes[4][5][1];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+1137, dvrr_stack+1889, dvrr_stack+1305);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+317326, dvrr_stack+85819, dvrr_stack+1889);
 tmp = dvrr_stack + 317326;
 target_ptr = Libderiv->deriv_classes[4][6][1];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+2799, dvrr_stack+3748, dvrr_stack+3015);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+317746, dvrr_stack+88846, dvrr_stack+3748);
 tmp = dvrr_stack + 317746;
 target_ptr = Libderiv->deriv_classes[4][7][1];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+6838, dvrr_stack+8027, dvrr_stack+7108);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+180643, dvrr_stack+96730, dvrr_stack+8027);
 tmp = dvrr_stack + 180643;
 target_ptr = Libderiv->deriv_classes[4][8][1];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+12077, dvrr_stack+13561, dvrr_stack+12407);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+181318, dvrr_stack+106940, dvrr_stack+13561);
 tmp = dvrr_stack + 181318;
 target_ptr = Libderiv->deriv_classes[4][9][1];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+225000, dvrr_stack+36871, dvrr_stack+801);
 tmp = dvrr_stack + 225000;
 target_ptr = Libderiv->deriv_classes[3][5][1];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+182143, dvrr_stack+152501, dvrr_stack+36871);
 tmp = dvrr_stack + 182143;
 target_ptr = Libderiv->deriv_classes[5][5][1];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+182584, dvrr_stack+37718, dvrr_stack+1721);
 tmp = dvrr_stack + 182584;
 target_ptr = Libderiv->deriv_classes[3][6][1];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+300447, dvrr_stack+154377, dvrr_stack+37718);
 tmp = dvrr_stack + 300447;
 target_ptr = Libderiv->deriv_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+301035, dvrr_stack+39767, dvrr_stack+3532);
 tmp = dvrr_stack + 301035;
 target_ptr = Libderiv->deriv_classes[3][7][1];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+303573, dvrr_stack+158581, dvrr_stack+39767);
 tmp = dvrr_stack + 303573;
 target_ptr = Libderiv->deriv_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+28143, dvrr_stack+45257, dvrr_stack+7757);
 tmp = dvrr_stack + 28143;
 target_ptr = Libderiv->deriv_classes[3][8][1];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+367341, dvrr_stack+169303, dvrr_stack+45257);
 tmp = dvrr_stack + 367341;
 target_ptr = Libderiv->deriv_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+368286, dvrr_stack+52377, dvrr_stack+13231);
 tmp = dvrr_stack + 368286;
 target_ptr = Libderiv->deriv_classes[3][9][1];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+368836, dvrr_stack+183173, dvrr_stack+52377);
 tmp = dvrr_stack + 368836;
 target_ptr = Libderiv->deriv_classes[5][9][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+369991, dvrr_stack+301809, dvrr_stack+84678);
 tmp = dvrr_stack + 369991;
 target_ptr = Libderiv->deriv_classes[6][5][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+323779, dvrr_stack+304357, dvrr_stack+85819);
 tmp = dvrr_stack + 323779;
 target_ptr = Libderiv->deriv_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+324563, dvrr_stack+310693, dvrr_stack+88846);
 tmp = dvrr_stack + 324563;
 target_ptr = Libderiv->deriv_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+325571, dvrr_stack+318343, dvrr_stack+96730);
 tmp = dvrr_stack + 325571;
 target_ptr = Libderiv->deriv_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+18701, dvrr_stack+328251, dvrr_stack+106940);
 tmp = dvrr_stack + 18701;
 target_ptr = Libderiv->deriv_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+326831, dvrr_stack+364776, dvrr_stack+152501);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+370579, dvrr_stack+153089, dvrr_stack+154377);

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+371587, dvrr_stack+156925, dvrr_stack+158581);

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+372883, dvrr_stack+167233, dvrr_stack+169303);

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+374503, dvrr_stack+314851, dvrr_stack+183173);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+182864, dvrr_stack+927, dvrr_stack+503);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+301395, dvrr_stack+84678, dvrr_stack+927);
 tmp = dvrr_stack + 301395;
 target_ptr = Libderiv->deriv_classes[4][5][0];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+927, dvrr_stack+1889, dvrr_stack+1305);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+44402, dvrr_stack+85819, dvrr_stack+1889);
 tmp = dvrr_stack + 44402;
 target_ptr = Libderiv->deriv_classes[4][6][0];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+1889, dvrr_stack+3748, dvrr_stack+3015);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+12572, dvrr_stack+88846, dvrr_stack+3748);
 tmp = dvrr_stack + 12572;
 target_ptr = Libderiv->deriv_classes[4][7][0];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+17351, dvrr_stack+8027, dvrr_stack+7108);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+85119, dvrr_stack+96730, dvrr_stack+8027);
 tmp = dvrr_stack + 85119;
 target_ptr = Libderiv->deriv_classes[4][8][0];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+8027, dvrr_stack+13561, dvrr_stack+12407);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+38903, dvrr_stack+106940, dvrr_stack+13561);
 tmp = dvrr_stack + 38903;
 target_ptr = Libderiv->deriv_classes[4][9][0];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+13561, dvrr_stack+36871, dvrr_stack+801);
 tmp = dvrr_stack + 13561;
 target_ptr = Libderiv->deriv_classes[3][5][0];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+7108, dvrr_stack+152501, dvrr_stack+36871);
 tmp = dvrr_stack + 7108;
 target_ptr = Libderiv->deriv_classes[5][5][0];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+13771, dvrr_stack+37718, dvrr_stack+1721);
 tmp = dvrr_stack + 13771;
 target_ptr = Libderiv->deriv_classes[3][6][0];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+51782, dvrr_stack+154377, dvrr_stack+37718);
 tmp = dvrr_stack + 51782;
 target_ptr = Libderiv->deriv_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+3748, dvrr_stack+39767, dvrr_stack+3532);
 tmp = dvrr_stack + 3748;
 target_ptr = Libderiv->deriv_classes[3][7][0];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+0, dvrr_stack+158581, dvrr_stack+39767);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+3015, dvrr_stack+45257, dvrr_stack+7757);
 tmp = dvrr_stack + 3015;
 target_ptr = Libderiv->deriv_classes[3][8][0];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+36472, dvrr_stack+169303, dvrr_stack+45257);
 tmp = dvrr_stack + 36472;
 target_ptr = Libderiv->deriv_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+45257, dvrr_stack+52377, dvrr_stack+13231);
 tmp = dvrr_stack + 45257;
 target_ptr = Libderiv->deriv_classes[3][9][0];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+376483, dvrr_stack+183173, dvrr_stack+52377);
 tmp = dvrr_stack + 376483;
 target_ptr = Libderiv->deriv_classes[5][9][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+52370, dvrr_stack+301809, dvrr_stack+84678);
 tmp = dvrr_stack + 52370;
 target_ptr = Libderiv->deriv_classes[6][5][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+301710, dvrr_stack+304357, dvrr_stack+85819);
 tmp = dvrr_stack + 301710;
 target_ptr = Libderiv->deriv_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+304329, dvrr_stack+310693, dvrr_stack+88846);
 tmp = dvrr_stack + 304329;
 target_ptr = Libderiv->deriv_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+310684, dvrr_stack+318343, dvrr_stack+96730);
 tmp = dvrr_stack + 310684;
 target_ptr = Libderiv->deriv_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+318286, dvrr_stack+328251, dvrr_stack+106940);
 tmp = dvrr_stack + 318286;
 target_ptr = Libderiv->deriv_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+88738, dvrr_stack+364776, dvrr_stack+152501);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+364587, dvrr_stack+153089, dvrr_stack+154377);

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+152501, dvrr_stack+156925, dvrr_stack+158581);

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+156925, dvrr_stack+167233, dvrr_stack+169303);

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+167233, dvrr_stack+314851, dvrr_stack+183173);

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,210,dvrr_stack+314851, dvrr_stack+6208, NULL);
 tmp = dvrr_stack + 314851;
 target_ptr = Libderiv->deriv2_classes[3][5][143];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,280,dvrr_stack+315061, dvrr_stack+11237, NULL);
 tmp = dvrr_stack + 315061;
 target_ptr = Libderiv->deriv2_classes[3][6][143];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,360,dvrr_stack+315341, dvrr_stack+17621, NULL);
 tmp = dvrr_stack + 315341;
 target_ptr = Libderiv->deriv2_classes[3][7][143];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,450,dvrr_stack+315701, dvrr_stack+25497, NULL);
 tmp = dvrr_stack + 315701;
 target_ptr = Libderiv->deriv2_classes[3][8][143];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,550,dvrr_stack+316151, dvrr_stack+34822, NULL);
 tmp = dvrr_stack + 316151;
 target_ptr = Libderiv->deriv2_classes[3][9][143];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,315,dvrr_stack+316701, dvrr_stack+43457, NULL);
 tmp = dvrr_stack + 316701;
 target_ptr = Libderiv->deriv2_classes[4][5][143];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,420,dvrr_stack+169213, dvrr_stack+50072, NULL);
 tmp = dvrr_stack + 169213;
 target_ptr = Libderiv->deriv2_classes[4][6][143];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,540,dvrr_stack+169633, dvrr_stack+58467, NULL);
 tmp = dvrr_stack + 169633;
 target_ptr = Libderiv->deriv2_classes[4][7][143];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,675,dvrr_stack+158545, dvrr_stack+68856, NULL);
 tmp = dvrr_stack + 158545;
 target_ptr = Libderiv->deriv2_classes[4][8][143];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,825,dvrr_stack+153797, dvrr_stack+81453, NULL);
 tmp = dvrr_stack + 153797;
 target_ptr = Libderiv->deriv2_classes[4][9][143];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,441,dvrr_stack+154622, dvrr_stack+94012, NULL);
 tmp = dvrr_stack + 154622;
 target_ptr = Libderiv->deriv2_classes[5][5][143];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,588,dvrr_stack+182990, dvrr_stack+103471, NULL);
 tmp = dvrr_stack + 182990;
 target_ptr = Libderiv->deriv2_classes[5][6][143];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,756,dvrr_stack+183578, dvrr_stack+115466, NULL);
 tmp = dvrr_stack + 183578;
 target_ptr = Libderiv->deriv2_classes[5][7][143];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,945,dvrr_stack+83928, dvrr_stack+130301, NULL);
 tmp = dvrr_stack + 83928;
 target_ptr = Libderiv->deriv2_classes[5][8][143];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+327587, dvrr_stack+148280, NULL);
 tmp = dvrr_stack + 327587;
 target_ptr = Libderiv->deriv2_classes[5][9][143];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,588,dvrr_stack+85794, dvrr_stack+165469, NULL);
 tmp = dvrr_stack + 85794;
 target_ptr = Libderiv->deriv2_classes[6][5][143];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,784,dvrr_stack+328742, dvrr_stack+178291, NULL);
 tmp = dvrr_stack + 328742;
 target_ptr = Libderiv->deriv2_classes[6][6][143];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+106855, dvrr_stack+194541, NULL);
 tmp = dvrr_stack + 106855;
 target_ptr = Libderiv->deriv2_classes[6][7][143];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+377638, dvrr_stack+214629, NULL);
 tmp = dvrr_stack + 377638;
 target_ptr = Libderiv->deriv2_classes[6][8][143];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+378898, dvrr_stack+237015, NULL);
 tmp = dvrr_stack + 378898;
 target_ptr = Libderiv->deriv2_classes[6][9][143];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,210,dvrr_stack+317016, dvrr_stack+6208, NULL);
 tmp = dvrr_stack + 317016;
 target_ptr = Libderiv->deriv2_classes[3][5][131];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,280,dvrr_stack+170173, dvrr_stack+11237, NULL);
 tmp = dvrr_stack + 170173;
 target_ptr = Libderiv->deriv2_classes[3][6][131];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,360,dvrr_stack+159220, dvrr_stack+17621, NULL);
 tmp = dvrr_stack + 159220;
 target_ptr = Libderiv->deriv2_classes[3][7][131];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,450,dvrr_stack+7549, dvrr_stack+25497, NULL);
 tmp = dvrr_stack + 7549;
 target_ptr = Libderiv->deriv2_classes[3][8][131];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,550,dvrr_stack+1305, dvrr_stack+34822, NULL);
 tmp = dvrr_stack + 1305;
 target_ptr = Libderiv->deriv2_classes[3][9][131];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,315,dvrr_stack+184334, dvrr_stack+43457, NULL);
 tmp = dvrr_stack + 184334;
 target_ptr = Libderiv->deriv2_classes[4][5][131];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,420,dvrr_stack+380438, dvrr_stack+50072, NULL);
 tmp = dvrr_stack + 380438;
 target_ptr = Libderiv->deriv2_classes[4][6][131];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,540,dvrr_stack+37417, dvrr_stack+58467, NULL);
 tmp = dvrr_stack + 37417;
 target_ptr = Libderiv->deriv2_classes[4][7][131];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,675,dvrr_stack+329526, dvrr_stack+68856, NULL);
 tmp = dvrr_stack + 329526;
 target_ptr = Libderiv->deriv2_classes[4][8][131];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,825,dvrr_stack+96631, dvrr_stack+81453, NULL);
 tmp = dvrr_stack + 96631;
 target_ptr = Libderiv->deriv2_classes[4][9][131];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,441,dvrr_stack+13112, dvrr_stack+94012, NULL);
 tmp = dvrr_stack + 13112;
 target_ptr = Libderiv->deriv2_classes[5][5][131];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,588,dvrr_stack+380858, dvrr_stack+103471, NULL);
 tmp = dvrr_stack + 380858;
 target_ptr = Libderiv->deriv2_classes[5][6][131];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,756,dvrr_stack+381446, dvrr_stack+115466, NULL);
 tmp = dvrr_stack + 381446;
 target_ptr = Libderiv->deriv2_classes[5][7][131];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,945,dvrr_stack+382202, dvrr_stack+130301, NULL);
 tmp = dvrr_stack + 382202;
 target_ptr = Libderiv->deriv2_classes[5][8][131];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1155,dvrr_stack+383147, dvrr_stack+148280, NULL);
 tmp = dvrr_stack + 383147;
 target_ptr = Libderiv->deriv2_classes[5][9][131];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,588,dvrr_stack+384302, dvrr_stack+165469, NULL);
 tmp = dvrr_stack + 384302;
 target_ptr = Libderiv->deriv2_classes[6][5][131];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,784,dvrr_stack+384890, dvrr_stack+178291, NULL);
 tmp = dvrr_stack + 384890;
 target_ptr = Libderiv->deriv2_classes[6][6][131];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1008,dvrr_stack+385674, dvrr_stack+194541, NULL);
 tmp = dvrr_stack + 385674;
 target_ptr = Libderiv->deriv2_classes[6][7][131];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1260,dvrr_stack+386682, dvrr_stack+214629, NULL);
 tmp = dvrr_stack + 386682;
 target_ptr = Libderiv->deriv2_classes[6][8][131];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1540,dvrr_stack+387942, dvrr_stack+237015, NULL);
 tmp = dvrr_stack + 387942;
 target_ptr = Libderiv->deriv2_classes[6][9][131];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,210,dvrr_stack+3465, dvrr_stack+218409, NULL);
 tmp = dvrr_stack + 3465;
 target_ptr = Libderiv->deriv2_classes[3][5][130];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+389482, dvrr_stack+219039, NULL);
 tmp = dvrr_stack + 389482;
 target_ptr = Libderiv->deriv2_classes[3][6][130];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+39728, dvrr_stack+60142, NULL);
 tmp = dvrr_stack + 39728;
 target_ptr = Libderiv->deriv2_classes[3][7][130];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+389762, dvrr_stack+133136, NULL);
 tmp = dvrr_stack + 389762;
 target_ptr = Libderiv->deriv2_classes[3][8][130];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,550,dvrr_stack+390212, dvrr_stack+241635, NULL);
 tmp = dvrr_stack + 390212;
 target_ptr = Libderiv->deriv2_classes[3][9][130];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+390762, dvrr_stack+134486, NULL);
 tmp = dvrr_stack + 390762;
 target_ptr = Libderiv->deriv2_classes[4][5][130];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+391077, dvrr_stack+70881, NULL);
 tmp = dvrr_stack + 391077;
 target_ptr = Libderiv->deriv2_classes[4][6][130];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+391497, dvrr_stack+243285, NULL);
 tmp = dvrr_stack + 391497;
 target_ptr = Libderiv->deriv2_classes[4][7][130];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+392037, dvrr_stack+244905, NULL);
 tmp = dvrr_stack + 392037;
 target_ptr = Libderiv->deriv2_classes[4][8][130];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+392712, dvrr_stack+246930, NULL);
 tmp = dvrr_stack + 392712;
 target_ptr = Libderiv->deriv2_classes[4][9][130];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+393537, dvrr_stack+249405, NULL);
 tmp = dvrr_stack + 393537;
 target_ptr = Libderiv->deriv2_classes[5][5][130];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+393978, dvrr_stack+250728, NULL);
 tmp = dvrr_stack + 393978;
 target_ptr = Libderiv->deriv2_classes[5][6][130];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+394566, dvrr_stack+252492, NULL);
 tmp = dvrr_stack + 394566;
 target_ptr = Libderiv->deriv2_classes[5][7][130];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+395322, dvrr_stack+254760, NULL);
 tmp = dvrr_stack + 395322;
 target_ptr = Libderiv->deriv2_classes[5][8][130];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+396267, dvrr_stack+257595, NULL);
 tmp = dvrr_stack + 396267;
 target_ptr = Libderiv->deriv2_classes[5][9][130];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+397422, dvrr_stack+261060, NULL);
 tmp = dvrr_stack + 397422;
 target_ptr = Libderiv->deriv2_classes[6][5][130];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+398010, dvrr_stack+262824, NULL);
 tmp = dvrr_stack + 398010;
 target_ptr = Libderiv->deriv2_classes[6][6][130];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+398794, dvrr_stack+265176, NULL);
 tmp = dvrr_stack + 398794;
 target_ptr = Libderiv->deriv2_classes[6][7][130];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+399802, dvrr_stack+268200, NULL);
 tmp = dvrr_stack + 399802;
 target_ptr = Libderiv->deriv2_classes[6][8][130];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+401062, dvrr_stack+271980, NULL);
 tmp = dvrr_stack + 401062;
 target_ptr = Libderiv->deriv2_classes[6][9][130];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,210,dvrr_stack+402602, dvrr_stack+6208, NULL);
 tmp = dvrr_stack + 402602;
 target_ptr = Libderiv->deriv2_classes[3][5][119];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,280,dvrr_stack+6208, dvrr_stack+11237, NULL);
 tmp = dvrr_stack + 6208;
 target_ptr = Libderiv->deriv2_classes[3][6][119];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,360,dvrr_stack+11225, dvrr_stack+17621, NULL);
 tmp = dvrr_stack + 11225;
 target_ptr = Libderiv->deriv2_classes[3][7][119];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,450,dvrr_stack+17621, dvrr_stack+25497, NULL);
 tmp = dvrr_stack + 17621;
 target_ptr = Libderiv->deriv2_classes[3][8][119];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,550,dvrr_stack+18071, dvrr_stack+34822, NULL);
 tmp = dvrr_stack + 18071;
 target_ptr = Libderiv->deriv2_classes[3][9][119];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,315,dvrr_stack+6488, dvrr_stack+43457, NULL);
 tmp = dvrr_stack + 6488;
 target_ptr = Libderiv->deriv2_classes[4][5][119];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,420,dvrr_stack+34567, dvrr_stack+50072, NULL);
 tmp = dvrr_stack + 34567;
 target_ptr = Libderiv->deriv2_classes[4][6][119];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,540,dvrr_stack+34987, dvrr_stack+58467, NULL);
 tmp = dvrr_stack + 34987;
 target_ptr = Libderiv->deriv2_classes[4][7][119];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,675,dvrr_stack+35527, dvrr_stack+68856, NULL);
 tmp = dvrr_stack + 35527;
 target_ptr = Libderiv->deriv2_classes[4][8][119];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,825,dvrr_stack+68856, dvrr_stack+81453, NULL);
 tmp = dvrr_stack + 68856;
 target_ptr = Libderiv->deriv2_classes[4][9][119];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,441,dvrr_stack+69681, dvrr_stack+94012, NULL);
 tmp = dvrr_stack + 69681;
 target_ptr = Libderiv->deriv2_classes[5][5][119];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,588,dvrr_stack+70122, dvrr_stack+103471, NULL);
 tmp = dvrr_stack + 70122;
 target_ptr = Libderiv->deriv2_classes[5][6][119];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,756,dvrr_stack+81171, dvrr_stack+115466, NULL);
 tmp = dvrr_stack + 81171;
 target_ptr = Libderiv->deriv2_classes[5][7][119];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,945,dvrr_stack+81927, dvrr_stack+130301, NULL);
 tmp = dvrr_stack + 81927;
 target_ptr = Libderiv->deriv2_classes[5][8][119];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1155,dvrr_stack+103445, dvrr_stack+148280, NULL);
 tmp = dvrr_stack + 103445;
 target_ptr = Libderiv->deriv2_classes[5][9][119];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,588,dvrr_stack+82872, dvrr_stack+165469, NULL);
 tmp = dvrr_stack + 82872;
 target_ptr = Libderiv->deriv2_classes[6][5][119];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,784,dvrr_stack+165469, dvrr_stack+178291, NULL);
 tmp = dvrr_stack + 165469;
 target_ptr = Libderiv->deriv2_classes[6][6][119];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1008,dvrr_stack+178277, dvrr_stack+194541, NULL);
 tmp = dvrr_stack + 178277;
 target_ptr = Libderiv->deriv2_classes[6][7][119];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1260,dvrr_stack+194523, dvrr_stack+214629, NULL);
 tmp = dvrr_stack + 194523;
 target_ptr = Libderiv->deriv2_classes[6][8][119];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1540,dvrr_stack+214569, dvrr_stack+237015, NULL);
 tmp = dvrr_stack + 214569;
 target_ptr = Libderiv->deriv2_classes[6][9][119];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+166253, dvrr_stack+218409, NULL);
 tmp = dvrr_stack + 166253;
 target_ptr = Libderiv->deriv2_classes[3][5][118];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+166463, dvrr_stack+219039, NULL);
 tmp = dvrr_stack + 166463;
 target_ptr = Libderiv->deriv2_classes[3][6][118];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+166743, dvrr_stack+60142, NULL);
 tmp = dvrr_stack + 166743;
 target_ptr = Libderiv->deriv2_classes[3][7][118];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+83460, dvrr_stack+133136, NULL);
 tmp = dvrr_stack + 83460;
 target_ptr = Libderiv->deriv2_classes[3][8][118];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+216109, dvrr_stack+241635, NULL);
 tmp = dvrr_stack + 216109;
 target_ptr = Libderiv->deriv2_classes[3][9][118];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+216659, dvrr_stack+134486, NULL);
 tmp = dvrr_stack + 216659;
 target_ptr = Libderiv->deriv2_classes[4][5][118];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+216974, dvrr_stack+70881, NULL);
 tmp = dvrr_stack + 216974;
 target_ptr = Libderiv->deriv2_classes[4][6][118];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+70710, dvrr_stack+243285, NULL);
 tmp = dvrr_stack + 70710;
 target_ptr = Libderiv->deriv2_classes[4][7][118];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+71250, dvrr_stack+244905, NULL);
 tmp = dvrr_stack + 71250;
 target_ptr = Libderiv->deriv2_classes[4][8][118];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+217394, dvrr_stack+246930, NULL);
 tmp = dvrr_stack + 217394;
 target_ptr = Libderiv->deriv2_classes[4][9][118];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+218219, dvrr_stack+249405, NULL);
 tmp = dvrr_stack + 218219;
 target_ptr = Libderiv->deriv2_classes[5][5][118];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+218660, dvrr_stack+250728, NULL);
 tmp = dvrr_stack + 218660;
 target_ptr = Libderiv->deriv2_classes[5][6][118];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+195783, dvrr_stack+252492, NULL);
 tmp = dvrr_stack + 195783;
 target_ptr = Libderiv->deriv2_classes[5][7][118];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+196539, dvrr_stack+254760, NULL);
 tmp = dvrr_stack + 196539;
 target_ptr = Libderiv->deriv2_classes[5][8][118];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+236746, dvrr_stack+257595, NULL);
 tmp = dvrr_stack + 236746;
 target_ptr = Libderiv->deriv2_classes[5][9][118];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+219248, dvrr_stack+261060, NULL);
 tmp = dvrr_stack + 219248;
 target_ptr = Libderiv->deriv2_classes[6][5][118];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+237901, dvrr_stack+262824, NULL);
 tmp = dvrr_stack + 237901;
 target_ptr = Libderiv->deriv2_classes[6][6][118];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+238685, dvrr_stack+265176, NULL);
 tmp = dvrr_stack + 238685;
 target_ptr = Libderiv->deriv2_classes[6][7][118];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+239693, dvrr_stack+268200, NULL);
 tmp = dvrr_stack + 239693;
 target_ptr = Libderiv->deriv2_classes[6][8][118];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+240953, dvrr_stack+271980, NULL);
 tmp = dvrr_stack + 240953;
 target_ptr = Libderiv->deriv2_classes[6][9][118];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+71925, dvrr_stack+276600, NULL);
 tmp = dvrr_stack + 71925;
 target_ptr = Libderiv->deriv2_classes[3][5][117];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+227385, dvrr_stack+4948, NULL);
 tmp = dvrr_stack + 227385;
 target_ptr = Libderiv->deriv2_classes[3][6][117];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+104600, dvrr_stack+9557, NULL);
 tmp = dvrr_stack + 104600;
 target_ptr = Libderiv->deriv2_classes[3][7][117];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+242493, dvrr_stack+15461, NULL);
 tmp = dvrr_stack + 242493;
 target_ptr = Libderiv->deriv2_classes[3][8][117];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+242943, dvrr_stack+22797, NULL);
 tmp = dvrr_stack + 242943;
 target_ptr = Libderiv->deriv2_classes[3][9][117];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+22797, dvrr_stack+31522, NULL);
 tmp = dvrr_stack + 22797;
 target_ptr = Libderiv->deriv2_classes[4][5][117];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+23112, dvrr_stack+41567, NULL);
 tmp = dvrr_stack + 23112;
 target_ptr = Libderiv->deriv2_classes[4][6][117];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+41567, dvrr_stack+47552, NULL);
 tmp = dvrr_stack + 41567;
 target_ptr = Libderiv->deriv2_classes[4][7][117];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+47552, dvrr_stack+55227, NULL);
 tmp = dvrr_stack + 47552;
 target_ptr = Libderiv->deriv2_classes[4][8][117];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+48227, dvrr_stack+64806, NULL);
 tmp = dvrr_stack + 48227;
 target_ptr = Libderiv->deriv2_classes[4][9][117];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+42107, dvrr_stack+76503, NULL);
 tmp = dvrr_stack + 42107;
 target_ptr = Libderiv->deriv2_classes[5][5][117];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+23532, dvrr_stack+91366, NULL);
 tmp = dvrr_stack + 23532;
 target_ptr = Libderiv->deriv2_classes[5][6][117];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+91306, dvrr_stack+99943, NULL);
 tmp = dvrr_stack + 91306;
 target_ptr = Libderiv->deriv2_classes[5][7][117];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+99943, dvrr_stack+110930, NULL);
 tmp = dvrr_stack + 99943;
 target_ptr = Libderiv->deriv2_classes[5][8][117];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+100888, dvrr_stack+124631, NULL);
 tmp = dvrr_stack + 100888;
 target_ptr = Libderiv->deriv2_classes[5][9][117];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+110765, dvrr_stack+141350, NULL);
 tmp = dvrr_stack + 110765;
 target_ptr = Libderiv->deriv2_classes[6][5][117];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+111353, dvrr_stack+161941, NULL);
 tmp = dvrr_stack + 111353;
 target_ptr = Libderiv->deriv2_classes[6][6][117];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+112137, dvrr_stack+173587, NULL);
 tmp = dvrr_stack + 112137;
 target_ptr = Libderiv->deriv2_classes[6][7][117];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+9377, dvrr_stack+188493, NULL);
 tmp = dvrr_stack + 9377;
 target_ptr = Libderiv->deriv2_classes[6][8][117];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+188409, dvrr_stack+207069, NULL);
 tmp = dvrr_stack + 188409;
 target_ptr = Libderiv->deriv2_classes[6][9][117];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+42548, dvrr_stack+228693, dvrr_stack+228543);
 tmp = dvrr_stack + 42548;
 target_ptr = Libderiv->deriv2_classes[3][5][107];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+24120, dvrr_stack+44897, dvrr_stack+228973);
 tmp = dvrr_stack + 24120;
 target_ptr = Libderiv->deriv2_classes[3][6][107];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+113145, dvrr_stack+229183, dvrr_stack+228693);
 tmp = dvrr_stack + 113145;
 target_ptr = Libderiv->deriv2_classes[3][7][107];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+189949, dvrr_stack+229633, dvrr_stack+44897);
 tmp = dvrr_stack + 189949;
 target_ptr = Libderiv->deriv2_classes[3][8][107];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+190399, dvrr_stack+230183, dvrr_stack+229183);
 tmp = dvrr_stack + 190399;
 target_ptr = Libderiv->deriv2_classes[3][9][107];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+190949, dvrr_stack+5788, dvrr_stack+231843);
 tmp = dvrr_stack + 190949;
 target_ptr = Libderiv->deriv2_classes[4][5][107];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+191264, dvrr_stack+232383, dvrr_stack+232068);
 tmp = dvrr_stack + 191264;
 target_ptr = Libderiv->deriv2_classes[4][6][107];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+191684, dvrr_stack+232923, dvrr_stack+5788);
 tmp = dvrr_stack + 191684;
 target_ptr = Libderiv->deriv2_classes[4][7][107];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+92062, dvrr_stack+233598, dvrr_stack+232383);
 tmp = dvrr_stack + 92062;
 target_ptr = Libderiv->deriv2_classes[4][8][107];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+207015, dvrr_stack+234423, dvrr_stack+232923);
 tmp = dvrr_stack + 207015;
 target_ptr = Libderiv->deriv2_classes[4][9][107];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+207840, dvrr_stack+212004, dvrr_stack+211689);
 tmp = dvrr_stack + 207840;
 target_ptr = Libderiv->deriv2_classes[5][5][107];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+208281, dvrr_stack+213033, dvrr_stack+212592);
 tmp = dvrr_stack + 208281;
 target_ptr = Libderiv->deriv2_classes[5][6][107];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+208869, dvrr_stack+192273, dvrr_stack+212004);
 tmp = dvrr_stack + 208869;
 target_ptr = Libderiv->deriv2_classes[5][7][107];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+209625, dvrr_stack+193218, dvrr_stack+213033);
 tmp = dvrr_stack + 209625;
 target_ptr = Libderiv->deriv2_classes[5][8][107];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+173569, dvrr_stack+176611, dvrr_stack+192273);
 tmp = dvrr_stack + 173569;
 target_ptr = Libderiv->deriv2_classes[5][9][107];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+210570, dvrr_stack+143114, dvrr_stack+164293);
 tmp = dvrr_stack + 210570;
 target_ptr = Libderiv->deriv2_classes[6][5][107];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+174724, dvrr_stack+143898, dvrr_stack+164713);
 tmp = dvrr_stack + 174724;
 target_ptr = Libderiv->deriv2_classes[6][6][107];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+175508, dvrr_stack+144906, dvrr_stack+143114);
 tmp = dvrr_stack + 175508;
 target_ptr = Libderiv->deriv2_classes[6][7][107];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+161741, dvrr_stack+146166, dvrr_stack+143898);
 tmp = dvrr_stack + 161741;
 target_ptr = Libderiv->deriv2_classes[6][8][107];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+141243, dvrr_stack+128096, dvrr_stack+144906);
 tmp = dvrr_stack + 141243;
 target_ptr = Libderiv->deriv2_classes[6][9][107];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+113505, dvrr_stack+177997, dvrr_stack+214419);
 tmp = dvrr_stack + 113505;
 target_ptr = Libderiv->deriv2_classes[3][5][106];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+92737, dvrr_stack+147916, dvrr_stack+147706);
 tmp = dvrr_stack + 92737;
 target_ptr = Libderiv->deriv2_classes[3][6][106];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+211158, dvrr_stack+113765, dvrr_stack+177997);
 tmp = dvrr_stack + 211158;
 target_ptr = Libderiv->deriv2_classes[3][7][106];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+163001, dvrr_stack+114215, dvrr_stack+147916);
 tmp = dvrr_stack + 163001;
 target_ptr = Libderiv->deriv2_classes[3][8][106];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+163451, dvrr_stack+114765, dvrr_stack+113765);
 tmp = dvrr_stack + 163451;
 target_ptr = Libderiv->deriv2_classes[3][9][106];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+142783, dvrr_stack+93130, dvrr_stack+129944);
 tmp = dvrr_stack + 142783;
 target_ptr = Libderiv->deriv2_classes[4][5][106];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+124617, dvrr_stack+77826, dvrr_stack+93550);
 tmp = dvrr_stack + 124617;
 target_ptr = Libderiv->deriv2_classes[4][6][106];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+125037, dvrr_stack+78366, dvrr_stack+93130);
 tmp = dvrr_stack + 125037;
 target_ptr = Libderiv->deriv2_classes[4][7][106];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+125577, dvrr_stack+79041, dvrr_stack+77826);
 tmp = dvrr_stack + 125577;
 target_ptr = Libderiv->deriv2_classes[4][8][106];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+126252, dvrr_stack+79866, dvrr_stack+78366);
 tmp = dvrr_stack + 126252;
 target_ptr = Libderiv->deriv2_classes[4][9][106];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+127077, dvrr_stack+67281, dvrr_stack+80856);
 tmp = dvrr_stack + 127077;
 target_ptr = Libderiv->deriv2_classes[5][5][106];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+243493, dvrr_stack+57252, dvrr_stack+67869);
 tmp = dvrr_stack + 243493;
 target_ptr = Libderiv->deriv2_classes[5][6][106];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+244081, dvrr_stack+32467, dvrr_stack+67281);
 tmp = dvrr_stack + 244081;
 target_ptr = Libderiv->deriv2_classes[5][7][106];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+244837, dvrr_stack+33412, dvrr_stack+57252);
 tmp = dvrr_stack + 244837;
 target_ptr = Libderiv->deriv2_classes[5][8][106];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+245782, dvrr_stack+277230, dvrr_stack+32467);
 tmp = dvrr_stack + 245782;
 target_ptr = Libderiv->deriv2_classes[5][9][106];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+246937, dvrr_stack+49172, dvrr_stack+68310);
 tmp = dvrr_stack + 246937;
 target_ptr = Libderiv->deriv2_classes[6][5][106];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+247525, dvrr_stack+24447, dvrr_stack+42827);
 tmp = dvrr_stack + 247525;
 target_ptr = Libderiv->deriv2_classes[6][6][106];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+248309, dvrr_stack+278616, dvrr_stack+49172);
 tmp = dvrr_stack + 248309;
 target_ptr = Libderiv->deriv2_classes[6][7][106];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+249317, dvrr_stack+279876, dvrr_stack+24447);
 tmp = dvrr_stack + 249317;
 target_ptr = Libderiv->deriv2_classes[6][8][106];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+250577, dvrr_stack+281416, dvrr_stack+278616);
 tmp = dvrr_stack + 250577;
 target_ptr = Libderiv->deriv2_classes[6][9][106];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+52958, dvrr_stack+228093, dvrr_stack+194373);
 tmp = dvrr_stack + 52958;
 target_ptr = Libderiv->deriv2_classes[3][5][105];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+164001, dvrr_stack+2169, dvrr_stack+4108);
 tmp = dvrr_stack + 164001;
 target_ptr = Libderiv->deriv2_classes[3][6][105];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+127518, dvrr_stack+8477, dvrr_stack+228093);
 tmp = dvrr_stack + 127518;
 target_ptr = Libderiv->deriv2_classes[3][7][105];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+252117, dvrr_stack+14111, dvrr_stack+2169);
 tmp = dvrr_stack + 252117;
 target_ptr = Libderiv->deriv2_classes[3][8][105];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+252567, dvrr_stack+21147, dvrr_stack+8477);
 tmp = dvrr_stack + 252567;
 target_ptr = Libderiv->deriv2_classes[3][9][105];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+253117, dvrr_stack+231168, dvrr_stack+29542);
 tmp = dvrr_stack + 253117;
 target_ptr = Libderiv->deriv2_classes[4][5][105];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+253432, dvrr_stack+38138, dvrr_stack+40307);
 tmp = dvrr_stack + 253432;
 target_ptr = Libderiv->deriv2_classes[4][6][105];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+253852, dvrr_stack+45932, dvrr_stack+231168);
 tmp = dvrr_stack + 253852;
 target_ptr = Libderiv->deriv2_classes[4][7][105];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+254392, dvrr_stack+53202, dvrr_stack+38138);
 tmp = dvrr_stack + 254392;
 target_ptr = Libderiv->deriv2_classes[4][8][105];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+255067, dvrr_stack+21807, dvrr_stack+45932);
 tmp = dvrr_stack + 255067;
 target_ptr = Libderiv->deriv2_classes[4][9][105];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+255892, dvrr_stack+235878, dvrr_stack+73533);
 tmp = dvrr_stack + 255892;
 target_ptr = Libderiv->deriv2_classes[5][5][105];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+256333, dvrr_stack+86407, dvrr_stack+89602);
 tmp = dvrr_stack + 256333;
 target_ptr = Libderiv->deriv2_classes[5][6][105];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+256921, dvrr_stack+46607, dvrr_stack+235878);
 tmp = dvrr_stack + 256921;
 target_ptr = Libderiv->deriv2_classes[5][7][105];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+257677, dvrr_stack+108095, dvrr_stack+86407);
 tmp = dvrr_stack + 257677;
 target_ptr = Libderiv->deriv2_classes[5][8][105];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+258622, dvrr_stack+121166, dvrr_stack+46607);
 tmp = dvrr_stack + 258622;
 target_ptr = Libderiv->deriv2_classes[5][9][105];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+259777, dvrr_stack+102211, dvrr_stack+137192);
 tmp = dvrr_stack + 259777;
 target_ptr = Libderiv->deriv2_classes[6][5][105];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+260365, dvrr_stack+155161, dvrr_stack+159589);
 tmp = dvrr_stack + 260365;
 target_ptr = Libderiv->deriv2_classes[6][6][105];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+261149, dvrr_stack+170563, dvrr_stack+102211);
 tmp = dvrr_stack + 261149;
 target_ptr = Libderiv->deriv2_classes[6][7][105];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+262157, dvrr_stack+184713, dvrr_stack+155161);
 tmp = dvrr_stack + 262157;
 target_ptr = Libderiv->deriv2_classes[6][8][105];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+263417, dvrr_stack+202449, dvrr_stack+170563);
 tmp = dvrr_stack + 263417;
 target_ptr = Libderiv->deriv2_classes[6][9][105];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+231588, dvrr_stack+222490, dvrr_stack+222340);
 tmp = dvrr_stack + 231588;
 target_ptr = Libderiv->deriv2_classes[3][5][104];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+264957, dvrr_stack+222980, dvrr_stack+222770);
 tmp = dvrr_stack + 264957;
 target_ptr = Libderiv->deriv2_classes[3][6][104];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+265237, dvrr_stack+223340, dvrr_stack+222490);
 tmp = dvrr_stack + 265237;
 target_ptr = Libderiv->deriv2_classes[3][7][104];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+265597, dvrr_stack+223790, dvrr_stack+222980);
 tmp = dvrr_stack + 265597;
 target_ptr = Libderiv->deriv2_classes[3][8][104];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+266047, dvrr_stack+224340, dvrr_stack+223340);
 tmp = dvrr_stack + 266047;
 target_ptr = Libderiv->deriv2_classes[3][9][104];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+266597, dvrr_stack+225435, dvrr_stack+225210);
 tmp = dvrr_stack + 266597;
 target_ptr = Libderiv->deriv2_classes[4][5][104];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+266912, dvrr_stack+226170, dvrr_stack+225855);
 tmp = dvrr_stack + 266912;
 target_ptr = Libderiv->deriv2_classes[4][6][104];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+267332, dvrr_stack+226710, dvrr_stack+225435);
 tmp = dvrr_stack + 267332;
 target_ptr = Libderiv->deriv2_classes[4][7][104];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+267872, dvrr_stack+204297, dvrr_stack+226170);
 tmp = dvrr_stack + 267872;
 target_ptr = Libderiv->deriv2_classes[4][8][104];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+268547, dvrr_stack+205122, dvrr_stack+226710);
 tmp = dvrr_stack + 268547;
 target_ptr = Libderiv->deriv2_classes[4][9][104];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+269372, dvrr_stack+206427, dvrr_stack+206112);
 tmp = dvrr_stack + 269372;
 target_ptr = Libderiv->deriv2_classes[5][5][104];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+269813, dvrr_stack+156169, dvrr_stack+186253);
 tmp = dvrr_stack + 269813;
 target_ptr = Libderiv->deriv2_classes[5][6][104];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+270401, dvrr_stack+40622, dvrr_stack+206427);
 tmp = dvrr_stack + 270401;
 target_ptr = Libderiv->deriv2_classes[5][7][104];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+271157, dvrr_stack+186694, dvrr_stack+156169);
 tmp = dvrr_stack + 271157;
 target_ptr = Libderiv->deriv2_classes[5][8][104];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+272102, dvrr_stack+171823, dvrr_stack+40622);
 tmp = dvrr_stack + 272102;
 target_ptr = Libderiv->deriv2_classes[5][9][104];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+273257, dvrr_stack+160597, dvrr_stack+160177);
 tmp = dvrr_stack + 273257;
 target_ptr = Libderiv->deriv2_classes[6][5][104];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+273845, dvrr_stack+138200, dvrr_stack+137612);
 tmp = dvrr_stack + 273845;
 target_ptr = Libderiv->deriv2_classes[6][6][104];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+274629, dvrr_stack+139208, dvrr_stack+160597);
 tmp = dvrr_stack + 274629;
 target_ptr = Libderiv->deriv2_classes[6][7][104];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+275637, dvrr_stack+122552, dvrr_stack+138200);
 tmp = dvrr_stack + 275637;
 target_ptr = Libderiv->deriv2_classes[6][8][104];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+64791, dvrr_stack+97675, dvrr_stack+139208);
 tmp = dvrr_stack + 64791;
 target_ptr = Libderiv->deriv2_classes[6][9][104];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+36202, dvrr_stack+228693, dvrr_stack+228543);
 tmp = dvrr_stack + 36202;
 target_ptr = Libderiv->deriv2_classes[3][5][95];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+276897, dvrr_stack+44897, dvrr_stack+228973);
 tmp = dvrr_stack + 276897;
 target_ptr = Libderiv->deriv2_classes[3][6][95];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+76419, dvrr_stack+229183, dvrr_stack+228693);
 tmp = dvrr_stack + 76419;
 target_ptr = Libderiv->deriv2_classes[3][7][95];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+76779, dvrr_stack+229633, dvrr_stack+44897);
 tmp = dvrr_stack + 76779;
 target_ptr = Libderiv->deriv2_classes[3][8][95];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+77229, dvrr_stack+230183, dvrr_stack+229183);
 tmp = dvrr_stack + 77229;
 target_ptr = Libderiv->deriv2_classes[3][9][95];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+66331, dvrr_stack+5788, dvrr_stack+231843);
 tmp = dvrr_stack + 66331;
 target_ptr = Libderiv->deriv2_classes[4][5][95];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+66646, dvrr_stack+232383, dvrr_stack+232068);
 tmp = dvrr_stack + 66646;
 target_ptr = Libderiv->deriv2_classes[4][6][95];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+55035, dvrr_stack+232923, dvrr_stack+5788);
 tmp = dvrr_stack + 55035;
 target_ptr = Libderiv->deriv2_classes[4][7][95];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+55575, dvrr_stack+233598, dvrr_stack+232383);
 tmp = dvrr_stack + 55575;
 target_ptr = Libderiv->deriv2_classes[4][8][95];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+56250, dvrr_stack+234423, dvrr_stack+232923);
 tmp = dvrr_stack + 56250;
 target_ptr = Libderiv->deriv2_classes[4][9][95];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+31468, dvrr_stack+212004, dvrr_stack+211689);
 tmp = dvrr_stack + 31468;
 target_ptr = Libderiv->deriv2_classes[5][5][95];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+15445, dvrr_stack+213033, dvrr_stack+212592);
 tmp = dvrr_stack + 15445;
 target_ptr = Libderiv->deriv2_classes[5][6][95];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+16033, dvrr_stack+192273, dvrr_stack+212004);
 tmp = dvrr_stack + 16033;
 target_ptr = Libderiv->deriv2_classes[5][7][95];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+179285, dvrr_stack+193218, dvrr_stack+213033);
 tmp = dvrr_stack + 179285;
 target_ptr = Libderiv->deriv2_classes[5][8][95];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+148276, dvrr_stack+176611, dvrr_stack+192273);
 tmp = dvrr_stack + 148276;
 target_ptr = Libderiv->deriv2_classes[5][9][95];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+4868, dvrr_stack+143114, dvrr_stack+164293);
 tmp = dvrr_stack + 4868;
 target_ptr = Libderiv->deriv2_classes[6][5][95];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+149431, dvrr_stack+143898, dvrr_stack+164713);
 tmp = dvrr_stack + 149431;
 target_ptr = Libderiv->deriv2_classes[6][6][95];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+150215, dvrr_stack+144906, dvrr_stack+143114);
 tmp = dvrr_stack + 150215;
 target_ptr = Libderiv->deriv2_classes[6][7][95];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+130169, dvrr_stack+146166, dvrr_stack+143898);
 tmp = dvrr_stack + 130169;
 target_ptr = Libderiv->deriv2_classes[6][8][95];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+131429, dvrr_stack+128096, dvrr_stack+144906);
 tmp = dvrr_stack + 131429;
 target_ptr = Libderiv->deriv2_classes[6][9][95];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+227835, dvrr_stack+177997, dvrr_stack+214419);
 tmp = dvrr_stack + 227835;
 target_ptr = Libderiv->deriv2_classes[3][5][94];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+31909, dvrr_stack+147916, dvrr_stack+147706);
 tmp = dvrr_stack + 31909;
 target_ptr = Libderiv->deriv2_classes[3][6][94];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+180230, dvrr_stack+113765, dvrr_stack+177997);
 tmp = dvrr_stack + 180230;
 target_ptr = Libderiv->deriv2_classes[3][7][94];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+151223, dvrr_stack+114215, dvrr_stack+147916);
 tmp = dvrr_stack + 151223;
 target_ptr = Libderiv->deriv2_classes[3][8][94];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+132969, dvrr_stack+114765, dvrr_stack+113765);
 tmp = dvrr_stack + 132969;
 target_ptr = Libderiv->deriv2_classes[3][9][94];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+5456, dvrr_stack+93130, dvrr_stack+129944);
 tmp = dvrr_stack + 5456;
 target_ptr = Libderiv->deriv2_classes[4][5][94];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+133519, dvrr_stack+77826, dvrr_stack+93550);
 tmp = dvrr_stack + 133519;
 target_ptr = Libderiv->deriv2_classes[4][6][94];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+133939, dvrr_stack+78366, dvrr_stack+93130);
 tmp = dvrr_stack + 133939;
 target_ptr = Libderiv->deriv2_classes[4][7][94];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+134479, dvrr_stack+79041, dvrr_stack+77826);
 tmp = dvrr_stack + 134479;
 target_ptr = Libderiv->deriv2_classes[4][8][94];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+115425, dvrr_stack+79866, dvrr_stack+78366);
 tmp = dvrr_stack + 115425;
 target_ptr = Libderiv->deriv2_classes[4][9][94];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+116250, dvrr_stack+67281, dvrr_stack+80856);
 tmp = dvrr_stack + 116250;
 target_ptr = Libderiv->deriv2_classes[5][5][94];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+116691, dvrr_stack+57252, dvrr_stack+67869);
 tmp = dvrr_stack + 116691;
 target_ptr = Libderiv->deriv2_classes[5][6][94];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+93865, dvrr_stack+32467, dvrr_stack+67281);
 tmp = dvrr_stack + 93865;
 target_ptr = Libderiv->deriv2_classes[5][7][94];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+58428, dvrr_stack+33412, dvrr_stack+57252);
 tmp = dvrr_stack + 58428;
 target_ptr = Libderiv->deriv2_classes[5][8][94];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+59373, dvrr_stack+277230, dvrr_stack+32467);
 tmp = dvrr_stack + 59373;
 target_ptr = Libderiv->deriv2_classes[5][9][94];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+94621, dvrr_stack+49172, dvrr_stack+68310);
 tmp = dvrr_stack + 94621;
 target_ptr = Libderiv->deriv2_classes[6][5][94];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+49956, dvrr_stack+24447, dvrr_stack+42827);
 tmp = dvrr_stack + 49956;
 target_ptr = Libderiv->deriv2_classes[6][6][94];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+25455, dvrr_stack+278616, dvrr_stack+49172);
 tmp = dvrr_stack + 25455;
 target_ptr = Libderiv->deriv2_classes[6][7][94];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+402812, dvrr_stack+279876, dvrr_stack+24447);
 tmp = dvrr_stack + 402812;
 target_ptr = Libderiv->deriv2_classes[6][8][94];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+404072, dvrr_stack+281416, dvrr_stack+278616);
 tmp = dvrr_stack + 404072;
 target_ptr = Libderiv->deriv2_classes[6][9][94];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+405612, dvrr_stack+228093, dvrr_stack+194373);
 tmp = dvrr_stack + 405612;
 target_ptr = Libderiv->deriv2_classes[3][5][93];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+117279, dvrr_stack+2169, dvrr_stack+4108);
 tmp = dvrr_stack + 117279;
 target_ptr = Libderiv->deriv2_classes[3][6][93];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+60528, dvrr_stack+8477, dvrr_stack+228093);
 tmp = dvrr_stack + 60528;
 target_ptr = Libderiv->deriv2_classes[3][7][93];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+50740, dvrr_stack+14111, dvrr_stack+2169);
 tmp = dvrr_stack + 50740;
 target_ptr = Libderiv->deriv2_classes[3][8][93];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+43415, dvrr_stack+21147, dvrr_stack+8477);
 tmp = dvrr_stack + 43415;
 target_ptr = Libderiv->deriv2_classes[3][9][93];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+60888, dvrr_stack+231168, dvrr_stack+29542);
 tmp = dvrr_stack + 60888;
 target_ptr = Libderiv->deriv2_classes[4][5][93];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+43965, dvrr_stack+38138, dvrr_stack+40307);
 tmp = dvrr_stack + 43965;
 target_ptr = Libderiv->deriv2_classes[4][6][93];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+405822, dvrr_stack+45932, dvrr_stack+231168);
 tmp = dvrr_stack + 405822;
 target_ptr = Libderiv->deriv2_classes[4][7][93];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+406362, dvrr_stack+53202, dvrr_stack+38138);
 tmp = dvrr_stack + 406362;
 target_ptr = Libderiv->deriv2_classes[4][8][93];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+407037, dvrr_stack+21807, dvrr_stack+45932);
 tmp = dvrr_stack + 407037;
 target_ptr = Libderiv->deriv2_classes[4][9][93];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+11585, dvrr_stack+235878, dvrr_stack+73533);
 tmp = dvrr_stack + 11585;
 target_ptr = Libderiv->deriv2_classes[5][5][93];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+407862, dvrr_stack+86407, dvrr_stack+89602);
 tmp = dvrr_stack + 407862;
 target_ptr = Libderiv->deriv2_classes[5][6][93];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+408450, dvrr_stack+46607, dvrr_stack+235878);
 tmp = dvrr_stack + 408450;
 target_ptr = Libderiv->deriv2_classes[5][7][93];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+409206, dvrr_stack+108095, dvrr_stack+86407);
 tmp = dvrr_stack + 409206;
 target_ptr = Libderiv->deriv2_classes[5][8][93];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+410151, dvrr_stack+121166, dvrr_stack+46607);
 tmp = dvrr_stack + 410151;
 target_ptr = Libderiv->deriv2_classes[5][9][93];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+411306, dvrr_stack+102211, dvrr_stack+137192);
 tmp = dvrr_stack + 411306;
 target_ptr = Libderiv->deriv2_classes[6][5][93];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+411894, dvrr_stack+155161, dvrr_stack+159589);
 tmp = dvrr_stack + 411894;
 target_ptr = Libderiv->deriv2_classes[6][6][93];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+412678, dvrr_stack+170563, dvrr_stack+102211);
 tmp = dvrr_stack + 412678;
 target_ptr = Libderiv->deriv2_classes[6][7][93];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+413686, dvrr_stack+184713, dvrr_stack+155161);
 tmp = dvrr_stack + 413686;
 target_ptr = Libderiv->deriv2_classes[6][8][93];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+414946, dvrr_stack+202449, dvrr_stack+170563);
 tmp = dvrr_stack + 414946;
 target_ptr = Libderiv->deriv2_classes[6][9][93];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+416486, dvrr_stack+222490, dvrr_stack+222340);
 tmp = dvrr_stack + 416486;
 target_ptr = Libderiv->deriv2_classes[3][5][92];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+416696, dvrr_stack+222980, dvrr_stack+222770);
 tmp = dvrr_stack + 416696;
 target_ptr = Libderiv->deriv2_classes[3][6][92];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+26463, dvrr_stack+223340, dvrr_stack+222490);
 tmp = dvrr_stack + 26463;
 target_ptr = Libderiv->deriv2_classes[3][7][92];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+416976, dvrr_stack+223790, dvrr_stack+222980);
 tmp = dvrr_stack + 416976;
 target_ptr = Libderiv->deriv2_classes[3][8][92];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+417426, dvrr_stack+224340, dvrr_stack+223340);
 tmp = dvrr_stack + 417426;
 target_ptr = Libderiv->deriv2_classes[3][9][92];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+417976, dvrr_stack+225435, dvrr_stack+225210);
 tmp = dvrr_stack + 417976;
 target_ptr = Libderiv->deriv2_classes[4][5][92];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+418291, dvrr_stack+226170, dvrr_stack+225855);
 tmp = dvrr_stack + 418291;
 target_ptr = Libderiv->deriv2_classes[4][6][92];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+418711, dvrr_stack+226710, dvrr_stack+225435);
 tmp = dvrr_stack + 418711;
 target_ptr = Libderiv->deriv2_classes[4][7][92];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+419251, dvrr_stack+204297, dvrr_stack+226170);
 tmp = dvrr_stack + 419251;
 target_ptr = Libderiv->deriv2_classes[4][8][92];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+419926, dvrr_stack+205122, dvrr_stack+226710);
 tmp = dvrr_stack + 419926;
 target_ptr = Libderiv->deriv2_classes[4][9][92];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+420751, dvrr_stack+206427, dvrr_stack+206112);
 tmp = dvrr_stack + 420751;
 target_ptr = Libderiv->deriv2_classes[5][5][92];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+421192, dvrr_stack+156169, dvrr_stack+186253);
 tmp = dvrr_stack + 421192;
 target_ptr = Libderiv->deriv2_classes[5][6][92];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+421780, dvrr_stack+40622, dvrr_stack+206427);
 tmp = dvrr_stack + 421780;
 target_ptr = Libderiv->deriv2_classes[5][7][92];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+422536, dvrr_stack+186694, dvrr_stack+156169);
 tmp = dvrr_stack + 422536;
 target_ptr = Libderiv->deriv2_classes[5][8][92];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+423481, dvrr_stack+171823, dvrr_stack+40622);
 tmp = dvrr_stack + 423481;
 target_ptr = Libderiv->deriv2_classes[5][9][92];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+424636, dvrr_stack+160597, dvrr_stack+160177);
 tmp = dvrr_stack + 424636;
 target_ptr = Libderiv->deriv2_classes[6][5][92];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+425224, dvrr_stack+138200, dvrr_stack+137612);
 tmp = dvrr_stack + 425224;
 target_ptr = Libderiv->deriv2_classes[6][6][92];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+426008, dvrr_stack+139208, dvrr_stack+160597);
 tmp = dvrr_stack + 426008;
 target_ptr = Libderiv->deriv2_classes[6][7][92];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+427016, dvrr_stack+122552, dvrr_stack+138200);
 tmp = dvrr_stack + 427016;
 target_ptr = Libderiv->deriv2_classes[6][8][92];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+428276, dvrr_stack+97675, dvrr_stack+139208);
 tmp = dvrr_stack + 428276;
 target_ptr = Libderiv->deriv2_classes[6][9][92];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+84873, dvrr_stack+188129, dvrr_stack+227685);
 tmp = dvrr_stack + 84873;
 target_ptr = Libderiv->deriv2_classes[3][5][91];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+429816, dvrr_stack+161381, dvrr_stack+173209);
 tmp = dvrr_stack + 429816;
 target_ptr = Libderiv->deriv2_classes[3][6][91];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+430096, dvrr_stack+102995, dvrr_stack+188129);
 tmp = dvrr_stack + 430096;
 target_ptr = Libderiv->deriv2_classes[3][7][91];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+430456, dvrr_stack+140468, dvrr_stack+161381);
 tmp = dvrr_stack + 430456;
 target_ptr = Libderiv->deriv2_classes[3][8][91];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+430906, dvrr_stack+109250, dvrr_stack+102995);
 tmp = dvrr_stack + 430906;
 target_ptr = Libderiv->deriv2_classes[3][9][91];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+431456, dvrr_stack+99523, dvrr_stack+141018);
 tmp = dvrr_stack + 431456;
 target_ptr = Libderiv->deriv2_classes[4][5][91];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+431771, dvrr_stack+109910, dvrr_stack+124092);
 tmp = dvrr_stack + 431771;
 target_ptr = Libderiv->deriv2_classes[4][6][91];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+432191, dvrr_stack+90043, dvrr_stack+99523);
 tmp = dvrr_stack + 432191;
 target_ptr = Libderiv->deriv2_classes[4][7][91];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+432731, dvrr_stack+73848, dvrr_stack+109910);
 tmp = dvrr_stack + 432731;
 target_ptr = Libderiv->deriv2_classes[4][8][91];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+433406, dvrr_stack+74673, dvrr_stack+90043);
 tmp = dvrr_stack + 433406;
 target_ptr = Libderiv->deriv2_classes[4][9][91];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+434231, dvrr_stack+90718, dvrr_stack+110450);
 tmp = dvrr_stack + 434231;
 target_ptr = Libderiv->deriv2_classes[5][5][91];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+434672, dvrr_stack+75663, dvrr_stack+87163);
 tmp = dvrr_stack + 434672;
 target_ptr = Libderiv->deriv2_classes[5][6][91];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+435260, dvrr_stack+62331, dvrr_stack+90718);
 tmp = dvrr_stack + 435260;
 target_ptr = Libderiv->deriv2_classes[5][7][91];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+436016, dvrr_stack+63276, dvrr_stack+75663);
 tmp = dvrr_stack + 436016;
 target_ptr = Libderiv->deriv2_classes[5][8][91];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+436961, dvrr_stack+29767, dvrr_stack+62331);
 tmp = dvrr_stack + 436961;
 target_ptr = Libderiv->deriv2_classes[5][9][91];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+438116, dvrr_stack+14661, dvrr_stack+54027);
 tmp = dvrr_stack + 438116;
 target_ptr = Libderiv->deriv2_classes[6][5][91];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+438704, dvrr_stack+283264, dvrr_stack+54447);
 tmp = dvrr_stack + 438704;
 target_ptr = Libderiv->deriv2_classes[6][6][91];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+439488, dvrr_stack+284272, dvrr_stack+14661);
 tmp = dvrr_stack + 439488;
 target_ptr = Libderiv->deriv2_classes[6][7][91];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+440496, dvrr_stack+285532, dvrr_stack+283264);
 tmp = dvrr_stack + 440496;
 target_ptr = Libderiv->deriv2_classes[6][8][91];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+441756, dvrr_stack+287072, dvrr_stack+284272);
 tmp = dvrr_stack + 441756;
 target_ptr = Libderiv->deriv2_classes[6][9][91];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+443296, dvrr_stack+228693, dvrr_stack+228543);
 tmp = dvrr_stack + 443296;
 target_ptr = Libderiv->deriv2_classes[3][5][83];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+443506, dvrr_stack+44897, dvrr_stack+228973);
 tmp = dvrr_stack + 443506;
 target_ptr = Libderiv->deriv2_classes[3][6][83];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+443786, dvrr_stack+229183, dvrr_stack+228693);
 tmp = dvrr_stack + 443786;
 target_ptr = Libderiv->deriv2_classes[3][7][83];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+444146, dvrr_stack+229633, dvrr_stack+44897);
 tmp = dvrr_stack + 444146;
 target_ptr = Libderiv->deriv2_classes[3][8][83];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+444596, dvrr_stack+230183, dvrr_stack+229183);
 tmp = dvrr_stack + 444596;
 target_ptr = Libderiv->deriv2_classes[3][9][83];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+230183, dvrr_stack+5788, dvrr_stack+231843);
 tmp = dvrr_stack + 230183;
 target_ptr = Libderiv->deriv2_classes[4][5][83];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+445146, dvrr_stack+232383, dvrr_stack+232068);
 tmp = dvrr_stack + 445146;
 target_ptr = Libderiv->deriv2_classes[4][6][83];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+445566, dvrr_stack+232923, dvrr_stack+5788);
 tmp = dvrr_stack + 445566;
 target_ptr = Libderiv->deriv2_classes[4][7][83];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+446106, dvrr_stack+233598, dvrr_stack+232383);
 tmp = dvrr_stack + 446106;
 target_ptr = Libderiv->deriv2_classes[4][8][83];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+446781, dvrr_stack+234423, dvrr_stack+232923);
 tmp = dvrr_stack + 446781;
 target_ptr = Libderiv->deriv2_classes[4][9][83];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+234423, dvrr_stack+212004, dvrr_stack+211689);
 tmp = dvrr_stack + 234423;
 target_ptr = Libderiv->deriv2_classes[5][5][83];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+447606, dvrr_stack+213033, dvrr_stack+212592);
 tmp = dvrr_stack + 447606;
 target_ptr = Libderiv->deriv2_classes[5][6][83];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+448194, dvrr_stack+192273, dvrr_stack+212004);
 tmp = dvrr_stack + 448194;
 target_ptr = Libderiv->deriv2_classes[5][7][83];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+448950, dvrr_stack+193218, dvrr_stack+213033);
 tmp = dvrr_stack + 448950;
 target_ptr = Libderiv->deriv2_classes[5][8][83];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+449895, dvrr_stack+176611, dvrr_stack+192273);
 tmp = dvrr_stack + 449895;
 target_ptr = Libderiv->deriv2_classes[5][9][83];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+451050, dvrr_stack+143114, dvrr_stack+164293);
 tmp = dvrr_stack + 451050;
 target_ptr = Libderiv->deriv2_classes[6][5][83];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+176516, dvrr_stack+143898, dvrr_stack+164713);
 tmp = dvrr_stack + 176516;
 target_ptr = Libderiv->deriv2_classes[6][6][83];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+451638, dvrr_stack+144906, dvrr_stack+143114);
 tmp = dvrr_stack + 451638;
 target_ptr = Libderiv->deriv2_classes[6][7][83];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+452646, dvrr_stack+146166, dvrr_stack+143898);
 tmp = dvrr_stack + 452646;
 target_ptr = Libderiv->deriv2_classes[6][8][83];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+453906, dvrr_stack+128096, dvrr_stack+144906);
 tmp = dvrr_stack + 453906;
 target_ptr = Libderiv->deriv2_classes[6][9][83];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+234864, dvrr_stack+177997, dvrr_stack+214419);
 tmp = dvrr_stack + 234864;
 target_ptr = Libderiv->deriv2_classes[3][5][82];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+235074, dvrr_stack+147916, dvrr_stack+147706);
 tmp = dvrr_stack + 235074;
 target_ptr = Libderiv->deriv2_classes[3][6][82];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+455446, dvrr_stack+113765, dvrr_stack+177997);
 tmp = dvrr_stack + 455446;
 target_ptr = Libderiv->deriv2_classes[3][7][82];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+211518, dvrr_stack+114215, dvrr_stack+147916);
 tmp = dvrr_stack + 211518;
 target_ptr = Libderiv->deriv2_classes[3][8][82];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+177300, dvrr_stack+114765, dvrr_stack+113765);
 tmp = dvrr_stack + 177300;
 target_ptr = Libderiv->deriv2_classes[3][9][82];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+114765, dvrr_stack+93130, dvrr_stack+129944);
 tmp = dvrr_stack + 114765;
 target_ptr = Libderiv->deriv2_classes[4][5][82];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+164281, dvrr_stack+77826, dvrr_stack+93550);
 tmp = dvrr_stack + 164281;
 target_ptr = Libderiv->deriv2_classes[4][6][82];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+127878, dvrr_stack+78366, dvrr_stack+93130);
 tmp = dvrr_stack + 127878;
 target_ptr = Libderiv->deriv2_classes[4][7][82];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+128418, dvrr_stack+79041, dvrr_stack+77826);
 tmp = dvrr_stack + 128418;
 target_ptr = Libderiv->deriv2_classes[4][8][82];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+129093, dvrr_stack+79866, dvrr_stack+78366);
 tmp = dvrr_stack + 129093;
 target_ptr = Libderiv->deriv2_classes[4][9][82];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+79866, dvrr_stack+67281, dvrr_stack+80856);
 tmp = dvrr_stack + 79866;
 target_ptr = Libderiv->deriv2_classes[5][5][82];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+80307, dvrr_stack+57252, dvrr_stack+67869);
 tmp = dvrr_stack + 80307;
 target_ptr = Libderiv->deriv2_classes[5][6][82];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+455806, dvrr_stack+32467, dvrr_stack+67281);
 tmp = dvrr_stack + 455806;
 target_ptr = Libderiv->deriv2_classes[5][7][82];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+456562, dvrr_stack+33412, dvrr_stack+57252);
 tmp = dvrr_stack + 456562;
 target_ptr = Libderiv->deriv2_classes[5][8][82];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+457507, dvrr_stack+277230, dvrr_stack+32467);
 tmp = dvrr_stack + 457507;
 target_ptr = Libderiv->deriv2_classes[5][9][82];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+277177, dvrr_stack+49172, dvrr_stack+68310);
 tmp = dvrr_stack + 277177;
 target_ptr = Libderiv->deriv2_classes[6][5][82];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+277765, dvrr_stack+24447, dvrr_stack+42827);
 tmp = dvrr_stack + 277765;
 target_ptr = Libderiv->deriv2_classes[6][6][82];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+458662, dvrr_stack+278616, dvrr_stack+49172);
 tmp = dvrr_stack + 458662;
 target_ptr = Libderiv->deriv2_classes[6][7][82];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+459670, dvrr_stack+279876, dvrr_stack+24447);
 tmp = dvrr_stack + 459670;
 target_ptr = Libderiv->deriv2_classes[6][8][82];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+460930, dvrr_stack+281416, dvrr_stack+278616);
 tmp = dvrr_stack + 460930;
 target_ptr = Libderiv->deriv2_classes[6][9][82];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+281416, dvrr_stack+228093, dvrr_stack+194373);
 tmp = dvrr_stack + 281416;
 target_ptr = Libderiv->deriv2_classes[3][5][81];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+281626, dvrr_stack+2169, dvrr_stack+4108);
 tmp = dvrr_stack + 281626;
 target_ptr = Libderiv->deriv2_classes[3][6][81];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+281906, dvrr_stack+8477, dvrr_stack+228093);
 tmp = dvrr_stack + 281906;
 target_ptr = Libderiv->deriv2_classes[3][7][81];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+282266, dvrr_stack+14111, dvrr_stack+2169);
 tmp = dvrr_stack + 282266;
 target_ptr = Libderiv->deriv2_classes[3][8][81];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+462470, dvrr_stack+21147, dvrr_stack+8477);
 tmp = dvrr_stack + 462470;
 target_ptr = Libderiv->deriv2_classes[3][9][81];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+21147, dvrr_stack+231168, dvrr_stack+29542);
 tmp = dvrr_stack + 21147;
 target_ptr = Libderiv->deriv2_classes[4][5][81];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+68310, dvrr_stack+38138, dvrr_stack+40307);
 tmp = dvrr_stack + 68310;
 target_ptr = Libderiv->deriv2_classes[4][6][81];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+282716, dvrr_stack+45932, dvrr_stack+231168);
 tmp = dvrr_stack + 282716;
 target_ptr = Libderiv->deriv2_classes[4][7][81];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+463020, dvrr_stack+53202, dvrr_stack+38138);
 tmp = dvrr_stack + 463020;
 target_ptr = Libderiv->deriv2_classes[4][8][81];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+463695, dvrr_stack+21807, dvrr_stack+45932);
 tmp = dvrr_stack + 463695;
 target_ptr = Libderiv->deriv2_classes[4][9][81];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+21462, dvrr_stack+235878, dvrr_stack+73533);
 tmp = dvrr_stack + 21462;
 target_ptr = Libderiv->deriv2_classes[5][5][81];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+21903, dvrr_stack+86407, dvrr_stack+89602);
 tmp = dvrr_stack + 21903;
 target_ptr = Libderiv->deriv2_classes[5][6][81];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+464520, dvrr_stack+46607, dvrr_stack+235878);
 tmp = dvrr_stack + 464520;
 target_ptr = Libderiv->deriv2_classes[5][7][81];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+465276, dvrr_stack+108095, dvrr_stack+86407);
 tmp = dvrr_stack + 465276;
 target_ptr = Libderiv->deriv2_classes[5][8][81];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+466221, dvrr_stack+121166, dvrr_stack+46607);
 tmp = dvrr_stack + 466221;
 target_ptr = Libderiv->deriv2_classes[5][9][81];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+467376, dvrr_stack+102211, dvrr_stack+137192);
 tmp = dvrr_stack + 467376;
 target_ptr = Libderiv->deriv2_classes[6][5][81];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+121010, dvrr_stack+155161, dvrr_stack+159589);
 tmp = dvrr_stack + 121010;
 target_ptr = Libderiv->deriv2_classes[6][6][81];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+467964, dvrr_stack+170563, dvrr_stack+102211);
 tmp = dvrr_stack + 467964;
 target_ptr = Libderiv->deriv2_classes[6][7][81];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+468972, dvrr_stack+184713, dvrr_stack+155161);
 tmp = dvrr_stack + 468972;
 target_ptr = Libderiv->deriv2_classes[6][8][81];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+470232, dvrr_stack+202449, dvrr_stack+170563);
 tmp = dvrr_stack + 470232;
 target_ptr = Libderiv->deriv2_classes[6][9][81];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+22491, dvrr_stack+222490, dvrr_stack+222340);
 tmp = dvrr_stack + 22491;
 target_ptr = Libderiv->deriv2_classes[3][5][80];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+115080, dvrr_stack+222980, dvrr_stack+222770);
 tmp = dvrr_stack + 115080;
 target_ptr = Libderiv->deriv2_classes[3][6][80];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+202338, dvrr_stack+223340, dvrr_stack+222490);
 tmp = dvrr_stack + 202338;
 target_ptr = Libderiv->deriv2_classes[3][7][80];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+202698, dvrr_stack+223790, dvrr_stack+222980);
 tmp = dvrr_stack + 202698;
 target_ptr = Libderiv->deriv2_classes[3][8][80];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+203148, dvrr_stack+224340, dvrr_stack+223340);
 tmp = dvrr_stack + 203148;
 target_ptr = Libderiv->deriv2_classes[3][9][80];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+224340, dvrr_stack+225435, dvrr_stack+225210);
 tmp = dvrr_stack + 224340;
 target_ptr = Libderiv->deriv2_classes[4][5][80];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+203698, dvrr_stack+226170, dvrr_stack+225855);
 tmp = dvrr_stack + 203698;
 target_ptr = Libderiv->deriv2_classes[4][6][80];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+121794, dvrr_stack+226710, dvrr_stack+225435);
 tmp = dvrr_stack + 121794;
 target_ptr = Libderiv->deriv2_classes[4][7][80];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+471772, dvrr_stack+204297, dvrr_stack+226170);
 tmp = dvrr_stack + 471772;
 target_ptr = Libderiv->deriv2_classes[4][8][80];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+472447, dvrr_stack+205122, dvrr_stack+226710);
 tmp = dvrr_stack + 472447;
 target_ptr = Libderiv->deriv2_classes[4][9][80];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+205122, dvrr_stack+206427, dvrr_stack+206112);
 tmp = dvrr_stack + 205122;
 target_ptr = Libderiv->deriv2_classes[5][5][80];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+205563, dvrr_stack+156169, dvrr_stack+186253);
 tmp = dvrr_stack + 205563;
 target_ptr = Libderiv->deriv2_classes[5][6][80];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+473272, dvrr_stack+40622, dvrr_stack+206427);
 tmp = dvrr_stack + 473272;
 target_ptr = Libderiv->deriv2_classes[5][7][80];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+474028, dvrr_stack+186694, dvrr_stack+156169);
 tmp = dvrr_stack + 474028;
 target_ptr = Libderiv->deriv2_classes[5][8][80];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+474973, dvrr_stack+171823, dvrr_stack+40622);
 tmp = dvrr_stack + 474973;
 target_ptr = Libderiv->deriv2_classes[5][9][80];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+171823, dvrr_stack+160597, dvrr_stack+160177);
 tmp = dvrr_stack + 171823;
 target_ptr = Libderiv->deriv2_classes[6][5][80];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+172411, dvrr_stack+138200, dvrr_stack+137612);
 tmp = dvrr_stack + 172411;
 target_ptr = Libderiv->deriv2_classes[6][6][80];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+476128, dvrr_stack+139208, dvrr_stack+160597);
 tmp = dvrr_stack + 476128;
 target_ptr = Libderiv->deriv2_classes[6][7][80];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+477136, dvrr_stack+122552, dvrr_stack+138200);
 tmp = dvrr_stack + 477136;
 target_ptr = Libderiv->deriv2_classes[6][8][80];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+478396, dvrr_stack+97675, dvrr_stack+139208);
 tmp = dvrr_stack + 478396;
 target_ptr = Libderiv->deriv2_classes[6][9][80];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+160177, dvrr_stack+188129, dvrr_stack+227685);
 tmp = dvrr_stack + 160177;
 target_ptr = Libderiv->deriv2_classes[3][5][79];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+224655, dvrr_stack+161381, dvrr_stack+173209);
 tmp = dvrr_stack + 224655;
 target_ptr = Libderiv->deriv2_classes[3][6][79];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+97456, dvrr_stack+102995, dvrr_stack+188129);
 tmp = dvrr_stack + 97456;
 target_ptr = Libderiv->deriv2_classes[3][7][79];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+97816, dvrr_stack+140468, dvrr_stack+161381);
 tmp = dvrr_stack + 97816;
 target_ptr = Libderiv->deriv2_classes[3][8][79];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+98266, dvrr_stack+109250, dvrr_stack+102995);
 tmp = dvrr_stack + 98266;
 target_ptr = Libderiv->deriv2_classes[3][9][79];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+109250, dvrr_stack+99523, dvrr_stack+141018);
 tmp = dvrr_stack + 109250;
 target_ptr = Libderiv->deriv2_classes[4][5][79];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+98816, dvrr_stack+109910, dvrr_stack+124092);
 tmp = dvrr_stack + 98816;
 target_ptr = Libderiv->deriv2_classes[4][6][79];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+136965, dvrr_stack+90043, dvrr_stack+99523);
 tmp = dvrr_stack + 136965;
 target_ptr = Libderiv->deriv2_classes[4][7][79];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+479936, dvrr_stack+73848, dvrr_stack+109910);
 tmp = dvrr_stack + 479936;
 target_ptr = Libderiv->deriv2_classes[4][8][79];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+480611, dvrr_stack+74673, dvrr_stack+90043);
 tmp = dvrr_stack + 480611;
 target_ptr = Libderiv->deriv2_classes[4][9][79];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+74673, dvrr_stack+90718, dvrr_stack+110450);
 tmp = dvrr_stack + 74673;
 target_ptr = Libderiv->deriv2_classes[5][5][79];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+481436, dvrr_stack+75663, dvrr_stack+87163);
 tmp = dvrr_stack + 481436;
 target_ptr = Libderiv->deriv2_classes[5][6][79];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+482024, dvrr_stack+62331, dvrr_stack+90718);
 tmp = dvrr_stack + 482024;
 target_ptr = Libderiv->deriv2_classes[5][7][79];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+482780, dvrr_stack+63276, dvrr_stack+75663);
 tmp = dvrr_stack + 482780;
 target_ptr = Libderiv->deriv2_classes[5][8][79];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+483725, dvrr_stack+29767, dvrr_stack+62331);
 tmp = dvrr_stack + 483725;
 target_ptr = Libderiv->deriv2_classes[5][9][79];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+29402, dvrr_stack+14661, dvrr_stack+54027);
 tmp = dvrr_stack + 29402;
 target_ptr = Libderiv->deriv2_classes[6][5][79];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+29990, dvrr_stack+283264, dvrr_stack+54447);
 tmp = dvrr_stack + 29990;
 target_ptr = Libderiv->deriv2_classes[6][6][79];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+484880, dvrr_stack+284272, dvrr_stack+14661);
 tmp = dvrr_stack + 484880;
 target_ptr = Libderiv->deriv2_classes[6][7][79];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+485888, dvrr_stack+285532, dvrr_stack+283264);
 tmp = dvrr_stack + 485888;
 target_ptr = Libderiv->deriv2_classes[6][8][79];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+487148, dvrr_stack+287072, dvrr_stack+284272);
 tmp = dvrr_stack + 487148;
 target_ptr = Libderiv->deriv2_classes[6][9][79];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+160387, dvrr_stack+236466, dvrr_stack+173419);
 tmp = dvrr_stack + 160387;
 target_ptr = Libderiv->deriv2_classes[3][5][78];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+287072, dvrr_stack+64431, dvrr_stack+124407);
 tmp = dvrr_stack + 287072;
 target_ptr = Libderiv->deriv2_classes[3][6][78];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+287352, dvrr_stack+8927, dvrr_stack+236466);
 tmp = dvrr_stack + 287352;
 target_ptr = Libderiv->deriv2_classes[3][7][78];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+287712, dvrr_stack+4318, dvrr_stack+64431);
 tmp = dvrr_stack + 287712;
 target_ptr = Libderiv->deriv2_classes[3][8][78];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+288162, dvrr_stack+20487, dvrr_stack+8927);
 tmp = dvrr_stack + 288162;
 target_ptr = Libderiv->deriv2_classes[3][9][78];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+110450, dvrr_stack+58008, dvrr_stack+38678);
 tmp = dvrr_stack + 110450;
 target_ptr = Libderiv->deriv2_classes[4][5][78];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+54027, dvrr_stack+16811, dvrr_stack+31153);
 tmp = dvrr_stack + 54027;
 target_ptr = Libderiv->deriv2_classes[4][6][78];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+75114, dvrr_stack+28727, dvrr_stack+58008);
 tmp = dvrr_stack + 75114;
 target_ptr = Libderiv->deriv2_classes[4][7][78];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+20241, dvrr_stack+288920, dvrr_stack+16811);
 tmp = dvrr_stack + 20241;
 target_ptr = Libderiv->deriv2_classes[4][8][78];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+488688, dvrr_stack+61222, dvrr_stack+28727);
 tmp = dvrr_stack + 488688;
 target_ptr = Libderiv->deriv2_classes[4][9][78];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+489513, dvrr_stack+10637, dvrr_stack+230843);
 tmp = dvrr_stack + 489513;
 target_ptr = Libderiv->deriv2_classes[5][5][78];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+230498, dvrr_stack+72582, dvrr_stack+72141);
 tmp = dvrr_stack + 230498;
 target_ptr = Libderiv->deriv2_classes[5][6][78];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+61203, dvrr_stack+289745, dvrr_stack+10637);
 tmp = dvrr_stack + 61203;
 target_ptr = Libderiv->deriv2_classes[5][7][78];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+489954, dvrr_stack+290690, dvrr_stack+72582);
 tmp = dvrr_stack + 489954;
 target_ptr = Libderiv->deriv2_classes[5][8][78];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+490899, dvrr_stack+291845, dvrr_stack+289745);
 tmp = dvrr_stack + 490899;
 target_ptr = Libderiv->deriv2_classes[5][9][78];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+291845, dvrr_stack+135851, dvrr_stack+135431);
 tmp = dvrr_stack + 291845;
 target_ptr = Libderiv->deriv2_classes[6][5][78];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+292433, dvrr_stack+293819, dvrr_stack+293231);
 tmp = dvrr_stack + 292433;
 target_ptr = Libderiv->deriv2_classes[6][6][78];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+492054, dvrr_stack+294827, dvrr_stack+135851);
 tmp = dvrr_stack + 492054;
 target_ptr = Libderiv->deriv2_classes[6][7][78];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+493062, dvrr_stack+296087, dvrr_stack+293819);
 tmp = dvrr_stack + 493062;
 target_ptr = Libderiv->deriv2_classes[6][8][78];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+494322, dvrr_stack+297627, dvrr_stack+294827);
 tmp = dvrr_stack + 494322;
 target_ptr = Libderiv->deriv2_classes[6][9][78];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,21,dvrr_stack+297627, dvrr_stack+232068, dvrr_stack+68730);
 tmp = dvrr_stack + 297627;
 target_ptr = Libderiv->deriv2_classes[3][5][35];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,28,dvrr_stack+297837, dvrr_stack+5788, dvrr_stack+165301);
 tmp = dvrr_stack + 297837;
 target_ptr = Libderiv->deriv2_classes[3][6][35];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,36,dvrr_stack+298117, dvrr_stack+232383, dvrr_stack+187849);
 tmp = dvrr_stack + 298117;
 target_ptr = Libderiv->deriv2_classes[3][7][35];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,45,dvrr_stack+298477, dvrr_stack+232923, dvrr_stack+2529);
 tmp = dvrr_stack + 298477;
 target_ptr = Libderiv->deriv2_classes[3][8][35];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_f(Data,55,dvrr_stack+135154, dvrr_stack+233598, dvrr_stack+136635);
 tmp = dvrr_stack + 135154;
 target_ptr = Libderiv->deriv2_classes[3][9][35];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,21,dvrr_stack+298927, dvrr_stack+212592, dvrr_stack+228973);
 tmp = dvrr_stack + 298927;
 target_ptr = Libderiv->deriv2_classes[4][5][35];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,28,dvrr_stack+73338, dvrr_stack+212004, dvrr_stack+228693);
 tmp = dvrr_stack + 73338;
 target_ptr = Libderiv->deriv2_classes[4][6][35];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,36,dvrr_stack+495862, dvrr_stack+213033, dvrr_stack+44897);
 tmp = dvrr_stack + 495862;
 target_ptr = Libderiv->deriv2_classes[4][7][35];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,45,dvrr_stack+496402, dvrr_stack+192273, dvrr_stack+229183);
 tmp = dvrr_stack + 496402;
 target_ptr = Libderiv->deriv2_classes[4][8][35];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,55,dvrr_stack+497077, dvrr_stack+193218, dvrr_stack+229633);
 tmp = dvrr_stack + 497077;
 target_ptr = Libderiv->deriv2_classes[4][9][35];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,21,dvrr_stack+497902, dvrr_stack+164713, dvrr_stack+232068);
 tmp = dvrr_stack + 497902;
 target_ptr = Libderiv->deriv2_classes[5][5][35];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,28,dvrr_stack+498343, dvrr_stack+143114, dvrr_stack+5788);
 tmp = dvrr_stack + 498343;
 target_ptr = Libderiv->deriv2_classes[5][6][35];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,36,dvrr_stack+498931, dvrr_stack+143898, dvrr_stack+232383);
 tmp = dvrr_stack + 498931;
 target_ptr = Libderiv->deriv2_classes[5][7][35];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,45,dvrr_stack+499687, dvrr_stack+144906, dvrr_stack+232923);
 tmp = dvrr_stack + 499687;
 target_ptr = Libderiv->deriv2_classes[5][8][35];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,55,dvrr_stack+500632, dvrr_stack+146166, dvrr_stack+233598);
 tmp = dvrr_stack + 500632;
 target_ptr = Libderiv->deriv2_classes[5][9][35];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,21,dvrr_stack+501787, dvrr_stack+307633, dvrr_stack+212592);
 tmp = dvrr_stack + 501787;
 target_ptr = Libderiv->deriv2_classes[6][5][35];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,28,dvrr_stack+502375, dvrr_stack+87730, dvrr_stack+212004);
 tmp = dvrr_stack + 502375;
 target_ptr = Libderiv->deriv2_classes[6][6][35];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,36,dvrr_stack+503159, dvrr_stack+95335, dvrr_stack+213033);
 tmp = dvrr_stack + 503159;
 target_ptr = Libderiv->deriv2_classes[6][7][35];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,45,dvrr_stack+504167, dvrr_stack+105235, dvrr_stack+192273);
 tmp = dvrr_stack + 504167;
 target_ptr = Libderiv->deriv2_classes[6][8][35];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,55,dvrr_stack+505427, dvrr_stack+197565, dvrr_stack+193218);
 tmp = dvrr_stack + 505427;
 target_ptr = Libderiv->deriv2_classes[6][9][35];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+299242, dvrr_stack+93550, dvrr_stack+335091);
 tmp = dvrr_stack + 299242;
 target_ptr = Libderiv->deriv2_classes[3][5][34];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+109565, dvrr_stack+93130, dvrr_stack+335217);
 tmp = dvrr_stack + 109565;
 target_ptr = Libderiv->deriv2_classes[3][6][34];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+61959, dvrr_stack+77826, dvrr_stack+335385);
 tmp = dvrr_stack + 61959;
 target_ptr = Libderiv->deriv2_classes[3][7][34];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+506967, dvrr_stack+78366, dvrr_stack+335601);
 tmp = dvrr_stack + 506967;
 target_ptr = Libderiv->deriv2_classes[3][8][34];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+507417, dvrr_stack+79041, dvrr_stack+335871);
 tmp = dvrr_stack + 507417;
 target_ptr = Libderiv->deriv2_classes[3][9][34];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+228373, dvrr_stack+67869, dvrr_stack+147706);
 tmp = dvrr_stack + 228373;
 target_ptr = Libderiv->deriv2_classes[4][5][34];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+507967, dvrr_stack+67281, dvrr_stack+177997);
 tmp = dvrr_stack + 507967;
 target_ptr = Libderiv->deriv2_classes[4][6][34];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+508387, dvrr_stack+57252, dvrr_stack+147916);
 tmp = dvrr_stack + 508387;
 target_ptr = Libderiv->deriv2_classes[4][7][34];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+508927, dvrr_stack+32467, dvrr_stack+113765);
 tmp = dvrr_stack + 508927;
 target_ptr = Libderiv->deriv2_classes[4][8][34];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+509602, dvrr_stack+33412, dvrr_stack+114215);
 tmp = dvrr_stack + 509602;
 target_ptr = Libderiv->deriv2_classes[4][9][34];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+510427, dvrr_stack+42827, dvrr_stack+93550);
 tmp = dvrr_stack + 510427;
 target_ptr = Libderiv->deriv2_classes[5][5][34];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+510868, dvrr_stack+49172, dvrr_stack+93130);
 tmp = dvrr_stack + 510868;
 target_ptr = Libderiv->deriv2_classes[5][6][34];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+511456, dvrr_stack+24447, dvrr_stack+77826);
 tmp = dvrr_stack + 511456;
 target_ptr = Libderiv->deriv2_classes[5][7][34];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+512212, dvrr_stack+278616, dvrr_stack+78366);
 tmp = dvrr_stack + 512212;
 target_ptr = Libderiv->deriv2_classes[5][8][34];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+513157, dvrr_stack+279876, dvrr_stack+79041);
 tmp = dvrr_stack + 513157;
 target_ptr = Libderiv->deriv2_classes[5][9][34];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+514312, dvrr_stack+199545, dvrr_stack+67869);
 tmp = dvrr_stack + 514312;
 target_ptr = Libderiv->deriv2_classes[6][5][34];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+514900, dvrr_stack+200301, dvrr_stack+67281);
 tmp = dvrr_stack + 514900;
 target_ptr = Libderiv->deriv2_classes[6][6][34];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+515684, dvrr_stack+117734, dvrr_stack+57252);
 tmp = dvrr_stack + 515684;
 target_ptr = Libderiv->deriv2_classes[6][7][34];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+516692, dvrr_stack+119030, dvrr_stack+32467);
 tmp = dvrr_stack + 516692;
 target_ptr = Libderiv->deriv2_classes[6][8][34];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+517952, dvrr_stack+345255, dvrr_stack+33412);
 tmp = dvrr_stack + 517952;
 target_ptr = Libderiv->deriv2_classes[6][9][34];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+38678, dvrr_stack+40307, dvrr_stack+336201);
 tmp = dvrr_stack + 38678;
 target_ptr = Libderiv->deriv2_classes[3][5][33];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+519492, dvrr_stack+231168, dvrr_stack+219879);
 tmp = dvrr_stack + 519492;
 target_ptr = Libderiv->deriv2_classes[3][6][33];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+30774, dvrr_stack+38138, dvrr_stack+220047);
 tmp = dvrr_stack + 30774;
 target_ptr = Libderiv->deriv2_classes[3][7][33];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+519772, dvrr_stack+45932, dvrr_stack+220263);
 tmp = dvrr_stack + 519772;
 target_ptr = Libderiv->deriv2_classes[3][8][33];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+520222, dvrr_stack+53202, dvrr_stack+220533);
 tmp = dvrr_stack + 520222;
 target_ptr = Libderiv->deriv2_classes[3][9][33];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+520772, dvrr_stack+89602, dvrr_stack+4108);
 tmp = dvrr_stack + 520772;
 target_ptr = Libderiv->deriv2_classes[4][5][33];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+521087, dvrr_stack+235878, dvrr_stack+228093);
 tmp = dvrr_stack + 521087;
 target_ptr = Libderiv->deriv2_classes[4][6][33];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+521507, dvrr_stack+86407, dvrr_stack+2169);
 tmp = dvrr_stack + 521507;
 target_ptr = Libderiv->deriv2_classes[4][7][33];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+522047, dvrr_stack+46607, dvrr_stack+8477);
 tmp = dvrr_stack + 522047;
 target_ptr = Libderiv->deriv2_classes[4][8][33];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+522722, dvrr_stack+108095, dvrr_stack+14111);
 tmp = dvrr_stack + 522722;
 target_ptr = Libderiv->deriv2_classes[4][9][33];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+523547, dvrr_stack+159589, dvrr_stack+40307);
 tmp = dvrr_stack + 523547;
 target_ptr = Libderiv->deriv2_classes[5][5][33];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+523988, dvrr_stack+102211, dvrr_stack+231168);
 tmp = dvrr_stack + 523988;
 target_ptr = Libderiv->deriv2_classes[5][6][33];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+524576, dvrr_stack+155161, dvrr_stack+38138);
 tmp = dvrr_stack + 524576;
 target_ptr = Libderiv->deriv2_classes[5][7][33];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+525332, dvrr_stack+170563, dvrr_stack+45932);
 tmp = dvrr_stack + 525332;
 target_ptr = Libderiv->deriv2_classes[5][8][33];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+526277, dvrr_stack+184713, dvrr_stack+53202);
 tmp = dvrr_stack + 526277;
 target_ptr = Libderiv->deriv2_classes[5][9][33];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+527432, dvrr_stack+299475, dvrr_stack+89602);
 tmp = dvrr_stack + 527432;
 target_ptr = Libderiv->deriv2_classes[6][5][33];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+528020, dvrr_stack+305365, dvrr_stack+235878);
 tmp = dvrr_stack + 528020;
 target_ptr = Libderiv->deriv2_classes[6][6][33];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+528804, dvrr_stack+311989, dvrr_stack+86407);
 tmp = dvrr_stack + 528804;
 target_ptr = Libderiv->deriv2_classes[6][7][33];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+529812, dvrr_stack+319963, dvrr_stack+46607);
 tmp = dvrr_stack + 529812;
 target_ptr = Libderiv->deriv2_classes[6][8][33];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+531072, dvrr_stack+330231, dvrr_stack+108095);
 tmp = dvrr_stack + 531072;
 target_ptr = Libderiv->deriv2_classes[6][9][33];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+141018, dvrr_stack+225855, dvrr_stack+339315);
 tmp = dvrr_stack + 141018;
 target_ptr = Libderiv->deriv2_classes[3][5][32];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+532612, dvrr_stack+225435, dvrr_stack+339441);
 tmp = dvrr_stack + 532612;
 target_ptr = Libderiv->deriv2_classes[3][6][32];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+532892, dvrr_stack+226170, dvrr_stack+339609);
 tmp = dvrr_stack + 532892;
 target_ptr = Libderiv->deriv2_classes[3][7][32];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+533252, dvrr_stack+226710, dvrr_stack+339825);
 tmp = dvrr_stack + 533252;
 target_ptr = Libderiv->deriv2_classes[3][8][32];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+533702, dvrr_stack+204297, dvrr_stack+340095);
 tmp = dvrr_stack + 533702;
 target_ptr = Libderiv->deriv2_classes[3][9][32];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+534252, dvrr_stack+186253, dvrr_stack+222770);
 tmp = dvrr_stack + 534252;
 target_ptr = Libderiv->deriv2_classes[4][5][32];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+534567, dvrr_stack+206427, dvrr_stack+222490);
 tmp = dvrr_stack + 534567;
 target_ptr = Libderiv->deriv2_classes[4][6][32];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+534987, dvrr_stack+156169, dvrr_stack+222980);
 tmp = dvrr_stack + 534987;
 target_ptr = Libderiv->deriv2_classes[4][7][32];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+535527, dvrr_stack+40622, dvrr_stack+223340);
 tmp = dvrr_stack + 535527;
 target_ptr = Libderiv->deriv2_classes[4][8][32];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+536202, dvrr_stack+186694, dvrr_stack+223790);
 tmp = dvrr_stack + 536202;
 target_ptr = Libderiv->deriv2_classes[4][9][32];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+537027, dvrr_stack+137612, dvrr_stack+225855);
 tmp = dvrr_stack + 537027;
 target_ptr = Libderiv->deriv2_classes[5][5][32];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+537468, dvrr_stack+160597, dvrr_stack+225435);
 tmp = dvrr_stack + 537468;
 target_ptr = Libderiv->deriv2_classes[5][6][32];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+538056, dvrr_stack+138200, dvrr_stack+226170);
 tmp = dvrr_stack + 538056;
 target_ptr = Libderiv->deriv2_classes[5][7][32];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+538812, dvrr_stack+139208, dvrr_stack+226710);
 tmp = dvrr_stack + 538812;
 target_ptr = Libderiv->deriv2_classes[5][8][32];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+539757, dvrr_stack+122552, dvrr_stack+204297);
 tmp = dvrr_stack + 539757;
 target_ptr = Libderiv->deriv2_classes[5][9][32];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+540912, dvrr_stack+341371, dvrr_stack+186253);
 tmp = dvrr_stack + 540912;
 target_ptr = Libderiv->deriv2_classes[6][5][32];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+541500, dvrr_stack+342127, dvrr_stack+206427);
 tmp = dvrr_stack + 541500;
 target_ptr = Libderiv->deriv2_classes[6][6][32];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+542284, dvrr_stack+343135, dvrr_stack+156169);
 tmp = dvrr_stack + 542284;
 target_ptr = Libderiv->deriv2_classes[6][7][32];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+543292, dvrr_stack+332211, dvrr_stack+40622);
 tmp = dvrr_stack + 543292;
 target_ptr = Libderiv->deriv2_classes[6][8][32];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+544552, dvrr_stack+321583, dvrr_stack+186694);
 tmp = dvrr_stack + 544552;
 target_ptr = Libderiv->deriv2_classes[6][9][32];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+206151, dvrr_stack+124092, dvrr_stack+340425);
 tmp = dvrr_stack + 206151;
 target_ptr = Libderiv->deriv2_classes[3][5][31];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+546092, dvrr_stack+99523, dvrr_stack+340551);
 tmp = dvrr_stack + 546092;
 target_ptr = Libderiv->deriv2_classes[3][6][31];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+546372, dvrr_stack+109910, dvrr_stack+235413);
 tmp = dvrr_stack + 546372;
 target_ptr = Libderiv->deriv2_classes[3][7][31];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+546732, dvrr_stack+90043, dvrr_stack+213789);
 tmp = dvrr_stack + 546732;
 target_ptr = Libderiv->deriv2_classes[3][8][31];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+547182, dvrr_stack+73848, dvrr_stack+214059);
 tmp = dvrr_stack + 547182;
 target_ptr = Libderiv->deriv2_classes[3][9][31];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+547732, dvrr_stack+87163, dvrr_stack+173209);
 tmp = dvrr_stack + 547732;
 target_ptr = Libderiv->deriv2_classes[4][5][31];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+548047, dvrr_stack+90718, dvrr_stack+188129);
 tmp = dvrr_stack + 548047;
 target_ptr = Libderiv->deriv2_classes[4][6][31];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+548467, dvrr_stack+75663, dvrr_stack+161381);
 tmp = dvrr_stack + 548467;
 target_ptr = Libderiv->deriv2_classes[4][7][31];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+549007, dvrr_stack+62331, dvrr_stack+102995);
 tmp = dvrr_stack + 549007;
 target_ptr = Libderiv->deriv2_classes[4][8][31];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+549682, dvrr_stack+63276, dvrr_stack+140468);
 tmp = dvrr_stack + 549682;
 target_ptr = Libderiv->deriv2_classes[4][9][31];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+550507, dvrr_stack+54447, dvrr_stack+124092);
 tmp = dvrr_stack + 550507;
 target_ptr = Libderiv->deriv2_classes[5][5][31];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+550948, dvrr_stack+14661, dvrr_stack+99523);
 tmp = dvrr_stack + 550948;
 target_ptr = Libderiv->deriv2_classes[5][6][31];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+551536, dvrr_stack+283264, dvrr_stack+109910);
 tmp = dvrr_stack + 551536;
 target_ptr = Libderiv->deriv2_classes[5][7][31];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+552292, dvrr_stack+284272, dvrr_stack+90043);
 tmp = dvrr_stack + 552292;
 target_ptr = Libderiv->deriv2_classes[5][8][31];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+553237, dvrr_stack+285532, dvrr_stack+73848);
 tmp = dvrr_stack + 553237;
 target_ptr = Libderiv->deriv2_classes[5][9][31];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+554392, dvrr_stack+344431, dvrr_stack+87163);
 tmp = dvrr_stack + 554392;
 target_ptr = Libderiv->deriv2_classes[6][5][31];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+554980, dvrr_stack+333831, dvrr_stack+90718);
 tmp = dvrr_stack + 554980;
 target_ptr = Libderiv->deriv2_classes[6][6][31];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+555764, dvrr_stack+313285, dvrr_stack+75663);
 tmp = dvrr_stack + 555764;
 target_ptr = Libderiv->deriv2_classes[6][7][31];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+556772, dvrr_stack+347235, dvrr_stack+62331);
 tmp = dvrr_stack + 556772;
 target_ptr = Libderiv->deriv2_classes[6][8][31];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+558032, dvrr_stack+348855, dvrr_stack+63276);
 tmp = dvrr_stack + 558032;
 target_ptr = Libderiv->deriv2_classes[6][9][31];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+225210, dvrr_stack+31153, dvrr_stack+235629);
 tmp = dvrr_stack + 225210;
 target_ptr = Libderiv->deriv2_classes[3][5][30];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+559572, dvrr_stack+58008, dvrr_stack+334839);
 tmp = dvrr_stack + 559572;
 target_ptr = Libderiv->deriv2_classes[3][6][30];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+559852, dvrr_stack+16811, dvrr_stack+323563);
 tmp = dvrr_stack + 559852;
 target_ptr = Libderiv->deriv2_classes[3][7][30];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+560212, dvrr_stack+28727, dvrr_stack+314581);
 tmp = dvrr_stack + 560212;
 target_ptr = Libderiv->deriv2_classes[3][8][30];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+560662, dvrr_stack+288920, dvrr_stack+306373);
 tmp = dvrr_stack + 560662;
 target_ptr = Libderiv->deriv2_classes[3][9][30];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+561212, dvrr_stack+72141, dvrr_stack+124407);
 tmp = dvrr_stack + 561212;
 target_ptr = Libderiv->deriv2_classes[4][5][30];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+561527, dvrr_stack+10637, dvrr_stack+236466);
 tmp = dvrr_stack + 561527;
 target_ptr = Libderiv->deriv2_classes[4][6][30];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+561947, dvrr_stack+72582, dvrr_stack+64431);
 tmp = dvrr_stack + 561947;
 target_ptr = Libderiv->deriv2_classes[4][7][30];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+562487, dvrr_stack+289745, dvrr_stack+8927);
 tmp = dvrr_stack + 562487;
 target_ptr = Libderiv->deriv2_classes[4][8][30];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+563162, dvrr_stack+290690, dvrr_stack+4318);
 tmp = dvrr_stack + 563162;
 target_ptr = Libderiv->deriv2_classes[4][9][30];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+563987, dvrr_stack+293231, dvrr_stack+31153);
 tmp = dvrr_stack + 563987;
 target_ptr = Libderiv->deriv2_classes[5][5][30];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+564428, dvrr_stack+135851, dvrr_stack+58008);
 tmp = dvrr_stack + 564428;
 target_ptr = Libderiv->deriv2_classes[5][6][30];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+565016, dvrr_stack+293819, dvrr_stack+16811);
 tmp = dvrr_stack + 565016;
 target_ptr = Libderiv->deriv2_classes[5][7][30];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+565772, dvrr_stack+294827, dvrr_stack+28727);
 tmp = dvrr_stack + 565772;
 target_ptr = Libderiv->deriv2_classes[5][8][30];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+566717, dvrr_stack+296087, dvrr_stack+288920);
 tmp = dvrr_stack + 566717;
 target_ptr = Libderiv->deriv2_classes[5][9][30];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+567872, dvrr_stack+306703, dvrr_stack+72141);
 tmp = dvrr_stack + 567872;
 target_ptr = Libderiv->deriv2_classes[6][5][30];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+568460, dvrr_stack+220863, dvrr_stack+10637);
 tmp = dvrr_stack + 568460;
 target_ptr = Libderiv->deriv2_classes[6][6][30];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+569244, dvrr_stack+350835, dvrr_stack+72582);
 tmp = dvrr_stack + 569244;
 target_ptr = Libderiv->deriv2_classes[6][7][30];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+570252, dvrr_stack+352131, dvrr_stack+289745);
 tmp = dvrr_stack + 570252;
 target_ptr = Libderiv->deriv2_classes[6][8][30];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+571512, dvrr_stack+353751, dvrr_stack+290690);
 tmp = dvrr_stack + 571512;
 target_ptr = Libderiv->deriv2_classes[6][9][30];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+80895, dvrr_stack+340845, dvrr_stack+340719);
 tmp = dvrr_stack + 80895;
 target_ptr = Libderiv->deriv2_classes[3][5][26];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+573052, dvrr_stack+221871, dvrr_stack+341160);
 tmp = dvrr_stack + 573052;
 target_ptr = Libderiv->deriv2_classes[3][6][26];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+573332, dvrr_stack+336327, dvrr_stack+300231);
 tmp = dvrr_stack + 573332;
 target_ptr = Libderiv->deriv2_classes[3][7][26];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+573692, dvrr_stack+336867, dvrr_stack+355731);
 tmp = dvrr_stack + 573692;
 target_ptr = Libderiv->deriv2_classes[3][8][26];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+574142, dvrr_stack+337872, dvrr_stack+337542);
 tmp = dvrr_stack + 574142;
 target_ptr = Libderiv->deriv2_classes[3][9][26];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+574692, dvrr_stack+201309, dvrr_stack+338697);
 tmp = dvrr_stack + 574692;
 target_ptr = Libderiv->deriv2_classes[4][5][26];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+575007, dvrr_stack+201750, dvrr_stack+338907);
 tmp = dvrr_stack + 575007;
 target_ptr = Libderiv->deriv2_classes[4][6][26];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+575427, dvrr_stack+356001, dvrr_stack+120650);
 tmp = dvrr_stack + 575427;
 target_ptr = Libderiv->deriv2_classes[4][7][26];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+575967, dvrr_stack+356757, dvrr_stack+51332);
 tmp = dvrr_stack + 575967;
 target_ptr = Libderiv->deriv2_classes[4][8][26];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+576642, dvrr_stack+358252, dvrr_stack+357702);
 tmp = dvrr_stack + 576642;
 target_ptr = Libderiv->deriv2_classes[4][9][26];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+577467, dvrr_stack+359407, dvrr_stack+340845);
 tmp = dvrr_stack + 577467;
 target_ptr = Libderiv->deriv2_classes[5][5][26];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+577908, dvrr_stack+359995, dvrr_stack+221871);
 tmp = dvrr_stack + 577908;
 target_ptr = Libderiv->deriv2_classes[5][6][26];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+578496, dvrr_stack+360779, dvrr_stack+336327);
 tmp = dvrr_stack + 578496;
 target_ptr = Libderiv->deriv2_classes[5][7][26];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+579252, dvrr_stack+361787, dvrr_stack+336867);
 tmp = dvrr_stack + 579252;
 target_ptr = Libderiv->deriv2_classes[5][8][26];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+580197, dvrr_stack+363047, dvrr_stack+337872);
 tmp = dvrr_stack + 580197;
 target_ptr = Libderiv->deriv2_classes[5][9][26];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+581352, dvrr_stack+151745, dvrr_stack+201309);
 tmp = dvrr_stack + 581352;
 target_ptr = Libderiv->deriv2_classes[6][5][26];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+581940, dvrr_stack+302565, dvrr_stack+201750);
 tmp = dvrr_stack + 581940;
 target_ptr = Libderiv->deriv2_classes[6][6][26];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+582724, dvrr_stack+26847, dvrr_stack+356001);
 tmp = dvrr_stack + 582724;
 target_ptr = Libderiv->deriv2_classes[6][7][26];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+583732, dvrr_stack+365721, dvrr_stack+356757);
 tmp = dvrr_stack + 583732;
 target_ptr = Libderiv->deriv2_classes[6][8][26];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+584992, dvrr_stack+308389, dvrr_stack+358252);
 tmp = dvrr_stack + 584992;
 target_ptr = Libderiv->deriv2_classes[6][9][26];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,21,dvrr_stack+586532, dvrr_stack+232068, dvrr_stack+68730);
 tmp = dvrr_stack + 586532;
 target_ptr = Libderiv->deriv2_classes[3][5][23];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,28,dvrr_stack+99236, dvrr_stack+5788, dvrr_stack+165301);
 tmp = dvrr_stack + 99236;
 target_ptr = Libderiv->deriv2_classes[3][6][23];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,36,dvrr_stack+586742, dvrr_stack+232383, dvrr_stack+187849);
 tmp = dvrr_stack + 586742;
 target_ptr = Libderiv->deriv2_classes[3][7][23];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,45,dvrr_stack+587102, dvrr_stack+232923, dvrr_stack+2529);
 tmp = dvrr_stack + 587102;
 target_ptr = Libderiv->deriv2_classes[3][8][23];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_f(Data,55,dvrr_stack+587552, dvrr_stack+233598, dvrr_stack+136635);
 tmp = dvrr_stack + 587552;
 target_ptr = Libderiv->deriv2_classes[3][9][23];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,21,dvrr_stack+588102, dvrr_stack+212592, dvrr_stack+228973);
 tmp = dvrr_stack + 588102;
 target_ptr = Libderiv->deriv2_classes[4][5][23];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,28,dvrr_stack+588417, dvrr_stack+212004, dvrr_stack+228693);
 tmp = dvrr_stack + 588417;
 target_ptr = Libderiv->deriv2_classes[4][6][23];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,36,dvrr_stack+588837, dvrr_stack+213033, dvrr_stack+44897);
 tmp = dvrr_stack + 588837;
 target_ptr = Libderiv->deriv2_classes[4][7][23];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,45,dvrr_stack+589377, dvrr_stack+192273, dvrr_stack+229183);
 tmp = dvrr_stack + 589377;
 target_ptr = Libderiv->deriv2_classes[4][8][23];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,55,dvrr_stack+590052, dvrr_stack+193218, dvrr_stack+229633);
 tmp = dvrr_stack + 590052;
 target_ptr = Libderiv->deriv2_classes[4][9][23];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,21,dvrr_stack+590877, dvrr_stack+164713, dvrr_stack+232068);
 tmp = dvrr_stack + 590877;
 target_ptr = Libderiv->deriv2_classes[5][5][23];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,28,dvrr_stack+591318, dvrr_stack+143114, dvrr_stack+5788);
 tmp = dvrr_stack + 591318;
 target_ptr = Libderiv->deriv2_classes[5][6][23];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,36,dvrr_stack+591906, dvrr_stack+143898, dvrr_stack+232383);
 tmp = dvrr_stack + 591906;
 target_ptr = Libderiv->deriv2_classes[5][7][23];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,45,dvrr_stack+592662, dvrr_stack+144906, dvrr_stack+232923);
 tmp = dvrr_stack + 592662;
 target_ptr = Libderiv->deriv2_classes[5][8][23];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,55,dvrr_stack+593607, dvrr_stack+146166, dvrr_stack+233598);
 tmp = dvrr_stack + 593607;
 target_ptr = Libderiv->deriv2_classes[5][9][23];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,21,dvrr_stack+594762, dvrr_stack+307633, dvrr_stack+212592);
 tmp = dvrr_stack + 594762;
 target_ptr = Libderiv->deriv2_classes[6][5][23];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,28,dvrr_stack+595350, dvrr_stack+87730, dvrr_stack+212004);
 tmp = dvrr_stack + 595350;
 target_ptr = Libderiv->deriv2_classes[6][6][23];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,36,dvrr_stack+596134, dvrr_stack+95335, dvrr_stack+213033);
 tmp = dvrr_stack + 596134;
 target_ptr = Libderiv->deriv2_classes[6][7][23];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,45,dvrr_stack+597142, dvrr_stack+105235, dvrr_stack+192273);
 tmp = dvrr_stack + 597142;
 target_ptr = Libderiv->deriv2_classes[6][8][23];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,55,dvrr_stack+598402, dvrr_stack+197565, dvrr_stack+193218);
 tmp = dvrr_stack + 598402;
 target_ptr = Libderiv->deriv2_classes[6][9][23];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+231798, dvrr_stack+93550, dvrr_stack+335091);
 tmp = dvrr_stack + 231798;
 target_ptr = Libderiv->deriv2_classes[3][5][22];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+599942, dvrr_stack+93130, dvrr_stack+335217);
 tmp = dvrr_stack + 599942;
 target_ptr = Libderiv->deriv2_classes[3][6][22];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+600222, dvrr_stack+77826, dvrr_stack+335385);
 tmp = dvrr_stack + 600222;
 target_ptr = Libderiv->deriv2_classes[3][7][22];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+600582, dvrr_stack+78366, dvrr_stack+335601);
 tmp = dvrr_stack + 600582;
 target_ptr = Libderiv->deriv2_classes[3][8][22];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+601032, dvrr_stack+79041, dvrr_stack+335871);
 tmp = dvrr_stack + 601032;
 target_ptr = Libderiv->deriv2_classes[3][9][22];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+601582, dvrr_stack+67869, dvrr_stack+147706);
 tmp = dvrr_stack + 601582;
 target_ptr = Libderiv->deriv2_classes[4][5][22];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+601897, dvrr_stack+67281, dvrr_stack+177997);
 tmp = dvrr_stack + 601897;
 target_ptr = Libderiv->deriv2_classes[4][6][22];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+602317, dvrr_stack+57252, dvrr_stack+147916);
 tmp = dvrr_stack + 602317;
 target_ptr = Libderiv->deriv2_classes[4][7][22];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+602857, dvrr_stack+32467, dvrr_stack+113765);
 tmp = dvrr_stack + 602857;
 target_ptr = Libderiv->deriv2_classes[4][8][22];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+603532, dvrr_stack+33412, dvrr_stack+114215);
 tmp = dvrr_stack + 603532;
 target_ptr = Libderiv->deriv2_classes[4][9][22];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+604357, dvrr_stack+42827, dvrr_stack+93550);
 tmp = dvrr_stack + 604357;
 target_ptr = Libderiv->deriv2_classes[5][5][22];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+604798, dvrr_stack+49172, dvrr_stack+93130);
 tmp = dvrr_stack + 604798;
 target_ptr = Libderiv->deriv2_classes[5][6][22];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+605386, dvrr_stack+24447, dvrr_stack+77826);
 tmp = dvrr_stack + 605386;
 target_ptr = Libderiv->deriv2_classes[5][7][22];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+606142, dvrr_stack+278616, dvrr_stack+78366);
 tmp = dvrr_stack + 606142;
 target_ptr = Libderiv->deriv2_classes[5][8][22];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+607087, dvrr_stack+279876, dvrr_stack+79041);
 tmp = dvrr_stack + 607087;
 target_ptr = Libderiv->deriv2_classes[5][9][22];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+608242, dvrr_stack+199545, dvrr_stack+67869);
 tmp = dvrr_stack + 608242;
 target_ptr = Libderiv->deriv2_classes[6][5][22];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+608830, dvrr_stack+200301, dvrr_stack+67281);
 tmp = dvrr_stack + 608830;
 target_ptr = Libderiv->deriv2_classes[6][6][22];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+609614, dvrr_stack+117734, dvrr_stack+57252);
 tmp = dvrr_stack + 609614;
 target_ptr = Libderiv->deriv2_classes[6][7][22];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+610622, dvrr_stack+119030, dvrr_stack+32467);
 tmp = dvrr_stack + 610622;
 target_ptr = Libderiv->deriv2_classes[6][8][22];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+611882, dvrr_stack+345255, dvrr_stack+33412);
 tmp = dvrr_stack + 611882;
 target_ptr = Libderiv->deriv2_classes[6][9][22];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+613422, dvrr_stack+40307, dvrr_stack+336201);
 tmp = dvrr_stack + 613422;
 target_ptr = Libderiv->deriv2_classes[3][5][21];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+613632, dvrr_stack+231168, dvrr_stack+219879);
 tmp = dvrr_stack + 613632;
 target_ptr = Libderiv->deriv2_classes[3][6][21];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+613912, dvrr_stack+38138, dvrr_stack+220047);
 tmp = dvrr_stack + 613912;
 target_ptr = Libderiv->deriv2_classes[3][7][21];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+614272, dvrr_stack+45932, dvrr_stack+220263);
 tmp = dvrr_stack + 614272;
 target_ptr = Libderiv->deriv2_classes[3][8][21];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+614722, dvrr_stack+53202, dvrr_stack+220533);
 tmp = dvrr_stack + 614722;
 target_ptr = Libderiv->deriv2_classes[3][9][21];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+615272, dvrr_stack+89602, dvrr_stack+4108);
 tmp = dvrr_stack + 615272;
 target_ptr = Libderiv->deriv2_classes[4][5][21];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+615587, dvrr_stack+235878, dvrr_stack+228093);
 tmp = dvrr_stack + 615587;
 target_ptr = Libderiv->deriv2_classes[4][6][21];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+616007, dvrr_stack+86407, dvrr_stack+2169);
 tmp = dvrr_stack + 616007;
 target_ptr = Libderiv->deriv2_classes[4][7][21];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+616547, dvrr_stack+46607, dvrr_stack+8477);
 tmp = dvrr_stack + 616547;
 target_ptr = Libderiv->deriv2_classes[4][8][21];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+617222, dvrr_stack+108095, dvrr_stack+14111);
 tmp = dvrr_stack + 617222;
 target_ptr = Libderiv->deriv2_classes[4][9][21];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+618047, dvrr_stack+159589, dvrr_stack+40307);
 tmp = dvrr_stack + 618047;
 target_ptr = Libderiv->deriv2_classes[5][5][21];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+618488, dvrr_stack+102211, dvrr_stack+231168);
 tmp = dvrr_stack + 618488;
 target_ptr = Libderiv->deriv2_classes[5][6][21];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+619076, dvrr_stack+155161, dvrr_stack+38138);
 tmp = dvrr_stack + 619076;
 target_ptr = Libderiv->deriv2_classes[5][7][21];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+619832, dvrr_stack+170563, dvrr_stack+45932);
 tmp = dvrr_stack + 619832;
 target_ptr = Libderiv->deriv2_classes[5][8][21];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+620777, dvrr_stack+184713, dvrr_stack+53202);
 tmp = dvrr_stack + 620777;
 target_ptr = Libderiv->deriv2_classes[5][9][21];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+621932, dvrr_stack+299475, dvrr_stack+89602);
 tmp = dvrr_stack + 621932;
 target_ptr = Libderiv->deriv2_classes[6][5][21];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+622520, dvrr_stack+305365, dvrr_stack+235878);
 tmp = dvrr_stack + 622520;
 target_ptr = Libderiv->deriv2_classes[6][6][21];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+623304, dvrr_stack+311989, dvrr_stack+86407);
 tmp = dvrr_stack + 623304;
 target_ptr = Libderiv->deriv2_classes[6][7][21];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+624312, dvrr_stack+319963, dvrr_stack+46607);
 tmp = dvrr_stack + 624312;
 target_ptr = Libderiv->deriv2_classes[6][8][21];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+625572, dvrr_stack+330231, dvrr_stack+108095);
 tmp = dvrr_stack + 625572;
 target_ptr = Libderiv->deriv2_classes[6][9][21];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+627112, dvrr_stack+225855, dvrr_stack+339315);
 tmp = dvrr_stack + 627112;
 target_ptr = Libderiv->deriv2_classes[3][5][20];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+627322, dvrr_stack+225435, dvrr_stack+339441);
 tmp = dvrr_stack + 627322;
 target_ptr = Libderiv->deriv2_classes[3][6][20];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+627602, dvrr_stack+226170, dvrr_stack+339609);
 tmp = dvrr_stack + 627602;
 target_ptr = Libderiv->deriv2_classes[3][7][20];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+627962, dvrr_stack+226710, dvrr_stack+339825);
 tmp = dvrr_stack + 627962;
 target_ptr = Libderiv->deriv2_classes[3][8][20];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+628412, dvrr_stack+204297, dvrr_stack+340095);
 tmp = dvrr_stack + 628412;
 target_ptr = Libderiv->deriv2_classes[3][9][20];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+628962, dvrr_stack+186253, dvrr_stack+222770);
 tmp = dvrr_stack + 628962;
 target_ptr = Libderiv->deriv2_classes[4][5][20];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+629277, dvrr_stack+206427, dvrr_stack+222490);
 tmp = dvrr_stack + 629277;
 target_ptr = Libderiv->deriv2_classes[4][6][20];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+629697, dvrr_stack+156169, dvrr_stack+222980);
 tmp = dvrr_stack + 629697;
 target_ptr = Libderiv->deriv2_classes[4][7][20];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+630237, dvrr_stack+40622, dvrr_stack+223340);
 tmp = dvrr_stack + 630237;
 target_ptr = Libderiv->deriv2_classes[4][8][20];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+630912, dvrr_stack+186694, dvrr_stack+223790);
 tmp = dvrr_stack + 630912;
 target_ptr = Libderiv->deriv2_classes[4][9][20];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+631737, dvrr_stack+137612, dvrr_stack+225855);
 tmp = dvrr_stack + 631737;
 target_ptr = Libderiv->deriv2_classes[5][5][20];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+632178, dvrr_stack+160597, dvrr_stack+225435);
 tmp = dvrr_stack + 632178;
 target_ptr = Libderiv->deriv2_classes[5][6][20];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+632766, dvrr_stack+138200, dvrr_stack+226170);
 tmp = dvrr_stack + 632766;
 target_ptr = Libderiv->deriv2_classes[5][7][20];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+633522, dvrr_stack+139208, dvrr_stack+226710);
 tmp = dvrr_stack + 633522;
 target_ptr = Libderiv->deriv2_classes[5][8][20];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+634467, dvrr_stack+122552, dvrr_stack+204297);
 tmp = dvrr_stack + 634467;
 target_ptr = Libderiv->deriv2_classes[5][9][20];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+635622, dvrr_stack+341371, dvrr_stack+186253);
 tmp = dvrr_stack + 635622;
 target_ptr = Libderiv->deriv2_classes[6][5][20];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+636210, dvrr_stack+342127, dvrr_stack+206427);
 tmp = dvrr_stack + 636210;
 target_ptr = Libderiv->deriv2_classes[6][6][20];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+636994, dvrr_stack+343135, dvrr_stack+156169);
 tmp = dvrr_stack + 636994;
 target_ptr = Libderiv->deriv2_classes[6][7][20];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+638002, dvrr_stack+332211, dvrr_stack+40622);
 tmp = dvrr_stack + 638002;
 target_ptr = Libderiv->deriv2_classes[6][8][20];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+639262, dvrr_stack+321583, dvrr_stack+186694);
 tmp = dvrr_stack + 639262;
 target_ptr = Libderiv->deriv2_classes[6][9][20];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+122334, dvrr_stack+124092, dvrr_stack+340425);
 tmp = dvrr_stack + 122334;
 target_ptr = Libderiv->deriv2_classes[3][5][19];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+640802, dvrr_stack+99523, dvrr_stack+340551);
 tmp = dvrr_stack + 640802;
 target_ptr = Libderiv->deriv2_classes[3][6][19];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+641082, dvrr_stack+109910, dvrr_stack+235413);
 tmp = dvrr_stack + 641082;
 target_ptr = Libderiv->deriv2_classes[3][7][19];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+641442, dvrr_stack+90043, dvrr_stack+213789);
 tmp = dvrr_stack + 641442;
 target_ptr = Libderiv->deriv2_classes[3][8][19];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+641892, dvrr_stack+73848, dvrr_stack+214059);
 tmp = dvrr_stack + 641892;
 target_ptr = Libderiv->deriv2_classes[3][9][19];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+642442, dvrr_stack+87163, dvrr_stack+173209);
 tmp = dvrr_stack + 642442;
 target_ptr = Libderiv->deriv2_classes[4][5][19];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+642757, dvrr_stack+90718, dvrr_stack+188129);
 tmp = dvrr_stack + 642757;
 target_ptr = Libderiv->deriv2_classes[4][6][19];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+643177, dvrr_stack+75663, dvrr_stack+161381);
 tmp = dvrr_stack + 643177;
 target_ptr = Libderiv->deriv2_classes[4][7][19];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+643717, dvrr_stack+62331, dvrr_stack+102995);
 tmp = dvrr_stack + 643717;
 target_ptr = Libderiv->deriv2_classes[4][8][19];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+644392, dvrr_stack+63276, dvrr_stack+140468);
 tmp = dvrr_stack + 644392;
 target_ptr = Libderiv->deriv2_classes[4][9][19];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+645217, dvrr_stack+54447, dvrr_stack+124092);
 tmp = dvrr_stack + 645217;
 target_ptr = Libderiv->deriv2_classes[5][5][19];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+645658, dvrr_stack+14661, dvrr_stack+99523);
 tmp = dvrr_stack + 645658;
 target_ptr = Libderiv->deriv2_classes[5][6][19];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+646246, dvrr_stack+283264, dvrr_stack+109910);
 tmp = dvrr_stack + 646246;
 target_ptr = Libderiv->deriv2_classes[5][7][19];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+647002, dvrr_stack+284272, dvrr_stack+90043);
 tmp = dvrr_stack + 647002;
 target_ptr = Libderiv->deriv2_classes[5][8][19];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+647947, dvrr_stack+285532, dvrr_stack+73848);
 tmp = dvrr_stack + 647947;
 target_ptr = Libderiv->deriv2_classes[5][9][19];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+649102, dvrr_stack+344431, dvrr_stack+87163);
 tmp = dvrr_stack + 649102;
 target_ptr = Libderiv->deriv2_classes[6][5][19];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+649690, dvrr_stack+333831, dvrr_stack+90718);
 tmp = dvrr_stack + 649690;
 target_ptr = Libderiv->deriv2_classes[6][6][19];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+650474, dvrr_stack+313285, dvrr_stack+75663);
 tmp = dvrr_stack + 650474;
 target_ptr = Libderiv->deriv2_classes[6][7][19];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+651482, dvrr_stack+347235, dvrr_stack+62331);
 tmp = dvrr_stack + 651482;
 target_ptr = Libderiv->deriv2_classes[6][8][19];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+652742, dvrr_stack+348855, dvrr_stack+63276);
 tmp = dvrr_stack + 652742;
 target_ptr = Libderiv->deriv2_classes[6][9][19];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+654282, dvrr_stack+31153, dvrr_stack+235629);
 tmp = dvrr_stack + 654282;
 target_ptr = Libderiv->deriv2_classes[3][5][18];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+654492, dvrr_stack+58008, dvrr_stack+334839);
 tmp = dvrr_stack + 654492;
 target_ptr = Libderiv->deriv2_classes[3][6][18];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+654772, dvrr_stack+16811, dvrr_stack+323563);
 tmp = dvrr_stack + 654772;
 target_ptr = Libderiv->deriv2_classes[3][7][18];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+655132, dvrr_stack+28727, dvrr_stack+314581);
 tmp = dvrr_stack + 655132;
 target_ptr = Libderiv->deriv2_classes[3][8][18];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+655582, dvrr_stack+288920, dvrr_stack+306373);
 tmp = dvrr_stack + 655582;
 target_ptr = Libderiv->deriv2_classes[3][9][18];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+656132, dvrr_stack+72141, dvrr_stack+124407);
 tmp = dvrr_stack + 656132;
 target_ptr = Libderiv->deriv2_classes[4][5][18];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+656447, dvrr_stack+10637, dvrr_stack+236466);
 tmp = dvrr_stack + 656447;
 target_ptr = Libderiv->deriv2_classes[4][6][18];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+656867, dvrr_stack+72582, dvrr_stack+64431);
 tmp = dvrr_stack + 656867;
 target_ptr = Libderiv->deriv2_classes[4][7][18];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+657407, dvrr_stack+289745, dvrr_stack+8927);
 tmp = dvrr_stack + 657407;
 target_ptr = Libderiv->deriv2_classes[4][8][18];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+658082, dvrr_stack+290690, dvrr_stack+4318);
 tmp = dvrr_stack + 658082;
 target_ptr = Libderiv->deriv2_classes[4][9][18];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+658907, dvrr_stack+293231, dvrr_stack+31153);
 tmp = dvrr_stack + 658907;
 target_ptr = Libderiv->deriv2_classes[5][5][18];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+659348, dvrr_stack+135851, dvrr_stack+58008);
 tmp = dvrr_stack + 659348;
 target_ptr = Libderiv->deriv2_classes[5][6][18];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+659936, dvrr_stack+293819, dvrr_stack+16811);
 tmp = dvrr_stack + 659936;
 target_ptr = Libderiv->deriv2_classes[5][7][18];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+660692, dvrr_stack+294827, dvrr_stack+28727);
 tmp = dvrr_stack + 660692;
 target_ptr = Libderiv->deriv2_classes[5][8][18];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+661637, dvrr_stack+296087, dvrr_stack+288920);
 tmp = dvrr_stack + 661637;
 target_ptr = Libderiv->deriv2_classes[5][9][18];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+662792, dvrr_stack+306703, dvrr_stack+72141);
 tmp = dvrr_stack + 662792;
 target_ptr = Libderiv->deriv2_classes[6][5][18];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+663380, dvrr_stack+220863, dvrr_stack+10637);
 tmp = dvrr_stack + 663380;
 target_ptr = Libderiv->deriv2_classes[6][6][18];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+664164, dvrr_stack+350835, dvrr_stack+72582);
 tmp = dvrr_stack + 664164;
 target_ptr = Libderiv->deriv2_classes[6][7][18];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+665172, dvrr_stack+352131, dvrr_stack+289745);
 tmp = dvrr_stack + 665172;
 target_ptr = Libderiv->deriv2_classes[6][8][18];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+666432, dvrr_stack+353751, dvrr_stack+290690);
 tmp = dvrr_stack + 666432;
 target_ptr = Libderiv->deriv2_classes[6][9][18];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+107863, dvrr_stack+340845, dvrr_stack+340719);
 tmp = dvrr_stack + 107863;
 target_ptr = Libderiv->deriv2_classes[3][5][14];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+667972, dvrr_stack+221871, dvrr_stack+341160);
 tmp = dvrr_stack + 667972;
 target_ptr = Libderiv->deriv2_classes[3][6][14];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+668252, dvrr_stack+336327, dvrr_stack+300231);
 tmp = dvrr_stack + 668252;
 target_ptr = Libderiv->deriv2_classes[3][7][14];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+668612, dvrr_stack+336867, dvrr_stack+355731);
 tmp = dvrr_stack + 668612;
 target_ptr = Libderiv->deriv2_classes[3][8][14];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+669062, dvrr_stack+337872, dvrr_stack+337542);
 tmp = dvrr_stack + 669062;
 target_ptr = Libderiv->deriv2_classes[3][9][14];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+669612, dvrr_stack+201309, dvrr_stack+338697);
 tmp = dvrr_stack + 669612;
 target_ptr = Libderiv->deriv2_classes[4][5][14];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+669927, dvrr_stack+201750, dvrr_stack+338907);
 tmp = dvrr_stack + 669927;
 target_ptr = Libderiv->deriv2_classes[4][6][14];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+670347, dvrr_stack+356001, dvrr_stack+120650);
 tmp = dvrr_stack + 670347;
 target_ptr = Libderiv->deriv2_classes[4][7][14];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+670887, dvrr_stack+356757, dvrr_stack+51332);
 tmp = dvrr_stack + 670887;
 target_ptr = Libderiv->deriv2_classes[4][8][14];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+671562, dvrr_stack+358252, dvrr_stack+357702);
 tmp = dvrr_stack + 671562;
 target_ptr = Libderiv->deriv2_classes[4][9][14];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+672387, dvrr_stack+359407, dvrr_stack+340845);
 tmp = dvrr_stack + 672387;
 target_ptr = Libderiv->deriv2_classes[5][5][14];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+672828, dvrr_stack+359995, dvrr_stack+221871);
 tmp = dvrr_stack + 672828;
 target_ptr = Libderiv->deriv2_classes[5][6][14];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+673416, dvrr_stack+360779, dvrr_stack+336327);
 tmp = dvrr_stack + 673416;
 target_ptr = Libderiv->deriv2_classes[5][7][14];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+674172, dvrr_stack+361787, dvrr_stack+336867);
 tmp = dvrr_stack + 674172;
 target_ptr = Libderiv->deriv2_classes[5][8][14];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+675117, dvrr_stack+363047, dvrr_stack+337872);
 tmp = dvrr_stack + 675117;
 target_ptr = Libderiv->deriv2_classes[5][9][14];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+676272, dvrr_stack+151745, dvrr_stack+201309);
 tmp = dvrr_stack + 676272;
 target_ptr = Libderiv->deriv2_classes[6][5][14];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+676860, dvrr_stack+302565, dvrr_stack+201750);
 tmp = dvrr_stack + 676860;
 target_ptr = Libderiv->deriv2_classes[6][6][14];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+677644, dvrr_stack+26847, dvrr_stack+356001);
 tmp = dvrr_stack + 677644;
 target_ptr = Libderiv->deriv2_classes[6][7][14];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+678652, dvrr_stack+365721, dvrr_stack+356757);
 tmp = dvrr_stack + 678652;
 target_ptr = Libderiv->deriv2_classes[6][8][14];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+679912, dvrr_stack+308389, dvrr_stack+358252);
 tmp = dvrr_stack + 679912;
 target_ptr = Libderiv->deriv2_classes[6][9][14];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+681452, dvrr_stack+310369, dvrr_stack+87604);
 tmp = dvrr_stack + 681452;
 target_ptr = Libderiv->deriv2_classes[3][5][13];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+681662, dvrr_stack+317326, dvrr_stack+1137);
 tmp = dvrr_stack + 681662;
 target_ptr = Libderiv->deriv2_classes[3][6][13];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+681942, dvrr_stack+317746, dvrr_stack+2799);
 tmp = dvrr_stack + 681942;
 target_ptr = Libderiv->deriv2_classes[3][7][13];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+682302, dvrr_stack+180643, dvrr_stack+6838);
 tmp = dvrr_stack + 682302;
 target_ptr = Libderiv->deriv2_classes[3][8][13];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+682752, dvrr_stack+181318, dvrr_stack+12077);
 tmp = dvrr_stack + 682752;
 target_ptr = Libderiv->deriv2_classes[3][9][13];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+683302, dvrr_stack+182143, dvrr_stack+225000);
 tmp = dvrr_stack + 683302;
 target_ptr = Libderiv->deriv2_classes[4][5][13];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+683617, dvrr_stack+300447, dvrr_stack+182584);
 tmp = dvrr_stack + 683617;
 target_ptr = Libderiv->deriv2_classes[4][6][13];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+684037, dvrr_stack+303573, dvrr_stack+301035);
 tmp = dvrr_stack + 684037;
 target_ptr = Libderiv->deriv2_classes[4][7][13];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+684577, dvrr_stack+367341, dvrr_stack+28143);
 tmp = dvrr_stack + 684577;
 target_ptr = Libderiv->deriv2_classes[4][8][13];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+685252, dvrr_stack+368836, dvrr_stack+368286);
 tmp = dvrr_stack + 685252;
 target_ptr = Libderiv->deriv2_classes[4][9][13];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+686077, dvrr_stack+369991, dvrr_stack+310369);
 tmp = dvrr_stack + 686077;
 target_ptr = Libderiv->deriv2_classes[5][5][13];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+686518, dvrr_stack+323779, dvrr_stack+317326);
 tmp = dvrr_stack + 686518;
 target_ptr = Libderiv->deriv2_classes[5][6][13];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+687106, dvrr_stack+324563, dvrr_stack+317746);
 tmp = dvrr_stack + 687106;
 target_ptr = Libderiv->deriv2_classes[5][7][13];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+687862, dvrr_stack+325571, dvrr_stack+180643);
 tmp = dvrr_stack + 687862;
 target_ptr = Libderiv->deriv2_classes[5][8][13];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+688807, dvrr_stack+18701, dvrr_stack+181318);
 tmp = dvrr_stack + 688807;
 target_ptr = Libderiv->deriv2_classes[5][9][13];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+689962, dvrr_stack+326831, dvrr_stack+182143);
 tmp = dvrr_stack + 689962;
 target_ptr = Libderiv->deriv2_classes[6][5][13];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+690550, dvrr_stack+370579, dvrr_stack+300447);
 tmp = dvrr_stack + 690550;
 target_ptr = Libderiv->deriv2_classes[6][6][13];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+691334, dvrr_stack+371587, dvrr_stack+303573);
 tmp = dvrr_stack + 691334;
 target_ptr = Libderiv->deriv2_classes[6][7][13];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+692342, dvrr_stack+372883, dvrr_stack+367341);
 tmp = dvrr_stack + 692342;
 target_ptr = Libderiv->deriv2_classes[6][8][13];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+693602, dvrr_stack+374503, dvrr_stack+368836);
 tmp = dvrr_stack + 693602;
 target_ptr = Libderiv->deriv2_classes[6][9][13];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,21,dvrr_stack+695142, dvrr_stack+232068, dvrr_stack+68730);
 tmp = dvrr_stack + 695142;
 target_ptr = Libderiv->deriv2_classes[3][5][11];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,28,dvrr_stack+695352, dvrr_stack+5788, dvrr_stack+165301);
 tmp = dvrr_stack + 695352;
 target_ptr = Libderiv->deriv2_classes[3][6][11];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,36,dvrr_stack+695632, dvrr_stack+232383, dvrr_stack+187849);
 tmp = dvrr_stack + 695632;
 target_ptr = Libderiv->deriv2_classes[3][7][11];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,45,dvrr_stack+695992, dvrr_stack+232923, dvrr_stack+2529);
 tmp = dvrr_stack + 695992;
 target_ptr = Libderiv->deriv2_classes[3][8][11];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_f(Data,55,dvrr_stack+696442, dvrr_stack+233598, dvrr_stack+136635);
 tmp = dvrr_stack + 696442;
 target_ptr = Libderiv->deriv2_classes[3][9][11];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,21,dvrr_stack+136635, dvrr_stack+212592, dvrr_stack+228973);
 tmp = dvrr_stack + 136635;
 target_ptr = Libderiv->deriv2_classes[4][5][11];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,28,dvrr_stack+696992, dvrr_stack+212004, dvrr_stack+228693);
 tmp = dvrr_stack + 696992;
 target_ptr = Libderiv->deriv2_classes[4][6][11];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,36,dvrr_stack+697412, dvrr_stack+213033, dvrr_stack+44897);
 tmp = dvrr_stack + 697412;
 target_ptr = Libderiv->deriv2_classes[4][7][11];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,45,dvrr_stack+697952, dvrr_stack+192273, dvrr_stack+229183);
 tmp = dvrr_stack + 697952;
 target_ptr = Libderiv->deriv2_classes[4][8][11];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,55,dvrr_stack+228688, dvrr_stack+193218, dvrr_stack+229633);
 tmp = dvrr_stack + 228688;
 target_ptr = Libderiv->deriv2_classes[4][9][11];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,21,dvrr_stack+229513, dvrr_stack+164713, dvrr_stack+232068);
 tmp = dvrr_stack + 229513;
 target_ptr = Libderiv->deriv2_classes[5][5][11];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,28,dvrr_stack+164701, dvrr_stack+143114, dvrr_stack+5788);
 tmp = dvrr_stack + 164701;
 target_ptr = Libderiv->deriv2_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,36,dvrr_stack+143098, dvrr_stack+143898, dvrr_stack+232383);
 tmp = dvrr_stack + 143098;
 target_ptr = Libderiv->deriv2_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,45,dvrr_stack+143854, dvrr_stack+144906, dvrr_stack+232923);
 tmp = dvrr_stack + 143854;
 target_ptr = Libderiv->deriv2_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,55,dvrr_stack+232008, dvrr_stack+146166, dvrr_stack+233598);
 tmp = dvrr_stack + 232008;
 target_ptr = Libderiv->deriv2_classes[5][9][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,21,dvrr_stack+233163, dvrr_stack+307633, dvrr_stack+212592);
 tmp = dvrr_stack + 233163;
 target_ptr = Libderiv->deriv2_classes[6][5][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,28,dvrr_stack+307459, dvrr_stack+87730, dvrr_stack+212004);
 tmp = dvrr_stack + 307459;
 target_ptr = Libderiv->deriv2_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,36,dvrr_stack+87730, dvrr_stack+95335, dvrr_stack+213033);
 tmp = dvrr_stack + 87730;
 target_ptr = Libderiv->deriv2_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,45,dvrr_stack+211968, dvrr_stack+105235, dvrr_stack+192273);
 tmp = dvrr_stack + 211968;
 target_ptr = Libderiv->deriv2_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,55,dvrr_stack+104960, dvrr_stack+197565, dvrr_stack+193218);
 tmp = dvrr_stack + 104960;
 target_ptr = Libderiv->deriv2_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+2529, dvrr_stack+93550, dvrr_stack+335091);
 tmp = dvrr_stack + 2529;
 target_ptr = Libderiv->deriv2_classes[3][5][10];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+187849, dvrr_stack+93130, dvrr_stack+335217);
 tmp = dvrr_stack + 187849;
 target_ptr = Libderiv->deriv2_classes[3][6][10];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+44822, dvrr_stack+77826, dvrr_stack+335385);
 tmp = dvrr_stack + 44822;
 target_ptr = Libderiv->deriv2_classes[3][7][10];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+335007, dvrr_stack+78366, dvrr_stack+335601);
 tmp = dvrr_stack + 335007;
 target_ptr = Libderiv->deriv2_classes[3][8][10];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+192224, dvrr_stack+79041, dvrr_stack+335871);
 tmp = dvrr_stack + 192224;
 target_ptr = Libderiv->deriv2_classes[3][9][10];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+698627, dvrr_stack+67869, dvrr_stack+147706);
 tmp = dvrr_stack + 698627;
 target_ptr = Libderiv->deriv2_classes[4][5][10];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+335457, dvrr_stack+67281, dvrr_stack+177997);
 tmp = dvrr_stack + 335457;
 target_ptr = Libderiv->deriv2_classes[4][6][10];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+192774, dvrr_stack+57252, dvrr_stack+147916);
 tmp = dvrr_stack + 192774;
 target_ptr = Libderiv->deriv2_classes[4][7][10];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+193314, dvrr_stack+32467, dvrr_stack+113765);
 tmp = dvrr_stack + 193314;
 target_ptr = Libderiv->deriv2_classes[4][8][10];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+197484, dvrr_stack+33412, dvrr_stack+114215);
 tmp = dvrr_stack + 197484;
 target_ptr = Libderiv->deriv2_classes[4][9][10];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+113715, dvrr_stack+42827, dvrr_stack+93550);
 tmp = dvrr_stack + 113715;
 target_ptr = Libderiv->deriv2_classes[5][5][10];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+42758, dvrr_stack+49172, dvrr_stack+93130);
 tmp = dvrr_stack + 42758;
 target_ptr = Libderiv->deriv2_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+49052, dvrr_stack+24447, dvrr_stack+77826);
 tmp = dvrr_stack + 49052;
 target_ptr = Libderiv->deriv2_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+24400, dvrr_stack+278616, dvrr_stack+78366);
 tmp = dvrr_stack + 24400;
 target_ptr = Libderiv->deriv2_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+198309, dvrr_stack+279876, dvrr_stack+79041);
 tmp = dvrr_stack + 198309;
 target_ptr = Libderiv->deriv2_classes[5][9][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+114156, dvrr_stack+199545, dvrr_stack+67869);
 tmp = dvrr_stack + 114156;
 target_ptr = Libderiv->deriv2_classes[6][5][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+93017, dvrr_stack+200301, dvrr_stack+67281);
 tmp = dvrr_stack + 93017;
 target_ptr = Libderiv->deriv2_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+199464, dvrr_stack+117734, dvrr_stack+57252);
 tmp = dvrr_stack + 199464;
 target_ptr = Libderiv->deriv2_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+144799, dvrr_stack+119030, dvrr_stack+32467);
 tmp = dvrr_stack + 144799;
 target_ptr = Libderiv->deriv2_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+146059, dvrr_stack+345255, dvrr_stack+33412);
 tmp = dvrr_stack + 146059;
 target_ptr = Libderiv->deriv2_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+335877, dvrr_stack+40307, dvrr_stack+336201);
 tmp = dvrr_stack + 335877;
 target_ptr = Libderiv->deriv2_classes[3][5][9];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+193989, dvrr_stack+231168, dvrr_stack+219879);
 tmp = dvrr_stack + 193989;
 target_ptr = Libderiv->deriv2_classes[3][6][9];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+233751, dvrr_stack+38138, dvrr_stack+220047);
 tmp = dvrr_stack + 233751;
 target_ptr = Libderiv->deriv2_classes[3][7][9];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+200472, dvrr_stack+45932, dvrr_stack+220263);
 tmp = dvrr_stack + 200472;
 target_ptr = Libderiv->deriv2_classes[3][8][9];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+219836, dvrr_stack+53202, dvrr_stack+220533);
 tmp = dvrr_stack + 219836;
 target_ptr = Libderiv->deriv2_classes[3][9][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+220386, dvrr_stack+89602, dvrr_stack+4108);
 tmp = dvrr_stack + 220386;
 target_ptr = Libderiv->deriv2_classes[4][5][9];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+345187, dvrr_stack+235878, dvrr_stack+228093);
 tmp = dvrr_stack + 345187;
 target_ptr = Libderiv->deriv2_classes[4][6][9];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+345607, dvrr_stack+86407, dvrr_stack+2169);
 tmp = dvrr_stack + 345607;
 target_ptr = Libderiv->deriv2_classes[4][7][9];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+346147, dvrr_stack+46607, dvrr_stack+8477);
 tmp = dvrr_stack + 346147;
 target_ptr = Libderiv->deriv2_classes[4][8][9];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+278549, dvrr_stack+108095, dvrr_stack+14111);
 tmp = dvrr_stack + 278549;
 target_ptr = Libderiv->deriv2_classes[4][9][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+14051, dvrr_stack+159589, dvrr_stack+40307);
 tmp = dvrr_stack + 14051;
 target_ptr = Libderiv->deriv2_classes[5][5][9];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+159580, dvrr_stack+102211, dvrr_stack+231168);
 tmp = dvrr_stack + 159580;
 target_ptr = Libderiv->deriv2_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+102043, dvrr_stack+155161, dvrr_stack+38138);
 tmp = dvrr_stack + 102043;
 target_ptr = Libderiv->deriv2_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+155063, dvrr_stack+170563, dvrr_stack+45932);
 tmp = dvrr_stack + 155063;
 target_ptr = Libderiv->deriv2_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+170453, dvrr_stack+184713, dvrr_stack+53202);
 tmp = dvrr_stack + 170453;
 target_ptr = Libderiv->deriv2_classes[5][9][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+45807, dvrr_stack+299475, dvrr_stack+89602);
 tmp = dvrr_stack + 45807;
 target_ptr = Libderiv->deriv2_classes[6][5][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+184649, dvrr_stack+305365, dvrr_stack+235878);
 tmp = dvrr_stack + 184649;
 target_ptr = Libderiv->deriv2_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+305337, dvrr_stack+311989, dvrr_stack+86407);
 tmp = dvrr_stack + 305337;
 target_ptr = Libderiv->deriv2_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+311944, dvrr_stack+319963, dvrr_stack+46607);
 tmp = dvrr_stack + 311944;
 target_ptr = Libderiv->deriv2_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+319826, dvrr_stack+330231, dvrr_stack+108095);
 tmp = dvrr_stack + 319826;
 target_ptr = Libderiv->deriv2_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+4108, dvrr_stack+225855, dvrr_stack+339315);
 tmp = dvrr_stack + 4108;
 target_ptr = Libderiv->deriv2_classes[3][5][8];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+299452, dvrr_stack+225435, dvrr_stack+339441);
 tmp = dvrr_stack + 299452;
 target_ptr = Libderiv->deriv2_classes[3][6][8];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+299732, dvrr_stack+226170, dvrr_stack+339609);
 tmp = dvrr_stack + 299732;
 target_ptr = Libderiv->deriv2_classes[3][7][8];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+231086, dvrr_stack+226710, dvrr_stack+339825);
 tmp = dvrr_stack + 231086;
 target_ptr = Libderiv->deriv2_classes[3][8][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+46395, dvrr_stack+204297, dvrr_stack+340095);
 tmp = dvrr_stack + 46395;
 target_ptr = Libderiv->deriv2_classes[3][9][8];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+46945, dvrr_stack+186253, dvrr_stack+222770);
 tmp = dvrr_stack + 46945;
 target_ptr = Libderiv->deriv2_classes[4][5][8];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+8357, dvrr_stack+206427, dvrr_stack+222490);
 tmp = dvrr_stack + 8357;
 target_ptr = Libderiv->deriv2_classes[4][6][8];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+185433, dvrr_stack+156169, dvrr_stack+222980);
 tmp = dvrr_stack + 185433;
 target_ptr = Libderiv->deriv2_classes[4][7][8];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+86382, dvrr_stack+40622, dvrr_stack+223340);
 tmp = dvrr_stack + 86382;
 target_ptr = Libderiv->deriv2_classes[4][8][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+53168, dvrr_stack+186694, dvrr_stack+223790);
 tmp = dvrr_stack + 53168;
 target_ptr = Libderiv->deriv2_classes[4][9][8];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+89494, dvrr_stack+137612, dvrr_stack+225855);
 tmp = dvrr_stack + 89494;
 target_ptr = Libderiv->deriv2_classes[5][5][8];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+37957, dvrr_stack+160597, dvrr_stack+225435);
 tmp = dvrr_stack + 37957;
 target_ptr = Libderiv->deriv2_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+160597, dvrr_stack+138200, dvrr_stack+226170);
 tmp = dvrr_stack + 160597;
 target_ptr = Libderiv->deriv2_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+225420, dvrr_stack+139208, dvrr_stack+226710);
 tmp = dvrr_stack + 225420;
 target_ptr = Libderiv->deriv2_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+330201, dvrr_stack+122552, dvrr_stack+204297);
 tmp = dvrr_stack + 330201;
 target_ptr = Libderiv->deriv2_classes[5][9][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+226365, dvrr_stack+341371, dvrr_stack+186253);
 tmp = dvrr_stack + 226365;
 target_ptr = Libderiv->deriv2_classes[6][5][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+341328, dvrr_stack+342127, dvrr_stack+206427);
 tmp = dvrr_stack + 341328;
 target_ptr = Libderiv->deriv2_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+342112, dvrr_stack+343135, dvrr_stack+156169);
 tmp = dvrr_stack + 342112;
 target_ptr = Libderiv->deriv2_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+343120, dvrr_stack+332211, dvrr_stack+40622);
 tmp = dvrr_stack + 343120;
 target_ptr = Libderiv->deriv2_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+331356, dvrr_stack+321583, dvrr_stack+186694);
 tmp = dvrr_stack + 331356;
 target_ptr = Libderiv->deriv2_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+206361, dvrr_stack+124092, dvrr_stack+340425);
 tmp = dvrr_stack + 206361;
 target_ptr = Libderiv->deriv2_classes[3][5][7];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+206571, dvrr_stack+99523, dvrr_stack+340551);
 tmp = dvrr_stack + 206571;
 target_ptr = Libderiv->deriv2_classes[3][6][7];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+226953, dvrr_stack+109910, dvrr_stack+235413);
 tmp = dvrr_stack + 226953;
 target_ptr = Libderiv->deriv2_classes[3][7][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+156008, dvrr_stack+90043, dvrr_stack+213789);
 tmp = dvrr_stack + 156008;
 target_ptr = Libderiv->deriv2_classes[3][8][7];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+321366, dvrr_stack+73848, dvrr_stack+214059);
 tmp = dvrr_stack + 321366;
 target_ptr = Libderiv->deriv2_classes[3][9][7];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+156458, dvrr_stack+87163, dvrr_stack+173209);
 tmp = dvrr_stack + 156458;
 target_ptr = Libderiv->deriv2_classes[4][5][7];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+2105, dvrr_stack+90718, dvrr_stack+188129);
 tmp = dvrr_stack + 2105;
 target_ptr = Libderiv->deriv2_classes[4][6][7];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+321916, dvrr_stack+75663, dvrr_stack+161381);
 tmp = dvrr_stack + 321916;
 target_ptr = Libderiv->deriv2_classes[4][7][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+322456, dvrr_stack+62331, dvrr_stack+102995);
 tmp = dvrr_stack + 322456;
 target_ptr = Libderiv->deriv2_classes[4][8][7];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+185973, dvrr_stack+63276, dvrr_stack+140468);
 tmp = dvrr_stack + 185973;
 target_ptr = Libderiv->deriv2_classes[4][9][7];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+102799, dvrr_stack+54447, dvrr_stack+124092);
 tmp = dvrr_stack + 102799;
 target_ptr = Libderiv->deriv2_classes[5][5][7];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+54447, dvrr_stack+14661, dvrr_stack+99523);
 tmp = dvrr_stack + 54447;
 target_ptr = Libderiv->deriv2_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+14492, dvrr_stack+283264, dvrr_stack+109910);
 tmp = dvrr_stack + 14492;
 target_ptr = Libderiv->deriv2_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+283256, dvrr_stack+284272, dvrr_stack+90043);
 tmp = dvrr_stack + 283256;
 target_ptr = Libderiv->deriv2_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+284201, dvrr_stack+285532, dvrr_stack+73848);
 tmp = dvrr_stack + 284201;
 target_ptr = Libderiv->deriv2_classes[5][9][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+109845, dvrr_stack+344431, dvrr_stack+87163);
 tmp = dvrr_stack + 109845;
 target_ptr = Libderiv->deriv2_classes[6][5][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+285356, dvrr_stack+333831, dvrr_stack+90718);
 tmp = dvrr_stack + 285356;
 target_ptr = Libderiv->deriv2_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+186798, dvrr_stack+313285, dvrr_stack+75663);
 tmp = dvrr_stack + 186798;
 target_ptr = Libderiv->deriv2_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+313204, dvrr_stack+347235, dvrr_stack+62331);
 tmp = dvrr_stack + 313204;
 target_ptr = Libderiv->deriv2_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+346822, dvrr_stack+348855, dvrr_stack+63276);
 tmp = dvrr_stack + 346822;
 target_ptr = Libderiv->deriv2_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+188129, dvrr_stack+31153, dvrr_stack+235629);
 tmp = dvrr_stack + 188129;
 target_ptr = Libderiv->deriv2_classes[3][5][6];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+161353, dvrr_stack+58008, dvrr_stack+334839);
 tmp = dvrr_stack + 161353;
 target_ptr = Libderiv->deriv2_classes[3][6][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+75654, dvrr_stack+16811, dvrr_stack+323563);
 tmp = dvrr_stack + 75654;
 target_ptr = Libderiv->deriv2_classes[3][7][6];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+286140, dvrr_stack+28727, dvrr_stack+314581);
 tmp = dvrr_stack + 286140;
 target_ptr = Libderiv->deriv2_classes[3][8][6];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+235354, dvrr_stack+288920, dvrr_stack+306373);
 tmp = dvrr_stack + 235354;
 target_ptr = Libderiv->deriv2_classes[3][9][6];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+76014, dvrr_stack+72141, dvrr_stack+124407);
 tmp = dvrr_stack + 76014;
 target_ptr = Libderiv->deriv2_classes[4][5][6];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+286590, dvrr_stack+10637, dvrr_stack+236466);
 tmp = dvrr_stack + 286590;
 target_ptr = Libderiv->deriv2_classes[4][6][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+235904, dvrr_stack+72582, dvrr_stack+64431);
 tmp = dvrr_stack + 235904;
 target_ptr = Libderiv->deriv2_classes[4][7][6];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+89935, dvrr_stack+289745, dvrr_stack+8927);
 tmp = dvrr_stack + 89935;
 target_ptr = Libderiv->deriv2_classes[4][8][6];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+348362, dvrr_stack+290690, dvrr_stack+4318);
 tmp = dvrr_stack + 348362;
 target_ptr = Libderiv->deriv2_classes[4][9][6];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+4318, dvrr_stack+293231, dvrr_stack+31153);
 tmp = dvrr_stack + 4318;
 target_ptr = Libderiv->deriv2_classes[5][5][6];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+293217, dvrr_stack+135851, dvrr_stack+58008);
 tmp = dvrr_stack + 293217;
 target_ptr = Libderiv->deriv2_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+344380, dvrr_stack+293819, dvrr_stack+16811);
 tmp = dvrr_stack + 344380;
 target_ptr = Libderiv->deriv2_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+293805, dvrr_stack+294827, dvrr_stack+28727);
 tmp = dvrr_stack + 293805;
 target_ptr = Libderiv->deriv2_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+294750, dvrr_stack+296087, dvrr_stack+288920);
 tmp = dvrr_stack + 294750;
 target_ptr = Libderiv->deriv2_classes[5][9][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+295905, dvrr_stack+306703, dvrr_stack+72141);
 tmp = dvrr_stack + 295905;
 target_ptr = Libderiv->deriv2_classes[6][5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+296493, dvrr_stack+220863, dvrr_stack+10637);
 tmp = dvrr_stack + 296493;
 target_ptr = Libderiv->deriv2_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+288712, dvrr_stack+350835, dvrr_stack+72582);
 tmp = dvrr_stack + 288712;
 target_ptr = Libderiv->deriv2_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+349187, dvrr_stack+352131, dvrr_stack+289745);
 tmp = dvrr_stack + 349187;
 target_ptr = Libderiv->deriv2_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+350447, dvrr_stack+353751, dvrr_stack+290690);
 tmp = dvrr_stack + 350447;
 target_ptr = Libderiv->deriv2_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+10637, dvrr_stack+340845, dvrr_stack+340719);
 tmp = dvrr_stack + 10637;
 target_ptr = Libderiv->deriv2_classes[3][5][2];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+10847, dvrr_stack+221871, dvrr_stack+341160);
 tmp = dvrr_stack + 10847;
 target_ptr = Libderiv->deriv2_classes[3][6][2];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+289720, dvrr_stack+336327, dvrr_stack+300231);
 tmp = dvrr_stack + 289720;
 target_ptr = Libderiv->deriv2_classes[3][7][2];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+290080, dvrr_stack+336867, dvrr_stack+355731);
 tmp = dvrr_stack + 290080;
 target_ptr = Libderiv->deriv2_classes[3][8][2];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+290530, dvrr_stack+337872, dvrr_stack+337542);
 tmp = dvrr_stack + 290530;
 target_ptr = Libderiv->deriv2_classes[3][9][2];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+337542, dvrr_stack+201309, dvrr_stack+338697);
 tmp = dvrr_stack + 337542;
 target_ptr = Libderiv->deriv2_classes[4][5][2];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+291080, dvrr_stack+201750, dvrr_stack+338907);
 tmp = dvrr_stack + 291080;
 target_ptr = Libderiv->deriv2_classes[4][6][2];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+338697, dvrr_stack+356001, dvrr_stack+120650);
 tmp = dvrr_stack + 338697;
 target_ptr = Libderiv->deriv2_classes[4][7][2];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+339237, dvrr_stack+356757, dvrr_stack+51332);
 tmp = dvrr_stack + 339237;
 target_ptr = Libderiv->deriv2_classes[4][8][2];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+339912, dvrr_stack+358252, dvrr_stack+357702);
 tmp = dvrr_stack + 339912;
 target_ptr = Libderiv->deriv2_classes[4][9][2];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+357702, dvrr_stack+359407, dvrr_stack+340845);
 tmp = dvrr_stack + 357702;
 target_ptr = Libderiv->deriv2_classes[5][5][2];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+359407, dvrr_stack+359995, dvrr_stack+221871);
 tmp = dvrr_stack + 359407;
 target_ptr = Libderiv->deriv2_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+359995, dvrr_stack+360779, dvrr_stack+336327);
 tmp = dvrr_stack + 359995;
 target_ptr = Libderiv->deriv2_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+360751, dvrr_stack+361787, dvrr_stack+336867);
 tmp = dvrr_stack + 360751;
 target_ptr = Libderiv->deriv2_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+361696, dvrr_stack+363047, dvrr_stack+337872);
 tmp = dvrr_stack + 361696;
 target_ptr = Libderiv->deriv2_classes[5][9][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+362851, dvrr_stack+151745, dvrr_stack+201309);
 tmp = dvrr_stack + 362851;
 target_ptr = Libderiv->deriv2_classes[6][5][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+363439, dvrr_stack+302565, dvrr_stack+201750);
 tmp = dvrr_stack + 363439;
 target_ptr = Libderiv->deriv2_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+72135, dvrr_stack+26847, dvrr_stack+356001);
 tmp = dvrr_stack + 72135;
 target_ptr = Libderiv->deriv2_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+336087, dvrr_stack+365721, dvrr_stack+356757);
 tmp = dvrr_stack + 336087;
 target_ptr = Libderiv->deriv2_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+365595, dvrr_stack+308389, dvrr_stack+358252);
 tmp = dvrr_stack + 365595;
 target_ptr = Libderiv->deriv2_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+364223, dvrr_stack+310369, dvrr_stack+87604);
 tmp = dvrr_stack + 364223;
 target_ptr = Libderiv->deriv2_classes[3][5][1];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+358143, dvrr_stack+317326, dvrr_stack+1137);
 tmp = dvrr_stack + 358143;
 target_ptr = Libderiv->deriv2_classes[3][6][1];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+358423, dvrr_stack+317746, dvrr_stack+2799);
 tmp = dvrr_stack + 358423;
 target_ptr = Libderiv->deriv2_classes[3][7][1];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+358783, dvrr_stack+180643, dvrr_stack+6838);
 tmp = dvrr_stack + 358783;
 target_ptr = Libderiv->deriv2_classes[3][8][1];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+340737, dvrr_stack+181318, dvrr_stack+12077);
 tmp = dvrr_stack + 340737;
 target_ptr = Libderiv->deriv2_classes[3][9][1];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+337857, dvrr_stack+182143, dvrr_stack+225000);
 tmp = dvrr_stack + 337857;
 target_ptr = Libderiv->deriv2_classes[4][5][1];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+338172, dvrr_stack+300447, dvrr_stack+182584);
 tmp = dvrr_stack + 338172;
 target_ptr = Libderiv->deriv2_classes[4][6][1];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+8777, dvrr_stack+303573, dvrr_stack+301035);
 tmp = dvrr_stack + 8777;
 target_ptr = Libderiv->deriv2_classes[4][7][1];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+302494, dvrr_stack+367341, dvrr_stack+28143);
 tmp = dvrr_stack + 302494;
 target_ptr = Libderiv->deriv2_classes[4][8][1];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+306345, dvrr_stack+368836, dvrr_stack+368286);
 tmp = dvrr_stack + 306345;
 target_ptr = Libderiv->deriv2_classes[4][9][1];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+368286, dvrr_stack+369991, dvrr_stack+310369);
 tmp = dvrr_stack + 368286;
 target_ptr = Libderiv->deriv2_classes[5][5][1];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+369991, dvrr_stack+323779, dvrr_stack+317326);
 tmp = dvrr_stack + 369991;
 target_ptr = Libderiv->deriv2_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+323131, dvrr_stack+324563, dvrr_stack+317746);
 tmp = dvrr_stack + 323131;
 target_ptr = Libderiv->deriv2_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+317226, dvrr_stack+325571, dvrr_stack+180643);
 tmp = dvrr_stack + 317226;
 target_ptr = Libderiv->deriv2_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+323887, dvrr_stack+18701, dvrr_stack+181318);
 tmp = dvrr_stack + 323887;
 target_ptr = Libderiv->deriv2_classes[5][9][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+18621, dvrr_stack+326831, dvrr_stack+182143);
 tmp = dvrr_stack + 18621;
 target_ptr = Libderiv->deriv2_classes[6][5][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+19209, dvrr_stack+370579, dvrr_stack+300447);
 tmp = dvrr_stack + 19209;
 target_ptr = Libderiv->deriv2_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+370579, dvrr_stack+371587, dvrr_stack+303573);
 tmp = dvrr_stack + 370579;
 target_ptr = Libderiv->deriv2_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+371587, dvrr_stack+372883, dvrr_stack+367341);
 tmp = dvrr_stack + 371587;
 target_ptr = Libderiv->deriv2_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+372847, dvrr_stack+374503, dvrr_stack+368836);
 tmp = dvrr_stack + 372847;
 target_ptr = Libderiv->deriv2_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+1095, dvrr_stack+301395, dvrr_stack+182864);
 tmp = dvrr_stack + 1095;
 target_ptr = Libderiv->deriv2_classes[3][5][0];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+374387, dvrr_stack+44402, dvrr_stack+927);
 tmp = dvrr_stack + 374387;
 target_ptr = Libderiv->deriv2_classes[3][6][0];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+374667, dvrr_stack+12572, dvrr_stack+1889);
 tmp = dvrr_stack + 374667;
 target_ptr = Libderiv->deriv2_classes[3][7][0];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+375027, dvrr_stack+85119, dvrr_stack+17351);
 tmp = dvrr_stack + 375027;
 target_ptr = Libderiv->deriv2_classes[3][8][0];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+375477, dvrr_stack+38903, dvrr_stack+8027);
 tmp = dvrr_stack + 375477;
 target_ptr = Libderiv->deriv2_classes[3][9][0];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+376027, dvrr_stack+7108, dvrr_stack+13561);
 tmp = dvrr_stack + 376027;
 target_ptr = Libderiv->deriv2_classes[4][5][0];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+368727, dvrr_stack+51782, dvrr_stack+13771);
 tmp = dvrr_stack + 368727;
 target_ptr = Libderiv->deriv2_classes[4][6][0];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+369147, dvrr_stack+0, dvrr_stack+3748);
 tmp = dvrr_stack + 369147;
 target_ptr = Libderiv->deriv2_classes[4][7][0];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+300092, dvrr_stack+36472, dvrr_stack+3015);
 tmp = dvrr_stack + 300092;
 target_ptr = Libderiv->deriv2_classes[4][8][0];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+325042, dvrr_stack+376483, dvrr_stack+45257);
 tmp = dvrr_stack + 325042;
 target_ptr = Libderiv->deriv2_classes[4][9][0];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+2739, dvrr_stack+52370, dvrr_stack+301395);
 tmp = dvrr_stack + 2739;
 target_ptr = Libderiv->deriv2_classes[5][5][0];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+52370, dvrr_stack+301710, dvrr_stack+44402);
 tmp = dvrr_stack + 52370;
 target_ptr = Libderiv->deriv2_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+300767, dvrr_stack+304329, dvrr_stack+12572);
 tmp = dvrr_stack + 300767;
 target_ptr = Libderiv->deriv2_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+301523, dvrr_stack+310684, dvrr_stack+85119);
 tmp = dvrr_stack + 301523;
 target_ptr = Libderiv->deriv2_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+325867, dvrr_stack+318286, dvrr_stack+38903);
 tmp = dvrr_stack + 325867;
 target_ptr = Libderiv->deriv2_classes[5][9][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+38888, dvrr_stack+88738, dvrr_stack+7108);
 tmp = dvrr_stack + 38888;
 target_ptr = Libderiv->deriv2_classes[6][5][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+318171, dvrr_stack+364587, dvrr_stack+51782);
 tmp = dvrr_stack + 318171;
 target_ptr = Libderiv->deriv2_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+364433, dvrr_stack+152501, dvrr_stack+0);
 tmp = dvrr_stack + 364433;
 target_ptr = Libderiv->deriv2_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+303169, dvrr_stack+156925, dvrr_stack+36472);
 tmp = dvrr_stack + 303169;
 target_ptr = Libderiv->deriv2_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+156773, dvrr_stack+167233, dvrr_stack+376483);
 tmp = dvrr_stack + 156773;
 target_ptr = Libderiv->deriv2_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];


}

