/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (gf|hg) integrals */

void d12vrr_order_gfhg(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+0, dvrr_stack+3, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+12, dvrr_stack+0, Data->F+3, Data->F+4, NULL);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+21, dvrr_stack+15, dvrr_stack+6, NULL, NULL, dvrr_stack+0);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+39, dvrr_stack+15, dvrr_stack+6, dvrr_stack+12, dvrr_stack+0, NULL);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+49, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+52, dvrr_stack+49, dvrr_stack+12, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+58, dvrr_stack+52, dvrr_stack+15, dvrr_stack+49, dvrr_stack+12, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+68, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+71, dvrr_stack+3, dvrr_stack+68, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+77, dvrr_stack+6, dvrr_stack+71, dvrr_stack+0, dvrr_stack+3, NULL);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+87, dvrr_stack+39, dvrr_stack+77, NULL, NULL, dvrr_stack+6);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+117, dvrr_stack+58, dvrr_stack+39, NULL, NULL, dvrr_stack+15);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+147, dvrr_stack+117, dvrr_stack+87, dvrr_stack+58, dvrr_stack+39, dvrr_stack+21);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+207, dvrr_stack+39, dvrr_stack+77, dvrr_stack+15, dvrr_stack+6, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+222, dvrr_stack+58, dvrr_stack+39, dvrr_stack+52, dvrr_stack+15, NULL);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+237, dvrr_stack+222, dvrr_stack+207, NULL, NULL, dvrr_stack+39);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+282, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+285, dvrr_stack+282, dvrr_stack+49, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+291, dvrr_stack+285, dvrr_stack+52, dvrr_stack+282, dvrr_stack+49, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+301, dvrr_stack+291, dvrr_stack+58, dvrr_stack+285, dvrr_stack+52, NULL);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+316, dvrr_stack+301, dvrr_stack+222, NULL, NULL, dvrr_stack+58);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+361, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+364, dvrr_stack+68, dvrr_stack+361, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+370, dvrr_stack+71, dvrr_stack+364, dvrr_stack+3, dvrr_stack+68, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+380, dvrr_stack+77, dvrr_stack+370, dvrr_stack+6, dvrr_stack+71, NULL);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+395, dvrr_stack+207, dvrr_stack+380, NULL, NULL, dvrr_stack+77);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+440, dvrr_stack+237, dvrr_stack+395, dvrr_stack+222, dvrr_stack+207, dvrr_stack+87);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+530, dvrr_stack+316, dvrr_stack+237, dvrr_stack+301, dvrr_stack+222, dvrr_stack+117);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+620, dvrr_stack+530, dvrr_stack+440, dvrr_stack+316, dvrr_stack+237, dvrr_stack+147);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+770, dvrr_stack+222, dvrr_stack+207, dvrr_stack+58, dvrr_stack+39, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+791, dvrr_stack+301, dvrr_stack+222, dvrr_stack+291, dvrr_stack+58, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+812, dvrr_stack+207, dvrr_stack+380, dvrr_stack+39, dvrr_stack+77, NULL);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+833, dvrr_stack+770, dvrr_stack+812, NULL, NULL, dvrr_stack+207);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+896, dvrr_stack+791, dvrr_stack+770, NULL, NULL, dvrr_stack+222);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+959, dvrr_stack+896, dvrr_stack+833, dvrr_stack+791, dvrr_stack+770, dvrr_stack+237);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1085, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1088, dvrr_stack+1085, dvrr_stack+282, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1094, dvrr_stack+1088, dvrr_stack+285, dvrr_stack+1085, dvrr_stack+282, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1104, dvrr_stack+1094, dvrr_stack+291, dvrr_stack+1088, dvrr_stack+285, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1119, dvrr_stack+1104, dvrr_stack+301, dvrr_stack+1094, dvrr_stack+291, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1140, dvrr_stack+1119, dvrr_stack+791, NULL, NULL, dvrr_stack+301);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1203, dvrr_stack+1140, dvrr_stack+896, dvrr_stack+1119, dvrr_stack+791, dvrr_stack+316);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+282, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1085, dvrr_stack+361, dvrr_stack+282, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1329, dvrr_stack+364, dvrr_stack+1085, dvrr_stack+68, dvrr_stack+361, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1339, dvrr_stack+370, dvrr_stack+1329, dvrr_stack+71, dvrr_stack+364, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1354, dvrr_stack+380, dvrr_stack+1339, dvrr_stack+77, dvrr_stack+370, NULL);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1375, dvrr_stack+812, dvrr_stack+1354, NULL, NULL, dvrr_stack+380);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1438, dvrr_stack+833, dvrr_stack+1375, dvrr_stack+770, dvrr_stack+812, dvrr_stack+395);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+1564, dvrr_stack+959, dvrr_stack+1438, dvrr_stack+896, dvrr_stack+833, dvrr_stack+440);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+1774, dvrr_stack+1203, dvrr_stack+959, dvrr_stack+1140, dvrr_stack+896, dvrr_stack+530);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+1984, dvrr_stack+1774, dvrr_stack+1564, dvrr_stack+1203, dvrr_stack+959, dvrr_stack+620);
 tmp = dvrr_stack + 1984;
 target_ptr = Libderiv->dvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1140, dvrr_stack+770, dvrr_stack+812, dvrr_stack+222, dvrr_stack+207, NULL);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1168, dvrr_stack+791, dvrr_stack+770, dvrr_stack+301, dvrr_stack+222, NULL);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2299, dvrr_stack+812, dvrr_stack+1354, dvrr_stack+207, dvrr_stack+380, NULL);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2327, dvrr_stack+1140, dvrr_stack+2299, NULL, NULL, dvrr_stack+812);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2411, dvrr_stack+1168, dvrr_stack+1140, NULL, NULL, dvrr_stack+770);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+2495, dvrr_stack+2411, dvrr_stack+2327, dvrr_stack+1168, dvrr_stack+1140, dvrr_stack+833);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2663, dvrr_stack+1119, dvrr_stack+791, dvrr_stack+1104, dvrr_stack+301, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2691, dvrr_stack+2663, dvrr_stack+1168, NULL, NULL, dvrr_stack+791);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+2775, dvrr_stack+2691, dvrr_stack+2411, dvrr_stack+2663, dvrr_stack+1168, dvrr_stack+896);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1091, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+896, dvrr_stack+282, dvrr_stack+1091, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+902, dvrr_stack+1085, dvrr_stack+896, dvrr_stack+361, dvrr_stack+282, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+222, dvrr_stack+1329, dvrr_stack+902, dvrr_stack+364, dvrr_stack+1085, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+912, dvrr_stack+1339, dvrr_stack+222, dvrr_stack+370, dvrr_stack+1329, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2943, dvrr_stack+1354, dvrr_stack+912, dvrr_stack+380, dvrr_stack+1339, NULL);

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2971, dvrr_stack+2299, dvrr_stack+2943, NULL, NULL, dvrr_stack+1354);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+3055, dvrr_stack+2327, dvrr_stack+2971, dvrr_stack+1140, dvrr_stack+2299, dvrr_stack+1375);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+3223, dvrr_stack+2495, dvrr_stack+3055, dvrr_stack+2411, dvrr_stack+2327, dvrr_stack+1438);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+3503, dvrr_stack+2775, dvrr_stack+2495, dvrr_stack+2691, dvrr_stack+2411, dvrr_stack+959);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+3783, dvrr_stack+3503, dvrr_stack+3223, dvrr_stack+2775, dvrr_stack+2495, dvrr_stack+1564);
 tmp = dvrr_stack + 3783;
 target_ptr = Libderiv->dvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+4203,dvrr_stack+3783,dvrr_stack+1984,15);


 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2691, dvrr_stack+1140, dvrr_stack+2299, dvrr_stack+770, dvrr_stack+812, NULL);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2727, dvrr_stack+1168, dvrr_stack+1140, dvrr_stack+791, dvrr_stack+770, NULL);

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5148, dvrr_stack+2299, dvrr_stack+2943, dvrr_stack+812, dvrr_stack+1354, NULL);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5184, dvrr_stack+2691, dvrr_stack+5148, NULL, NULL, dvrr_stack+2299);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5292, dvrr_stack+2727, dvrr_stack+2691, NULL, NULL, dvrr_stack+1140);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5400, dvrr_stack+5292, dvrr_stack+5184, dvrr_stack+2727, dvrr_stack+2691, dvrr_stack+2327);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5616, dvrr_stack+2663, dvrr_stack+1168, dvrr_stack+1119, dvrr_stack+791, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5652, dvrr_stack+5616, dvrr_stack+2727, NULL, NULL, dvrr_stack+1168);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5760, dvrr_stack+5652, dvrr_stack+5292, dvrr_stack+5616, dvrr_stack+2727, dvrr_stack+2411);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+2411, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+2414, dvrr_stack+1091, dvrr_stack+2411, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2420, dvrr_stack+896, dvrr_stack+2414, dvrr_stack+282, dvrr_stack+1091, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2430, dvrr_stack+902, dvrr_stack+2420, dvrr_stack+1085, dvrr_stack+896, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1119, dvrr_stack+222, dvrr_stack+2430, dvrr_stack+1329, dvrr_stack+902, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2445, dvrr_stack+912, dvrr_stack+1119, dvrr_stack+1339, dvrr_stack+222, NULL);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+770, dvrr_stack+2943, dvrr_stack+2445, dvrr_stack+1354, dvrr_stack+912, NULL);

 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5976, dvrr_stack+5148, dvrr_stack+770, NULL, NULL, dvrr_stack+2943);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6084, dvrr_stack+5184, dvrr_stack+5976, dvrr_stack+2691, dvrr_stack+5148, dvrr_stack+2971);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6300, dvrr_stack+5400, dvrr_stack+6084, dvrr_stack+5292, dvrr_stack+5184, dvrr_stack+3055);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6660, dvrr_stack+5760, dvrr_stack+5400, dvrr_stack+5652, dvrr_stack+5292, dvrr_stack+2495);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7020, dvrr_stack+6660, dvrr_stack+6300, dvrr_stack+5760, dvrr_stack+5400, dvrr_stack+3223);
 tmp = dvrr_stack + 7020;
 target_ptr = Libderiv->dvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+7560,dvrr_stack+7020,dvrr_stack+3783,15);


 /* compute (4 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+8820,dvrr_stack+7560,dvrr_stack+4203,15);


 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,315,dvrr_stack+10710, dvrr_stack+8820, dvrr_stack+1984);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+5652, dvrr_stack+2691, dvrr_stack+5148, dvrr_stack+1140, dvrr_stack+2299, NULL);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+5697, dvrr_stack+2727, dvrr_stack+2691, dvrr_stack+1168, dvrr_stack+1140, NULL);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11655, dvrr_stack+5148, dvrr_stack+770, dvrr_stack+2299, dvrr_stack+2943, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11700, dvrr_stack+5652, dvrr_stack+11655, NULL, NULL, dvrr_stack+5148);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11835, dvrr_stack+5697, dvrr_stack+5652, NULL, NULL, dvrr_stack+2691);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11970, dvrr_stack+11835, dvrr_stack+11700, dvrr_stack+5697, dvrr_stack+5652, dvrr_stack+5184);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12240, dvrr_stack+5616, dvrr_stack+2727, dvrr_stack+2663, dvrr_stack+1168, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12285, dvrr_stack+12240, dvrr_stack+5697, NULL, NULL, dvrr_stack+2727);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12420, dvrr_stack+12285, dvrr_stack+11835, dvrr_stack+12240, dvrr_stack+5697, dvrr_stack+5292);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+5292, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+806, dvrr_stack+2411, dvrr_stack+5292, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+5295, dvrr_stack+2414, dvrr_stack+806, dvrr_stack+1091, dvrr_stack+2411, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+5305, dvrr_stack+2420, dvrr_stack+5295, dvrr_stack+896, dvrr_stack+2414, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+5320, dvrr_stack+2430, dvrr_stack+5305, dvrr_stack+902, dvrr_stack+2420, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2663, dvrr_stack+1119, dvrr_stack+5320, dvrr_stack+222, dvrr_stack+2430, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5341, dvrr_stack+2445, dvrr_stack+2663, dvrr_stack+912, dvrr_stack+1119, NULL);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1140, dvrr_stack+770, dvrr_stack+5341, dvrr_stack+2943, dvrr_stack+2445, NULL);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12690, dvrr_stack+11655, dvrr_stack+1140, NULL, NULL, dvrr_stack+770);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12825, dvrr_stack+11700, dvrr_stack+12690, dvrr_stack+5652, dvrr_stack+11655, dvrr_stack+5976);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13095, dvrr_stack+11970, dvrr_stack+12825, dvrr_stack+11835, dvrr_stack+11700, dvrr_stack+6084);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13545, dvrr_stack+12420, dvrr_stack+11970, dvrr_stack+12285, dvrr_stack+11835, dvrr_stack+5400);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13995, dvrr_stack+13545, dvrr_stack+13095, dvrr_stack+12420, dvrr_stack+11970, dvrr_stack+6300);
 tmp = dvrr_stack + 13995;
 target_ptr = Libderiv->dvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+14670,dvrr_stack+13995,dvrr_stack+7020,15);


 /* compute (4 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+16290,dvrr_stack+14670,dvrr_stack+7560,15);


 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,420,dvrr_stack+18810, dvrr_stack+16290, dvrr_stack+3783);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12285, dvrr_stack+5652, dvrr_stack+11655, dvrr_stack+2691, dvrr_stack+5148, NULL);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12340, dvrr_stack+5697, dvrr_stack+5652, dvrr_stack+2727, dvrr_stack+2691, NULL);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20070, dvrr_stack+11655, dvrr_stack+1140, dvrr_stack+5148, dvrr_stack+770, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20125, dvrr_stack+12285, dvrr_stack+20070, NULL, NULL, dvrr_stack+11655);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20290, dvrr_stack+12340, dvrr_stack+12285, NULL, NULL, dvrr_stack+5652);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20455, dvrr_stack+20290, dvrr_stack+20125, dvrr_stack+12340, dvrr_stack+12285, dvrr_stack+11700);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20785, dvrr_stack+12240, dvrr_stack+5697, dvrr_stack+5616, dvrr_stack+2727, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20840, dvrr_stack+20785, dvrr_stack+12340, NULL, NULL, dvrr_stack+5697);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21005, dvrr_stack+20840, dvrr_stack+20290, dvrr_stack+20785, dvrr_stack+12340, dvrr_stack+11835);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+11835, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+11838, dvrr_stack+5292, dvrr_stack+11835, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+11844, dvrr_stack+806, dvrr_stack+11838, dvrr_stack+2411, dvrr_stack+5292, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+11854, dvrr_stack+5295, dvrr_stack+11844, dvrr_stack+2414, dvrr_stack+806, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+11869, dvrr_stack+5305, dvrr_stack+11854, dvrr_stack+2420, dvrr_stack+5295, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+11890, dvrr_stack+5320, dvrr_stack+11869, dvrr_stack+2430, dvrr_stack+5305, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5616, dvrr_stack+2663, dvrr_stack+11890, dvrr_stack+1119, dvrr_stack+5320, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11918, dvrr_stack+5341, dvrr_stack+5616, dvrr_stack+2445, dvrr_stack+2663, NULL);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2691, dvrr_stack+1140, dvrr_stack+11918, dvrr_stack+770, dvrr_stack+5341, NULL);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21335, dvrr_stack+20070, dvrr_stack+2691, NULL, NULL, dvrr_stack+1140);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21500, dvrr_stack+20125, dvrr_stack+21335, dvrr_stack+12285, dvrr_stack+20070, dvrr_stack+12690);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21830, dvrr_stack+20455, dvrr_stack+21500, dvrr_stack+20290, dvrr_stack+20125, dvrr_stack+12825);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+22380, dvrr_stack+21005, dvrr_stack+20455, dvrr_stack+20840, dvrr_stack+20290, dvrr_stack+11970);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+22930, dvrr_stack+22380, dvrr_stack+21830, dvrr_stack+21005, dvrr_stack+20455, dvrr_stack+13095);
 tmp = dvrr_stack + 22930;
 target_ptr = Libderiv->dvrr_classes[4][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+23755,dvrr_stack+22930,dvrr_stack+13995,15);


 /* compute (4 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+25780,dvrr_stack+23755,dvrr_stack+14670,15);


 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,540,dvrr_stack+29020, dvrr_stack+25780, dvrr_stack+7020);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20840, dvrr_stack+12285, dvrr_stack+20070, dvrr_stack+5652, dvrr_stack+11655, NULL);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20906, dvrr_stack+12340, dvrr_stack+12285, dvrr_stack+5697, dvrr_stack+5652, NULL);

 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30640, dvrr_stack+20070, dvrr_stack+2691, dvrr_stack+11655, dvrr_stack+1140, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30706, dvrr_stack+20840, dvrr_stack+30640, NULL, NULL, dvrr_stack+20070);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30904, dvrr_stack+20906, dvrr_stack+20840, NULL, NULL, dvrr_stack+12285);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31102, dvrr_stack+30904, dvrr_stack+30706, dvrr_stack+20906, dvrr_stack+20840, dvrr_stack+20125);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31498, dvrr_stack+20785, dvrr_stack+12340, dvrr_stack+12240, dvrr_stack+5697, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31564, dvrr_stack+31498, dvrr_stack+20906, NULL, NULL, dvrr_stack+12340);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31762, dvrr_stack+31564, dvrr_stack+30904, dvrr_stack+31498, dvrr_stack+20906, dvrr_stack+20290);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+2411, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+20290, dvrr_stack+11835, dvrr_stack+2411, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+20296, dvrr_stack+11838, dvrr_stack+20290, dvrr_stack+5292, dvrr_stack+11835, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+20306, dvrr_stack+11844, dvrr_stack+20296, dvrr_stack+806, dvrr_stack+11838, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+20321, dvrr_stack+11854, dvrr_stack+20306, dvrr_stack+5295, dvrr_stack+11844, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+20342, dvrr_stack+11869, dvrr_stack+20321, dvrr_stack+5305, dvrr_stack+11854, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+20370, dvrr_stack+11890, dvrr_stack+20342, dvrr_stack+5320, dvrr_stack+11869, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12240, dvrr_stack+5616, dvrr_stack+20370, dvrr_stack+2663, dvrr_stack+11890, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+5652, dvrr_stack+11918, dvrr_stack+12240, dvrr_stack+5341, dvrr_stack+5616, NULL);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32158, dvrr_stack+2691, dvrr_stack+5652, dvrr_stack+1140, dvrr_stack+11918, NULL);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32224, dvrr_stack+30640, dvrr_stack+32158, NULL, NULL, dvrr_stack+2691);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32422, dvrr_stack+30706, dvrr_stack+32224, dvrr_stack+20840, dvrr_stack+30640, dvrr_stack+21335);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32818, dvrr_stack+31102, dvrr_stack+32422, dvrr_stack+30904, dvrr_stack+30706, dvrr_stack+21500);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33478, dvrr_stack+31762, dvrr_stack+31102, dvrr_stack+31564, dvrr_stack+30904, dvrr_stack+20455);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+34138, dvrr_stack+33478, dvrr_stack+32818, dvrr_stack+31762, dvrr_stack+31102, dvrr_stack+21830);

 /* compute (4 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+35128,dvrr_stack+34138,dvrr_stack+22930,15);


 /* compute (4 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+37603,dvrr_stack+35128,dvrr_stack+23755,15);


 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,675,dvrr_stack+41653, dvrr_stack+37603, dvrr_stack+13995);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31564, dvrr_stack+20840, dvrr_stack+30640, dvrr_stack+12285, dvrr_stack+20070, NULL);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31642, dvrr_stack+20906, dvrr_stack+20840, dvrr_stack+12340, dvrr_stack+12285, NULL);

 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31720, dvrr_stack+30640, dvrr_stack+32158, dvrr_stack+20070, dvrr_stack+2691, NULL);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31798, dvrr_stack+31564, dvrr_stack+31720, NULL, NULL, dvrr_stack+30640);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+43678, dvrr_stack+31642, dvrr_stack+31564, NULL, NULL, dvrr_stack+20840);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+43912, dvrr_stack+43678, dvrr_stack+31798, dvrr_stack+31642, dvrr_stack+31564, dvrr_stack+30706);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32032, dvrr_stack+31498, dvrr_stack+20906, dvrr_stack+20785, dvrr_stack+12340, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+44380, dvrr_stack+32032, dvrr_stack+31642, NULL, NULL, dvrr_stack+20906);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+44614, dvrr_stack+44380, dvrr_stack+43678, dvrr_stack+32032, dvrr_stack+31642, dvrr_stack+30904);

 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+5292, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+806, dvrr_stack+2411, dvrr_stack+5292, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+30904, dvrr_stack+20290, dvrr_stack+806, dvrr_stack+11835, dvrr_stack+2411, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+30914, dvrr_stack+20296, dvrr_stack+30904, dvrr_stack+11838, dvrr_stack+20290, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+30929, dvrr_stack+20306, dvrr_stack+30914, dvrr_stack+11844, dvrr_stack+20296, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+30950, dvrr_stack+20321, dvrr_stack+30929, dvrr_stack+11854, dvrr_stack+20306, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+30978, dvrr_stack+20342, dvrr_stack+30950, dvrr_stack+11869, dvrr_stack+20321, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+31014, dvrr_stack+20370, dvrr_stack+30978, dvrr_stack+11890, dvrr_stack+20342, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31642, dvrr_stack+12240, dvrr_stack+31014, dvrr_stack+5616, dvrr_stack+20370, NULL);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31498, dvrr_stack+5652, dvrr_stack+31642, dvrr_stack+11918, dvrr_stack+12240, NULL);

 /* compute (0 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32032, dvrr_stack+32158, dvrr_stack+31498, dvrr_stack+2691, dvrr_stack+5652, NULL);

 /* compute (1 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45082, dvrr_stack+31720, dvrr_stack+32032, NULL, NULL, dvrr_stack+32158);

 /* compute (2 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45316, dvrr_stack+31798, dvrr_stack+45082, dvrr_stack+31564, dvrr_stack+31720, dvrr_stack+32224);

 /* compute (3 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45784, dvrr_stack+43912, dvrr_stack+45316, dvrr_stack+43678, dvrr_stack+31798, dvrr_stack+32422);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+46564, dvrr_stack+44614, dvrr_stack+43912, dvrr_stack+44380, dvrr_stack+43678, dvrr_stack+31102);

 /* compute (4 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+47344, dvrr_stack+46564, dvrr_stack+45784, dvrr_stack+44614, dvrr_stack+43912, dvrr_stack+32818);

 /* compute (4 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+48514,dvrr_stack+47344,dvrr_stack+34138,15);


 /* compute (4 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+51484,dvrr_stack+48514,dvrr_stack+35128,15);


 /* compute (4 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,825,dvrr_stack+56434, dvrr_stack+51484, dvrr_stack+22930);

 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+43678, dvrr_stack+0, dvrr_stack+3, NULL, NULL, Data->F+5);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+1185, dvrr_stack+6, dvrr_stack+71, NULL, NULL, dvrr_stack+3);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+43687, dvrr_stack+21, dvrr_stack+1185, dvrr_stack+15, dvrr_stack+6, dvrr_stack+43678);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+43723, dvrr_stack+77, dvrr_stack+370, NULL, NULL, dvrr_stack+71);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+43753, dvrr_stack+87, dvrr_stack+43723, dvrr_stack+39, dvrr_stack+77, dvrr_stack+1185);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+44380, dvrr_stack+147, dvrr_stack+43753, dvrr_stack+117, dvrr_stack+87, dvrr_stack+43687);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+43813, dvrr_stack+380, dvrr_stack+1339, NULL, NULL, dvrr_stack+370);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+44480, dvrr_stack+395, dvrr_stack+43813, dvrr_stack+207, dvrr_stack+380, dvrr_stack+43723);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+44570, dvrr_stack+440, dvrr_stack+44480, dvrr_stack+237, dvrr_stack+395, dvrr_stack+43753);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+44720, dvrr_stack+620, dvrr_stack+44570, dvrr_stack+530, dvrr_stack+440, dvrr_stack+44380);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+44945, dvrr_stack+1354, dvrr_stack+912, NULL, NULL, dvrr_stack+1339);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+20785, dvrr_stack+1375, dvrr_stack+44945, dvrr_stack+812, dvrr_stack+1354, dvrr_stack+43813);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+58909, dvrr_stack+1438, dvrr_stack+20785, dvrr_stack+833, dvrr_stack+1375, dvrr_stack+44480);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+59119, dvrr_stack+1564, dvrr_stack+58909, dvrr_stack+959, dvrr_stack+1438, dvrr_stack+44570);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+59434, dvrr_stack+1984, dvrr_stack+59119, dvrr_stack+1774, dvrr_stack+1564, dvrr_stack+44720);
 tmp = dvrr_stack + 59434;
 target_ptr = Libderiv->dvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+812, dvrr_stack+2943, dvrr_stack+2445, NULL, NULL, dvrr_stack+912);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+59875, dvrr_stack+2971, dvrr_stack+812, dvrr_stack+2299, dvrr_stack+2943, dvrr_stack+44945);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+60043, dvrr_stack+3055, dvrr_stack+59875, dvrr_stack+2327, dvrr_stack+2971, dvrr_stack+20785);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+60323, dvrr_stack+3223, dvrr_stack+60043, dvrr_stack+2495, dvrr_stack+3055, dvrr_stack+58909);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+60743, dvrr_stack+3783, dvrr_stack+60323, dvrr_stack+3503, dvrr_stack+3223, dvrr_stack+59119);
 tmp = dvrr_stack + 60743;
 target_ptr = Libderiv->dvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+61331,dvrr_stack+60743,dvrr_stack+59434,21);


 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2299, dvrr_stack+770, dvrr_stack+5341, NULL, NULL, dvrr_stack+2445);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+62654, dvrr_stack+5976, dvrr_stack+2299, dvrr_stack+5148, dvrr_stack+770, dvrr_stack+812);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+62870, dvrr_stack+6084, dvrr_stack+62654, dvrr_stack+5184, dvrr_stack+5976, dvrr_stack+59875);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+63230, dvrr_stack+6300, dvrr_stack+62870, dvrr_stack+5400, dvrr_stack+6084, dvrr_stack+60043);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+63770, dvrr_stack+7020, dvrr_stack+63230, dvrr_stack+6660, dvrr_stack+6300, dvrr_stack+60323);
 tmp = dvrr_stack + 63770;
 target_ptr = Libderiv->dvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+64526,dvrr_stack+63770,dvrr_stack+60743,21);


 /* compute (5 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+66290,dvrr_stack+64526,dvrr_stack+61331,21);


 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,441,dvrr_stack+68936, dvrr_stack+66290, dvrr_stack+59434);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12285, dvrr_stack+1140, dvrr_stack+11918, NULL, NULL, dvrr_stack+5341);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+70259, dvrr_stack+12690, dvrr_stack+12285, dvrr_stack+11655, dvrr_stack+1140, dvrr_stack+2299);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+70529, dvrr_stack+12825, dvrr_stack+70259, dvrr_stack+11700, dvrr_stack+12690, dvrr_stack+62654);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+70979, dvrr_stack+13095, dvrr_stack+70529, dvrr_stack+11970, dvrr_stack+12825, dvrr_stack+62870);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+71654, dvrr_stack+13995, dvrr_stack+70979, dvrr_stack+13545, dvrr_stack+13095, dvrr_stack+63230);
 tmp = dvrr_stack + 71654;
 target_ptr = Libderiv->dvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+72599,dvrr_stack+71654,dvrr_stack+63770,21);


 /* compute (5 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+74867,dvrr_stack+72599,dvrr_stack+64526,21);


 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,588,dvrr_stack+78395, dvrr_stack+74867, dvrr_stack+60743);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11655, dvrr_stack+2691, dvrr_stack+5652, NULL, NULL, dvrr_stack+11918);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+80159, dvrr_stack+21335, dvrr_stack+11655, dvrr_stack+20070, dvrr_stack+2691, dvrr_stack+12285);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+80489, dvrr_stack+21500, dvrr_stack+80159, dvrr_stack+20125, dvrr_stack+21335, dvrr_stack+70259);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+81039, dvrr_stack+21830, dvrr_stack+80489, dvrr_stack+20455, dvrr_stack+21500, dvrr_stack+70529);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+81864, dvrr_stack+22930, dvrr_stack+81039, dvrr_stack+22380, dvrr_stack+21830, dvrr_stack+70979);
 tmp = dvrr_stack + 81864;
 target_ptr = Libderiv->dvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+83019,dvrr_stack+81864,dvrr_stack+71654,21);


 /* compute (5 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+85854,dvrr_stack+83019,dvrr_stack+72599,21);


 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,756,dvrr_stack+90390, dvrr_stack+85854, dvrr_stack+63770);

 /* compute (1 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20070, dvrr_stack+32158, dvrr_stack+31498, NULL, NULL, dvrr_stack+5652);

 /* compute (2 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+92658, dvrr_stack+32224, dvrr_stack+20070, dvrr_stack+30640, dvrr_stack+32158, dvrr_stack+11655);

 /* compute (3 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+93054, dvrr_stack+32422, dvrr_stack+92658, dvrr_stack+30706, dvrr_stack+32224, dvrr_stack+80159);

 /* compute (4 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+93714, dvrr_stack+32818, dvrr_stack+93054, dvrr_stack+31102, dvrr_stack+32422, dvrr_stack+80489);

 /* compute (5 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+94704, dvrr_stack+34138, dvrr_stack+93714, dvrr_stack+33478, dvrr_stack+32818, dvrr_stack+81039);

 /* compute (5 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+96090,dvrr_stack+94704,dvrr_stack+81864,21);


 /* compute (5 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+99555,dvrr_stack+96090,dvrr_stack+83019,21);


 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,945,dvrr_stack+105225, dvrr_stack+99555, dvrr_stack+71654);

 /* compute (0 0 | 1 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+30640, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+30643, dvrr_stack+5292, dvrr_stack+30640, Data->F+14, Data->F+15, NULL);

 /* compute (0 0 | 3 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+39, dvrr_stack+806, dvrr_stack+30643, dvrr_stack+2411, dvrr_stack+5292, NULL);

 /* compute (0 0 | 4 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+207, dvrr_stack+30904, dvrr_stack+39, dvrr_stack+20290, dvrr_stack+806, NULL);

 /* compute (0 0 | 5 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+30649, dvrr_stack+30914, dvrr_stack+207, dvrr_stack+20296, dvrr_stack+30904, NULL);

 /* compute (0 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+30670, dvrr_stack+30929, dvrr_stack+30649, dvrr_stack+20306, dvrr_stack+30914, NULL);

 /* compute (0 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+30698, dvrr_stack+30950, dvrr_stack+30670, dvrr_stack+20321, dvrr_stack+30929, NULL);

 /* compute (0 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+237, dvrr_stack+30978, dvrr_stack+30698, dvrr_stack+20342, dvrr_stack+30950, NULL);

 /* compute (0 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+30734, dvrr_stack+31014, dvrr_stack+237, dvrr_stack+20370, dvrr_stack+30978, NULL);

 /* compute (0 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30789, dvrr_stack+31642, dvrr_stack+30734, dvrr_stack+12240, dvrr_stack+31014, NULL);

 /* compute (0 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31564, dvrr_stack+31498, dvrr_stack+30789, dvrr_stack+5652, dvrr_stack+31642, NULL);

 /* compute (1 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31059, dvrr_stack+32032, dvrr_stack+31564, NULL, NULL, dvrr_stack+31498);

 /* compute (2 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+108060, dvrr_stack+45082, dvrr_stack+31059, dvrr_stack+31720, dvrr_stack+32032, dvrr_stack+20070);

 /* compute (3 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+108528, dvrr_stack+45316, dvrr_stack+108060, dvrr_stack+31798, dvrr_stack+45082, dvrr_stack+92658);

 /* compute (4 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+109308, dvrr_stack+45784, dvrr_stack+108528, dvrr_stack+43912, dvrr_stack+45316, dvrr_stack+93054);

 /* compute (5 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+110478, dvrr_stack+47344, dvrr_stack+109308, dvrr_stack+46564, dvrr_stack+45784, dvrr_stack+93714);

 /* compute (5 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+112116,dvrr_stack+110478,dvrr_stack+94704,21);


 /* compute (5 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+116274,dvrr_stack+112116,dvrr_stack+96090,21);


 /* compute (5 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1155,dvrr_stack+123204, dvrr_stack+116274, dvrr_stack+81864);

 /* compute (1 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+46564, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+46567, dvrr_stack+3, dvrr_stack+68, NULL, NULL, Data->F+6);

 /* compute (2 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+46576, dvrr_stack+43678, dvrr_stack+46567, dvrr_stack+0, dvrr_stack+3, dvrr_stack+46564);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+46594, dvrr_stack+71, dvrr_stack+364, NULL, NULL, dvrr_stack+68);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+46612, dvrr_stack+1185, dvrr_stack+46594, dvrr_stack+6, dvrr_stack+71, dvrr_stack+46567);

 /* compute (3 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+46648, dvrr_stack+43687, dvrr_stack+46612, dvrr_stack+21, dvrr_stack+1185, dvrr_stack+46576);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+46708, dvrr_stack+370, dvrr_stack+1329, NULL, NULL, dvrr_stack+364);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+46738, dvrr_stack+43723, dvrr_stack+46708, dvrr_stack+77, dvrr_stack+370, dvrr_stack+46594);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+46798, dvrr_stack+43753, dvrr_stack+46738, dvrr_stack+87, dvrr_stack+43723, dvrr_stack+46612);

 /* compute (4 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+46898, dvrr_stack+44380, dvrr_stack+46798, dvrr_stack+147, dvrr_stack+43753, dvrr_stack+46648);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+47048, dvrr_stack+1339, dvrr_stack+222, NULL, NULL, dvrr_stack+1329);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+47093, dvrr_stack+43813, dvrr_stack+47048, dvrr_stack+380, dvrr_stack+1339, dvrr_stack+46708);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+47183, dvrr_stack+44480, dvrr_stack+47093, dvrr_stack+395, dvrr_stack+43813, dvrr_stack+46738);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+43858, dvrr_stack+44570, dvrr_stack+47183, dvrr_stack+440, dvrr_stack+44480, dvrr_stack+46798);

 /* compute (5 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+31697, dvrr_stack+44720, dvrr_stack+43858, dvrr_stack+620, dvrr_stack+44570, dvrr_stack+46898);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+380, dvrr_stack+912, dvrr_stack+1119, NULL, NULL, dvrr_stack+222);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+5148, dvrr_stack+44945, dvrr_stack+380, dvrr_stack+1354, dvrr_stack+912, dvrr_stack+47048);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+44083, dvrr_stack+20785, dvrr_stack+5148, dvrr_stack+1375, dvrr_stack+44945, dvrr_stack+47093);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+20406, dvrr_stack+58909, dvrr_stack+44083, dvrr_stack+1438, dvrr_stack+20785, dvrr_stack+47183);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+126669, dvrr_stack+59119, dvrr_stack+20406, dvrr_stack+1564, dvrr_stack+58909, dvrr_stack+43858);

 /* compute (6 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+127110, dvrr_stack+59434, dvrr_stack+126669, dvrr_stack+1984, dvrr_stack+59119, dvrr_stack+31697);
 tmp = dvrr_stack + 127110;
 target_ptr = Libderiv->dvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1354, dvrr_stack+2445, dvrr_stack+2663, NULL, NULL, dvrr_stack+1119);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+1438, dvrr_stack+812, dvrr_stack+1354, dvrr_stack+2943, dvrr_stack+2445, dvrr_stack+380);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+127698, dvrr_stack+59875, dvrr_stack+1438, dvrr_stack+2971, dvrr_stack+812, dvrr_stack+5148);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+127978, dvrr_stack+60043, dvrr_stack+127698, dvrr_stack+3055, dvrr_stack+59875, dvrr_stack+44083);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+128398, dvrr_stack+60323, dvrr_stack+127978, dvrr_stack+3223, dvrr_stack+60043, dvrr_stack+20406);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+128986, dvrr_stack+60743, dvrr_stack+128398, dvrr_stack+3783, dvrr_stack+60323, dvrr_stack+126669);
 tmp = dvrr_stack + 128986;
 target_ptr = Libderiv->dvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+129770,dvrr_stack+128986,dvrr_stack+127110,28);


 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2943, dvrr_stack+5341, dvrr_stack+5616, NULL, NULL, dvrr_stack+2663);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3051, dvrr_stack+2299, dvrr_stack+2943, dvrr_stack+770, dvrr_stack+5341, dvrr_stack+1354);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+131534, dvrr_stack+62654, dvrr_stack+3051, dvrr_stack+5976, dvrr_stack+2299, dvrr_stack+1438);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+131894, dvrr_stack+62870, dvrr_stack+131534, dvrr_stack+6084, dvrr_stack+62654, dvrr_stack+127698);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+132434, dvrr_stack+63230, dvrr_stack+131894, dvrr_stack+6300, dvrr_stack+62870, dvrr_stack+127978);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+133190, dvrr_stack+63770, dvrr_stack+132434, dvrr_stack+7020, dvrr_stack+63230, dvrr_stack+128398);
 tmp = dvrr_stack + 133190;
 target_ptr = Libderiv->dvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+134198,dvrr_stack+133190,dvrr_stack+128986,28);


 /* compute (6 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+136550,dvrr_stack+134198,dvrr_stack+129770,28);


 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,588,dvrr_stack+140078, dvrr_stack+136550, dvrr_stack+127110);

 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+5976, dvrr_stack+11918, dvrr_stack+12240, NULL, NULL, dvrr_stack+5616);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6111, dvrr_stack+12285, dvrr_stack+5976, dvrr_stack+1140, dvrr_stack+11918, dvrr_stack+2943);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+141842, dvrr_stack+70259, dvrr_stack+6111, dvrr_stack+12690, dvrr_stack+12285, dvrr_stack+3051);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+142292, dvrr_stack+70529, dvrr_stack+141842, dvrr_stack+12825, dvrr_stack+70259, dvrr_stack+131534);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+142967, dvrr_stack+70979, dvrr_stack+142292, dvrr_stack+13095, dvrr_stack+70529, dvrr_stack+131894);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+143912, dvrr_stack+71654, dvrr_stack+142967, dvrr_stack+13995, dvrr_stack+70979, dvrr_stack+132434);
 tmp = dvrr_stack + 143912;
 target_ptr = Libderiv->dvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+145172,dvrr_stack+143912,dvrr_stack+133190,28);


 /* compute (6 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+148196,dvrr_stack+145172,dvrr_stack+134198,28);


 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,784,dvrr_stack+152900, dvrr_stack+148196, dvrr_stack+128986);

 /* compute (1 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12690, dvrr_stack+5652, dvrr_stack+31642, NULL, NULL, dvrr_stack+12240);

 /* compute (2 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12855, dvrr_stack+11655, dvrr_stack+12690, dvrr_stack+2691, dvrr_stack+5652, dvrr_stack+5976);

 /* compute (3 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+155252, dvrr_stack+80159, dvrr_stack+12855, dvrr_stack+21335, dvrr_stack+11655, dvrr_stack+6111);

 /* compute (4 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+155802, dvrr_stack+80489, dvrr_stack+155252, dvrr_stack+21500, dvrr_stack+80159, dvrr_stack+141842);

 /* compute (5 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+156627, dvrr_stack+81039, dvrr_stack+155802, dvrr_stack+21830, dvrr_stack+80489, dvrr_stack+142292);

 /* compute (6 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+157782, dvrr_stack+81864, dvrr_stack+156627, dvrr_stack+22930, dvrr_stack+81039, dvrr_stack+142967);
 tmp = dvrr_stack + 157782;
 target_ptr = Libderiv->dvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+159322,dvrr_stack+157782,dvrr_stack+143912,28);


 /* compute (6 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+163102,dvrr_stack+159322,dvrr_stack+145172,28);


 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1008,dvrr_stack+169150, dvrr_stack+163102, dvrr_stack+133190);

 /* compute (1 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+21335, dvrr_stack+31498, dvrr_stack+30789, NULL, NULL, dvrr_stack+31642);

 /* compute (2 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+21533, dvrr_stack+20070, dvrr_stack+21335, dvrr_stack+32158, dvrr_stack+31498, dvrr_stack+12690);

 /* compute (3 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+172174, dvrr_stack+92658, dvrr_stack+21533, dvrr_stack+32224, dvrr_stack+20070, dvrr_stack+12855);

 /* compute (4 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+172834, dvrr_stack+93054, dvrr_stack+172174, dvrr_stack+32422, dvrr_stack+92658, dvrr_stack+155252);

 /* compute (5 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+173824, dvrr_stack+93714, dvrr_stack+172834, dvrr_stack+32818, dvrr_stack+93054, dvrr_stack+155802);

 /* compute (6 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+175210, dvrr_stack+94704, dvrr_stack+173824, dvrr_stack+34138, dvrr_stack+93714, dvrr_stack+156627);

 /* compute (6 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+177058,dvrr_stack+175210,dvrr_stack+157782,28);


 /* compute (6 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+181678,dvrr_stack+177058,dvrr_stack+159322,28);


 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1260,dvrr_stack+189238, dvrr_stack+181678, dvrr_stack+143912);

 /* compute (0 0 | 1 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+21929, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+30640, dvrr_stack+21929, Data->F+15, Data->F+16, NULL);

 /* compute (0 0 | 3 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+21932, dvrr_stack+30643, dvrr_stack+6, dvrr_stack+5292, dvrr_stack+30640, NULL);

 /* compute (0 0 | 4 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+21942, dvrr_stack+39, dvrr_stack+21932, dvrr_stack+806, dvrr_stack+30643, NULL);

 /* compute (0 0 | 5 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+5274, dvrr_stack+207, dvrr_stack+21942, dvrr_stack+30904, dvrr_stack+39, NULL);

 /* compute (0 0 | 6 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+21957, dvrr_stack+30649, dvrr_stack+5274, dvrr_stack+30914, dvrr_stack+207, NULL);

 /* compute (0 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+21985, dvrr_stack+30670, dvrr_stack+21957, dvrr_stack+30929, dvrr_stack+30649, NULL);

 /* compute (0 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1140, dvrr_stack+30698, dvrr_stack+21985, dvrr_stack+30950, dvrr_stack+30670, NULL);

 /* compute (0 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+22021, dvrr_stack+237, dvrr_stack+1140, dvrr_stack+30978, dvrr_stack+30698, NULL);

 /* compute (0 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+22076, dvrr_stack+30734, dvrr_stack+22021, dvrr_stack+31014, dvrr_stack+237, NULL);

 /* compute (0 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+22142, dvrr_stack+30789, dvrr_stack+22076, dvrr_stack+31642, dvrr_stack+30734, NULL);

 /* compute (1 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+13185, dvrr_stack+31564, dvrr_stack+22142, NULL, NULL, dvrr_stack+30789);

 /* compute (2 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32110, dvrr_stack+31059, dvrr_stack+13185, dvrr_stack+32032, dvrr_stack+31564, dvrr_stack+21335);

 /* compute (3 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32578, dvrr_stack+108060, dvrr_stack+32110, dvrr_stack+45082, dvrr_stack+31059, dvrr_stack+21533);

 /* compute (4 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+193018, dvrr_stack+108528, dvrr_stack+32578, dvrr_stack+45316, dvrr_stack+108060, dvrr_stack+172174);

 /* compute (5 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+194188, dvrr_stack+109308, dvrr_stack+193018, dvrr_stack+45784, dvrr_stack+108528, dvrr_stack+172834);

 /* compute (6 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+195826, dvrr_stack+110478, dvrr_stack+194188, dvrr_stack+47344, dvrr_stack+109308, dvrr_stack+173824);

 /* compute (6 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+198010,dvrr_stack+195826,dvrr_stack+175210,28);


 /* compute (6 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+203554,dvrr_stack+198010,dvrr_stack+177058,28);


 /* compute (6 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1540,dvrr_stack+212794, dvrr_stack+203554, dvrr_stack+157782);

 /* compute (1 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+22220, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+22223, dvrr_stack+46564, dvrr_stack+22220, Data->F+5, Data->F+6, NULL);

 /* compute (1 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+22229, dvrr_stack+68, dvrr_stack+361, NULL, NULL, Data->F+7);

 /* compute (2 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+22238, dvrr_stack+46567, dvrr_stack+22229, dvrr_stack+3, dvrr_stack+68, dvrr_stack+22220);

 /* compute (3 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+22256, dvrr_stack+46576, dvrr_stack+22238, dvrr_stack+43678, dvrr_stack+46567, dvrr_stack+22223);

 /* compute (1 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+22286, dvrr_stack+364, dvrr_stack+1085, NULL, NULL, dvrr_stack+361);

 /* compute (2 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+22304, dvrr_stack+46594, dvrr_stack+22286, dvrr_stack+71, dvrr_stack+364, dvrr_stack+22229);

 /* compute (3 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+2691, dvrr_stack+46612, dvrr_stack+22304, dvrr_stack+1185, dvrr_stack+46594, dvrr_stack+22238);

 /* compute (4 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+13419, dvrr_stack+46648, dvrr_stack+2691, dvrr_stack+43687, dvrr_stack+46612, dvrr_stack+22256);

 /* compute (1 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+71, dvrr_stack+1329, dvrr_stack+902, NULL, NULL, dvrr_stack+1085);

 /* compute (2 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+6381, dvrr_stack+46708, dvrr_stack+71, dvrr_stack+370, dvrr_stack+1329, dvrr_stack+22286);

 /* compute (3 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+6441, dvrr_stack+46738, dvrr_stack+6381, dvrr_stack+43723, dvrr_stack+46708, dvrr_stack+22304);

 /* compute (4 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+3267, dvrr_stack+46798, dvrr_stack+6441, dvrr_stack+43753, dvrr_stack+46738, dvrr_stack+2691);

 /* compute (5 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+45008, dvrr_stack+46898, dvrr_stack+3267, dvrr_stack+44380, dvrr_stack+46798, dvrr_stack+13419);

 /* compute (1 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+43723, dvrr_stack+222, dvrr_stack+2430, NULL, NULL, dvrr_stack+902);

 /* compute (2 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+6541, dvrr_stack+47048, dvrr_stack+43723, dvrr_stack+1339, dvrr_stack+222, dvrr_stack+71);

 /* compute (3 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+1606, dvrr_stack+47093, dvrr_stack+6541, dvrr_stack+43813, dvrr_stack+47048, dvrr_stack+6381);

 /* compute (4 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+45218, dvrr_stack+47183, dvrr_stack+1606, dvrr_stack+44480, dvrr_stack+47093, dvrr_stack+6441);

 /* compute (5 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+45443, dvrr_stack+43858, dvrr_stack+45218, dvrr_stack+44570, dvrr_stack+47183, dvrr_stack+3267);

 /* compute (6 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+45758, dvrr_stack+31697, dvrr_stack+45443, dvrr_stack+44720, dvrr_stack+43858, dvrr_stack+45008);

 /* compute (1 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+44480, dvrr_stack+1119, dvrr_stack+5320, NULL, NULL, dvrr_stack+2430);

 /* compute (2 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+44543, dvrr_stack+380, dvrr_stack+44480, dvrr_stack+912, dvrr_stack+1119, dvrr_stack+43723);

 /* compute (3 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+46178, dvrr_stack+5148, dvrr_stack+44543, dvrr_stack+44945, dvrr_stack+380, dvrr_stack+6541);

 /* compute (4 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+217414, dvrr_stack+44083, dvrr_stack+46178, dvrr_stack+20785, dvrr_stack+5148, dvrr_stack+1606);

 /* compute (5 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+217729, dvrr_stack+20406, dvrr_stack+217414, dvrr_stack+58909, dvrr_stack+44083, dvrr_stack+45218);

 /* compute (6 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+218170, dvrr_stack+126669, dvrr_stack+217729, dvrr_stack+59119, dvrr_stack+20406, dvrr_stack+45443);

 /* compute (7 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+218758, dvrr_stack+127110, dvrr_stack+218170, dvrr_stack+59434, dvrr_stack+126669, dvrr_stack+45758);
 tmp = dvrr_stack + 218758;
 target_ptr = Libderiv->dvrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+58909, dvrr_stack+2663, dvrr_stack+11890, NULL, NULL, dvrr_stack+5320);

 /* compute (2 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+58993, dvrr_stack+1354, dvrr_stack+58909, dvrr_stack+2445, dvrr_stack+2663, dvrr_stack+44480);

 /* compute (3 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+20721, dvrr_stack+1438, dvrr_stack+58993, dvrr_stack+812, dvrr_stack+1354, dvrr_stack+44543);

 /* compute (4 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+219514, dvrr_stack+127698, dvrr_stack+20721, dvrr_stack+59875, dvrr_stack+1438, dvrr_stack+46178);

 /* compute (5 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+219934, dvrr_stack+127978, dvrr_stack+219514, dvrr_stack+60043, dvrr_stack+127698, dvrr_stack+217414);

 /* compute (6 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+220522, dvrr_stack+128398, dvrr_stack+219934, dvrr_stack+60323, dvrr_stack+127978, dvrr_stack+217729);

 /* compute (7 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+221306, dvrr_stack+128986, dvrr_stack+220522, dvrr_stack+60743, dvrr_stack+128398, dvrr_stack+218170);
 tmp = dvrr_stack + 221306;
 target_ptr = Libderiv->dvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+222314,dvrr_stack+221306,dvrr_stack+218758,36);


 /* compute (1 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+59875, dvrr_stack+5616, dvrr_stack+20370, NULL, NULL, dvrr_stack+11890);

 /* compute (2 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+59983, dvrr_stack+2943, dvrr_stack+59875, dvrr_stack+5341, dvrr_stack+5616, dvrr_stack+58909);

 /* compute (3 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+60199, dvrr_stack+3051, dvrr_stack+59983, dvrr_stack+2299, dvrr_stack+2943, dvrr_stack+58993);

 /* compute (4 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+224582, dvrr_stack+131534, dvrr_stack+60199, dvrr_stack+62654, dvrr_stack+3051, dvrr_stack+20721);

 /* compute (5 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+225122, dvrr_stack+131894, dvrr_stack+224582, dvrr_stack+62870, dvrr_stack+131534, dvrr_stack+219514);

 /* compute (6 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+225878, dvrr_stack+132434, dvrr_stack+225122, dvrr_stack+63230, dvrr_stack+131894, dvrr_stack+219934);

 /* compute (7 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+226886, dvrr_stack+133190, dvrr_stack+225878, dvrr_stack+63770, dvrr_stack+132434, dvrr_stack+220522);
 tmp = dvrr_stack + 226886;
 target_ptr = Libderiv->dvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+228182,dvrr_stack+226886,dvrr_stack+221306,36);


 /* compute (7 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+231206,dvrr_stack+228182,dvrr_stack+222314,36);


 /* compute (7 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,756,dvrr_stack+235742, dvrr_stack+231206, dvrr_stack+218758);

 /* compute (1 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+62654, dvrr_stack+12240, dvrr_stack+31014, NULL, NULL, dvrr_stack+20370);

 /* compute (2 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+62789, dvrr_stack+5976, dvrr_stack+62654, dvrr_stack+11918, dvrr_stack+12240, dvrr_stack+59875);

 /* compute (3 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+63059, dvrr_stack+6111, dvrr_stack+62789, dvrr_stack+12285, dvrr_stack+5976, dvrr_stack+59983);

 /* compute (4 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+238010, dvrr_stack+141842, dvrr_stack+63059, dvrr_stack+70259, dvrr_stack+6111, dvrr_stack+60199);

 /* compute (5 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+238685, dvrr_stack+142292, dvrr_stack+238010, dvrr_stack+70529, dvrr_stack+141842, dvrr_stack+224582);

 /* compute (6 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+239630, dvrr_stack+142967, dvrr_stack+238685, dvrr_stack+70979, dvrr_stack+142292, dvrr_stack+225122);

 /* compute (7 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+240890, dvrr_stack+143912, dvrr_stack+239630, dvrr_stack+71654, dvrr_stack+142967, dvrr_stack+225878);
 tmp = dvrr_stack + 240890;
 target_ptr = Libderiv->dvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+242510,dvrr_stack+240890,dvrr_stack+226886,36);


 /* compute (7 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+246398,dvrr_stack+242510,dvrr_stack+228182,36);


 /* compute (7 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1008,dvrr_stack+252446, dvrr_stack+246398, dvrr_stack+221306);

 /* compute (1 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+70259, dvrr_stack+31642, dvrr_stack+30734, NULL, NULL, dvrr_stack+31014);

 /* compute (2 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+70424, dvrr_stack+12690, dvrr_stack+70259, dvrr_stack+5652, dvrr_stack+31642, dvrr_stack+62654);

 /* compute (3 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+70754, dvrr_stack+12855, dvrr_stack+70424, dvrr_stack+11655, dvrr_stack+12690, dvrr_stack+62789);

 /* compute (4 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+255470, dvrr_stack+155252, dvrr_stack+70754, dvrr_stack+80159, dvrr_stack+12855, dvrr_stack+63059);

 /* compute (5 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+256295, dvrr_stack+155802, dvrr_stack+255470, dvrr_stack+80489, dvrr_stack+155252, dvrr_stack+238010);

 /* compute (6 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+257450, dvrr_stack+156627, dvrr_stack+256295, dvrr_stack+81039, dvrr_stack+155802, dvrr_stack+238685);

 /* compute (7 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+258990, dvrr_stack+157782, dvrr_stack+257450, dvrr_stack+81864, dvrr_stack+156627, dvrr_stack+239630);

 /* compute (7 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+260970,dvrr_stack+258990,dvrr_stack+240890,36);


 /* compute (7 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+265830,dvrr_stack+260970,dvrr_stack+242510,36);


 /* compute (7 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1296,dvrr_stack+273606, dvrr_stack+265830, dvrr_stack+226886);

 /* compute (1 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+80159, dvrr_stack+30789, dvrr_stack+22076, NULL, NULL, dvrr_stack+30734);

 /* compute (2 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+80357, dvrr_stack+21335, dvrr_stack+80159, dvrr_stack+31498, dvrr_stack+30789, dvrr_stack+70259);

 /* compute (3 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+80753, dvrr_stack+21533, dvrr_stack+80357, dvrr_stack+20070, dvrr_stack+21335, dvrr_stack+70424);

 /* compute (4 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+277494, dvrr_stack+172174, dvrr_stack+80753, dvrr_stack+92658, dvrr_stack+21533, dvrr_stack+70754);

 /* compute (5 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+278484, dvrr_stack+172834, dvrr_stack+277494, dvrr_stack+93054, dvrr_stack+172174, dvrr_stack+255470);

 /* compute (6 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+279870, dvrr_stack+173824, dvrr_stack+278484, dvrr_stack+93714, dvrr_stack+172834, dvrr_stack+256295);

 /* compute (7 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+281718, dvrr_stack+175210, dvrr_stack+279870, dvrr_stack+94704, dvrr_stack+173824, dvrr_stack+257450);

 /* compute (7 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+284094,dvrr_stack+281718,dvrr_stack+258990,36);


 /* compute (7 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+290034,dvrr_stack+284094,dvrr_stack+260970,36);


 /* compute (7 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1620,dvrr_stack+299754, dvrr_stack+290034, dvrr_stack+240890);

 /* compute (0 0 | 1 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+17, Data->F+18, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+92658, dvrr_stack+21929, dvrr_stack+3, Data->F+16, Data->F+17, NULL);

 /* compute (0 0 | 3 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+370, dvrr_stack+6, dvrr_stack+92658, dvrr_stack+30640, dvrr_stack+21929, NULL);

 /* compute (0 0 | 4 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1339, dvrr_stack+21932, dvrr_stack+370, dvrr_stack+30643, dvrr_stack+6, NULL);

 /* compute (0 0 | 5 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+92658, dvrr_stack+21942, dvrr_stack+1339, dvrr_stack+39, dvrr_stack+21932, NULL);

 /* compute (0 0 | 6 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+92679, dvrr_stack+5274, dvrr_stack+92658, dvrr_stack+207, dvrr_stack+21942, NULL);

 /* compute (0 0 | 7 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+13509, dvrr_stack+21957, dvrr_stack+92679, dvrr_stack+30649, dvrr_stack+5274, NULL);

 /* compute (0 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+92658, dvrr_stack+21985, dvrr_stack+13509, dvrr_stack+30670, dvrr_stack+21957, NULL);

 /* compute (0 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+92703, dvrr_stack+1140, dvrr_stack+92658, dvrr_stack+30698, dvrr_stack+21985, NULL);

 /* compute (0 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+92758, dvrr_stack+22021, dvrr_stack+92703, dvrr_stack+237, dvrr_stack+1140, NULL);

 /* compute (0 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+92824, dvrr_stack+22076, dvrr_stack+92758, dvrr_stack+30734, dvrr_stack+22021, NULL);

 /* compute (1 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+92902, dvrr_stack+22142, dvrr_stack+92824, NULL, NULL, dvrr_stack+22076);

 /* compute (2 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+93136, dvrr_stack+13185, dvrr_stack+92902, dvrr_stack+31564, dvrr_stack+22142, dvrr_stack+80159);

 /* compute (3 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+93604, dvrr_stack+32110, dvrr_stack+93136, dvrr_stack+31059, dvrr_stack+13185, dvrr_stack+80357);

 /* compute (4 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+304614, dvrr_stack+32578, dvrr_stack+93604, dvrr_stack+108060, dvrr_stack+32110, dvrr_stack+80753);

 /* compute (5 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+92824, dvrr_stack+193018, dvrr_stack+304614, dvrr_stack+108528, dvrr_stack+32578, dvrr_stack+277494);

 /* compute (6 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+304614, dvrr_stack+194188, dvrr_stack+92824, dvrr_stack+109308, dvrr_stack+193018, dvrr_stack+278484);

 /* compute (7 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+306798, dvrr_stack+195826, dvrr_stack+304614, dvrr_stack+110478, dvrr_stack+194188, dvrr_stack+279870);

 /* compute (7 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+309606,dvrr_stack+306798,dvrr_stack+281718,36);


 /* compute (7 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+316734,dvrr_stack+309606,dvrr_stack+284094,36);


 /* compute (7 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1980,dvrr_stack+328614, dvrr_stack+316734, dvrr_stack+258990);

 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,315,dvrr_stack+304614, dvrr_stack+8820, dvrr_stack+1984);

 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,420,dvrr_stack+193018, dvrr_stack+16290, dvrr_stack+3783);

 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,540,dvrr_stack+92824, dvrr_stack+25780, dvrr_stack+7020);

 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,675,dvrr_stack+108060, dvrr_stack+37603, dvrr_stack+13995);

 /* compute (4 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,825,dvrr_stack+334554, dvrr_stack+51484, dvrr_stack+22930);

 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,441,dvrr_stack+194278, dvrr_stack+66290, dvrr_stack+59434);

 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,588,dvrr_stack+337029, dvrr_stack+74867, dvrr_stack+60743);

 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,756,dvrr_stack+338793, dvrr_stack+85854, dvrr_stack+63770);

 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,945,dvrr_stack+341061, dvrr_stack+99555, dvrr_stack+71654);

 /* compute (5 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1155,dvrr_stack+343896, dvrr_stack+116274, dvrr_stack+81864);

 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,588,dvrr_stack+347361, dvrr_stack+136550, dvrr_stack+127110);

 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,784,dvrr_stack+349125, dvrr_stack+148196, dvrr_stack+128986);

 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1008,dvrr_stack+351477, dvrr_stack+163102, dvrr_stack+133190);

 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1260,dvrr_stack+354501, dvrr_stack+181678, dvrr_stack+143912);

 /* compute (6 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1540,dvrr_stack+358281, dvrr_stack+203554, dvrr_stack+157782);

 /* compute (7 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,756,dvrr_stack+362901, dvrr_stack+231206, dvrr_stack+218758);

 /* compute (7 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1008,dvrr_stack+365169, dvrr_stack+246398, dvrr_stack+221306);

 /* compute (7 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1296,dvrr_stack+368193, dvrr_stack+265830, dvrr_stack+226886);

 /* compute (7 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1620,dvrr_stack+372081, dvrr_stack+290034, dvrr_stack+240890);

 /* compute (7 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1980,dvrr_stack+376941, dvrr_stack+316734, dvrr_stack+258990);

 /* compute (4 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,315,dvrr_stack+305559, dvrr_stack+8820, dvrr_stack+1984);

 /* compute (4 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,420,dvrr_stack+8820, dvrr_stack+16290, dvrr_stack+3783);

 /* compute (4 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,540,dvrr_stack+16290, dvrr_stack+25780, dvrr_stack+7020);

 /* compute (4 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,675,dvrr_stack+25780, dvrr_stack+37603, dvrr_stack+13995);

 /* compute (4 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,825,dvrr_stack+37603, dvrr_stack+51484, dvrr_stack+22930);

 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,441,dvrr_stack+51484, dvrr_stack+66290, dvrr_stack+59434);

 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,588,dvrr_stack+66290, dvrr_stack+74867, dvrr_stack+60743);

 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,756,dvrr_stack+74867, dvrr_stack+85854, dvrr_stack+63770);

 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,945,dvrr_stack+85854, dvrr_stack+99555, dvrr_stack+71654);

 /* compute (5 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1155,dvrr_stack+99555, dvrr_stack+116274, dvrr_stack+81864);

 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,588,dvrr_stack+116274, dvrr_stack+136550, dvrr_stack+127110);

 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,784,dvrr_stack+136550, dvrr_stack+148196, dvrr_stack+128986);

 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1008,dvrr_stack+148196, dvrr_stack+163102, dvrr_stack+133190);

 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1260,dvrr_stack+163102, dvrr_stack+181678, dvrr_stack+143912);

 /* compute (6 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1540,dvrr_stack+181678, dvrr_stack+203554, dvrr_stack+157782);

 /* compute (7 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,756,dvrr_stack+166882, dvrr_stack+231206, dvrr_stack+218758);

 /* compute (7 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1008,dvrr_stack+231206, dvrr_stack+246398, dvrr_stack+221306);

 /* compute (7 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1296,dvrr_stack+246398, dvrr_stack+265830, dvrr_stack+226886);

 /* compute (7 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1620,dvrr_stack+265830, dvrr_stack+290034, dvrr_stack+240890);

 /* compute (7 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1980,dvrr_stack+290034, dvrr_stack+316734, dvrr_stack+258990);

 /* compute (1 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+3, dvrr_stack+12, dvrr_stack+0, NULL, NULL, Data->F+4);

 /* compute (1 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+1185, dvrr_stack+52, dvrr_stack+15, NULL, NULL, dvrr_stack+12);

 /* compute (2 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+13509, dvrr_stack+1185, dvrr_stack+21, dvrr_stack+52, dvrr_stack+15, dvrr_stack+3);

 /* compute (1 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+316734, dvrr_stack+291, dvrr_stack+58, NULL, NULL, dvrr_stack+52);

 /* compute (2 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+316764, dvrr_stack+316734, dvrr_stack+117, dvrr_stack+291, dvrr_stack+58, dvrr_stack+1185);

 /* compute (3 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+316824, dvrr_stack+316764, dvrr_stack+147, dvrr_stack+316734, dvrr_stack+117, dvrr_stack+13509);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+92658, dvrr_stack+1104, dvrr_stack+301, NULL, NULL, dvrr_stack+291);

 /* compute (2 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+43768, dvrr_stack+92658, dvrr_stack+316, dvrr_stack+1104, dvrr_stack+301, dvrr_stack+316734);

 /* compute (3 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+316924, dvrr_stack+43768, dvrr_stack+530, dvrr_stack+92658, dvrr_stack+316, dvrr_stack+316764);

 /* compute (4 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+195601, dvrr_stack+316924, dvrr_stack+620, dvrr_stack+43768, dvrr_stack+530, dvrr_stack+316824);

 /* compute (4 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+317074,dvrr_stack+1984,dvrr_stack+195601,15);


 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,225,dvrr_stack+317749, dvrr_stack+317074, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+317974, dvrr_stack+7560, NULL);
 tmp = dvrr_stack + 317974;
 target_ptr = Libderiv->deriv_classes[4][6][11];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+318394, dvrr_stack+4203, NULL);
 tmp = dvrr_stack + 318394;
 target_ptr = Libderiv->deriv_classes[4][5][11];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,540,dvrr_stack+318709, dvrr_stack+14670, NULL);
 tmp = dvrr_stack + 318709;
 target_ptr = Libderiv->deriv_classes[4][7][11];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,675,dvrr_stack+319249, dvrr_stack+23755, NULL);
 tmp = dvrr_stack + 319249;
 target_ptr = Libderiv->deriv_classes[4][8][11];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,825,dvrr_stack+319924, dvrr_stack+35128, NULL);
 tmp = dvrr_stack + 319924;
 target_ptr = Libderiv->deriv_classes[4][9][11];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,990,dvrr_stack+320749, dvrr_stack+48514, NULL);

 /* compute (1 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+43768, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (2 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+1756, dvrr_stack+3, dvrr_stack+43678, dvrr_stack+12, dvrr_stack+0, dvrr_stack+43768);

 /* compute (3 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+301, dvrr_stack+13509, dvrr_stack+43687, dvrr_stack+1185, dvrr_stack+21, dvrr_stack+1756);

 /* compute (4 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+321739, dvrr_stack+316824, dvrr_stack+44380, dvrr_stack+316764, dvrr_stack+147, dvrr_stack+301);

 /* compute (5 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+321889, dvrr_stack+195601, dvrr_stack+44720, dvrr_stack+316924, dvrr_stack+620, dvrr_stack+321739);

 /* compute (5 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+322204,dvrr_stack+59434,dvrr_stack+321889,21);


 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+323149, dvrr_stack+322204, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+323464, dvrr_stack+64526, NULL);
 tmp = dvrr_stack + 323464;
 target_ptr = Libderiv->deriv_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,441,dvrr_stack+324052, dvrr_stack+61331, NULL);
 tmp = dvrr_stack + 324052;
 target_ptr = Libderiv->deriv_classes[5][5][11];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+324493, dvrr_stack+72599, NULL);
 tmp = dvrr_stack + 324493;
 target_ptr = Libderiv->deriv_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+325249, dvrr_stack+83019, NULL);
 tmp = dvrr_stack + 325249;
 target_ptr = Libderiv->deriv_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+326194, dvrr_stack+96090, NULL);
 tmp = dvrr_stack + 326194;
 target_ptr = Libderiv->deriv_classes[5][9][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+295974, dvrr_stack+112116, NULL);

 /* compute (2 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+43771, dvrr_stack+43768, dvrr_stack+46564, Data->F+4, Data->F+5, NULL);

 /* compute (3 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+43777, dvrr_stack+1756, dvrr_stack+46576, dvrr_stack+3, dvrr_stack+43678, dvrr_stack+43771);

 /* compute (4 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+327349, dvrr_stack+301, dvrr_stack+46648, dvrr_stack+13509, dvrr_stack+43687, dvrr_stack+43777);

 /* compute (5 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+327439, dvrr_stack+321739, dvrr_stack+46898, dvrr_stack+316824, dvrr_stack+44380, dvrr_stack+327349);

 /* compute (6 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+327649, dvrr_stack+321889, dvrr_stack+31697, dvrr_stack+195601, dvrr_stack+44720, dvrr_stack+327439);

 /* compute (6 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+77135,dvrr_stack+127110,dvrr_stack+327649,28);


 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+328069, dvrr_stack+77135, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,784,dvrr_stack+297360, dvrr_stack+134198, NULL);
 tmp = dvrr_stack + 297360;
 target_ptr = Libderiv->deriv_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+298144, dvrr_stack+129770, NULL);
 tmp = dvrr_stack + 298144;
 target_ptr = Libderiv->deriv_classes[6][5][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+298732, dvrr_stack+145172, NULL);
 tmp = dvrr_stack + 298732;
 target_ptr = Libderiv->deriv_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+270690, dvrr_stack+159322, NULL);
 tmp = dvrr_stack + 270690;
 target_ptr = Libderiv->deriv_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+271950, dvrr_stack+177058, NULL);
 tmp = dvrr_stack + 271950;
 target_ptr = Libderiv->deriv_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+250286, dvrr_stack+198010, NULL);

 /* compute (3 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+58, dvrr_stack+43771, dvrr_stack+22223, dvrr_stack+43768, dvrr_stack+46564, NULL);

 /* compute (4 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+43678, dvrr_stack+43777, dvrr_stack+22256, dvrr_stack+1756, dvrr_stack+46576, dvrr_stack+58);

 /* compute (5 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+252134, dvrr_stack+327349, dvrr_stack+13419, dvrr_stack+301, dvrr_stack+46648, dvrr_stack+43678);

 /* compute (6 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+234230, dvrr_stack+327439, dvrr_stack+45008, dvrr_stack+321739, dvrr_stack+46898, dvrr_stack+252134);

 /* compute (7 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+234510, dvrr_stack+327649, dvrr_stack+45758, dvrr_stack+321889, dvrr_stack+31697, dvrr_stack+234230);

 /* compute (7 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+203554,dvrr_stack+218758,dvrr_stack+234510,36);


 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,540,dvrr_stack+235050, dvrr_stack+203554, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+205174, dvrr_stack+228182, NULL);
 tmp = dvrr_stack + 205174;
 target_ptr = Libderiv->deriv_classes[7][6][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+206182, dvrr_stack+222314, NULL);
 tmp = dvrr_stack + 206182;
 target_ptr = Libderiv->deriv_classes[7][5][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+206938, dvrr_stack+242510, NULL);
 tmp = dvrr_stack + 206938;
 target_ptr = Libderiv->deriv_classes[7][7][11];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+208234, dvrr_stack+260970, NULL);
 tmp = dvrr_stack + 208234;
 target_ptr = Libderiv->deriv_classes[7][8][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+209854, dvrr_stack+284094, NULL);
 tmp = dvrr_stack + 209854;
 target_ptr = Libderiv->deriv_classes[7][9][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+186298, dvrr_stack+309606, NULL);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,225,dvrr_stack+211834, dvrr_stack+317074, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+212059, dvrr_stack+7560, NULL);
 tmp = dvrr_stack + 212059;
 target_ptr = Libderiv->deriv_classes[4][6][10];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+212479, dvrr_stack+4203, NULL);
 tmp = dvrr_stack + 212479;
 target_ptr = Libderiv->deriv_classes[4][5][10];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+188674, dvrr_stack+14670, NULL);
 tmp = dvrr_stack + 188674;
 target_ptr = Libderiv->deriv_classes[4][7][10];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+151220, dvrr_stack+23755, NULL);
 tmp = dvrr_stack + 151220;
 target_ptr = Libderiv->deriv_classes[4][8][10];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+151895, dvrr_stack+35128, NULL);
 tmp = dvrr_stack + 151895;
 target_ptr = Libderiv->deriv_classes[4][9][10];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,990,dvrr_stack+138902, dvrr_stack+48514, NULL);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+118038, dvrr_stack+322204, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+118353, dvrr_stack+64526, NULL);
 tmp = dvrr_stack + 118353;
 target_ptr = Libderiv->deriv_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+118941, dvrr_stack+61331, NULL);
 tmp = dvrr_stack + 118941;
 target_ptr = Libderiv->deriv_classes[5][5][10];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+119382, dvrr_stack+72599, NULL);
 tmp = dvrr_stack + 119382;
 target_ptr = Libderiv->deriv_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+120138, dvrr_stack+83019, NULL);
 tmp = dvrr_stack + 120138;
 target_ptr = Libderiv->deriv_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+121083, dvrr_stack+96090, NULL);
 tmp = dvrr_stack + 121083;
 target_ptr = Libderiv->deriv_classes[5][9][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+103020, dvrr_stack+112116, NULL);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+122238, dvrr_stack+77135, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+104406, dvrr_stack+134198, NULL);
 tmp = dvrr_stack + 104406;
 target_ptr = Libderiv->deriv_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+88689, dvrr_stack+129770, NULL);
 tmp = dvrr_stack + 88689;
 target_ptr = Libderiv->deriv_classes[6][5][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+89277, dvrr_stack+145172, NULL);
 tmp = dvrr_stack + 89277;
 target_ptr = Libderiv->deriv_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+52807, dvrr_stack+159322, NULL);
 tmp = dvrr_stack + 52807;
 target_ptr = Libderiv->deriv_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+54067, dvrr_stack+177058, NULL);
 tmp = dvrr_stack + 54067;
 target_ptr = Libderiv->deriv_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+382881, dvrr_stack+198010, NULL);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+122658, dvrr_stack+203554, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+40078, dvrr_stack+228182, NULL);
 tmp = dvrr_stack + 40078;
 target_ptr = Libderiv->deriv_classes[7][6][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+68054, dvrr_stack+222314, NULL);
 tmp = dvrr_stack + 68054;
 target_ptr = Libderiv->deriv_classes[7][5][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+32012, dvrr_stack+242510, NULL);
 tmp = dvrr_stack + 32012;
 target_ptr = Libderiv->deriv_classes[7][7][10];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+384729, dvrr_stack+260970, NULL);
 tmp = dvrr_stack + 384729;
 target_ptr = Libderiv->deriv_classes[7][8][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+386349, dvrr_stack+284094, NULL);
 tmp = dvrr_stack + 386349;
 target_ptr = Libderiv->deriv_classes[7][9][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+388329, dvrr_stack+309606, NULL);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,225,dvrr_stack+55607, dvrr_stack+317074, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+317074, dvrr_stack+7560, NULL);
 tmp = dvrr_stack + 317074;
 target_ptr = Libderiv->deriv_classes[4][6][9];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+7560, dvrr_stack+4203, NULL);
 tmp = dvrr_stack + 7560;
 target_ptr = Libderiv->deriv_classes[4][5][9];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+4203, dvrr_stack+14670, NULL);
 tmp = dvrr_stack + 4203;
 target_ptr = Libderiv->deriv_classes[4][7][9];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+14670, dvrr_stack+23755, NULL);
 tmp = dvrr_stack + 14670;
 target_ptr = Libderiv->deriv_classes[4][8][9];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+23755, dvrr_stack+35128, NULL);
 tmp = dvrr_stack + 23755;
 target_ptr = Libderiv->deriv_classes[4][9][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,990,dvrr_stack+35128, dvrr_stack+48514, NULL);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+48514, dvrr_stack+322204, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+322204, dvrr_stack+64526, NULL);
 tmp = dvrr_stack + 322204;
 target_ptr = Libderiv->deriv_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+64526, dvrr_stack+61331, NULL);
 tmp = dvrr_stack + 64526;
 target_ptr = Libderiv->deriv_classes[5][5][9];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+61331, dvrr_stack+72599, NULL);
 tmp = dvrr_stack + 61331;
 target_ptr = Libderiv->deriv_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+15345, dvrr_stack+83019, NULL);
 tmp = dvrr_stack + 15345;
 target_ptr = Libderiv->deriv_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+83019, dvrr_stack+96090, NULL);
 tmp = dvrr_stack + 83019;
 target_ptr = Libderiv->deriv_classes[5][9][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+96090, dvrr_stack+112116, NULL);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+112116, dvrr_stack+77135, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+77135, dvrr_stack+134198, NULL);
 tmp = dvrr_stack + 77135;
 target_ptr = Libderiv->deriv_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+134198, dvrr_stack+129770, NULL);
 tmp = dvrr_stack + 134198;
 target_ptr = Libderiv->deriv_classes[6][5][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+129770, dvrr_stack+145172, NULL);
 tmp = dvrr_stack + 129770;
 target_ptr = Libderiv->deriv_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+145172, dvrr_stack+159322, NULL);
 tmp = dvrr_stack + 145172;
 target_ptr = Libderiv->deriv_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+159322, dvrr_stack+177058, NULL);
 tmp = dvrr_stack + 159322;
 target_ptr = Libderiv->deriv_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+177058, dvrr_stack+198010, NULL);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+198010, dvrr_stack+203554, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+198550, dvrr_stack+228182, NULL);
 tmp = dvrr_stack + 198550;
 target_ptr = Libderiv->deriv_classes[7][6][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+130778, dvrr_stack+222314, NULL);
 tmp = dvrr_stack + 130778;
 target_ptr = Libderiv->deriv_classes[7][5][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+222314, dvrr_stack+242510, NULL);
 tmp = dvrr_stack + 222314;
 target_ptr = Libderiv->deriv_classes[7][7][9];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+242510, dvrr_stack+260970, NULL);
 tmp = dvrr_stack + 242510;
 target_ptr = Libderiv->deriv_classes[7][8][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+260970, dvrr_stack+284094, NULL);
 tmp = dvrr_stack + 260970;
 target_ptr = Libderiv->deriv_classes[7][9][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+284094, dvrr_stack+309606, NULL);

 /* compute (1 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+309606, dvrr_stack+49, dvrr_stack+12, NULL, NULL, Data->F+3);

 /* compute (2 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+309615, dvrr_stack+309606, dvrr_stack+3, dvrr_stack+49, dvrr_stack+12, dvrr_stack+0);

 /* compute (1 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+12, dvrr_stack+285, dvrr_stack+52, NULL, NULL, dvrr_stack+49);

 /* compute (2 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+309633, dvrr_stack+12, dvrr_stack+1185, dvrr_stack+285, dvrr_stack+52, dvrr_stack+309606);

 /* compute (3 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+309669, dvrr_stack+309633, dvrr_stack+13509, dvrr_stack+12, dvrr_stack+1185, dvrr_stack+309615);

 /* compute (1 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+309729, dvrr_stack+1094, dvrr_stack+291, NULL, NULL, dvrr_stack+285);

 /* compute (2 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+309759, dvrr_stack+309729, dvrr_stack+316734, dvrr_stack+1094, dvrr_stack+291, dvrr_stack+12);

 /* compute (3 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+309819, dvrr_stack+309759, dvrr_stack+316764, dvrr_stack+309729, dvrr_stack+316734, dvrr_stack+309633);

 /* compute (4 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+309919, dvrr_stack+309819, dvrr_stack+316824, dvrr_stack+309759, dvrr_stack+316764, dvrr_stack+309669);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,15,1,dvrr_stack+310069, dvrr_stack+1984, dvrr_stack+309919);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+310294, dvrr_stack+7020, dvrr_stack+1984);
 tmp = dvrr_stack + 310294;
 target_ptr = Libderiv->deriv_classes[4][6][8];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+310714, dvrr_stack+3783, dvrr_stack+195601);
 tmp = dvrr_stack + 310714;
 target_ptr = Libderiv->deriv_classes[4][5][8];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+311029, dvrr_stack+13995, dvrr_stack+3783);
 tmp = dvrr_stack + 311029;
 target_ptr = Libderiv->deriv_classes[4][7][8];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+311569, dvrr_stack+22930, dvrr_stack+7020);
 tmp = dvrr_stack + 311569;
 target_ptr = Libderiv->deriv_classes[4][8][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+312244, dvrr_stack+34138, dvrr_stack+13995);
 tmp = dvrr_stack + 312244;
 target_ptr = Libderiv->deriv_classes[4][9][8];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,15,1,dvrr_stack+313069, dvrr_stack+47344, dvrr_stack+22930);

 /* compute (2 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+123198, dvrr_stack+0, dvrr_stack+43768, Data->F+3, Data->F+4, NULL);

 /* compute (3 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+309729, dvrr_stack+309615, dvrr_stack+1756, dvrr_stack+309606, dvrr_stack+3, dvrr_stack+123198);

 /* compute (4 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+314059, dvrr_stack+309669, dvrr_stack+301, dvrr_stack+309633, dvrr_stack+13509, dvrr_stack+309729);

 /* compute (5 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+314149, dvrr_stack+309919, dvrr_stack+321739, dvrr_stack+309819, dvrr_stack+316824, dvrr_stack+314059);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,21,1,dvrr_stack+314359, dvrr_stack+59434, dvrr_stack+314149);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+314674, dvrr_stack+63770, dvrr_stack+59434);
 tmp = dvrr_stack + 314674;
 target_ptr = Libderiv->deriv_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+315262, dvrr_stack+60743, dvrr_stack+321889);
 tmp = dvrr_stack + 315262;
 target_ptr = Libderiv->deriv_classes[5][5][8];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+315703, dvrr_stack+71654, dvrr_stack+60743);
 tmp = dvrr_stack + 315703;
 target_ptr = Libderiv->deriv_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+7875, dvrr_stack+81864, dvrr_stack+63770);
 tmp = dvrr_stack + 7875;
 target_ptr = Libderiv->deriv_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+286470, dvrr_stack+94704, dvrr_stack+71654);
 tmp = dvrr_stack + 286470;
 target_ptr = Libderiv->deriv_classes[5][9][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+287625, dvrr_stack+110478, dvrr_stack+81864);

 /* compute (3 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+370, dvrr_stack+123198, dvrr_stack+43771, dvrr_stack+0, dvrr_stack+43768, NULL);

 /* compute (4 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+92658, dvrr_stack+309729, dvrr_stack+43777, dvrr_stack+309615, dvrr_stack+1756, dvrr_stack+370);

 /* compute (5 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+68810, dvrr_stack+314059, dvrr_stack+327349, dvrr_stack+309669, dvrr_stack+301, dvrr_stack+92658);

 /* compute (6 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+316459, dvrr_stack+314149, dvrr_stack+327439, dvrr_stack+309919, dvrr_stack+321739, dvrr_stack+68810);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,28,1,dvrr_stack+289011, dvrr_stack+127110, dvrr_stack+316459);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+262950, dvrr_stack+133190, dvrr_stack+127110);
 tmp = dvrr_stack + 262950;
 target_ptr = Libderiv->deriv_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+289431, dvrr_stack+128986, dvrr_stack+327649);
 tmp = dvrr_stack + 289431;
 target_ptr = Libderiv->deriv_classes[6][5][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+263734, dvrr_stack+143912, dvrr_stack+128986);
 tmp = dvrr_stack + 263734;
 target_ptr = Libderiv->deriv_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+244130, dvrr_stack+157782, dvrr_stack+133190);
 tmp = dvrr_stack + 244130;
 target_ptr = Libderiv->deriv_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+228182, dvrr_stack+175210, dvrr_stack+143912);
 tmp = dvrr_stack + 228182;
 target_ptr = Libderiv->deriv_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+199558, dvrr_stack+195826, dvrr_stack+157782);

 /* compute (4 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+290019, dvrr_stack+370, dvrr_stack+58, dvrr_stack+123198, dvrr_stack+43771, NULL);

 /* compute (5 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+321739, dvrr_stack+92658, dvrr_stack+43678, dvrr_stack+309729, dvrr_stack+43777, dvrr_stack+290019);

 /* compute (6 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+309606, dvrr_stack+68810, dvrr_stack+252134, dvrr_stack+314059, dvrr_stack+327349, dvrr_stack+321739);

 /* compute (7 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+264742, dvrr_stack+316459, dvrr_stack+234230, dvrr_stack+314149, dvrr_stack+327439, dvrr_stack+309606);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,36,1,dvrr_stack+265102, dvrr_stack+218758, dvrr_stack+264742);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+245390, dvrr_stack+226886, dvrr_stack+218758);
 tmp = dvrr_stack + 245390;
 target_ptr = Libderiv->deriv_classes[7][6][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+223610, dvrr_stack+221306, dvrr_stack+234510);
 tmp = dvrr_stack + 223610;
 target_ptr = Libderiv->deriv_classes[7][5][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+229722, dvrr_stack+240890, dvrr_stack+221306);
 tmp = dvrr_stack + 229722;
 target_ptr = Libderiv->deriv_classes[7][7][8];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+201406, dvrr_stack+258990, dvrr_stack+226886);
 tmp = dvrr_stack + 201406;
 target_ptr = Libderiv->deriv_classes[7][8][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+203026, dvrr_stack+281718, dvrr_stack+240890);
 tmp = dvrr_stack + 203026;
 target_ptr = Libderiv->deriv_classes[7][9][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+178906, dvrr_stack+306798, dvrr_stack+258990);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,15,1,dvrr_stack+309606, dvrr_stack+1984, dvrr_stack+309919);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+160862, dvrr_stack+7020, dvrr_stack+1984);
 tmp = dvrr_stack + 160862;
 target_ptr = Libderiv->deriv_classes[4][6][7];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+181282, dvrr_stack+3783, dvrr_stack+195601);
 tmp = dvrr_stack + 181282;
 target_ptr = Libderiv->deriv_classes[4][5][7];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+161282, dvrr_stack+13995, dvrr_stack+3783);
 tmp = dvrr_stack + 161282;
 target_ptr = Libderiv->deriv_classes[4][7][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+161822, dvrr_stack+22930, dvrr_stack+7020);
 tmp = dvrr_stack + 161822;
 target_ptr = Libderiv->deriv_classes[4][8][7];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+146432, dvrr_stack+34138, dvrr_stack+13995);
 tmp = dvrr_stack + 146432;
 target_ptr = Libderiv->deriv_classes[4][9][7];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,15,1,dvrr_stack+134786, dvrr_stack+47344, dvrr_stack+22930);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,21,1,dvrr_stack+162497, dvrr_stack+59434, dvrr_stack+314149);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+147257, dvrr_stack+63770, dvrr_stack+59434);
 tmp = dvrr_stack + 147257;
 target_ptr = Libderiv->deriv_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+135776, dvrr_stack+60743, dvrr_stack+321889);
 tmp = dvrr_stack + 135776;
 target_ptr = Libderiv->deriv_classes[5][5][7];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+112536, dvrr_stack+71654, dvrr_stack+60743);
 tmp = dvrr_stack + 112536;
 target_ptr = Libderiv->deriv_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+113292, dvrr_stack+81864, dvrr_stack+63770);
 tmp = dvrr_stack + 113292;
 target_ptr = Libderiv->deriv_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+114237, dvrr_stack+94704, dvrr_stack+71654);
 tmp = dvrr_stack + 114237;
 target_ptr = Libderiv->deriv_classes[5][9][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+97476, dvrr_stack+110478, dvrr_stack+81864);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,28,1,dvrr_stack+77919, dvrr_stack+127110, dvrr_stack+316459);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+115392, dvrr_stack+133190, dvrr_stack+127110);
 tmp = dvrr_stack + 115392;
 target_ptr = Libderiv->deriv_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+98862, dvrr_stack+128986, dvrr_stack+327649);
 tmp = dvrr_stack + 98862;
 target_ptr = Libderiv->deriv_classes[6][5][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+84174, dvrr_stack+143912, dvrr_stack+128986);
 tmp = dvrr_stack + 84174;
 target_ptr = Libderiv->deriv_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+72599, dvrr_stack+157782, dvrr_stack+133190);
 tmp = dvrr_stack + 72599;
 target_ptr = Libderiv->deriv_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+48829, dvrr_stack+175210, dvrr_stack+143912);
 tmp = dvrr_stack + 48829;
 target_ptr = Libderiv->deriv_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+390705, dvrr_stack+195826, dvrr_stack+157782);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,36,1,dvrr_stack+85182, dvrr_stack+218758, dvrr_stack+264742);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+73859, dvrr_stack+226886, dvrr_stack+218758);
 tmp = dvrr_stack + 73859;
 target_ptr = Libderiv->deriv_classes[7][6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+64967, dvrr_stack+221306, dvrr_stack+234510);
 tmp = dvrr_stack + 64967;
 target_ptr = Libderiv->deriv_classes[7][5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+36118, dvrr_stack+240890, dvrr_stack+221306);
 tmp = dvrr_stack + 36118;
 target_ptr = Libderiv->deriv_classes[7][7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+392553, dvrr_stack+258990, dvrr_stack+226886);
 tmp = dvrr_stack + 392553;
 target_ptr = Libderiv->deriv_classes[7][8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+394173, dvrr_stack+281718, dvrr_stack+240890);
 tmp = dvrr_stack + 394173;
 target_ptr = Libderiv->deriv_classes[7][9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+396153, dvrr_stack+306798, dvrr_stack+258990);

 /* compute (4 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,15,1,dvrr_stack+162812, dvrr_stack+1984, dvrr_stack+309919);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+62087, dvrr_stack+7020, dvrr_stack+1984);
 tmp = dvrr_stack + 62087;
 target_ptr = Libderiv->deriv_classes[4][6][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+147845, dvrr_stack+3783, dvrr_stack+195601);
 tmp = dvrr_stack + 147845;
 target_ptr = Libderiv->deriv_classes[4][5][6];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+65723, dvrr_stack+13995, dvrr_stack+3783);
 tmp = dvrr_stack + 65723;
 target_ptr = Libderiv->deriv_classes[4][7][6];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+50369, dvrr_stack+22930, dvrr_stack+7020);
 tmp = dvrr_stack + 50369;
 target_ptr = Libderiv->deriv_classes[4][8][6];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+24580, dvrr_stack+34138, dvrr_stack+13995);
 tmp = dvrr_stack + 24580;
 target_ptr = Libderiv->deriv_classes[4][9][6];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,15,1,dvrr_stack+34138, dvrr_stack+47344, dvrr_stack+22930);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,21,1,dvrr_stack+136217, dvrr_stack+59434, dvrr_stack+314149);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+55832, dvrr_stack+63770, dvrr_stack+59434);
 tmp = dvrr_stack + 55832;
 target_ptr = Libderiv->deriv_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+41086, dvrr_stack+60743, dvrr_stack+321889);
 tmp = dvrr_stack + 41086;
 target_ptr = Libderiv->deriv_classes[5][5][6];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+27805, dvrr_stack+71654, dvrr_stack+60743);
 tmp = dvrr_stack + 27805;
 target_ptr = Libderiv->deriv_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+47333, dvrr_stack+81864, dvrr_stack+63770);
 tmp = dvrr_stack + 47333;
 target_ptr = Libderiv->deriv_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+398529, dvrr_stack+94704, dvrr_stack+71654);
 tmp = dvrr_stack + 398529;
 target_ptr = Libderiv->deriv_classes[5][9][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+94444, dvrr_stack+110478, dvrr_stack+81864);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,28,1,dvrr_stack+321739, dvrr_stack+127110, dvrr_stack+316459);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+17910, dvrr_stack+133190, dvrr_stack+127110);
 tmp = dvrr_stack + 17910;
 target_ptr = Libderiv->deriv_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+10080, dvrr_stack+128986, dvrr_stack+327649);
 tmp = dvrr_stack + 10080;
 target_ptr = Libderiv->deriv_classes[6][5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+110085, dvrr_stack+143912, dvrr_stack+128986);
 tmp = dvrr_stack + 110085;
 target_ptr = Libderiv->deriv_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+399684, dvrr_stack+157782, dvrr_stack+133190);
 tmp = dvrr_stack + 399684;
 target_ptr = Libderiv->deriv_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+400944, dvrr_stack+175210, dvrr_stack+143912);
 tmp = dvrr_stack + 400944;
 target_ptr = Libderiv->deriv_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+402484, dvrr_stack+195826, dvrr_stack+157782);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,36,1,dvrr_stack+195601, dvrr_stack+218758, dvrr_stack+264742);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+196141, dvrr_stack+226886, dvrr_stack+218758);
 tmp = dvrr_stack + 196141;
 target_ptr = Libderiv->deriv_classes[7][6][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+197149, dvrr_stack+221306, dvrr_stack+234510);
 tmp = dvrr_stack + 197149;
 target_ptr = Libderiv->deriv_classes[7][5][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+404332, dvrr_stack+240890, dvrr_stack+221306);
 tmp = dvrr_stack + 404332;
 target_ptr = Libderiv->deriv_classes[7][7][6];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+405628, dvrr_stack+258990, dvrr_stack+226886);
 tmp = dvrr_stack + 405628;
 target_ptr = Libderiv->deriv_classes[7][8][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+407248, dvrr_stack+281718, dvrr_stack+240890);
 tmp = dvrr_stack + 407248;
 target_ptr = Libderiv->deriv_classes[7][9][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+409228, dvrr_stack+306798, dvrr_stack+258990);

 /* compute (3 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+306504,dvrr_stack+3503,dvrr_stack+1774,10);


 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,210,dvrr_stack+264742, dvrr_stack+306504, NULL);

 /* compute (3 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+307134,dvrr_stack+6660,dvrr_stack+3503,10);


 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,280,dvrr_stack+316459, dvrr_stack+307134, NULL);

 /* compute (3 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+307974,dvrr_stack+13545,dvrr_stack+6660,10);


 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,360,dvrr_stack+51044, dvrr_stack+307974, NULL);

 /* compute (3 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+411604,dvrr_stack+22380,dvrr_stack+13545,10);


 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,450,dvrr_stack+28561, dvrr_stack+411604, NULL);

 /* compute (3 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+412954,dvrr_stack+33478,dvrr_stack+22380,10);


 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,550,dvrr_stack+309054, dvrr_stack+412954, NULL);

 /* compute (1 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+43768, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+123198, dvrr_stack+22220, dvrr_stack+43768, Data->F+6, Data->F+7, NULL);

 /* compute (3 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+370, dvrr_stack+22223, dvrr_stack+123198, dvrr_stack+46564, dvrr_stack+22220, NULL);

 /* compute (1 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+29011, dvrr_stack+361, dvrr_stack+282, NULL, NULL, Data->F+8);

 /* compute (2 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+1756, dvrr_stack+22229, dvrr_stack+29011, dvrr_stack+68, dvrr_stack+361, dvrr_stack+43768);

 /* compute (3 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+264952, dvrr_stack+22238, dvrr_stack+1756, dvrr_stack+46567, dvrr_stack+22229, dvrr_stack+123198);

 /* compute (4 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+322159, dvrr_stack+22256, dvrr_stack+264952, dvrr_stack+46576, dvrr_stack+22238, dvrr_stack+370);

 /* compute (1 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+1185, dvrr_stack+1085, dvrr_stack+896, NULL, NULL, dvrr_stack+282);

 /* compute (2 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+13509, dvrr_stack+22286, dvrr_stack+1185, dvrr_stack+364, dvrr_stack+1085, dvrr_stack+29011);

 /* compute (3 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+264982, dvrr_stack+22304, dvrr_stack+13509, dvrr_stack+46594, dvrr_stack+22286, dvrr_stack+1756);

 /* compute (4 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+316739, dvrr_stack+2691, dvrr_stack+264982, dvrr_stack+46612, dvrr_stack+22304, dvrr_stack+264952);

 /* compute (5 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+68810, dvrr_stack+13419, dvrr_stack+316739, dvrr_stack+46648, dvrr_stack+2691, dvrr_stack+322159);

 /* compute (1 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+265042, dvrr_stack+902, dvrr_stack+2420, NULL, NULL, dvrr_stack+896);

 /* compute (2 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+316829, dvrr_stack+71, dvrr_stack+265042, dvrr_stack+1329, dvrr_stack+902, dvrr_stack+1185);

 /* compute (3 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+197905, dvrr_stack+6381, dvrr_stack+316829, dvrr_stack+46708, dvrr_stack+71, dvrr_stack+13509);

 /* compute (4 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+309831, dvrr_stack+6441, dvrr_stack+197905, dvrr_stack+46738, dvrr_stack+6381, dvrr_stack+264982);

 /* compute (5 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+314059, dvrr_stack+3267, dvrr_stack+309831, dvrr_stack+46798, dvrr_stack+6441, dvrr_stack+316739);

 /* compute (6 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+322792, dvrr_stack+45008, dvrr_stack+314059, dvrr_stack+46898, dvrr_stack+3267, dvrr_stack+68810);

 /* compute (1 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+92658, dvrr_stack+2430, dvrr_stack+5305, NULL, NULL, dvrr_stack+2420);

 /* compute (2 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+314269, dvrr_stack+43723, dvrr_stack+92658, dvrr_stack+222, dvrr_stack+2430, dvrr_stack+265042);

 /* compute (3 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+265642, dvrr_stack+6541, dvrr_stack+314269, dvrr_stack+47048, dvrr_stack+43723, dvrr_stack+316829);

 /* compute (4 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+25405, dvrr_stack+1606, dvrr_stack+265642, dvrr_stack+47093, dvrr_stack+6541, dvrr_stack+197905);

 /* compute (5 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+4743, dvrr_stack+45218, dvrr_stack+25405, dvrr_stack+47183, dvrr_stack+1606, dvrr_stack+309831);

 /* compute (6 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+111093, dvrr_stack+45443, dvrr_stack+4743, dvrr_stack+43858, dvrr_stack+45218, dvrr_stack+314059);

 /* compute (7 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+111513, dvrr_stack+45758, dvrr_stack+111093, dvrr_stack+31697, dvrr_stack+45443, dvrr_stack+322792);

 /* compute (1 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+112053, dvrr_stack+5320, dvrr_stack+11869, NULL, NULL, dvrr_stack+5305);

 /* compute (2 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+41527, dvrr_stack+44480, dvrr_stack+112053, dvrr_stack+1119, dvrr_stack+5320, dvrr_stack+92658);

 /* compute (3 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+31697, dvrr_stack+44543, dvrr_stack+41527, dvrr_stack+380, dvrr_stack+44480, dvrr_stack+314269);

 /* compute (4 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+380, dvrr_stack+46178, dvrr_stack+31697, dvrr_stack+5148, dvrr_stack+44543, dvrr_stack+265642);

 /* compute (5 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+31059, dvrr_stack+217414, dvrr_stack+380, dvrr_stack+44083, dvrr_stack+46178, dvrr_stack+25405);

 /* compute (6 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+43807, dvrr_stack+217729, dvrr_stack+31059, dvrr_stack+20406, dvrr_stack+217414, dvrr_stack+4743);

 /* compute (7 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+46388, dvrr_stack+218170, dvrr_stack+43807, dvrr_stack+126669, dvrr_stack+217729, dvrr_stack+111093);

 /* compute (8 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+414604, dvrr_stack+218758, dvrr_stack+46388, dvrr_stack+127110, dvrr_stack+218170, dvrr_stack+111513);

 /* compute (1 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+126669, dvrr_stack+11890, dvrr_stack+20342, NULL, NULL, dvrr_stack+11869);

 /* compute (2 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+205006, dvrr_stack+58909, dvrr_stack+126669, dvrr_stack+2663, dvrr_stack+11890, dvrr_stack+112053);

 /* compute (3 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+126753, dvrr_stack+58993, dvrr_stack+205006, dvrr_stack+1354, dvrr_stack+58909, dvrr_stack+41527);

 /* compute (4 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+415549, dvrr_stack+20721, dvrr_stack+126753, dvrr_stack+1438, dvrr_stack+58993, dvrr_stack+31697);

 /* compute (5 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+415969, dvrr_stack+219514, dvrr_stack+415549, dvrr_stack+127698, dvrr_stack+20721, dvrr_stack+380);

 /* compute (6 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+416557, dvrr_stack+219934, dvrr_stack+415969, dvrr_stack+127978, dvrr_stack+219514, dvrr_stack+31059);

 /* compute (7 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+417341, dvrr_stack+220522, dvrr_stack+416557, dvrr_stack+128398, dvrr_stack+219934, dvrr_stack+43807);

 /* compute (8 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+127698, dvrr_stack+221306, dvrr_stack+417341, dvrr_stack+128986, dvrr_stack+220522, dvrr_stack+46388);

 /* compute (8 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+418349,dvrr_stack+127698,dvrr_stack+414604,45);


 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+421184, dvrr_stack+418349, NULL);

 /* compute (1 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5652, dvrr_stack+20370, dvrr_stack+30978, NULL, NULL, dvrr_stack+20342);

 /* compute (2 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+224366, dvrr_stack+59875, dvrr_stack+5652, dvrr_stack+5616, dvrr_stack+20370, dvrr_stack+126669);

 /* compute (3 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+422129, dvrr_stack+59983, dvrr_stack+224366, dvrr_stack+2943, dvrr_stack+59875, dvrr_stack+205006);

 /* compute (4 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+422489, dvrr_stack+60199, dvrr_stack+422129, dvrr_stack+3051, dvrr_stack+59983, dvrr_stack+126753);

 /* compute (5 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+423029, dvrr_stack+224582, dvrr_stack+422489, dvrr_stack+131534, dvrr_stack+60199, dvrr_stack+415549);

 /* compute (6 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+423785, dvrr_stack+225122, dvrr_stack+423029, dvrr_stack+131894, dvrr_stack+224582, dvrr_stack+415969);

 /* compute (7 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+424793, dvrr_stack+225878, dvrr_stack+423785, dvrr_stack+132434, dvrr_stack+225122, dvrr_stack+416557);

 /* compute (8 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+131534, dvrr_stack+226886, dvrr_stack+424793, dvrr_stack+133190, dvrr_stack+225878, dvrr_stack+417341);

 /* compute (8 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+426089,dvrr_stack+131534,dvrr_stack+127698,45);


 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+429869, dvrr_stack+426089, NULL);

 /* compute (1 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12285, dvrr_stack+31014, dvrr_stack+237, NULL, NULL, dvrr_stack+30978);

 /* compute (2 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2943, dvrr_stack+62654, dvrr_stack+12285, dvrr_stack+12240, dvrr_stack+31014, dvrr_stack+5652);

 /* compute (3 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+431129, dvrr_stack+62789, dvrr_stack+2943, dvrr_stack+5976, dvrr_stack+62654, dvrr_stack+224366);

 /* compute (4 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+431579, dvrr_stack+63059, dvrr_stack+431129, dvrr_stack+6111, dvrr_stack+62789, dvrr_stack+422129);

 /* compute (5 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+432254, dvrr_stack+238010, dvrr_stack+431579, dvrr_stack+141842, dvrr_stack+63059, dvrr_stack+422489);

 /* compute (6 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+433199, dvrr_stack+238685, dvrr_stack+432254, dvrr_stack+142292, dvrr_stack+238010, dvrr_stack+423029);

 /* compute (7 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+434459, dvrr_stack+239630, dvrr_stack+433199, dvrr_stack+142967, dvrr_stack+238685, dvrr_stack+423785);

 /* compute (8 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+141842, dvrr_stack+240890, dvrr_stack+434459, dvrr_stack+143912, dvrr_stack+239630, dvrr_stack+424793);

 /* compute (8 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+436079,dvrr_stack+141842,dvrr_stack+131534,45);


 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+440939, dvrr_stack+436079, NULL);

 /* compute (1 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+5976, dvrr_stack+30734, dvrr_stack+22021, NULL, NULL, dvrr_stack+237);

 /* compute (2 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+442559, dvrr_stack+70259, dvrr_stack+5976, dvrr_stack+31642, dvrr_stack+30734, dvrr_stack+12285);

 /* compute (3 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+442889, dvrr_stack+70424, dvrr_stack+442559, dvrr_stack+12690, dvrr_stack+70259, dvrr_stack+2943);

 /* compute (4 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+443439, dvrr_stack+70754, dvrr_stack+442889, dvrr_stack+12855, dvrr_stack+70424, dvrr_stack+431129);

 /* compute (5 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+444264, dvrr_stack+255470, dvrr_stack+443439, dvrr_stack+155252, dvrr_stack+70754, dvrr_stack+431579);

 /* compute (6 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+445419, dvrr_stack+256295, dvrr_stack+444264, dvrr_stack+155802, dvrr_stack+255470, dvrr_stack+432254);

 /* compute (7 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+446959, dvrr_stack+257450, dvrr_stack+445419, dvrr_stack+156627, dvrr_stack+256295, dvrr_stack+433199);

 /* compute (8 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+155252, dvrr_stack+258990, dvrr_stack+446959, dvrr_stack+157782, dvrr_stack+257450, dvrr_stack+434459);

 /* compute (8 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+448939,dvrr_stack+155252,dvrr_stack+141842,45);


 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2025,dvrr_stack+455014, dvrr_stack+448939, NULL);

 /* compute (1 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12690, dvrr_stack+22076, dvrr_stack+92758, NULL, NULL, dvrr_stack+22021);

 /* compute (2 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12888, dvrr_stack+80159, dvrr_stack+12690, dvrr_stack+30789, dvrr_stack+22076, dvrr_stack+5976);

 /* compute (3 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+457039, dvrr_stack+80357, dvrr_stack+12888, dvrr_stack+21335, dvrr_stack+80159, dvrr_stack+442559);

 /* compute (4 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+457699, dvrr_stack+80753, dvrr_stack+457039, dvrr_stack+21533, dvrr_stack+80357, dvrr_stack+442889);

 /* compute (5 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+458689, dvrr_stack+277494, dvrr_stack+457699, dvrr_stack+172174, dvrr_stack+80753, dvrr_stack+443439);

 /* compute (6 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+460075, dvrr_stack+278484, dvrr_stack+458689, dvrr_stack+172834, dvrr_stack+277494, dvrr_stack+444264);

 /* compute (7 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+457039, dvrr_stack+279870, dvrr_stack+460075, dvrr_stack+173824, dvrr_stack+278484, dvrr_stack+445419);

 /* compute (8 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+172174, dvrr_stack+281718, dvrr_stack+457039, dvrr_stack+175210, dvrr_stack+279870, dvrr_stack+446959);

 /* compute (8 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+457039,dvrr_stack+172174,dvrr_stack+155252,45);


 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+277494, dvrr_stack+457039, NULL);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,210,dvrr_stack+464464, dvrr_stack+306504, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+464674, dvrr_stack+307134, NULL);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+279969, dvrr_stack+307974, NULL);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+280329, dvrr_stack+411604, NULL);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,550,dvrr_stack+280779, dvrr_stack+412954, NULL);

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+281329, dvrr_stack+418349, NULL);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+282274, dvrr_stack+426089, NULL);

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+175144, dvrr_stack+436079, NULL);

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2025,dvrr_stack+464954, dvrr_stack+448939, NULL);

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+466979, dvrr_stack+457039, NULL);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+469454, dvrr_stack+306504, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+306504, dvrr_stack+307134, NULL);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+306784, dvrr_stack+307974, NULL);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+307144, dvrr_stack+411604, NULL);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+411604, dvrr_stack+412954, NULL);

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+412154, dvrr_stack+418349, NULL);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+418349, dvrr_stack+426089, NULL);

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+426089, dvrr_stack+436079, NULL);

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+436079, dvrr_stack+448939, NULL);

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+448939, dvrr_stack+457039, NULL);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+457039, dvrr_stack+3503, dvrr_stack+316924);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+457249, dvrr_stack+6660, dvrr_stack+1774);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+457529, dvrr_stack+13545, dvrr_stack+3503);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+457889, dvrr_stack+22380, dvrr_stack+6660);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+458339, dvrr_stack+33478, dvrr_stack+13545);

 /* compute (4 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+290019, dvrr_stack+58, dvrr_stack+370, dvrr_stack+43771, dvrr_stack+22223, NULL);

 /* compute (5 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+458889, dvrr_stack+43678, dvrr_stack+322159, dvrr_stack+43777, dvrr_stack+22256, dvrr_stack+290019);

 /* compute (6 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+458952, dvrr_stack+252134, dvrr_stack+68810, dvrr_stack+327349, dvrr_stack+13419, dvrr_stack+458889);

 /* compute (7 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+459120, dvrr_stack+234230, dvrr_stack+322792, dvrr_stack+327439, dvrr_stack+45008, dvrr_stack+458952);

 /* compute (8 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+459480, dvrr_stack+234510, dvrr_stack+111513, dvrr_stack+327649, dvrr_stack+45758, dvrr_stack+459120);

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+460155, dvrr_stack+127698, dvrr_stack+459480);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+461100, dvrr_stack+131534, dvrr_stack+414604);

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+462360, dvrr_stack+141842, dvrr_stack+127698);

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+451414, dvrr_stack+155252, dvrr_stack+131534);

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+438104, dvrr_stack+172174, dvrr_stack+141842);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+234230, dvrr_stack+3503, dvrr_stack+316924);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+234440, dvrr_stack+6660, dvrr_stack+1774);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+440579, dvrr_stack+13545, dvrr_stack+3503);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+458889, dvrr_stack+22380, dvrr_stack+6660);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+327349, dvrr_stack+33478, dvrr_stack+13545);

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+453439, dvrr_stack+127698, dvrr_stack+459480);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+427709, dvrr_stack+131534, dvrr_stack+414604);

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+80159, dvrr_stack+141842, dvrr_stack+127698);

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+469664, dvrr_stack+155252, dvrr_stack+131534);

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+471689, dvrr_stack+172174, dvrr_stack+141842);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+234720, dvrr_stack+3503, dvrr_stack+316924);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+252134, dvrr_stack+6660, dvrr_stack+1774);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+463980, dvrr_stack+13545, dvrr_stack+3503);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+454384, dvrr_stack+22380, dvrr_stack+6660);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+428969, dvrr_stack+33478, dvrr_stack+13545);

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+419609, dvrr_stack+127698, dvrr_stack+459480);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+413099, dvrr_stack+131534, dvrr_stack+414604);

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+474164, dvrr_stack+141842, dvrr_stack+127698);

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+475784, dvrr_stack+155252, dvrr_stack+131534);

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+477809, dvrr_stack+172174, dvrr_stack+141842);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+172174, dvrr_stack+1984, dvrr_stack+1203);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+172384, dvrr_stack+127110, dvrr_stack+1984);
 tmp = dvrr_stack + 172384;
 target_ptr = Libderiv->deriv_classes[5][5][2];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+172825, dvrr_stack+3783, dvrr_stack+2775);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+173105, dvrr_stack+128986, dvrr_stack+3783);
 tmp = dvrr_stack + 173105;
 target_ptr = Libderiv->deriv_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+173693, dvrr_stack+7020, dvrr_stack+5760);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+174053, dvrr_stack+133190, dvrr_stack+7020);
 tmp = dvrr_stack + 174053;
 target_ptr = Libderiv->deriv_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+459339, dvrr_stack+13995, dvrr_stack+12420);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+307594, dvrr_stack+143912, dvrr_stack+13995);
 tmp = dvrr_stack + 307594;
 target_ptr = Libderiv->deriv_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+420554, dvrr_stack+22930, dvrr_stack+21005);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+480284, dvrr_stack+157782, dvrr_stack+22930);
 tmp = dvrr_stack + 480284;
 target_ptr = Libderiv->deriv_classes[5][9][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+20406, dvrr_stack+59434, dvrr_stack+1774);
 tmp = dvrr_stack + 20406;
 target_ptr = Libderiv->deriv_classes[4][5][2];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+21335, dvrr_stack+218758, dvrr_stack+59434);
 tmp = dvrr_stack + 21335;
 target_ptr = Libderiv->deriv_classes[6][5][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+308539, dvrr_stack+60743, dvrr_stack+3503);
 tmp = dvrr_stack + 308539;
 target_ptr = Libderiv->deriv_classes[4][6][2];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+33308, dvrr_stack+221306, dvrr_stack+60743);
 tmp = dvrr_stack + 33308;
 target_ptr = Libderiv->deriv_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+481439, dvrr_stack+63770, dvrr_stack+6660);
 tmp = dvrr_stack + 481439;
 target_ptr = Libderiv->deriv_classes[4][7][2];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+481979, dvrr_stack+226886, dvrr_stack+63770);
 tmp = dvrr_stack + 481979;
 target_ptr = Libderiv->deriv_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+12690, dvrr_stack+71654, dvrr_stack+13545);
 tmp = dvrr_stack + 12690;
 target_ptr = Libderiv->deriv_classes[4][8][2];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+482987, dvrr_stack+240890, dvrr_stack+71654);
 tmp = dvrr_stack + 482987;
 target_ptr = Libderiv->deriv_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+484247, dvrr_stack+81864, dvrr_stack+22380);
 tmp = dvrr_stack + 484247;
 target_ptr = Libderiv->deriv_classes[4][9][2];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+485072, dvrr_stack+258990, dvrr_stack+81864);
 tmp = dvrr_stack + 485072;
 target_ptr = Libderiv->deriv_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+486612, dvrr_stack+414604, dvrr_stack+127110);
 tmp = dvrr_stack + 486612;
 target_ptr = Libderiv->deriv_classes[7][5][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+487368, dvrr_stack+127698, dvrr_stack+128986);
 tmp = dvrr_stack + 487368;
 target_ptr = Libderiv->deriv_classes[7][6][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+488376, dvrr_stack+131534, dvrr_stack+133190);
 tmp = dvrr_stack + 488376;
 target_ptr = Libderiv->deriv_classes[7][7][2];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+489672, dvrr_stack+141842, dvrr_stack+143912);
 tmp = dvrr_stack + 489672;
 target_ptr = Libderiv->deriv_classes[7][8][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+491292, dvrr_stack+155252, dvrr_stack+157782);
 tmp = dvrr_stack + 491292;
 target_ptr = Libderiv->deriv_classes[7][9][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+174809, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+364, dvrr_stack+43768, dvrr_stack+174809, Data->F+7, Data->F+8, NULL);

 /* compute (3 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+174812, dvrr_stack+123198, dvrr_stack+364, dvrr_stack+22220, dvrr_stack+43768, NULL);

 /* compute (4 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+290019, dvrr_stack+370, dvrr_stack+174812, dvrr_stack+22223, dvrr_stack+123198, NULL);

 /* compute (1 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+370, dvrr_stack+282, dvrr_stack+1091, NULL, NULL, Data->F+9);

 /* compute (2 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+136532, dvrr_stack+29011, dvrr_stack+370, dvrr_stack+361, dvrr_stack+282, dvrr_stack+174809);

 /* compute (3 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+265072, dvrr_stack+1756, dvrr_stack+136532, dvrr_stack+22229, dvrr_stack+29011, dvrr_stack+364);

 /* compute (4 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+43678, dvrr_stack+264952, dvrr_stack+265072, dvrr_stack+22238, dvrr_stack+1756, dvrr_stack+174812);

 /* compute (5 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+174809, dvrr_stack+322159, dvrr_stack+43678, dvrr_stack+22256, dvrr_stack+264952, dvrr_stack+290019);

 /* compute (1 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+1756, dvrr_stack+896, dvrr_stack+2414, NULL, NULL, dvrr_stack+1091);

 /* compute (2 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+133154, dvrr_stack+1185, dvrr_stack+1756, dvrr_stack+1085, dvrr_stack+896, dvrr_stack+370);

 /* compute (3 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+174872, dvrr_stack+13509, dvrr_stack+133154, dvrr_stack+22286, dvrr_stack+1185, dvrr_stack+136532);

 /* compute (4 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+174932, dvrr_stack+264982, dvrr_stack+174872, dvrr_stack+22304, dvrr_stack+13509, dvrr_stack+265072);

 /* compute (5 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+459789, dvrr_stack+316739, dvrr_stack+174932, dvrr_stack+2691, dvrr_stack+264982, dvrr_stack+43678);

 /* compute (6 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+459915, dvrr_stack+68810, dvrr_stack+459789, dvrr_stack+13419, dvrr_stack+316739, dvrr_stack+174809);

 /* compute (1 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+265072, dvrr_stack+2420, dvrr_stack+5295, NULL, NULL, dvrr_stack+2414);

 /* compute (2 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+174809, dvrr_stack+265042, dvrr_stack+265072, dvrr_stack+902, dvrr_stack+2420, dvrr_stack+1756);

 /* compute (3 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+68810, dvrr_stack+316829, dvrr_stack+174809, dvrr_stack+71, dvrr_stack+265042, dvrr_stack+133154);

 /* compute (4 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+25630, dvrr_stack+197905, dvrr_stack+68810, dvrr_stack+6381, dvrr_stack+316829, dvrr_stack+174872);

 /* compute (5 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+316739, dvrr_stack+309831, dvrr_stack+25630, dvrr_stack+6441, dvrr_stack+197905, dvrr_stack+174932);

 /* compute (6 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+429519, dvrr_stack+314059, dvrr_stack+316739, dvrr_stack+3267, dvrr_stack+309831, dvrr_stack+459789);

 /* compute (7 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+493272, dvrr_stack+322792, dvrr_stack+429519, dvrr_stack+45008, dvrr_stack+314059, dvrr_stack+459915);

 /* compute (1 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+43678, dvrr_stack+5305, dvrr_stack+11854, NULL, NULL, dvrr_stack+5295);

 /* compute (2 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+314059, dvrr_stack+92658, dvrr_stack+43678, dvrr_stack+2430, dvrr_stack+5305, dvrr_stack+265072);

 /* compute (3 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+264952, dvrr_stack+314269, dvrr_stack+314059, dvrr_stack+43723, dvrr_stack+92658, dvrr_stack+174809);

 /* compute (4 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+174809, dvrr_stack+265642, dvrr_stack+264952, dvrr_stack+6541, dvrr_stack+314269, dvrr_stack+68810);

 /* compute (5 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+322792, dvrr_stack+25405, dvrr_stack+174809, dvrr_stack+1606, dvrr_stack+265642, dvrr_stack+25630);

 /* compute (6 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+283534, dvrr_stack+4743, dvrr_stack+322792, dvrr_stack+45218, dvrr_stack+25405, dvrr_stack+316739);

 /* compute (7 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+44669, dvrr_stack+111093, dvrr_stack+283534, dvrr_stack+45443, dvrr_stack+4743, dvrr_stack+429519);

 /* compute (8 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+493632, dvrr_stack+111513, dvrr_stack+44669, dvrr_stack+45758, dvrr_stack+111093, dvrr_stack+493272);

 /* compute (1 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+493272, dvrr_stack+11869, dvrr_stack+20321, NULL, NULL, dvrr_stack+11854);

 /* compute (2 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+68810, dvrr_stack+112053, dvrr_stack+493272, dvrr_stack+5320, dvrr_stack+11869, dvrr_stack+43678);

 /* compute (3 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+314149, dvrr_stack+41527, dvrr_stack+68810, dvrr_stack+44480, dvrr_stack+112053, dvrr_stack+314059);

 /* compute (4 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+111093, dvrr_stack+31697, dvrr_stack+314149, dvrr_stack+44543, dvrr_stack+41527, dvrr_stack+264952);

 /* compute (5 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+111408, dvrr_stack+380, dvrr_stack+111093, dvrr_stack+46178, dvrr_stack+31697, dvrr_stack+174809);

 /* compute (6 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+4743, dvrr_stack+31059, dvrr_stack+111408, dvrr_stack+217414, dvrr_stack+380, dvrr_stack+322792);

 /* compute (7 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+282, dvrr_stack+43807, dvrr_stack+4743, dvrr_stack+217729, dvrr_stack+31059, dvrr_stack+283534);

 /* compute (8 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+31059, dvrr_stack+46388, dvrr_stack+282, dvrr_stack+218170, dvrr_stack+43807, dvrr_stack+44669);

 /* compute (9 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+217414, dvrr_stack+414604, dvrr_stack+31059, dvrr_stack+218758, dvrr_stack+46388, dvrr_stack+493632);

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+43678, dvrr_stack+217414, dvrr_stack+218758);

 /* compute (1 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+283534, dvrr_stack+20342, dvrr_stack+30950, NULL, NULL, dvrr_stack+20321);

 /* compute (2 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+283618, dvrr_stack+126669, dvrr_stack+283534, dvrr_stack+11890, dvrr_stack+20342, dvrr_stack+493272);

 /* compute (3 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+493272, dvrr_stack+205006, dvrr_stack+283618, dvrr_stack+58909, dvrr_stack+126669, dvrr_stack+68810);

 /* compute (4 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+493552, dvrr_stack+126753, dvrr_stack+493272, dvrr_stack+58993, dvrr_stack+205006, dvrr_stack+314149);

 /* compute (5 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+493972, dvrr_stack+415549, dvrr_stack+493552, dvrr_stack+20721, dvrr_stack+126753, dvrr_stack+111093);

 /* compute (6 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+44623, dvrr_stack+415969, dvrr_stack+493972, dvrr_stack+219514, dvrr_stack+415549, dvrr_stack+111408);

 /* compute (7 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+111093, dvrr_stack+416557, dvrr_stack+44623, dvrr_stack+219934, dvrr_stack+415969, dvrr_stack+4743);

 /* compute (8 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+45407, dvrr_stack+417341, dvrr_stack+111093, dvrr_stack+220522, dvrr_stack+416557, dvrr_stack+282);

 /* compute (9 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+415549, dvrr_stack+127698, dvrr_stack+45407, dvrr_stack+221306, dvrr_stack+417341, dvrr_stack+31059);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+417089, dvrr_stack+415549, dvrr_stack+221306);

 /* compute (1 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+31059, dvrr_stack+30978, dvrr_stack+30698, NULL, NULL, dvrr_stack+30950);

 /* compute (2 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+31167, dvrr_stack+5652, dvrr_stack+31059, dvrr_stack+20370, dvrr_stack+30978, dvrr_stack+283534);

 /* compute (3 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+31383, dvrr_stack+224366, dvrr_stack+31167, dvrr_stack+59875, dvrr_stack+5652, dvrr_stack+283618);

 /* compute (4 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+283534, dvrr_stack+422129, dvrr_stack+31383, dvrr_stack+59983, dvrr_stack+224366, dvrr_stack+493272);

 /* compute (5 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+282, dvrr_stack+422489, dvrr_stack+283534, dvrr_stack+60199, dvrr_stack+422129, dvrr_stack+493552);

 /* compute (6 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4743, dvrr_stack+423029, dvrr_stack+282, dvrr_stack+224582, dvrr_stack+422489, dvrr_stack+493972);

 /* compute (7 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+493272, dvrr_stack+423785, dvrr_stack+4743, dvrr_stack+225122, dvrr_stack+423029, dvrr_stack+44623);

 /* compute (8 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+422129, dvrr_stack+424793, dvrr_stack+493272, dvrr_stack+225878, dvrr_stack+423785, dvrr_stack+111093);

 /* compute (9 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+224366, dvrr_stack+131534, dvrr_stack+422129, dvrr_stack+226886, dvrr_stack+424793, dvrr_stack+45407);

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+44623, dvrr_stack+224366, dvrr_stack+226886);

 /* compute (1 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+111093, dvrr_stack+237, dvrr_stack+1140, NULL, NULL, dvrr_stack+30698);

 /* compute (2 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+111228, dvrr_stack+12285, dvrr_stack+111093, dvrr_stack+31014, dvrr_stack+237, dvrr_stack+31059);

 /* compute (3 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+111498, dvrr_stack+2943, dvrr_stack+111228, dvrr_stack+62654, dvrr_stack+12285, dvrr_stack+31167);

 /* compute (4 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+46243, dvrr_stack+431129, dvrr_stack+111498, dvrr_stack+62789, dvrr_stack+2943, dvrr_stack+31383);

 /* compute (5 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+423749, dvrr_stack+431579, dvrr_stack+46243, dvrr_stack+63059, dvrr_stack+431129, dvrr_stack+283534);

 /* compute (6 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+424694, dvrr_stack+432254, dvrr_stack+423749, dvrr_stack+238010, dvrr_stack+431579, dvrr_stack+282);

 /* compute (7 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+219514, dvrr_stack+433199, dvrr_stack+424694, dvrr_stack+238685, dvrr_stack+432254, dvrr_stack+4743);

 /* compute (8 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+431129, dvrr_stack+434459, dvrr_stack+219514, dvrr_stack+239630, dvrr_stack+433199, dvrr_stack+493272);

 /* compute (9 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+238010, dvrr_stack+141842, dvrr_stack+431129, dvrr_stack+240890, dvrr_stack+434459, dvrr_stack+422129);

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+433154, dvrr_stack+238010, dvrr_stack+240890);

 /* compute (1 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+422129, dvrr_stack+22021, dvrr_stack+92703, NULL, NULL, dvrr_stack+1140);

 /* compute (2 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+422294, dvrr_stack+5976, dvrr_stack+422129, dvrr_stack+30734, dvrr_stack+22021, dvrr_stack+111093);

 /* compute (3 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+422624, dvrr_stack+442559, dvrr_stack+422294, dvrr_stack+70259, dvrr_stack+5976, dvrr_stack+111228);

 /* compute (4 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+493272, dvrr_stack+442889, dvrr_stack+422624, dvrr_stack+70424, dvrr_stack+442559, dvrr_stack+111498);

 /* compute (5 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+422129, dvrr_stack+443439, dvrr_stack+493272, dvrr_stack+70754, dvrr_stack+442889, dvrr_stack+46243);

 /* compute (6 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+493272, dvrr_stack+444264, dvrr_stack+422129, dvrr_stack+255470, dvrr_stack+443439, dvrr_stack+423749);

 /* compute (7 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+422129, dvrr_stack+445419, dvrr_stack+493272, dvrr_stack+256295, dvrr_stack+444264, dvrr_stack+424694);

 /* compute (8 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+442559, dvrr_stack+446959, dvrr_stack+422129, dvrr_stack+257450, dvrr_stack+445419, dvrr_stack+219514);

 /* compute (9 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+422129, dvrr_stack+155252, dvrr_stack+442559, dvrr_stack+258990, dvrr_stack+446959, dvrr_stack+431129);

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+442559, dvrr_stack+422129, dvrr_stack+258990);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+431129, dvrr_stack+1984, dvrr_stack+1203);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+126669, dvrr_stack+127110, dvrr_stack+1984);
 tmp = dvrr_stack + 126669;
 target_ptr = Libderiv->deriv_classes[5][5][1];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+431339, dvrr_stack+3783, dvrr_stack+2775);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+431619, dvrr_stack+128986, dvrr_stack+3783);
 tmp = dvrr_stack + 431619;
 target_ptr = Libderiv->deriv_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+432207, dvrr_stack+7020, dvrr_stack+5760);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+445034, dvrr_stack+133190, dvrr_stack+7020);
 tmp = dvrr_stack + 445034;
 target_ptr = Libderiv->deriv_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+432567, dvrr_stack+13995, dvrr_stack+12420);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+445790, dvrr_stack+143912, dvrr_stack+13995);
 tmp = dvrr_stack + 445790;
 target_ptr = Libderiv->deriv_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+446735, dvrr_stack+22930, dvrr_stack+21005);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+447285, dvrr_stack+157782, dvrr_stack+22930);
 tmp = dvrr_stack + 447285;
 target_ptr = Libderiv->deriv_classes[5][9][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+448440, dvrr_stack+59434, dvrr_stack+1774);
 tmp = dvrr_stack + 448440;
 target_ptr = Libderiv->deriv_classes[4][5][1];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+219514, dvrr_stack+218758, dvrr_stack+59434);
 tmp = dvrr_stack + 219514;
 target_ptr = Libderiv->deriv_classes[6][5][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+220102, dvrr_stack+60743, dvrr_stack+3503);
 tmp = dvrr_stack + 220102;
 target_ptr = Libderiv->deriv_classes[4][6][1];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+220522, dvrr_stack+221306, dvrr_stack+60743);
 tmp = dvrr_stack + 220522;
 target_ptr = Libderiv->deriv_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+226346, dvrr_stack+63770, dvrr_stack+6660);
 tmp = dvrr_stack + 226346;
 target_ptr = Libderiv->deriv_classes[4][7][1];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+493272, dvrr_stack+226886, dvrr_stack+63770);
 tmp = dvrr_stack + 493272;
 target_ptr = Libderiv->deriv_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+425154, dvrr_stack+71654, dvrr_stack+13545);
 tmp = dvrr_stack + 425154;
 target_ptr = Libderiv->deriv_classes[4][8][1];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+255470, dvrr_stack+240890, dvrr_stack+71654);
 tmp = dvrr_stack + 255470;
 target_ptr = Libderiv->deriv_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+256730, dvrr_stack+81864, dvrr_stack+22380);
 tmp = dvrr_stack + 256730;
 target_ptr = Libderiv->deriv_classes[4][9][1];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+494280, dvrr_stack+258990, dvrr_stack+81864);
 tmp = dvrr_stack + 494280;
 target_ptr = Libderiv->deriv_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+257555, dvrr_stack+414604, dvrr_stack+127110);
 tmp = dvrr_stack + 257555;
 target_ptr = Libderiv->deriv_classes[7][5][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+46243, dvrr_stack+127698, dvrr_stack+128986);
 tmp = dvrr_stack + 46243;
 target_ptr = Libderiv->deriv_classes[7][6][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+70259, dvrr_stack+131534, dvrr_stack+133190);
 tmp = dvrr_stack + 70259;
 target_ptr = Libderiv->deriv_classes[7][7][1];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+495820, dvrr_stack+141842, dvrr_stack+143912);
 tmp = dvrr_stack + 495820;
 target_ptr = Libderiv->deriv_classes[7][8][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+497440, dvrr_stack+155252, dvrr_stack+157782);
 tmp = dvrr_stack + 497440;
 target_ptr = Libderiv->deriv_classes[7][9][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+111093, dvrr_stack+217414, dvrr_stack+218758);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+62507, dvrr_stack+415549, dvrr_stack+221306);

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+499420, dvrr_stack+224366, dvrr_stack+226886);

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+501040, dvrr_stack+238010, dvrr_stack+240890);

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+503065, dvrr_stack+422129, dvrr_stack+258990);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+425829, dvrr_stack+1984, dvrr_stack+1203);

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+505540, dvrr_stack+127110, dvrr_stack+1984);
 tmp = dvrr_stack + 505540;
 target_ptr = Libderiv->deriv_classes[5][5][0];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+1984, dvrr_stack+3783, dvrr_stack+2775);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+2264, dvrr_stack+128986, dvrr_stack+3783);
 tmp = dvrr_stack + 2264;
 target_ptr = Libderiv->deriv_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+3783, dvrr_stack+7020, dvrr_stack+5760);

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+4743, dvrr_stack+133190, dvrr_stack+7020);
 tmp = dvrr_stack + 4743;
 target_ptr = Libderiv->deriv_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+7020, dvrr_stack+13995, dvrr_stack+12420);

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+5499, dvrr_stack+143912, dvrr_stack+13995);
 tmp = dvrr_stack + 5499;
 target_ptr = Libderiv->deriv_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+13995, dvrr_stack+22930, dvrr_stack+21005);

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+0, dvrr_stack+157782, dvrr_stack+22930);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv_classes[5][9][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+22930, dvrr_stack+59434, dvrr_stack+1774);
 tmp = dvrr_stack + 22930;
 target_ptr = Libderiv->deriv_classes[4][5][0];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+2852, dvrr_stack+218758, dvrr_stack+59434);
 tmp = dvrr_stack + 2852;
 target_ptr = Libderiv->deriv_classes[6][5][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+23245, dvrr_stack+60743, dvrr_stack+3503);
 tmp = dvrr_stack + 23245;
 target_ptr = Libderiv->deriv_classes[4][6][0];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+435179, dvrr_stack+221306, dvrr_stack+60743);
 tmp = dvrr_stack + 435179;
 target_ptr = Libderiv->deriv_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+258311, dvrr_stack+63770, dvrr_stack+6660);
 tmp = dvrr_stack + 258311;
 target_ptr = Libderiv->deriv_classes[4][7][0];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+58909, dvrr_stack+226886, dvrr_stack+63770);
 tmp = dvrr_stack + 58909;
 target_ptr = Libderiv->deriv_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+59917, dvrr_stack+71654, dvrr_stack+13545);
 tmp = dvrr_stack + 59917;
 target_ptr = Libderiv->deriv_classes[4][8][0];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+30640, dvrr_stack+240890, dvrr_stack+71654);
 tmp = dvrr_stack + 30640;
 target_ptr = Libderiv->deriv_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+71555, dvrr_stack+81864, dvrr_stack+22380);
 tmp = dvrr_stack + 71555;
 target_ptr = Libderiv->deriv_classes[4][9][0];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+505981, dvrr_stack+258990, dvrr_stack+81864);
 tmp = dvrr_stack + 505981;
 target_ptr = Libderiv->deriv_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+81779, dvrr_stack+414604, dvrr_stack+127110);
 tmp = dvrr_stack + 81779;
 target_ptr = Libderiv->deriv_classes[7][5][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+414359, dvrr_stack+127698, dvrr_stack+128986);
 tmp = dvrr_stack + 414359;
 target_ptr = Libderiv->deriv_classes[7][6][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+127110, dvrr_stack+131534, dvrr_stack+133190);
 tmp = dvrr_stack + 127110;
 target_ptr = Libderiv->deriv_classes[7][7][0];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+131534, dvrr_stack+141842, dvrr_stack+143912);
 tmp = dvrr_stack + 131534;
 target_ptr = Libderiv->deriv_classes[7][8][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+141842, dvrr_stack+155252, dvrr_stack+157782);
 tmp = dvrr_stack + 141842;
 target_ptr = Libderiv->deriv_classes[7][9][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+155252, dvrr_stack+217414, dvrr_stack+218758);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+217414, dvrr_stack+415549, dvrr_stack+221306);

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+156197, dvrr_stack+224366, dvrr_stack+226886);

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+507521, dvrr_stack+238010, dvrr_stack+240890);

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+238010, dvrr_stack+422129, dvrr_stack+258990);

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,315,dvrr_stack+422129, dvrr_stack+10710, NULL);
 tmp = dvrr_stack + 422129;
 target_ptr = Libderiv->deriv2_classes[4][5][143];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,420,dvrr_stack+422444, dvrr_stack+18810, NULL);
 tmp = dvrr_stack + 422444;
 target_ptr = Libderiv->deriv2_classes[4][6][143];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,540,dvrr_stack+422864, dvrr_stack+29020, NULL);
 tmp = dvrr_stack + 422864;
 target_ptr = Libderiv->deriv2_classes[4][7][143];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,675,dvrr_stack+423404, dvrr_stack+41653, NULL);
 tmp = dvrr_stack + 423404;
 target_ptr = Libderiv->deriv2_classes[4][8][143];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,825,dvrr_stack+424079, dvrr_stack+56434, NULL);
 tmp = dvrr_stack + 424079;
 target_ptr = Libderiv->deriv2_classes[4][9][143];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,441,dvrr_stack+240485, dvrr_stack+68936, NULL);
 tmp = dvrr_stack + 240485;
 target_ptr = Libderiv->deriv2_classes[5][5][143];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,588,dvrr_stack+240926, dvrr_stack+78395, NULL);
 tmp = dvrr_stack + 240926;
 target_ptr = Libderiv->deriv2_classes[5][6][143];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,756,dvrr_stack+241514, dvrr_stack+90390, NULL);
 tmp = dvrr_stack + 241514;
 target_ptr = Libderiv->deriv2_classes[5][7][143];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,945,dvrr_stack+226886, dvrr_stack+105225, NULL);
 tmp = dvrr_stack + 226886;
 target_ptr = Libderiv->deriv2_classes[5][8][143];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+224366, dvrr_stack+123204, NULL);
 tmp = dvrr_stack + 224366;
 target_ptr = Libderiv->deriv2_classes[5][9][143];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,588,dvrr_stack+225521, dvrr_stack+140078, NULL);
 tmp = dvrr_stack + 225521;
 target_ptr = Libderiv->deriv2_classes[6][5][143];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,784,dvrr_stack+221306, dvrr_stack+152900, NULL);
 tmp = dvrr_stack + 221306;
 target_ptr = Libderiv->deriv2_classes[6][6][143];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+157817, dvrr_stack+169150, NULL);
 tmp = dvrr_stack + 157817;
 target_ptr = Libderiv->deriv2_classes[6][7][143];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+143822, dvrr_stack+189238, NULL);
 tmp = dvrr_stack + 143822;
 target_ptr = Libderiv->deriv2_classes[6][8][143];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+258851, dvrr_stack+212794, NULL);
 tmp = dvrr_stack + 258851;
 target_ptr = Libderiv->deriv2_classes[6][9][143];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,756,dvrr_stack+218674, dvrr_stack+235742, NULL);
 tmp = dvrr_stack + 218674;
 target_ptr = Libderiv->deriv2_classes[7][5][143];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+133154, dvrr_stack+252446, NULL);
 tmp = dvrr_stack + 133154;
 target_ptr = Libderiv->deriv2_classes[7][6][143];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+128406, dvrr_stack+273606, NULL);
 tmp = dvrr_stack + 128406;
 target_ptr = Libderiv->deriv2_classes[7][7][143];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+415367, dvrr_stack+299754, NULL);
 tmp = dvrr_stack + 415367;
 target_ptr = Libderiv->deriv2_classes[7][8][143];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+509546, dvrr_stack+328614, NULL);
 tmp = dvrr_stack + 509546;
 target_ptr = Libderiv->deriv2_classes[7][9][143];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,315,dvrr_stack+227831, dvrr_stack+10710, NULL);
 tmp = dvrr_stack + 227831;
 target_ptr = Libderiv->deriv2_classes[4][5][131];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,420,dvrr_stack+158825, dvrr_stack+18810, NULL);
 tmp = dvrr_stack + 158825;
 target_ptr = Libderiv->deriv2_classes[4][6][131];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,540,dvrr_stack+260391, dvrr_stack+29020, NULL);
 tmp = dvrr_stack + 260391;
 target_ptr = Libderiv->deriv2_classes[4][7][131];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,675,dvrr_stack+60592, dvrr_stack+41653, NULL);
 tmp = dvrr_stack + 60592;
 target_ptr = Libderiv->deriv2_classes[4][8][131];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,825,dvrr_stack+21923, dvrr_stack+56434, NULL);
 tmp = dvrr_stack + 21923;
 target_ptr = Libderiv->deriv2_classes[4][9][131];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,441,dvrr_stack+511526, dvrr_stack+68936, NULL);
 tmp = dvrr_stack + 511526;
 target_ptr = Libderiv->deriv2_classes[5][5][131];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,588,dvrr_stack+20721, dvrr_stack+78395, NULL);
 tmp = dvrr_stack + 20721;
 target_ptr = Libderiv->deriv2_classes[5][6][131];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,756,dvrr_stack+1155, dvrr_stack+90390, NULL);
 tmp = dvrr_stack + 1155;
 target_ptr = Libderiv->deriv2_classes[5][7][131];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,945,dvrr_stack+11655, dvrr_stack+105225, NULL);
 tmp = dvrr_stack + 11655;
 target_ptr = Libderiv->deriv2_classes[5][8][131];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1155,dvrr_stack+511967, dvrr_stack+123204, NULL);
 tmp = dvrr_stack + 511967;
 target_ptr = Libderiv->deriv2_classes[5][9][131];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,588,dvrr_stack+513122, dvrr_stack+140078, NULL);
 tmp = dvrr_stack + 513122;
 target_ptr = Libderiv->deriv2_classes[6][5][131];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,784,dvrr_stack+513710, dvrr_stack+152900, NULL);
 tmp = dvrr_stack + 513710;
 target_ptr = Libderiv->deriv2_classes[6][6][131];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1008,dvrr_stack+514494, dvrr_stack+169150, NULL);
 tmp = dvrr_stack + 514494;
 target_ptr = Libderiv->deriv2_classes[6][7][131];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1260,dvrr_stack+515502, dvrr_stack+189238, NULL);
 tmp = dvrr_stack + 515502;
 target_ptr = Libderiv->deriv2_classes[6][8][131];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1540,dvrr_stack+516762, dvrr_stack+212794, NULL);
 tmp = dvrr_stack + 516762;
 target_ptr = Libderiv->deriv2_classes[6][9][131];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,756,dvrr_stack+63767, dvrr_stack+235742, NULL);
 tmp = dvrr_stack + 63767;
 target_ptr = Libderiv->deriv2_classes[7][5][131];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1008,dvrr_stack+518302, dvrr_stack+252446, NULL);
 tmp = dvrr_stack + 518302;
 target_ptr = Libderiv->deriv2_classes[7][6][131];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1296,dvrr_stack+519310, dvrr_stack+273606, NULL);
 tmp = dvrr_stack + 519310;
 target_ptr = Libderiv->deriv2_classes[7][7][131];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1620,dvrr_stack+520606, dvrr_stack+299754, NULL);
 tmp = dvrr_stack + 520606;
 target_ptr = Libderiv->deriv2_classes[7][8][131];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1980,dvrr_stack+522226, dvrr_stack+328614, NULL);
 tmp = dvrr_stack + 522226;
 target_ptr = Libderiv->deriv2_classes[7][9][131];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+3440, dvrr_stack+304614, NULL);
 tmp = dvrr_stack + 3440;
 target_ptr = Libderiv->deriv2_classes[4][5][130];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+524206, dvrr_stack+193018, NULL);
 tmp = dvrr_stack + 524206;
 target_ptr = Libderiv->deriv2_classes[4][6][130];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+6444, dvrr_stack+92824, NULL);
 tmp = dvrr_stack + 6444;
 target_ptr = Libderiv->deriv2_classes[4][7][130];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+524626, dvrr_stack+108060, NULL);
 tmp = dvrr_stack + 524626;
 target_ptr = Libderiv->deriv2_classes[4][8][130];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+525301, dvrr_stack+334554, NULL);
 tmp = dvrr_stack + 525301;
 target_ptr = Libderiv->deriv2_classes[4][9][130];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+526126, dvrr_stack+194278, NULL);
 tmp = dvrr_stack + 526126;
 target_ptr = Libderiv->deriv2_classes[5][5][130];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+13365, dvrr_stack+337029, NULL);
 tmp = dvrr_stack + 13365;
 target_ptr = Libderiv->deriv2_classes[5][6][130];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+526567, dvrr_stack+338793, NULL);
 tmp = dvrr_stack + 526567;
 target_ptr = Libderiv->deriv2_classes[5][7][130];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+527323, dvrr_stack+341061, NULL);
 tmp = dvrr_stack + 527323;
 target_ptr = Libderiv->deriv2_classes[5][8][130];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+528268, dvrr_stack+343896, NULL);
 tmp = dvrr_stack + 528268;
 target_ptr = Libderiv->deriv2_classes[5][9][130];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+529423, dvrr_stack+347361, NULL);
 tmp = dvrr_stack + 529423;
 target_ptr = Libderiv->deriv2_classes[6][5][130];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+530011, dvrr_stack+349125, NULL);
 tmp = dvrr_stack + 530011;
 target_ptr = Libderiv->deriv2_classes[6][6][130];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+530795, dvrr_stack+351477, NULL);
 tmp = dvrr_stack + 530795;
 target_ptr = Libderiv->deriv2_classes[6][7][130];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+531803, dvrr_stack+354501, NULL);
 tmp = dvrr_stack + 531803;
 target_ptr = Libderiv->deriv2_classes[6][8][130];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+533063, dvrr_stack+358281, NULL);
 tmp = dvrr_stack + 533063;
 target_ptr = Libderiv->deriv2_classes[6][9][130];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+534603, dvrr_stack+362901, NULL);
 tmp = dvrr_stack + 534603;
 target_ptr = Libderiv->deriv2_classes[7][5][130];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+535359, dvrr_stack+365169, NULL);
 tmp = dvrr_stack + 535359;
 target_ptr = Libderiv->deriv2_classes[7][6][130];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+536367, dvrr_stack+368193, NULL);
 tmp = dvrr_stack + 536367;
 target_ptr = Libderiv->deriv2_classes[7][7][130];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+537663, dvrr_stack+372081, NULL);
 tmp = dvrr_stack + 537663;
 target_ptr = Libderiv->deriv2_classes[7][8][130];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+539283, dvrr_stack+376941, NULL);
 tmp = dvrr_stack + 539283;
 target_ptr = Libderiv->deriv2_classes[7][9][130];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,315,dvrr_stack+541263, dvrr_stack+10710, NULL);
 tmp = dvrr_stack + 541263;
 target_ptr = Libderiv->deriv2_classes[4][5][119];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,420,dvrr_stack+541578, dvrr_stack+18810, NULL);
 tmp = dvrr_stack + 541578;
 target_ptr = Libderiv->deriv2_classes[4][6][119];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,540,dvrr_stack+283534, dvrr_stack+29020, NULL);
 tmp = dvrr_stack + 283534;
 target_ptr = Libderiv->deriv2_classes[4][7][119];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,675,dvrr_stack+29011, dvrr_stack+41653, NULL);
 tmp = dvrr_stack + 29011;
 target_ptr = Libderiv->deriv2_classes[4][8][119];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,825,dvrr_stack+41527, dvrr_stack+56434, NULL);
 tmp = dvrr_stack + 41527;
 target_ptr = Libderiv->deriv2_classes[4][9][119];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,441,dvrr_stack+42352, dvrr_stack+68936, NULL);
 tmp = dvrr_stack + 42352;
 target_ptr = Libderiv->deriv2_classes[5][5][119];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,588,dvrr_stack+68810, dvrr_stack+78395, NULL);
 tmp = dvrr_stack + 68810;
 target_ptr = Libderiv->deriv2_classes[5][6][119];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,756,dvrr_stack+69398, dvrr_stack+90390, NULL);
 tmp = dvrr_stack + 69398;
 target_ptr = Libderiv->deriv2_classes[5][7][119];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,945,dvrr_stack+29686, dvrr_stack+105225, NULL);
 tmp = dvrr_stack + 29686;
 target_ptr = Libderiv->deriv2_classes[5][8][119];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1155,dvrr_stack+78339, dvrr_stack+123204, NULL);
 tmp = dvrr_stack + 78339;
 target_ptr = Libderiv->deriv2_classes[5][9][119];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,588,dvrr_stack+42793, dvrr_stack+140078, NULL);
 tmp = dvrr_stack + 42793;
 target_ptr = Libderiv->deriv2_classes[6][5][119];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,784,dvrr_stack+123198, dvrr_stack+152900, NULL);
 tmp = dvrr_stack + 123198;
 target_ptr = Libderiv->deriv2_classes[6][6][119];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1008,dvrr_stack+123982, dvrr_stack+169150, NULL);
 tmp = dvrr_stack + 123982;
 target_ptr = Libderiv->deriv2_classes[6][7][119];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1260,dvrr_stack+169150, dvrr_stack+189238, NULL);
 tmp = dvrr_stack + 169150;
 target_ptr = Libderiv->deriv2_classes[6][8][119];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1540,dvrr_stack+170410, dvrr_stack+212794, NULL);
 tmp = dvrr_stack + 170410;
 target_ptr = Libderiv->deriv2_classes[6][9][119];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,756,dvrr_stack+212794, dvrr_stack+235742, NULL);
 tmp = dvrr_stack + 212794;
 target_ptr = Libderiv->deriv2_classes[7][5][119];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1008,dvrr_stack+213550, dvrr_stack+252446, NULL);
 tmp = dvrr_stack + 213550;
 target_ptr = Libderiv->deriv2_classes[7][6][119];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1296,dvrr_stack+214558, dvrr_stack+273606, NULL);
 tmp = dvrr_stack + 214558;
 target_ptr = Libderiv->deriv2_classes[7][7][119];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1620,dvrr_stack+124990, dvrr_stack+299754, NULL);
 tmp = dvrr_stack + 124990;
 target_ptr = Libderiv->deriv2_classes[7][8][119];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1980,dvrr_stack+252414, dvrr_stack+328614, NULL);
 tmp = dvrr_stack + 252414;
 target_ptr = Libderiv->deriv2_classes[7][9][119];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+215854, dvrr_stack+304614, NULL);
 tmp = dvrr_stack + 215854;
 target_ptr = Libderiv->deriv2_classes[4][5][118];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+216169, dvrr_stack+193018, NULL);
 tmp = dvrr_stack + 216169;
 target_ptr = Libderiv->deriv2_classes[4][6][118];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+216589, dvrr_stack+92824, NULL);
 tmp = dvrr_stack + 216589;
 target_ptr = Libderiv->deriv2_classes[4][7][118];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+254394, dvrr_stack+108060, NULL);
 tmp = dvrr_stack + 254394;
 target_ptr = Libderiv->deriv2_classes[4][8][118];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+328489, dvrr_stack+334554, NULL);
 tmp = dvrr_stack + 328489;
 target_ptr = Libderiv->deriv2_classes[4][9][118];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+82535, dvrr_stack+194278, NULL);
 tmp = dvrr_stack + 82535;
 target_ptr = Libderiv->deriv2_classes[5][5][118];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+79494, dvrr_stack+337029, NULL);
 tmp = dvrr_stack + 79494;
 target_ptr = Libderiv->deriv2_classes[5][6][118];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+329314, dvrr_stack+338793, NULL);
 tmp = dvrr_stack + 329314;
 target_ptr = Libderiv->deriv2_classes[5][7][118];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+330070, dvrr_stack+341061, NULL);
 tmp = dvrr_stack + 330070;
 target_ptr = Libderiv->deriv2_classes[5][8][118];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+331015, dvrr_stack+343896, NULL);
 tmp = dvrr_stack + 331015;
 target_ptr = Libderiv->deriv2_classes[5][9][118];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+332170, dvrr_stack+347361, NULL);
 tmp = dvrr_stack + 332170;
 target_ptr = Libderiv->deriv2_classes[6][5][118];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+332758, dvrr_stack+349125, NULL);
 tmp = dvrr_stack + 332758;
 target_ptr = Libderiv->deriv2_classes[6][6][118];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+333542, dvrr_stack+351477, NULL);
 tmp = dvrr_stack + 333542;
 target_ptr = Libderiv->deriv2_classes[6][7][118];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+334550, dvrr_stack+354501, NULL);
 tmp = dvrr_stack + 334550;
 target_ptr = Libderiv->deriv2_classes[6][8][118];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+335810, dvrr_stack+358281, NULL);
 tmp = dvrr_stack + 335810;
 target_ptr = Libderiv->deriv2_classes[6][9][118];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+337350, dvrr_stack+362901, NULL);
 tmp = dvrr_stack + 337350;
 target_ptr = Libderiv->deriv2_classes[7][5][118];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+338106, dvrr_stack+365169, NULL);
 tmp = dvrr_stack + 338106;
 target_ptr = Libderiv->deriv2_classes[7][6][118];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+339114, dvrr_stack+368193, NULL);
 tmp = dvrr_stack + 339114;
 target_ptr = Libderiv->deriv2_classes[7][7][118];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+340410, dvrr_stack+372081, NULL);
 tmp = dvrr_stack + 340410;
 target_ptr = Libderiv->deriv2_classes[7][8][118];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+342030, dvrr_stack+376941, NULL);
 tmp = dvrr_stack + 342030;
 target_ptr = Libderiv->deriv2_classes[7][9][118];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+322792, dvrr_stack+305559, NULL);
 tmp = dvrr_stack + 322792;
 target_ptr = Libderiv->deriv2_classes[4][5][117];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+344010, dvrr_stack+8820, NULL);
 tmp = dvrr_stack + 344010;
 target_ptr = Libderiv->deriv2_classes[4][6][117];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+8820, dvrr_stack+16290, NULL);
 tmp = dvrr_stack + 8820;
 target_ptr = Libderiv->deriv2_classes[4][7][117];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+16290, dvrr_stack+25780, NULL);
 tmp = dvrr_stack + 16290;
 target_ptr = Libderiv->deriv2_classes[4][8][117];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+16965, dvrr_stack+37603, NULL);
 tmp = dvrr_stack + 16965;
 target_ptr = Libderiv->deriv2_classes[4][9][117];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+9360, dvrr_stack+51484, NULL);
 tmp = dvrr_stack + 9360;
 target_ptr = Libderiv->deriv2_classes[5][5][117];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+25405, dvrr_stack+66290, NULL);
 tmp = dvrr_stack + 25405;
 target_ptr = Libderiv->deriv2_classes[5][6][117];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+25993, dvrr_stack+74867, NULL);
 tmp = dvrr_stack + 25993;
 target_ptr = Libderiv->deriv2_classes[5][7][117];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+74867, dvrr_stack+85854, NULL);
 tmp = dvrr_stack + 74867;
 target_ptr = Libderiv->deriv2_classes[5][8][117];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+75812, dvrr_stack+99555, NULL);
 tmp = dvrr_stack + 75812;
 target_ptr = Libderiv->deriv2_classes[5][9][117];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+26749, dvrr_stack+116274, NULL);
 tmp = dvrr_stack + 26749;
 target_ptr = Libderiv->deriv2_classes[6][5][117];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+116176, dvrr_stack+136550, NULL);
 tmp = dvrr_stack + 116176;
 target_ptr = Libderiv->deriv2_classes[6][6][117];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+136532, dvrr_stack+148196, NULL);
 tmp = dvrr_stack + 136532;
 target_ptr = Libderiv->deriv2_classes[6][7][117];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+137540, dvrr_stack+163102, NULL);
 tmp = dvrr_stack + 137540;
 target_ptr = Libderiv->deriv2_classes[6][8][117];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+163037, dvrr_stack+181678, NULL);
 tmp = dvrr_stack + 163037;
 target_ptr = Libderiv->deriv2_classes[6][9][117];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+181597, dvrr_stack+166882, NULL);
 tmp = dvrr_stack + 181597;
 target_ptr = Libderiv->deriv2_classes[7][5][117];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+182353, dvrr_stack+231206, NULL);
 tmp = dvrr_stack + 182353;
 target_ptr = Libderiv->deriv2_classes[7][6][117];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+231018, dvrr_stack+246398, NULL);
 tmp = dvrr_stack + 231018;
 target_ptr = Libderiv->deriv2_classes[7][7][117];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+246398, dvrr_stack+265830, NULL);
 tmp = dvrr_stack + 246398;
 target_ptr = Libderiv->deriv2_classes[7][8][117];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+248018, dvrr_stack+290034, NULL);
 tmp = dvrr_stack + 248018;
 target_ptr = Libderiv->deriv2_classes[7][9][117];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+174809, dvrr_stack+317974, dvrr_stack+317749);
 tmp = dvrr_stack + 174809;
 target_ptr = Libderiv->deriv2_classes[4][5][107];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+27337, dvrr_stack+318709, dvrr_stack+318394);
 tmp = dvrr_stack + 27337;
 target_ptr = Libderiv->deriv2_classes[4][6][107];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+265642, dvrr_stack+319249, dvrr_stack+317974);
 tmp = dvrr_stack + 265642;
 target_ptr = Libderiv->deriv2_classes[4][7][107];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+266182, dvrr_stack+319924, dvrr_stack+318709);
 tmp = dvrr_stack + 266182;
 target_ptr = Libderiv->deriv2_classes[4][8][107];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+266857, dvrr_stack+320749, dvrr_stack+319249);
 tmp = dvrr_stack + 266857;
 target_ptr = Libderiv->deriv2_classes[4][9][107];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+267682, dvrr_stack+323464, dvrr_stack+323149);
 tmp = dvrr_stack + 267682;
 target_ptr = Libderiv->deriv2_classes[5][5][107];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+268123, dvrr_stack+324493, dvrr_stack+324052);
 tmp = dvrr_stack + 268123;
 target_ptr = Libderiv->deriv2_classes[5][6][107];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+268711, dvrr_stack+325249, dvrr_stack+323464);
 tmp = dvrr_stack + 268711;
 target_ptr = Libderiv->deriv2_classes[5][7][107];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+269467, dvrr_stack+326194, dvrr_stack+324493);
 tmp = dvrr_stack + 269467;
 target_ptr = Libderiv->deriv2_classes[5][8][107];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+290019, dvrr_stack+295974, dvrr_stack+325249);
 tmp = dvrr_stack + 290019;
 target_ptr = Libderiv->deriv2_classes[5][9][107];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+291174, dvrr_stack+297360, dvrr_stack+328069);
 tmp = dvrr_stack + 291174;
 target_ptr = Libderiv->deriv2_classes[6][5][107];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+291762, dvrr_stack+298732, dvrr_stack+298144);
 tmp = dvrr_stack + 291762;
 target_ptr = Libderiv->deriv2_classes[6][6][107];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+292546, dvrr_stack+270690, dvrr_stack+297360);
 tmp = dvrr_stack + 292546;
 target_ptr = Libderiv->deriv2_classes[6][7][107];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+293554, dvrr_stack+271950, dvrr_stack+298732);
 tmp = dvrr_stack + 293554;
 target_ptr = Libderiv->deriv2_classes[6][8][107];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+232314, dvrr_stack+250286, dvrr_stack+270690);
 tmp = dvrr_stack + 232314;
 target_ptr = Libderiv->deriv2_classes[6][9][107];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+294814, dvrr_stack+205174, dvrr_stack+235050);
 tmp = dvrr_stack + 294814;
 target_ptr = Libderiv->deriv2_classes[7][5][107];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+183361, dvrr_stack+206938, dvrr_stack+206182);
 tmp = dvrr_stack + 183361;
 target_ptr = Libderiv->deriv2_classes[7][6][107];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+184369, dvrr_stack+208234, dvrr_stack+205174);
 tmp = dvrr_stack + 184369;
 target_ptr = Libderiv->deriv2_classes[7][7][107];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+164577, dvrr_stack+209854, dvrr_stack+206938);
 tmp = dvrr_stack + 164577;
 target_ptr = Libderiv->deriv2_classes[7][8][107];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+166197, dvrr_stack+186298, dvrr_stack+208234);
 tmp = dvrr_stack + 166197;
 target_ptr = Libderiv->deriv2_classes[7][9][107];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+429519, dvrr_stack+212059, dvrr_stack+211834);
 tmp = dvrr_stack + 429519;
 target_ptr = Libderiv->deriv2_classes[4][5][106];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+185665, dvrr_stack+188674, dvrr_stack+212479);
 tmp = dvrr_stack + 185665;
 target_ptr = Libderiv->deriv2_classes[4][6][106];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+168177, dvrr_stack+151220, dvrr_stack+212059);
 tmp = dvrr_stack + 168177;
 target_ptr = Libderiv->deriv2_classes[4][7][106];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+148160, dvrr_stack+151895, dvrr_stack+188674);
 tmp = dvrr_stack + 148160;
 target_ptr = Libderiv->deriv2_classes[4][8][106];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+148835, dvrr_stack+138902, dvrr_stack+151220);
 tmp = dvrr_stack + 148835;
 target_ptr = Libderiv->deriv2_classes[4][9][106];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+149660, dvrr_stack+118353, dvrr_stack+118038);
 tmp = dvrr_stack + 149660;
 target_ptr = Libderiv->deriv2_classes[5][5][106];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+150101, dvrr_stack+119382, dvrr_stack+118941);
 tmp = dvrr_stack + 150101;
 target_ptr = Libderiv->deriv2_classes[5][6][106];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+116960, dvrr_stack+120138, dvrr_stack+118353);
 tmp = dvrr_stack + 116960;
 target_ptr = Libderiv->deriv2_classes[5][7][106];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+99450, dvrr_stack+121083, dvrr_stack+119382);
 tmp = dvrr_stack + 99450;
 target_ptr = Libderiv->deriv2_classes[5][8][106];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+100395, dvrr_stack+103020, dvrr_stack+120138);
 tmp = dvrr_stack + 100395;
 target_ptr = Libderiv->deriv2_classes[5][9][106];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+101550, dvrr_stack+104406, dvrr_stack+122238);
 tmp = dvrr_stack + 101550;
 target_ptr = Libderiv->deriv2_classes[6][5][106];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+102138, dvrr_stack+89277, dvrr_stack+88689);
 tmp = dvrr_stack + 102138;
 target_ptr = Libderiv->deriv2_classes[6][6][106];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+85722, dvrr_stack+52807, dvrr_stack+104406);
 tmp = dvrr_stack + 85722;
 target_ptr = Libderiv->deriv2_classes[6][7][106];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+86730, dvrr_stack+54067, dvrr_stack+89277);
 tmp = dvrr_stack + 86730;
 target_ptr = Libderiv->deriv2_classes[6][8][106];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+66263, dvrr_stack+382881, dvrr_stack+52807);
 tmp = dvrr_stack + 66263;
 target_ptr = Libderiv->deriv2_classes[6][9][106];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+51404, dvrr_stack+40078, dvrr_stack+122658);
 tmp = dvrr_stack + 51404;
 target_ptr = Libderiv->deriv2_classes[7][5][106];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+37414, dvrr_stack+32012, dvrr_stack+68054);
 tmp = dvrr_stack + 37414;
 target_ptr = Libderiv->deriv2_classes[7][6][106];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+38422, dvrr_stack+384729, dvrr_stack+40078);
 tmp = dvrr_stack + 38422;
 target_ptr = Libderiv->deriv2_classes[7][7][106];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+344430, dvrr_stack+386349, dvrr_stack+32012);
 tmp = dvrr_stack + 344430;
 target_ptr = Libderiv->deriv2_classes[7][8][106];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+346050, dvrr_stack+388329, dvrr_stack+384729);
 tmp = dvrr_stack + 346050;
 target_ptr = Libderiv->deriv2_classes[7][9][106];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+316739, dvrr_stack+317074, dvrr_stack+55607);
 tmp = dvrr_stack + 316739;
 target_ptr = Libderiv->deriv2_classes[4][5][105];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+168717, dvrr_stack+4203, dvrr_stack+7560);
 tmp = dvrr_stack + 168717;
 target_ptr = Libderiv->deriv2_classes[4][6][105];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+87990, dvrr_stack+14670, dvrr_stack+317074);
 tmp = dvrr_stack + 87990;
 target_ptr = Libderiv->deriv2_classes[4][7][105];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+348030, dvrr_stack+23755, dvrr_stack+4203);
 tmp = dvrr_stack + 348030;
 target_ptr = Libderiv->deriv2_classes[4][8][105];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+348705, dvrr_stack+35128, dvrr_stack+14670);
 tmp = dvrr_stack + 348705;
 target_ptr = Libderiv->deriv2_classes[4][9][105];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+150689, dvrr_stack+322204, dvrr_stack+48514);
 tmp = dvrr_stack + 150689;
 target_ptr = Libderiv->deriv2_classes[5][5][105];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+52160, dvrr_stack+61331, dvrr_stack+64526);
 tmp = dvrr_stack + 52160;
 target_ptr = Libderiv->deriv2_classes[5][6][105];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+349530, dvrr_stack+15345, dvrr_stack+322204);
 tmp = dvrr_stack + 349530;
 target_ptr = Libderiv->deriv2_classes[5][7][105];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+350286, dvrr_stack+83019, dvrr_stack+61331);
 tmp = dvrr_stack + 350286;
 target_ptr = Libderiv->deriv2_classes[5][8][105];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+351231, dvrr_stack+96090, dvrr_stack+15345);
 tmp = dvrr_stack + 351231;
 target_ptr = Libderiv->deriv2_classes[5][9][105];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+352386, dvrr_stack+77135, dvrr_stack+112116);
 tmp = dvrr_stack + 352386;
 target_ptr = Libderiv->deriv2_classes[6][5][105];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+352974, dvrr_stack+129770, dvrr_stack+134198);
 tmp = dvrr_stack + 352974;
 target_ptr = Libderiv->deriv2_classes[6][6][105];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+353758, dvrr_stack+145172, dvrr_stack+77135);
 tmp = dvrr_stack + 353758;
 target_ptr = Libderiv->deriv2_classes[6][7][105];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+354766, dvrr_stack+159322, dvrr_stack+129770);
 tmp = dvrr_stack + 354766;
 target_ptr = Libderiv->deriv2_classes[6][8][105];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+356026, dvrr_stack+177058, dvrr_stack+145172);
 tmp = dvrr_stack + 356026;
 target_ptr = Libderiv->deriv2_classes[6][9][105];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+357566, dvrr_stack+198550, dvrr_stack+198010);
 tmp = dvrr_stack + 357566;
 target_ptr = Libderiv->deriv2_classes[7][5][105];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+358322, dvrr_stack+222314, dvrr_stack+130778);
 tmp = dvrr_stack + 358322;
 target_ptr = Libderiv->deriv2_classes[7][6][105];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+359330, dvrr_stack+242510, dvrr_stack+198550);
 tmp = dvrr_stack + 359330;
 target_ptr = Libderiv->deriv2_classes[7][7][105];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+360626, dvrr_stack+260970, dvrr_stack+222314);
 tmp = dvrr_stack + 360626;
 target_ptr = Libderiv->deriv2_classes[7][8][105];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+362246, dvrr_stack+284094, dvrr_stack+242510);
 tmp = dvrr_stack + 362246;
 target_ptr = Libderiv->deriv2_classes[7][9][105];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+459789, dvrr_stack+310294, dvrr_stack+310069);
 tmp = dvrr_stack + 459789;
 target_ptr = Libderiv->deriv2_classes[4][5][104];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+364226, dvrr_stack+311029, dvrr_stack+310714);
 tmp = dvrr_stack + 364226;
 target_ptr = Libderiv->deriv2_classes[4][6][104];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+364646, dvrr_stack+311569, dvrr_stack+310294);
 tmp = dvrr_stack + 364646;
 target_ptr = Libderiv->deriv2_classes[4][7][104];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+365186, dvrr_stack+312244, dvrr_stack+311029);
 tmp = dvrr_stack + 365186;
 target_ptr = Libderiv->deriv2_classes[4][8][104];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+365861, dvrr_stack+313069, dvrr_stack+311569);
 tmp = dvrr_stack + 365861;
 target_ptr = Libderiv->deriv2_classes[4][9][104];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+366686, dvrr_stack+314674, dvrr_stack+314359);
 tmp = dvrr_stack + 366686;
 target_ptr = Libderiv->deriv2_classes[5][5][104];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+367127, dvrr_stack+315703, dvrr_stack+315262);
 tmp = dvrr_stack + 367127;
 target_ptr = Libderiv->deriv2_classes[5][6][104];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+367715, dvrr_stack+7875, dvrr_stack+314674);
 tmp = dvrr_stack + 367715;
 target_ptr = Libderiv->deriv2_classes[5][7][104];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+368471, dvrr_stack+286470, dvrr_stack+315703);
 tmp = dvrr_stack + 368471;
 target_ptr = Libderiv->deriv2_classes[5][8][104];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+369416, dvrr_stack+287625, dvrr_stack+7875);
 tmp = dvrr_stack + 369416;
 target_ptr = Libderiv->deriv2_classes[5][9][104];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+370571, dvrr_stack+262950, dvrr_stack+289011);
 tmp = dvrr_stack + 370571;
 target_ptr = Libderiv->deriv2_classes[6][5][104];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+371159, dvrr_stack+263734, dvrr_stack+289431);
 tmp = dvrr_stack + 371159;
 target_ptr = Libderiv->deriv2_classes[6][6][104];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+371943, dvrr_stack+244130, dvrr_stack+262950);
 tmp = dvrr_stack + 371943;
 target_ptr = Libderiv->deriv2_classes[6][7][104];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+372951, dvrr_stack+228182, dvrr_stack+263734);
 tmp = dvrr_stack + 372951;
 target_ptr = Libderiv->deriv2_classes[6][8][104];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+374211, dvrr_stack+199558, dvrr_stack+244130);
 tmp = dvrr_stack + 374211;
 target_ptr = Libderiv->deriv2_classes[6][9][104];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+375751, dvrr_stack+245390, dvrr_stack+265102);
 tmp = dvrr_stack + 375751;
 target_ptr = Libderiv->deriv2_classes[7][5][104];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+376507, dvrr_stack+229722, dvrr_stack+223610);
 tmp = dvrr_stack + 376507;
 target_ptr = Libderiv->deriv2_classes[7][6][104];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+377515, dvrr_stack+201406, dvrr_stack+245390);
 tmp = dvrr_stack + 377515;
 target_ptr = Libderiv->deriv2_classes[7][7][104];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+378811, dvrr_stack+203026, dvrr_stack+229722);
 tmp = dvrr_stack + 378811;
 target_ptr = Libderiv->deriv2_classes[7][8][104];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+380431, dvrr_stack+178906, dvrr_stack+201406);
 tmp = dvrr_stack + 380431;
 target_ptr = Libderiv->deriv2_classes[7][9][104];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+295570, dvrr_stack+317974, dvrr_stack+317749);
 tmp = dvrr_stack + 295570;
 target_ptr = Libderiv->deriv2_classes[4][5][95];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+382411, dvrr_stack+318709, dvrr_stack+318394);
 tmp = dvrr_stack + 382411;
 target_ptr = Libderiv->deriv2_classes[4][6][95];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+299740, dvrr_stack+319249, dvrr_stack+317974);
 tmp = dvrr_stack + 299740;
 target_ptr = Libderiv->deriv2_classes[4][7][95];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+300280, dvrr_stack+319924, dvrr_stack+318709);
 tmp = dvrr_stack + 300280;
 target_ptr = Libderiv->deriv2_classes[4][8][95];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+300955, dvrr_stack+320749, dvrr_stack+319249);
 tmp = dvrr_stack + 300955;
 target_ptr = Libderiv->deriv2_classes[4][9][95];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+301780, dvrr_stack+323464, dvrr_stack+323149);
 tmp = dvrr_stack + 301780;
 target_ptr = Libderiv->deriv2_classes[5][5][95];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+302221, dvrr_stack+324493, dvrr_stack+324052);
 tmp = dvrr_stack + 302221;
 target_ptr = Libderiv->deriv2_classes[5][6][95];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+302809, dvrr_stack+325249, dvrr_stack+323464);
 tmp = dvrr_stack + 302809;
 target_ptr = Libderiv->deriv2_classes[5][7][95];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+303565, dvrr_stack+326194, dvrr_stack+324493);
 tmp = dvrr_stack + 303565;
 target_ptr = Libderiv->deriv2_classes[5][8][95];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+304510, dvrr_stack+295974, dvrr_stack+325249);
 tmp = dvrr_stack + 304510;
 target_ptr = Libderiv->deriv2_classes[5][9][95];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+305665, dvrr_stack+297360, dvrr_stack+328069);
 tmp = dvrr_stack + 305665;
 target_ptr = Libderiv->deriv2_classes[6][5][95];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+273490, dvrr_stack+298732, dvrr_stack+298144);
 tmp = dvrr_stack + 273490;
 target_ptr = Libderiv->deriv2_classes[6][6][95];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+274274, dvrr_stack+270690, dvrr_stack+297360);
 tmp = dvrr_stack + 274274;
 target_ptr = Libderiv->deriv2_classes[6][7][95];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+275282, dvrr_stack+271950, dvrr_stack+298732);
 tmp = dvrr_stack + 275282;
 target_ptr = Libderiv->deriv2_classes[6][8][95];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+235590, dvrr_stack+250286, dvrr_stack+270690);
 tmp = dvrr_stack + 235590;
 target_ptr = Libderiv->deriv2_classes[6][9][95];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+276542, dvrr_stack+205174, dvrr_stack+235050);
 tmp = dvrr_stack + 276542;
 target_ptr = Libderiv->deriv2_classes[7][5][95];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+189214, dvrr_stack+206938, dvrr_stack+206182);
 tmp = dvrr_stack + 189214;
 target_ptr = Libderiv->deriv2_classes[7][6][95];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+190222, dvrr_stack+208234, dvrr_stack+205174);
 tmp = dvrr_stack + 190222;
 target_ptr = Libderiv->deriv2_classes[7][7][95];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+191518, dvrr_stack+209854, dvrr_stack+206938);
 tmp = dvrr_stack + 191518;
 target_ptr = Libderiv->deriv2_classes[7][8][95];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+193138, dvrr_stack+186298, dvrr_stack+208234);
 tmp = dvrr_stack + 193138;
 target_ptr = Libderiv->deriv2_classes[7][9][95];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+255069, dvrr_stack+212059, dvrr_stack+211834);
 tmp = dvrr_stack + 255069;
 target_ptr = Libderiv->deriv2_classes[4][5][94];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+237130, dvrr_stack+188674, dvrr_stack+212479);
 tmp = dvrr_stack + 237130;
 target_ptr = Libderiv->deriv2_classes[4][6][94];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+152720, dvrr_stack+151220, dvrr_stack+212059);
 tmp = dvrr_stack + 152720;
 target_ptr = Libderiv->deriv2_classes[4][7][94];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+153260, dvrr_stack+151895, dvrr_stack+188674);
 tmp = dvrr_stack + 153260;
 target_ptr = Libderiv->deriv2_classes[4][8][94];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+153935, dvrr_stack+138902, dvrr_stack+151220);
 tmp = dvrr_stack + 153935;
 target_ptr = Libderiv->deriv2_classes[4][9][94];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+237550, dvrr_stack+118353, dvrr_stack+118038);
 tmp = dvrr_stack + 237550;
 target_ptr = Libderiv->deriv2_classes[5][5][94];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+139892, dvrr_stack+119382, dvrr_stack+118941);
 tmp = dvrr_stack + 139892;
 target_ptr = Libderiv->deriv2_classes[5][6][94];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+140480, dvrr_stack+120138, dvrr_stack+118353);
 tmp = dvrr_stack + 140480;
 target_ptr = Libderiv->deriv2_classes[5][7][94];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+105190, dvrr_stack+121083, dvrr_stack+119382);
 tmp = dvrr_stack + 105190;
 target_ptr = Libderiv->deriv2_classes[5][8][94];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+106135, dvrr_stack+103020, dvrr_stack+120138);
 tmp = dvrr_stack + 106135;
 target_ptr = Libderiv->deriv2_classes[5][9][94];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+141236, dvrr_stack+104406, dvrr_stack+122238);
 tmp = dvrr_stack + 141236;
 target_ptr = Libderiv->deriv2_classes[6][5][94];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+107290, dvrr_stack+89277, dvrr_stack+88689);
 tmp = dvrr_stack + 107290;
 target_ptr = Libderiv->deriv2_classes[6][6][94];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+108074, dvrr_stack+52807, dvrr_stack+104406);
 tmp = dvrr_stack + 108074;
 target_ptr = Libderiv->deriv2_classes[6][7][94];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+90285, dvrr_stack+54067, dvrr_stack+89277);
 tmp = dvrr_stack + 90285;
 target_ptr = Libderiv->deriv2_classes[6][8][94];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+91545, dvrr_stack+382881, dvrr_stack+52807);
 tmp = dvrr_stack + 91545;
 target_ptr = Libderiv->deriv2_classes[6][9][94];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+109082, dvrr_stack+40078, dvrr_stack+122658);
 tmp = dvrr_stack + 109082;
 target_ptr = Libderiv->deriv2_classes[7][5][94];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+93085, dvrr_stack+32012, dvrr_stack+68054);
 tmp = dvrr_stack + 93085;
 target_ptr = Libderiv->deriv2_classes[7][6][94];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+56420, dvrr_stack+384729, dvrr_stack+40078);
 tmp = dvrr_stack + 56420;
 target_ptr = Libderiv->deriv2_classes[7][7][94];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+18694, dvrr_stack+386349, dvrr_stack+32012);
 tmp = dvrr_stack + 18694;
 target_ptr = Libderiv->deriv2_classes[7][8][94];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+541998, dvrr_stack+388329, dvrr_stack+384729);
 tmp = dvrr_stack + 541998;
 target_ptr = Libderiv->deriv2_classes[7][9][94];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+233854, dvrr_stack+317074, dvrr_stack+55607);
 tmp = dvrr_stack + 233854;
 target_ptr = Libderiv->deriv2_classes[4][5][93];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+195118, dvrr_stack+4203, dvrr_stack+7560);
 tmp = dvrr_stack + 195118;
 target_ptr = Libderiv->deriv2_classes[4][6][93];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+57716, dvrr_stack+14670, dvrr_stack+317074);
 tmp = dvrr_stack + 57716;
 target_ptr = Libderiv->deriv2_classes[4][7][93];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+10668, dvrr_stack+23755, dvrr_stack+4203);
 tmp = dvrr_stack + 10668;
 target_ptr = Libderiv->deriv2_classes[4][8][93];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+543978, dvrr_stack+35128, dvrr_stack+14670);
 tmp = dvrr_stack + 543978;
 target_ptr = Libderiv->deriv2_classes[4][9][93];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+154760, dvrr_stack+322204, dvrr_stack+48514);
 tmp = dvrr_stack + 154760;
 target_ptr = Libderiv->deriv2_classes[5][5][93];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+58256, dvrr_stack+61331, dvrr_stack+64526);
 tmp = dvrr_stack + 58256;
 target_ptr = Libderiv->deriv2_classes[5][6][93];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+544803, dvrr_stack+15345, dvrr_stack+322204);
 tmp = dvrr_stack + 544803;
 target_ptr = Libderiv->deriv2_classes[5][7][93];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+545559, dvrr_stack+83019, dvrr_stack+61331);
 tmp = dvrr_stack + 545559;
 target_ptr = Libderiv->deriv2_classes[5][8][93];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+546504, dvrr_stack+96090, dvrr_stack+15345);
 tmp = dvrr_stack + 546504;
 target_ptr = Libderiv->deriv2_classes[5][9][93];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+547659, dvrr_stack+77135, dvrr_stack+112116);
 tmp = dvrr_stack + 547659;
 target_ptr = Libderiv->deriv2_classes[6][5][93];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+548247, dvrr_stack+129770, dvrr_stack+134198);
 tmp = dvrr_stack + 548247;
 target_ptr = Libderiv->deriv2_classes[6][6][93];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+549031, dvrr_stack+145172, dvrr_stack+77135);
 tmp = dvrr_stack + 549031;
 target_ptr = Libderiv->deriv2_classes[6][7][93];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+550039, dvrr_stack+159322, dvrr_stack+129770);
 tmp = dvrr_stack + 550039;
 target_ptr = Libderiv->deriv2_classes[6][8][93];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+551299, dvrr_stack+177058, dvrr_stack+145172);
 tmp = dvrr_stack + 551299;
 target_ptr = Libderiv->deriv2_classes[6][9][93];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+552839, dvrr_stack+198550, dvrr_stack+198010);
 tmp = dvrr_stack + 552839;
 target_ptr = Libderiv->deriv2_classes[7][5][93];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+553595, dvrr_stack+222314, dvrr_stack+130778);
 tmp = dvrr_stack + 553595;
 target_ptr = Libderiv->deriv2_classes[7][6][93];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+554603, dvrr_stack+242510, dvrr_stack+198550);
 tmp = dvrr_stack + 554603;
 target_ptr = Libderiv->deriv2_classes[7][7][93];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+555899, dvrr_stack+260970, dvrr_stack+222314);
 tmp = dvrr_stack + 555899;
 target_ptr = Libderiv->deriv2_classes[7][8][93];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+557519, dvrr_stack+284094, dvrr_stack+242510);
 tmp = dvrr_stack + 557519;
 target_ptr = Libderiv->deriv2_classes[7][9][93];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+559499, dvrr_stack+310294, dvrr_stack+310069);
 tmp = dvrr_stack + 559499;
 target_ptr = Libderiv->deriv2_classes[4][5][92];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+559814, dvrr_stack+311029, dvrr_stack+310714);
 tmp = dvrr_stack + 559814;
 target_ptr = Libderiv->deriv2_classes[4][6][92];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+560234, dvrr_stack+311569, dvrr_stack+310294);
 tmp = dvrr_stack + 560234;
 target_ptr = Libderiv->deriv2_classes[4][7][92];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+560774, dvrr_stack+312244, dvrr_stack+311029);
 tmp = dvrr_stack + 560774;
 target_ptr = Libderiv->deriv2_classes[4][8][92];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+561449, dvrr_stack+313069, dvrr_stack+311569);
 tmp = dvrr_stack + 561449;
 target_ptr = Libderiv->deriv2_classes[4][9][92];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+562274, dvrr_stack+314674, dvrr_stack+314359);
 tmp = dvrr_stack + 562274;
 target_ptr = Libderiv->deriv2_classes[5][5][92];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+562715, dvrr_stack+315703, dvrr_stack+315262);
 tmp = dvrr_stack + 562715;
 target_ptr = Libderiv->deriv2_classes[5][6][92];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+563303, dvrr_stack+7875, dvrr_stack+314674);
 tmp = dvrr_stack + 563303;
 target_ptr = Libderiv->deriv2_classes[5][7][92];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+564059, dvrr_stack+286470, dvrr_stack+315703);
 tmp = dvrr_stack + 564059;
 target_ptr = Libderiv->deriv2_classes[5][8][92];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+565004, dvrr_stack+287625, dvrr_stack+7875);
 tmp = dvrr_stack + 565004;
 target_ptr = Libderiv->deriv2_classes[5][9][92];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+566159, dvrr_stack+262950, dvrr_stack+289011);
 tmp = dvrr_stack + 566159;
 target_ptr = Libderiv->deriv2_classes[6][5][92];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+566747, dvrr_stack+263734, dvrr_stack+289431);
 tmp = dvrr_stack + 566747;
 target_ptr = Libderiv->deriv2_classes[6][6][92];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+567531, dvrr_stack+244130, dvrr_stack+262950);
 tmp = dvrr_stack + 567531;
 target_ptr = Libderiv->deriv2_classes[6][7][92];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+568539, dvrr_stack+228182, dvrr_stack+263734);
 tmp = dvrr_stack + 568539;
 target_ptr = Libderiv->deriv2_classes[6][8][92];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+569799, dvrr_stack+199558, dvrr_stack+244130);
 tmp = dvrr_stack + 569799;
 target_ptr = Libderiv->deriv2_classes[6][9][92];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+571339, dvrr_stack+245390, dvrr_stack+265102);
 tmp = dvrr_stack + 571339;
 target_ptr = Libderiv->deriv2_classes[7][5][92];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+572095, dvrr_stack+229722, dvrr_stack+223610);
 tmp = dvrr_stack + 572095;
 target_ptr = Libderiv->deriv2_classes[7][6][92];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+573103, dvrr_stack+201406, dvrr_stack+245390);
 tmp = dvrr_stack + 573103;
 target_ptr = Libderiv->deriv2_classes[7][7][92];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+574399, dvrr_stack+203026, dvrr_stack+229722);
 tmp = dvrr_stack + 574399;
 target_ptr = Libderiv->deriv2_classes[7][8][92];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+576019, dvrr_stack+178906, dvrr_stack+201406);
 tmp = dvrr_stack + 576019;
 target_ptr = Libderiv->deriv2_classes[7][9][92];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+117716, dvrr_stack+160862, dvrr_stack+309606);
 tmp = dvrr_stack + 117716;
 target_ptr = Libderiv->deriv2_classes[4][5][91];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+577999, dvrr_stack+161282, dvrr_stack+181282);
 tmp = dvrr_stack + 577999;
 target_ptr = Libderiv->deriv2_classes[4][6][91];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+578419, dvrr_stack+161822, dvrr_stack+160862);
 tmp = dvrr_stack + 578419;
 target_ptr = Libderiv->deriv2_classes[4][7][91];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+578959, dvrr_stack+146432, dvrr_stack+161282);
 tmp = dvrr_stack + 578959;
 target_ptr = Libderiv->deriv2_classes[4][8][91];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+579634, dvrr_stack+134786, dvrr_stack+161822);
 tmp = dvrr_stack + 579634;
 target_ptr = Libderiv->deriv2_classes[4][9][91];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+580459, dvrr_stack+147257, dvrr_stack+162497);
 tmp = dvrr_stack + 580459;
 target_ptr = Libderiv->deriv2_classes[5][5][91];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+580900, dvrr_stack+112536, dvrr_stack+135776);
 tmp = dvrr_stack + 580900;
 target_ptr = Libderiv->deriv2_classes[5][6][91];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+581488, dvrr_stack+113292, dvrr_stack+147257);
 tmp = dvrr_stack + 581488;
 target_ptr = Libderiv->deriv2_classes[5][7][91];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+582244, dvrr_stack+114237, dvrr_stack+112536);
 tmp = dvrr_stack + 582244;
 target_ptr = Libderiv->deriv2_classes[5][8][91];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+583189, dvrr_stack+97476, dvrr_stack+113292);
 tmp = dvrr_stack + 583189;
 target_ptr = Libderiv->deriv2_classes[5][9][91];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+584344, dvrr_stack+115392, dvrr_stack+77919);
 tmp = dvrr_stack + 584344;
 target_ptr = Libderiv->deriv2_classes[6][5][91];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+584932, dvrr_stack+84174, dvrr_stack+98862);
 tmp = dvrr_stack + 584932;
 target_ptr = Libderiv->deriv2_classes[6][6][91];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+585716, dvrr_stack+72599, dvrr_stack+115392);
 tmp = dvrr_stack + 585716;
 target_ptr = Libderiv->deriv2_classes[6][7][91];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+586724, dvrr_stack+48829, dvrr_stack+84174);
 tmp = dvrr_stack + 586724;
 target_ptr = Libderiv->deriv2_classes[6][8][91];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+587984, dvrr_stack+390705, dvrr_stack+72599);
 tmp = dvrr_stack + 587984;
 target_ptr = Libderiv->deriv2_classes[6][9][91];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+589524, dvrr_stack+73859, dvrr_stack+85182);
 tmp = dvrr_stack + 589524;
 target_ptr = Libderiv->deriv2_classes[7][5][91];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+590280, dvrr_stack+36118, dvrr_stack+64967);
 tmp = dvrr_stack + 590280;
 target_ptr = Libderiv->deriv2_classes[7][6][91];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+591288, dvrr_stack+392553, dvrr_stack+73859);
 tmp = dvrr_stack + 591288;
 target_ptr = Libderiv->deriv2_classes[7][7][91];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+592584, dvrr_stack+394173, dvrr_stack+36118);
 tmp = dvrr_stack + 592584;
 target_ptr = Libderiv->deriv2_classes[7][8][91];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+594204, dvrr_stack+396153, dvrr_stack+392553);
 tmp = dvrr_stack + 594204;
 target_ptr = Libderiv->deriv2_classes[7][9][91];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+596184, dvrr_stack+317974, dvrr_stack+317749);
 tmp = dvrr_stack + 596184;
 target_ptr = Libderiv->deriv2_classes[4][5][83];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+596499, dvrr_stack+318709, dvrr_stack+318394);
 tmp = dvrr_stack + 596499;
 target_ptr = Libderiv->deriv2_classes[4][6][83];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+596919, dvrr_stack+319249, dvrr_stack+317974);
 tmp = dvrr_stack + 596919;
 target_ptr = Libderiv->deriv2_classes[4][7][83];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+597459, dvrr_stack+319924, dvrr_stack+318709);
 tmp = dvrr_stack + 597459;
 target_ptr = Libderiv->deriv2_classes[4][8][83];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+598134, dvrr_stack+320749, dvrr_stack+319249);
 tmp = dvrr_stack + 598134;
 target_ptr = Libderiv->deriv2_classes[4][9][83];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+320749, dvrr_stack+323464, dvrr_stack+323149);
 tmp = dvrr_stack + 320749;
 target_ptr = Libderiv->deriv2_classes[5][5][83];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+598959, dvrr_stack+324493, dvrr_stack+324052);
 tmp = dvrr_stack + 598959;
 target_ptr = Libderiv->deriv2_classes[5][6][83];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+599547, dvrr_stack+325249, dvrr_stack+323464);
 tmp = dvrr_stack + 599547;
 target_ptr = Libderiv->deriv2_classes[5][7][83];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+600303, dvrr_stack+326194, dvrr_stack+324493);
 tmp = dvrr_stack + 600303;
 target_ptr = Libderiv->deriv2_classes[5][8][83];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+601248, dvrr_stack+295974, dvrr_stack+325249);
 tmp = dvrr_stack + 601248;
 target_ptr = Libderiv->deriv2_classes[5][9][83];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+602403, dvrr_stack+297360, dvrr_stack+328069);
 tmp = dvrr_stack + 602403;
 target_ptr = Libderiv->deriv2_classes[6][5][83];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+295885, dvrr_stack+298732, dvrr_stack+298144);
 tmp = dvrr_stack + 295885;
 target_ptr = Libderiv->deriv2_classes[6][6][83];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+602991, dvrr_stack+270690, dvrr_stack+297360);
 tmp = dvrr_stack + 602991;
 target_ptr = Libderiv->deriv2_classes[6][7][83];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+603999, dvrr_stack+271950, dvrr_stack+298732);
 tmp = dvrr_stack + 603999;
 target_ptr = Libderiv->deriv2_classes[6][8][83];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+605259, dvrr_stack+250286, dvrr_stack+270690);
 tmp = dvrr_stack + 605259;
 target_ptr = Libderiv->deriv2_classes[6][9][83];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+249998, dvrr_stack+205174, dvrr_stack+235050);
 tmp = dvrr_stack + 249998;
 target_ptr = Libderiv->deriv2_classes[7][5][83];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+250754, dvrr_stack+206938, dvrr_stack+206182);
 tmp = dvrr_stack + 250754;
 target_ptr = Libderiv->deriv2_classes[7][6][83];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+606799, dvrr_stack+208234, dvrr_stack+205174);
 tmp = dvrr_stack + 606799;
 target_ptr = Libderiv->deriv2_classes[7][7][83];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+608095, dvrr_stack+209854, dvrr_stack+206938);
 tmp = dvrr_stack + 608095;
 target_ptr = Libderiv->deriv2_classes[7][8][83];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+609715, dvrr_stack+186298, dvrr_stack+208234);
 tmp = dvrr_stack + 609715;
 target_ptr = Libderiv->deriv2_classes[7][9][83];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+321190, dvrr_stack+212059, dvrr_stack+211834);
 tmp = dvrr_stack + 321190;
 target_ptr = Libderiv->deriv2_classes[4][5][82];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+296669, dvrr_stack+188674, dvrr_stack+212479);
 tmp = dvrr_stack + 296669;
 target_ptr = Libderiv->deriv2_classes[4][6][82];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+234930, dvrr_stack+151220, dvrr_stack+212059);
 tmp = dvrr_stack + 234930;
 target_ptr = Libderiv->deriv2_classes[4][7][82];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+186085, dvrr_stack+151895, dvrr_stack+188674);
 tmp = dvrr_stack + 186085;
 target_ptr = Libderiv->deriv2_classes[4][8][82];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+186760, dvrr_stack+138902, dvrr_stack+151220);
 tmp = dvrr_stack + 186760;
 target_ptr = Libderiv->deriv2_classes[4][9][82];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+138800, dvrr_stack+118353, dvrr_stack+118038);
 tmp = dvrr_stack + 138800;
 target_ptr = Libderiv->deriv2_classes[5][5][82];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+139241, dvrr_stack+119382, dvrr_stack+118941);
 tmp = dvrr_stack + 139241;
 target_ptr = Libderiv->deriv2_classes[5][6][82];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+187585, dvrr_stack+120138, dvrr_stack+118353);
 tmp = dvrr_stack + 187585;
 target_ptr = Libderiv->deriv2_classes[5][7][82];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+611695, dvrr_stack+121083, dvrr_stack+119382);
 tmp = dvrr_stack + 611695;
 target_ptr = Libderiv->deriv2_classes[5][8][82];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+612640, dvrr_stack+103020, dvrr_stack+120138);
 tmp = dvrr_stack + 612640;
 target_ptr = Libderiv->deriv2_classes[5][9][82];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+327899, dvrr_stack+104406, dvrr_stack+122238);
 tmp = dvrr_stack + 327899;
 target_ptr = Libderiv->deriv2_classes[6][5][82];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+102922, dvrr_stack+89277, dvrr_stack+88689);
 tmp = dvrr_stack + 102922;
 target_ptr = Libderiv->deriv2_classes[6][6][82];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+613795, dvrr_stack+52807, dvrr_stack+104406);
 tmp = dvrr_stack + 613795;
 target_ptr = Libderiv->deriv2_classes[6][7][82];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+614803, dvrr_stack+54067, dvrr_stack+89277);
 tmp = dvrr_stack + 614803;
 target_ptr = Libderiv->deriv2_classes[6][8][82];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+616063, dvrr_stack+382881, dvrr_stack+52807);
 tmp = dvrr_stack + 616063;
 target_ptr = Libderiv->deriv2_classes[6][9][82];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+382831, dvrr_stack+40078, dvrr_stack+122658);
 tmp = dvrr_stack + 382831;
 target_ptr = Libderiv->deriv2_classes[7][5][82];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+383587, dvrr_stack+32012, dvrr_stack+68054);
 tmp = dvrr_stack + 383587;
 target_ptr = Libderiv->deriv2_classes[7][6][82];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+617603, dvrr_stack+384729, dvrr_stack+40078);
 tmp = dvrr_stack + 617603;
 target_ptr = Libderiv->deriv2_classes[7][7][82];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+618899, dvrr_stack+386349, dvrr_stack+32012);
 tmp = dvrr_stack + 618899;
 target_ptr = Libderiv->deriv2_classes[7][8][82];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+620519, dvrr_stack+388329, dvrr_stack+384729);
 tmp = dvrr_stack + 620519;
 target_ptr = Libderiv->deriv2_classes[7][9][82];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+388329, dvrr_stack+317074, dvrr_stack+55607);
 tmp = dvrr_stack + 388329;
 target_ptr = Libderiv->deriv2_classes[4][5][81];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+388644, dvrr_stack+4203, dvrr_stack+7560);
 tmp = dvrr_stack + 388644;
 target_ptr = Libderiv->deriv2_classes[4][6][81];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+389064, dvrr_stack+14670, dvrr_stack+317074);
 tmp = dvrr_stack + 389064;
 target_ptr = Libderiv->deriv2_classes[4][7][81];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+389604, dvrr_stack+23755, dvrr_stack+4203);
 tmp = dvrr_stack + 389604;
 target_ptr = Libderiv->deriv2_classes[4][8][81];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+122238, dvrr_stack+35128, dvrr_stack+14670);
 tmp = dvrr_stack + 122238;
 target_ptr = Libderiv->deriv2_classes[4][9][81];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+35128, dvrr_stack+322204, dvrr_stack+48514);
 tmp = dvrr_stack + 35128;
 target_ptr = Libderiv->deriv2_classes[5][5][81];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+103706, dvrr_stack+61331, dvrr_stack+64526);
 tmp = dvrr_stack + 103706;
 target_ptr = Libderiv->deriv2_classes[5][6][81];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+622499, dvrr_stack+15345, dvrr_stack+322204);
 tmp = dvrr_stack + 622499;
 target_ptr = Libderiv->deriv2_classes[5][7][81];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+623255, dvrr_stack+83019, dvrr_stack+61331);
 tmp = dvrr_stack + 623255;
 target_ptr = Libderiv->deriv2_classes[5][8][81];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+624200, dvrr_stack+96090, dvrr_stack+15345);
 tmp = dvrr_stack + 624200;
 target_ptr = Libderiv->deriv2_classes[5][9][81];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+625355, dvrr_stack+77135, dvrr_stack+112116);
 tmp = dvrr_stack + 625355;
 target_ptr = Libderiv->deriv2_classes[6][5][81];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+95830, dvrr_stack+129770, dvrr_stack+134198);
 tmp = dvrr_stack + 95830;
 target_ptr = Libderiv->deriv2_classes[6][6][81];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+625943, dvrr_stack+145172, dvrr_stack+77135);
 tmp = dvrr_stack + 625943;
 target_ptr = Libderiv->deriv2_classes[6][7][81];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+626951, dvrr_stack+159322, dvrr_stack+129770);
 tmp = dvrr_stack + 626951;
 target_ptr = Libderiv->deriv2_classes[6][8][81];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+628211, dvrr_stack+177058, dvrr_stack+145172);
 tmp = dvrr_stack + 628211;
 target_ptr = Libderiv->deriv2_classes[6][9][81];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+176764, dvrr_stack+198550, dvrr_stack+198010);
 tmp = dvrr_stack + 176764;
 target_ptr = Libderiv->deriv2_classes[7][5][81];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+177520, dvrr_stack+222314, dvrr_stack+130778);
 tmp = dvrr_stack + 177520;
 target_ptr = Libderiv->deriv2_classes[7][6][81];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+629751, dvrr_stack+242510, dvrr_stack+198550);
 tmp = dvrr_stack + 629751;
 target_ptr = Libderiv->deriv2_classes[7][7][81];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+631047, dvrr_stack+260970, dvrr_stack+222314);
 tmp = dvrr_stack + 631047;
 target_ptr = Libderiv->deriv2_classes[7][8][81];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+632667, dvrr_stack+284094, dvrr_stack+242510);
 tmp = dvrr_stack + 632667;
 target_ptr = Libderiv->deriv2_classes[7][9][81];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+35569, dvrr_stack+310294, dvrr_stack+310069);
 tmp = dvrr_stack + 35569;
 target_ptr = Libderiv->deriv2_classes[4][5][80];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+390279, dvrr_stack+311029, dvrr_stack+310714);
 tmp = dvrr_stack + 390279;
 target_ptr = Libderiv->deriv2_classes[4][6][80];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+284074, dvrr_stack+311569, dvrr_stack+310294);
 tmp = dvrr_stack + 284074;
 target_ptr = Libderiv->deriv2_classes[4][7][80];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+284614, dvrr_stack+312244, dvrr_stack+311029);
 tmp = dvrr_stack + 284614;
 target_ptr = Libderiv->deriv2_classes[4][8][80];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+285289, dvrr_stack+313069, dvrr_stack+311569);
 tmp = dvrr_stack + 285289;
 target_ptr = Libderiv->deriv2_classes[4][9][80];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+313069, dvrr_stack+314674, dvrr_stack+314359);
 tmp = dvrr_stack + 313069;
 target_ptr = Libderiv->deriv2_classes[5][5][80];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+313510, dvrr_stack+315703, dvrr_stack+315262);
 tmp = dvrr_stack + 313510;
 target_ptr = Libderiv->deriv2_classes[5][6][80];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+96614, dvrr_stack+7875, dvrr_stack+314674);
 tmp = dvrr_stack + 96614;
 target_ptr = Libderiv->deriv2_classes[5][7][80];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+634647, dvrr_stack+286470, dvrr_stack+315703);
 tmp = dvrr_stack + 634647;
 target_ptr = Libderiv->deriv2_classes[5][8][80];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+635592, dvrr_stack+287625, dvrr_stack+7875);
 tmp = dvrr_stack + 635592;
 target_ptr = Libderiv->deriv2_classes[5][9][80];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+287625, dvrr_stack+262950, dvrr_stack+289011);
 tmp = dvrr_stack + 287625;
 target_ptr = Libderiv->deriv2_classes[6][5][80];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+288213, dvrr_stack+263734, dvrr_stack+289431);
 tmp = dvrr_stack + 288213;
 target_ptr = Libderiv->deriv2_classes[6][6][80];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+636747, dvrr_stack+244130, dvrr_stack+262950);
 tmp = dvrr_stack + 636747;
 target_ptr = Libderiv->deriv2_classes[6][7][80];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+637755, dvrr_stack+228182, dvrr_stack+263734);
 tmp = dvrr_stack + 637755;
 target_ptr = Libderiv->deriv2_classes[6][8][80];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+639015, dvrr_stack+199558, dvrr_stack+244130);
 tmp = dvrr_stack + 639015;
 target_ptr = Libderiv->deriv2_classes[6][9][80];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+199558, dvrr_stack+245390, dvrr_stack+265102);
 tmp = dvrr_stack + 199558;
 target_ptr = Libderiv->deriv2_classes[7][5][80];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+200314, dvrr_stack+229722, dvrr_stack+223610);
 tmp = dvrr_stack + 200314;
 target_ptr = Libderiv->deriv2_classes[7][6][80];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+640555, dvrr_stack+201406, dvrr_stack+245390);
 tmp = dvrr_stack + 640555;
 target_ptr = Libderiv->deriv2_classes[7][7][80];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+641851, dvrr_stack+203026, dvrr_stack+229722);
 tmp = dvrr_stack + 641851;
 target_ptr = Libderiv->deriv2_classes[7][8][80];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+643471, dvrr_stack+178906, dvrr_stack+201406);
 tmp = dvrr_stack + 643471;
 target_ptr = Libderiv->deriv2_classes[7][9][80];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+288997, dvrr_stack+160862, dvrr_stack+309606);
 tmp = dvrr_stack + 288997;
 target_ptr = Libderiv->deriv2_classes[4][5][79];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+314098, dvrr_stack+161282, dvrr_stack+181282);
 tmp = dvrr_stack + 314098;
 target_ptr = Libderiv->deriv2_classes[4][6][79];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+645451, dvrr_stack+161822, dvrr_stack+160862);
 tmp = dvrr_stack + 645451;
 target_ptr = Libderiv->deriv2_classes[4][7][79];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+264952, dvrr_stack+146432, dvrr_stack+161282);
 tmp = dvrr_stack + 264952;
 target_ptr = Libderiv->deriv2_classes[4][8][79];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+178528, dvrr_stack+134786, dvrr_stack+161822);
 tmp = dvrr_stack + 178528;
 target_ptr = Libderiv->deriv2_classes[4][9][79];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+134786, dvrr_stack+147257, dvrr_stack+162497);
 tmp = dvrr_stack + 134786;
 target_ptr = Libderiv->deriv2_classes[5][5][79];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+197905, dvrr_stack+112536, dvrr_stack+135776);
 tmp = dvrr_stack + 197905;
 target_ptr = Libderiv->deriv2_classes[5][6][79];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+179353, dvrr_stack+113292, dvrr_stack+147257);
 tmp = dvrr_stack + 179353;
 target_ptr = Libderiv->deriv2_classes[5][7][79];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+180109, dvrr_stack+114237, dvrr_stack+112536);
 tmp = dvrr_stack + 180109;
 target_ptr = Libderiv->deriv2_classes[5][8][79];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+645991, dvrr_stack+97476, dvrr_stack+113292);
 tmp = dvrr_stack + 645991;
 target_ptr = Libderiv->deriv2_classes[5][9][79];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+647146, dvrr_stack+115392, dvrr_stack+77919);
 tmp = dvrr_stack + 647146;
 target_ptr = Libderiv->deriv2_classes[6][5][79];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+97370, dvrr_stack+84174, dvrr_stack+98862);
 tmp = dvrr_stack + 97370;
 target_ptr = Libderiv->deriv2_classes[6][6][79];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+647734, dvrr_stack+72599, dvrr_stack+115392);
 tmp = dvrr_stack + 647734;
 target_ptr = Libderiv->deriv2_classes[6][7][79];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+648742, dvrr_stack+48829, dvrr_stack+84174);
 tmp = dvrr_stack + 648742;
 target_ptr = Libderiv->deriv2_classes[6][8][79];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+650002, dvrr_stack+390705, dvrr_stack+72599);
 tmp = dvrr_stack + 650002;
 target_ptr = Libderiv->deriv2_classes[6][9][79];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+390699, dvrr_stack+73859, dvrr_stack+85182);
 tmp = dvrr_stack + 390699;
 target_ptr = Libderiv->deriv2_classes[7][5][79];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+391455, dvrr_stack+36118, dvrr_stack+64967);
 tmp = dvrr_stack + 391455;
 target_ptr = Libderiv->deriv2_classes[7][6][79];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+651542, dvrr_stack+392553, dvrr_stack+73859);
 tmp = dvrr_stack + 651542;
 target_ptr = Libderiv->deriv2_classes[7][7][79];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+652838, dvrr_stack+394173, dvrr_stack+36118);
 tmp = dvrr_stack + 652838;
 target_ptr = Libderiv->deriv2_classes[7][8][79];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+654458, dvrr_stack+396153, dvrr_stack+392553);
 tmp = dvrr_stack + 654458;
 target_ptr = Libderiv->deriv2_classes[7][9][79];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+162497, dvrr_stack+62087, dvrr_stack+162812);
 tmp = dvrr_stack + 162497;
 target_ptr = Libderiv->deriv2_classes[4][5][78];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+77919, dvrr_stack+65723, dvrr_stack+147845);
 tmp = dvrr_stack + 77919;
 target_ptr = Libderiv->deriv2_classes[4][6][78];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+85182, dvrr_stack+50369, dvrr_stack+62087);
 tmp = dvrr_stack + 85182;
 target_ptr = Libderiv->deriv2_classes[4][7][78];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+396153, dvrr_stack+24580, dvrr_stack+65723);
 tmp = dvrr_stack + 396153;
 target_ptr = Libderiv->deriv2_classes[4][8][78];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+396828, dvrr_stack+34138, dvrr_stack+50369);
 tmp = dvrr_stack + 396828;
 target_ptr = Libderiv->deriv2_classes[4][9][78];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+397653, dvrr_stack+55832, dvrr_stack+136217);
 tmp = dvrr_stack + 397653;
 target_ptr = Libderiv->deriv2_classes[5][5][78];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+309604, dvrr_stack+27805, dvrr_stack+41086);
 tmp = dvrr_stack + 309604;
 target_ptr = Libderiv->deriv2_classes[5][6][78];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+34092, dvrr_stack+47333, dvrr_stack+55832);
 tmp = dvrr_stack + 34092;
 target_ptr = Libderiv->deriv2_classes[5][7][78];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+656438, dvrr_stack+398529, dvrr_stack+27805);
 tmp = dvrr_stack + 656438;
 target_ptr = Libderiv->deriv2_classes[5][8][78];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+657383, dvrr_stack+94444, dvrr_stack+47333);
 tmp = dvrr_stack + 657383;
 target_ptr = Libderiv->deriv2_classes[5][9][78];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+94093, dvrr_stack+17910, dvrr_stack+321739);
 tmp = dvrr_stack + 94093;
 target_ptr = Libderiv->deriv2_classes[6][5][78];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+94681, dvrr_stack+110085, dvrr_stack+10080);
 tmp = dvrr_stack + 94681;
 target_ptr = Libderiv->deriv2_classes[6][6][78];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+658538, dvrr_stack+399684, dvrr_stack+17910);
 tmp = dvrr_stack + 658538;
 target_ptr = Libderiv->deriv2_classes[6][7][78];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+659546, dvrr_stack+400944, dvrr_stack+110085);
 tmp = dvrr_stack + 659546;
 target_ptr = Libderiv->deriv2_classes[6][8][78];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+660806, dvrr_stack+402484, dvrr_stack+399684);
 tmp = dvrr_stack + 660806;
 target_ptr = Libderiv->deriv2_classes[6][9][78];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+402484, dvrr_stack+196141, dvrr_stack+195601);
 tmp = dvrr_stack + 402484;
 target_ptr = Libderiv->deriv2_classes[7][5][78];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+403240, dvrr_stack+404332, dvrr_stack+197149);
 tmp = dvrr_stack + 403240;
 target_ptr = Libderiv->deriv2_classes[7][6][78];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+662346, dvrr_stack+405628, dvrr_stack+196141);
 tmp = dvrr_stack + 662346;
 target_ptr = Libderiv->deriv2_classes[7][7][78];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+663642, dvrr_stack+407248, dvrr_stack+404332);
 tmp = dvrr_stack + 663642;
 target_ptr = Libderiv->deriv2_classes[7][8][78];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+665262, dvrr_stack+409228, dvrr_stack+405628);
 tmp = dvrr_stack + 665262;
 target_ptr = Libderiv->deriv2_classes[7][9][78];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,21,dvrr_stack+136217, dvrr_stack+324052, dvrr_stack+264742);
 tmp = dvrr_stack + 136217;
 target_ptr = Libderiv->deriv2_classes[4][5][35];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,28,dvrr_stack+409228, dvrr_stack+323464, dvrr_stack+316459);
 tmp = dvrr_stack + 409228;
 target_ptr = Libderiv->deriv2_classes[4][6][35];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,36,dvrr_stack+409648, dvrr_stack+324493, dvrr_stack+51044);
 tmp = dvrr_stack + 409648;
 target_ptr = Libderiv->deriv2_classes[4][7][35];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,45,dvrr_stack+410188, dvrr_stack+325249, dvrr_stack+28561);
 tmp = dvrr_stack + 410188;
 target_ptr = Libderiv->deriv2_classes[4][8][35];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_g(Data,55,dvrr_stack+667242, dvrr_stack+326194, dvrr_stack+309054);
 tmp = dvrr_stack + 667242;
 target_ptr = Libderiv->deriv2_classes[4][9][35];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,21,dvrr_stack+410863, dvrr_stack+298144, dvrr_stack+318394);
 tmp = dvrr_stack + 410863;
 target_ptr = Libderiv->deriv2_classes[5][5][35];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,28,dvrr_stack+321505, dvrr_stack+297360, dvrr_stack+317974);
 tmp = dvrr_stack + 321505;
 target_ptr = Libderiv->deriv2_classes[5][6][35];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,36,dvrr_stack+668067, dvrr_stack+298732, dvrr_stack+318709);
 tmp = dvrr_stack + 668067;
 target_ptr = Libderiv->deriv2_classes[5][7][35];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,45,dvrr_stack+668823, dvrr_stack+270690, dvrr_stack+319249);
 tmp = dvrr_stack + 668823;
 target_ptr = Libderiv->deriv2_classes[5][8][35];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,55,dvrr_stack+669768, dvrr_stack+271950, dvrr_stack+319924);
 tmp = dvrr_stack + 669768;
 target_ptr = Libderiv->deriv2_classes[5][9][35];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,21,dvrr_stack+195538, dvrr_stack+206182, dvrr_stack+324052);
 tmp = dvrr_stack + 195538;
 target_ptr = Libderiv->deriv2_classes[6][5][35];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,28,dvrr_stack+670923, dvrr_stack+205174, dvrr_stack+323464);
 tmp = dvrr_stack + 670923;
 target_ptr = Libderiv->deriv2_classes[6][6][35];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,36,dvrr_stack+671707, dvrr_stack+206938, dvrr_stack+324493);
 tmp = dvrr_stack + 671707;
 target_ptr = Libderiv->deriv2_classes[6][7][35];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,45,dvrr_stack+672715, dvrr_stack+208234, dvrr_stack+325249);
 tmp = dvrr_stack + 672715;
 target_ptr = Libderiv->deriv2_classes[6][8][35];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,55,dvrr_stack+673975, dvrr_stack+209854, dvrr_stack+326194);
 tmp = dvrr_stack + 673975;
 target_ptr = Libderiv->deriv2_classes[6][9][35];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,21,dvrr_stack+675515, dvrr_stack+421184, dvrr_stack+298144);
 tmp = dvrr_stack + 675515;
 target_ptr = Libderiv->deriv2_classes[7][5][35];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,28,dvrr_stack+676271, dvrr_stack+429869, dvrr_stack+297360);
 tmp = dvrr_stack + 676271;
 target_ptr = Libderiv->deriv2_classes[7][6][35];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,36,dvrr_stack+677279, dvrr_stack+440939, dvrr_stack+298732);
 tmp = dvrr_stack + 677279;
 target_ptr = Libderiv->deriv2_classes[7][7][35];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,45,dvrr_stack+678575, dvrr_stack+455014, dvrr_stack+270690);
 tmp = dvrr_stack + 678575;
 target_ptr = Libderiv->deriv2_classes[7][8][35];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,55,dvrr_stack+680195, dvrr_stack+277494, dvrr_stack+271950);
 tmp = dvrr_stack + 680195;
 target_ptr = Libderiv->deriv2_classes[7][9][35];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+398094, dvrr_stack+118941, dvrr_stack+464464);
 tmp = dvrr_stack + 398094;
 target_ptr = Libderiv->deriv2_classes[4][5][34];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+135227, dvrr_stack+118353, dvrr_stack+464674);
 tmp = dvrr_stack + 135227;
 target_ptr = Libderiv->deriv2_classes[4][6][34];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+682175, dvrr_stack+119382, dvrr_stack+279969);
 tmp = dvrr_stack + 682175;
 target_ptr = Libderiv->deriv2_classes[4][7][34];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+98154, dvrr_stack+120138, dvrr_stack+280329);
 tmp = dvrr_stack + 98154;
 target_ptr = Libderiv->deriv2_classes[4][8][34];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+682715, dvrr_stack+121083, dvrr_stack+280779);
 tmp = dvrr_stack + 682715;
 target_ptr = Libderiv->deriv2_classes[4][9][34];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+683540, dvrr_stack+88689, dvrr_stack+212479);
 tmp = dvrr_stack + 683540;
 target_ptr = Libderiv->deriv2_classes[5][5][34];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+683981, dvrr_stack+104406, dvrr_stack+212059);
 tmp = dvrr_stack + 683981;
 target_ptr = Libderiv->deriv2_classes[5][6][34];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+684569, dvrr_stack+89277, dvrr_stack+188674);
 tmp = dvrr_stack + 684569;
 target_ptr = Libderiv->deriv2_classes[5][7][34];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+685325, dvrr_stack+52807, dvrr_stack+151220);
 tmp = dvrr_stack + 685325;
 target_ptr = Libderiv->deriv2_classes[5][8][34];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+686270, dvrr_stack+54067, dvrr_stack+151895);
 tmp = dvrr_stack + 686270;
 target_ptr = Libderiv->deriv2_classes[5][9][34];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+687425, dvrr_stack+68054, dvrr_stack+118941);
 tmp = dvrr_stack + 687425;
 target_ptr = Libderiv->deriv2_classes[6][5][34];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+688013, dvrr_stack+40078, dvrr_stack+118353);
 tmp = dvrr_stack + 688013;
 target_ptr = Libderiv->deriv2_classes[6][6][34];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+688797, dvrr_stack+32012, dvrr_stack+119382);
 tmp = dvrr_stack + 688797;
 target_ptr = Libderiv->deriv2_classes[6][7][34];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+689805, dvrr_stack+384729, dvrr_stack+120138);
 tmp = dvrr_stack + 689805;
 target_ptr = Libderiv->deriv2_classes[6][8][34];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+691065, dvrr_stack+386349, dvrr_stack+121083);
 tmp = dvrr_stack + 691065;
 target_ptr = Libderiv->deriv2_classes[6][9][34];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+692605, dvrr_stack+281329, dvrr_stack+88689);
 tmp = dvrr_stack + 692605;
 target_ptr = Libderiv->deriv2_classes[7][5][34];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+693361, dvrr_stack+282274, dvrr_stack+104406);
 tmp = dvrr_stack + 693361;
 target_ptr = Libderiv->deriv2_classes[7][6][34];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+694369, dvrr_stack+175144, dvrr_stack+89277);
 tmp = dvrr_stack + 694369;
 target_ptr = Libderiv->deriv2_classes[7][7][34];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+695665, dvrr_stack+464954, dvrr_stack+52807);
 tmp = dvrr_stack + 695665;
 target_ptr = Libderiv->deriv2_classes[7][8][34];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+697285, dvrr_stack+466979, dvrr_stack+54067);
 tmp = dvrr_stack + 697285;
 target_ptr = Libderiv->deriv2_classes[7][9][34];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+251762, dvrr_stack+64526, dvrr_stack+469454);
 tmp = dvrr_stack + 251762;
 target_ptr = Libderiv->deriv2_classes[4][5][33];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+699265, dvrr_stack+322204, dvrr_stack+306504);
 tmp = dvrr_stack + 699265;
 target_ptr = Libderiv->deriv2_classes[4][6][33];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+48278, dvrr_stack+61331, dvrr_stack+306784);
 tmp = dvrr_stack + 48278;
 target_ptr = Libderiv->deriv2_classes[4][7][33];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+699685, dvrr_stack+15345, dvrr_stack+307144);
 tmp = dvrr_stack + 699685;
 target_ptr = Libderiv->deriv2_classes[4][8][33];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+700360, dvrr_stack+83019, dvrr_stack+411604);
 tmp = dvrr_stack + 700360;
 target_ptr = Libderiv->deriv2_classes[4][9][33];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+701185, dvrr_stack+134198, dvrr_stack+7560);
 tmp = dvrr_stack + 701185;
 target_ptr = Libderiv->deriv2_classes[5][5][33];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+701626, dvrr_stack+77135, dvrr_stack+317074);
 tmp = dvrr_stack + 701626;
 target_ptr = Libderiv->deriv2_classes[5][6][33];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+702214, dvrr_stack+129770, dvrr_stack+4203);
 tmp = dvrr_stack + 702214;
 target_ptr = Libderiv->deriv2_classes[5][7][33];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+702970, dvrr_stack+145172, dvrr_stack+14670);
 tmp = dvrr_stack + 702970;
 target_ptr = Libderiv->deriv2_classes[5][8][33];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+703915, dvrr_stack+159322, dvrr_stack+23755);
 tmp = dvrr_stack + 703915;
 target_ptr = Libderiv->deriv2_classes[5][9][33];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+705070, dvrr_stack+130778, dvrr_stack+64526);
 tmp = dvrr_stack + 705070;
 target_ptr = Libderiv->deriv2_classes[6][5][33];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+705658, dvrr_stack+198550, dvrr_stack+322204);
 tmp = dvrr_stack + 705658;
 target_ptr = Libderiv->deriv2_classes[6][6][33];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+706442, dvrr_stack+222314, dvrr_stack+61331);
 tmp = dvrr_stack + 706442;
 target_ptr = Libderiv->deriv2_classes[6][7][33];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+707450, dvrr_stack+242510, dvrr_stack+15345);
 tmp = dvrr_stack + 707450;
 target_ptr = Libderiv->deriv2_classes[6][8][33];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+708710, dvrr_stack+260970, dvrr_stack+83019);
 tmp = dvrr_stack + 708710;
 target_ptr = Libderiv->deriv2_classes[6][9][33];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+710250, dvrr_stack+412154, dvrr_stack+134198);
 tmp = dvrr_stack + 710250;
 target_ptr = Libderiv->deriv2_classes[7][5][33];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+711006, dvrr_stack+418349, dvrr_stack+77135);
 tmp = dvrr_stack + 711006;
 target_ptr = Libderiv->deriv2_classes[7][6][33];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+712014, dvrr_stack+426089, dvrr_stack+129770);
 tmp = dvrr_stack + 712014;
 target_ptr = Libderiv->deriv2_classes[7][7][33];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+713310, dvrr_stack+436079, dvrr_stack+145172);
 tmp = dvrr_stack + 713310;
 target_ptr = Libderiv->deriv2_classes[7][8][33];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+714930, dvrr_stack+448939, dvrr_stack+159322);
 tmp = dvrr_stack + 714930;
 target_ptr = Libderiv->deriv2_classes[7][9][33];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+112038, dvrr_stack+315262, dvrr_stack+457039);
 tmp = dvrr_stack + 112038;
 target_ptr = Libderiv->deriv2_classes[4][5][32];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+317494, dvrr_stack+314674, dvrr_stack+457249);
 tmp = dvrr_stack + 317494;
 target_ptr = Libderiv->deriv2_classes[4][6][32];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+716910, dvrr_stack+315703, dvrr_stack+457529);
 tmp = dvrr_stack + 716910;
 target_ptr = Libderiv->deriv2_classes[4][7][32];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+717450, dvrr_stack+7875, dvrr_stack+457889);
 tmp = dvrr_stack + 717450;
 target_ptr = Libderiv->deriv2_classes[4][8][32];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+718125, dvrr_stack+286470, dvrr_stack+458339);
 tmp = dvrr_stack + 718125;
 target_ptr = Libderiv->deriv2_classes[4][9][32];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+718950, dvrr_stack+289431, dvrr_stack+310714);
 tmp = dvrr_stack + 718950;
 target_ptr = Libderiv->deriv2_classes[5][5][32];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+719391, dvrr_stack+262950, dvrr_stack+310294);
 tmp = dvrr_stack + 719391;
 target_ptr = Libderiv->deriv2_classes[5][6][32];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+719979, dvrr_stack+263734, dvrr_stack+311029);
 tmp = dvrr_stack + 719979;
 target_ptr = Libderiv->deriv2_classes[5][7][32];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+720735, dvrr_stack+244130, dvrr_stack+311569);
 tmp = dvrr_stack + 720735;
 target_ptr = Libderiv->deriv2_classes[5][8][32];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+721680, dvrr_stack+228182, dvrr_stack+312244);
 tmp = dvrr_stack + 721680;
 target_ptr = Libderiv->deriv2_classes[5][9][32];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+722835, dvrr_stack+223610, dvrr_stack+315262);
 tmp = dvrr_stack + 722835;
 target_ptr = Libderiv->deriv2_classes[6][5][32];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+723423, dvrr_stack+245390, dvrr_stack+314674);
 tmp = dvrr_stack + 723423;
 target_ptr = Libderiv->deriv2_classes[6][6][32];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+724207, dvrr_stack+229722, dvrr_stack+315703);
 tmp = dvrr_stack + 724207;
 target_ptr = Libderiv->deriv2_classes[6][7][32];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+725215, dvrr_stack+201406, dvrr_stack+7875);
 tmp = dvrr_stack + 725215;
 target_ptr = Libderiv->deriv2_classes[6][8][32];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+726475, dvrr_stack+203026, dvrr_stack+286470);
 tmp = dvrr_stack + 726475;
 target_ptr = Libderiv->deriv2_classes[6][9][32];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+728015, dvrr_stack+460155, dvrr_stack+289431);
 tmp = dvrr_stack + 728015;
 target_ptr = Libderiv->deriv2_classes[7][5][32];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+728771, dvrr_stack+461100, dvrr_stack+262950);
 tmp = dvrr_stack + 728771;
 target_ptr = Libderiv->deriv2_classes[7][6][32];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+729779, dvrr_stack+462360, dvrr_stack+263734);
 tmp = dvrr_stack + 729779;
 target_ptr = Libderiv->deriv2_classes[7][7][32];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+731075, dvrr_stack+451414, dvrr_stack+244130);
 tmp = dvrr_stack + 731075;
 target_ptr = Libderiv->deriv2_classes[7][8][32];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+732695, dvrr_stack+438104, dvrr_stack+228182);
 tmp = dvrr_stack + 732695;
 target_ptr = Libderiv->deriv2_classes[7][9][32];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+734675, dvrr_stack+135776, dvrr_stack+234230);
 tmp = dvrr_stack + 734675;
 target_ptr = Libderiv->deriv2_classes[4][5][31];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+734990, dvrr_stack+147257, dvrr_stack+234440);
 tmp = dvrr_stack + 734990;
 target_ptr = Libderiv->deriv2_classes[4][6][31];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+735410, dvrr_stack+112536, dvrr_stack+440579);
 tmp = dvrr_stack + 735410;
 target_ptr = Libderiv->deriv2_classes[4][7][31];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+735950, dvrr_stack+113292, dvrr_stack+458889);
 tmp = dvrr_stack + 735950;
 target_ptr = Libderiv->deriv2_classes[4][8][31];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+736625, dvrr_stack+114237, dvrr_stack+327349);
 tmp = dvrr_stack + 736625;
 target_ptr = Libderiv->deriv2_classes[4][9][31];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+737450, dvrr_stack+98862, dvrr_stack+181282);
 tmp = dvrr_stack + 737450;
 target_ptr = Libderiv->deriv2_classes[5][5][31];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+737891, dvrr_stack+115392, dvrr_stack+160862);
 tmp = dvrr_stack + 737891;
 target_ptr = Libderiv->deriv2_classes[5][6][31];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+738479, dvrr_stack+84174, dvrr_stack+161282);
 tmp = dvrr_stack + 738479;
 target_ptr = Libderiv->deriv2_classes[5][7][31];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+739235, dvrr_stack+72599, dvrr_stack+161822);
 tmp = dvrr_stack + 739235;
 target_ptr = Libderiv->deriv2_classes[5][8][31];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+740180, dvrr_stack+48829, dvrr_stack+146432);
 tmp = dvrr_stack + 740180;
 target_ptr = Libderiv->deriv2_classes[5][9][31];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+741335, dvrr_stack+64967, dvrr_stack+135776);
 tmp = dvrr_stack + 741335;
 target_ptr = Libderiv->deriv2_classes[6][5][31];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+741923, dvrr_stack+73859, dvrr_stack+147257);
 tmp = dvrr_stack + 741923;
 target_ptr = Libderiv->deriv2_classes[6][6][31];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+742707, dvrr_stack+36118, dvrr_stack+112536);
 tmp = dvrr_stack + 742707;
 target_ptr = Libderiv->deriv2_classes[6][7][31];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+743715, dvrr_stack+392553, dvrr_stack+113292);
 tmp = dvrr_stack + 743715;
 target_ptr = Libderiv->deriv2_classes[6][8][31];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+744975, dvrr_stack+394173, dvrr_stack+114237);
 tmp = dvrr_stack + 744975;
 target_ptr = Libderiv->deriv2_classes[6][9][31];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+746515, dvrr_stack+453439, dvrr_stack+98862);
 tmp = dvrr_stack + 746515;
 target_ptr = Libderiv->deriv2_classes[7][5][31];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+747271, dvrr_stack+427709, dvrr_stack+115392);
 tmp = dvrr_stack + 747271;
 target_ptr = Libderiv->deriv2_classes[7][6][31];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+748279, dvrr_stack+80159, dvrr_stack+84174);
 tmp = dvrr_stack + 748279;
 target_ptr = Libderiv->deriv2_classes[7][7][31];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+749575, dvrr_stack+469664, dvrr_stack+72599);
 tmp = dvrr_stack + 749575;
 target_ptr = Libderiv->deriv2_classes[7][8][31];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+751195, dvrr_stack+471689, dvrr_stack+48829);
 tmp = dvrr_stack + 751195;
 target_ptr = Libderiv->deriv2_classes[7][9][31];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+753175, dvrr_stack+41086, dvrr_stack+234720);
 tmp = dvrr_stack + 753175;
 target_ptr = Libderiv->deriv2_classes[4][5][30];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+753490, dvrr_stack+55832, dvrr_stack+252134);
 tmp = dvrr_stack + 753490;
 target_ptr = Libderiv->deriv2_classes[4][6][30];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+753910, dvrr_stack+27805, dvrr_stack+463980);
 tmp = dvrr_stack + 753910;
 target_ptr = Libderiv->deriv2_classes[4][7][30];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+754450, dvrr_stack+47333, dvrr_stack+454384);
 tmp = dvrr_stack + 754450;
 target_ptr = Libderiv->deriv2_classes[4][8][30];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+755125, dvrr_stack+398529, dvrr_stack+428969);
 tmp = dvrr_stack + 755125;
 target_ptr = Libderiv->deriv2_classes[4][9][30];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+755950, dvrr_stack+10080, dvrr_stack+147845);
 tmp = dvrr_stack + 755950;
 target_ptr = Libderiv->deriv2_classes[5][5][30];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+756391, dvrr_stack+17910, dvrr_stack+62087);
 tmp = dvrr_stack + 756391;
 target_ptr = Libderiv->deriv2_classes[5][6][30];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+756979, dvrr_stack+110085, dvrr_stack+65723);
 tmp = dvrr_stack + 756979;
 target_ptr = Libderiv->deriv2_classes[5][7][30];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+757735, dvrr_stack+399684, dvrr_stack+50369);
 tmp = dvrr_stack + 757735;
 target_ptr = Libderiv->deriv2_classes[5][8][30];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+758680, dvrr_stack+400944, dvrr_stack+24580);
 tmp = dvrr_stack + 758680;
 target_ptr = Libderiv->deriv2_classes[5][9][30];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+759835, dvrr_stack+197149, dvrr_stack+41086);
 tmp = dvrr_stack + 759835;
 target_ptr = Libderiv->deriv2_classes[6][5][30];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+760423, dvrr_stack+196141, dvrr_stack+55832);
 tmp = dvrr_stack + 760423;
 target_ptr = Libderiv->deriv2_classes[6][6][30];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+761207, dvrr_stack+404332, dvrr_stack+27805);
 tmp = dvrr_stack + 761207;
 target_ptr = Libderiv->deriv2_classes[6][7][30];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+762215, dvrr_stack+405628, dvrr_stack+47333);
 tmp = dvrr_stack + 762215;
 target_ptr = Libderiv->deriv2_classes[6][8][30];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+763475, dvrr_stack+407248, dvrr_stack+398529);
 tmp = dvrr_stack + 763475;
 target_ptr = Libderiv->deriv2_classes[6][9][30];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+765015, dvrr_stack+419609, dvrr_stack+10080);
 tmp = dvrr_stack + 765015;
 target_ptr = Libderiv->deriv2_classes[7][5][30];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+765771, dvrr_stack+413099, dvrr_stack+17910);
 tmp = dvrr_stack + 765771;
 target_ptr = Libderiv->deriv2_classes[7][6][30];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+766779, dvrr_stack+474164, dvrr_stack+110085);
 tmp = dvrr_stack + 766779;
 target_ptr = Libderiv->deriv2_classes[7][7][30];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+768075, dvrr_stack+475784, dvrr_stack+399684);
 tmp = dvrr_stack + 768075;
 target_ptr = Libderiv->deriv2_classes[7][8][30];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+769695, dvrr_stack+477809, dvrr_stack+400944);
 tmp = dvrr_stack + 769695;
 target_ptr = Libderiv->deriv2_classes[7][9][30];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+771675, dvrr_stack+172384, dvrr_stack+172174);
 tmp = dvrr_stack + 771675;
 target_ptr = Libderiv->deriv2_classes[4][5][26];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+771990, dvrr_stack+173105, dvrr_stack+172825);
 tmp = dvrr_stack + 771990;
 target_ptr = Libderiv->deriv2_classes[4][6][26];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+772410, dvrr_stack+174053, dvrr_stack+173693);
 tmp = dvrr_stack + 772410;
 target_ptr = Libderiv->deriv2_classes[4][7][26];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+772950, dvrr_stack+307594, dvrr_stack+459339);
 tmp = dvrr_stack + 772950;
 target_ptr = Libderiv->deriv2_classes[4][8][26];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+773625, dvrr_stack+480284, dvrr_stack+420554);
 tmp = dvrr_stack + 773625;
 target_ptr = Libderiv->deriv2_classes[4][9][26];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+774450, dvrr_stack+21335, dvrr_stack+20406);
 tmp = dvrr_stack + 774450;
 target_ptr = Libderiv->deriv2_classes[5][5][26];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+774891, dvrr_stack+33308, dvrr_stack+308539);
 tmp = dvrr_stack + 774891;
 target_ptr = Libderiv->deriv2_classes[5][6][26];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+775479, dvrr_stack+481979, dvrr_stack+481439);
 tmp = dvrr_stack + 775479;
 target_ptr = Libderiv->deriv2_classes[5][7][26];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+776235, dvrr_stack+482987, dvrr_stack+12690);
 tmp = dvrr_stack + 776235;
 target_ptr = Libderiv->deriv2_classes[5][8][26];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+777180, dvrr_stack+485072, dvrr_stack+484247);
 tmp = dvrr_stack + 777180;
 target_ptr = Libderiv->deriv2_classes[5][9][26];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+778335, dvrr_stack+486612, dvrr_stack+172384);
 tmp = dvrr_stack + 778335;
 target_ptr = Libderiv->deriv2_classes[6][5][26];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+778923, dvrr_stack+487368, dvrr_stack+173105);
 tmp = dvrr_stack + 778923;
 target_ptr = Libderiv->deriv2_classes[6][6][26];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+779707, dvrr_stack+488376, dvrr_stack+174053);
 tmp = dvrr_stack + 779707;
 target_ptr = Libderiv->deriv2_classes[6][7][26];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+780715, dvrr_stack+489672, dvrr_stack+307594);
 tmp = dvrr_stack + 780715;
 target_ptr = Libderiv->deriv2_classes[6][8][26];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+781975, dvrr_stack+491292, dvrr_stack+480284);
 tmp = dvrr_stack + 781975;
 target_ptr = Libderiv->deriv2_classes[6][9][26];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+783515, dvrr_stack+43678, dvrr_stack+21335);
 tmp = dvrr_stack + 783515;
 target_ptr = Libderiv->deriv2_classes[7][5][26];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+784271, dvrr_stack+417089, dvrr_stack+33308);
 tmp = dvrr_stack + 784271;
 target_ptr = Libderiv->deriv2_classes[7][6][26];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+785279, dvrr_stack+44623, dvrr_stack+481979);
 tmp = dvrr_stack + 785279;
 target_ptr = Libderiv->deriv2_classes[7][7][26];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+786575, dvrr_stack+433154, dvrr_stack+482987);
 tmp = dvrr_stack + 786575;
 target_ptr = Libderiv->deriv2_classes[7][8][26];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+788195, dvrr_stack+442559, dvrr_stack+485072);
 tmp = dvrr_stack + 788195;
 target_ptr = Libderiv->deriv2_classes[7][9][26];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,21,dvrr_stack+790175, dvrr_stack+324052, dvrr_stack+264742);
 tmp = dvrr_stack + 790175;
 target_ptr = Libderiv->deriv2_classes[4][5][23];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,28,dvrr_stack+790490, dvrr_stack+323464, dvrr_stack+316459);
 tmp = dvrr_stack + 790490;
 target_ptr = Libderiv->deriv2_classes[4][6][23];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,36,dvrr_stack+790910, dvrr_stack+324493, dvrr_stack+51044);
 tmp = dvrr_stack + 790910;
 target_ptr = Libderiv->deriv2_classes[4][7][23];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,45,dvrr_stack+791450, dvrr_stack+325249, dvrr_stack+28561);
 tmp = dvrr_stack + 791450;
 target_ptr = Libderiv->deriv2_classes[4][8][23];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_g(Data,55,dvrr_stack+792125, dvrr_stack+326194, dvrr_stack+309054);
 tmp = dvrr_stack + 792125;
 target_ptr = Libderiv->deriv2_classes[4][9][23];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,21,dvrr_stack+792950, dvrr_stack+298144, dvrr_stack+318394);
 tmp = dvrr_stack + 792950;
 target_ptr = Libderiv->deriv2_classes[5][5][23];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,28,dvrr_stack+793391, dvrr_stack+297360, dvrr_stack+317974);
 tmp = dvrr_stack + 793391;
 target_ptr = Libderiv->deriv2_classes[5][6][23];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,36,dvrr_stack+793979, dvrr_stack+298732, dvrr_stack+318709);
 tmp = dvrr_stack + 793979;
 target_ptr = Libderiv->deriv2_classes[5][7][23];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,45,dvrr_stack+794735, dvrr_stack+270690, dvrr_stack+319249);
 tmp = dvrr_stack + 794735;
 target_ptr = Libderiv->deriv2_classes[5][8][23];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,55,dvrr_stack+795680, dvrr_stack+271950, dvrr_stack+319924);
 tmp = dvrr_stack + 795680;
 target_ptr = Libderiv->deriv2_classes[5][9][23];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,21,dvrr_stack+796835, dvrr_stack+206182, dvrr_stack+324052);
 tmp = dvrr_stack + 796835;
 target_ptr = Libderiv->deriv2_classes[6][5][23];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,28,dvrr_stack+797423, dvrr_stack+205174, dvrr_stack+323464);
 tmp = dvrr_stack + 797423;
 target_ptr = Libderiv->deriv2_classes[6][6][23];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,36,dvrr_stack+798207, dvrr_stack+206938, dvrr_stack+324493);
 tmp = dvrr_stack + 798207;
 target_ptr = Libderiv->deriv2_classes[6][7][23];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,45,dvrr_stack+799215, dvrr_stack+208234, dvrr_stack+325249);
 tmp = dvrr_stack + 799215;
 target_ptr = Libderiv->deriv2_classes[6][8][23];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,55,dvrr_stack+800475, dvrr_stack+209854, dvrr_stack+326194);
 tmp = dvrr_stack + 800475;
 target_ptr = Libderiv->deriv2_classes[6][9][23];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,21,dvrr_stack+802015, dvrr_stack+421184, dvrr_stack+298144);
 tmp = dvrr_stack + 802015;
 target_ptr = Libderiv->deriv2_classes[7][5][23];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,28,dvrr_stack+802771, dvrr_stack+429869, dvrr_stack+297360);
 tmp = dvrr_stack + 802771;
 target_ptr = Libderiv->deriv2_classes[7][6][23];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,36,dvrr_stack+803779, dvrr_stack+440939, dvrr_stack+298732);
 tmp = dvrr_stack + 803779;
 target_ptr = Libderiv->deriv2_classes[7][7][23];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,45,dvrr_stack+805075, dvrr_stack+455014, dvrr_stack+270690);
 tmp = dvrr_stack + 805075;
 target_ptr = Libderiv->deriv2_classes[7][8][23];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,55,dvrr_stack+806695, dvrr_stack+277494, dvrr_stack+271950);
 tmp = dvrr_stack + 806695;
 target_ptr = Libderiv->deriv2_classes[7][9][23];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+808675, dvrr_stack+118941, dvrr_stack+464464);
 tmp = dvrr_stack + 808675;
 target_ptr = Libderiv->deriv2_classes[4][5][22];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+808990, dvrr_stack+118353, dvrr_stack+464674);
 tmp = dvrr_stack + 808990;
 target_ptr = Libderiv->deriv2_classes[4][6][22];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+809410, dvrr_stack+119382, dvrr_stack+279969);
 tmp = dvrr_stack + 809410;
 target_ptr = Libderiv->deriv2_classes[4][7][22];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+809950, dvrr_stack+120138, dvrr_stack+280329);
 tmp = dvrr_stack + 809950;
 target_ptr = Libderiv->deriv2_classes[4][8][22];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+810625, dvrr_stack+121083, dvrr_stack+280779);
 tmp = dvrr_stack + 810625;
 target_ptr = Libderiv->deriv2_classes[4][9][22];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+811450, dvrr_stack+88689, dvrr_stack+212479);
 tmp = dvrr_stack + 811450;
 target_ptr = Libderiv->deriv2_classes[5][5][22];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+811891, dvrr_stack+104406, dvrr_stack+212059);
 tmp = dvrr_stack + 811891;
 target_ptr = Libderiv->deriv2_classes[5][6][22];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+812479, dvrr_stack+89277, dvrr_stack+188674);
 tmp = dvrr_stack + 812479;
 target_ptr = Libderiv->deriv2_classes[5][7][22];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+813235, dvrr_stack+52807, dvrr_stack+151220);
 tmp = dvrr_stack + 813235;
 target_ptr = Libderiv->deriv2_classes[5][8][22];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+814180, dvrr_stack+54067, dvrr_stack+151895);
 tmp = dvrr_stack + 814180;
 target_ptr = Libderiv->deriv2_classes[5][9][22];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+815335, dvrr_stack+68054, dvrr_stack+118941);
 tmp = dvrr_stack + 815335;
 target_ptr = Libderiv->deriv2_classes[6][5][22];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+815923, dvrr_stack+40078, dvrr_stack+118353);
 tmp = dvrr_stack + 815923;
 target_ptr = Libderiv->deriv2_classes[6][6][22];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+816707, dvrr_stack+32012, dvrr_stack+119382);
 tmp = dvrr_stack + 816707;
 target_ptr = Libderiv->deriv2_classes[6][7][22];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+817715, dvrr_stack+384729, dvrr_stack+120138);
 tmp = dvrr_stack + 817715;
 target_ptr = Libderiv->deriv2_classes[6][8][22];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+818975, dvrr_stack+386349, dvrr_stack+121083);
 tmp = dvrr_stack + 818975;
 target_ptr = Libderiv->deriv2_classes[6][9][22];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+820515, dvrr_stack+281329, dvrr_stack+88689);
 tmp = dvrr_stack + 820515;
 target_ptr = Libderiv->deriv2_classes[7][5][22];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+821271, dvrr_stack+282274, dvrr_stack+104406);
 tmp = dvrr_stack + 821271;
 target_ptr = Libderiv->deriv2_classes[7][6][22];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+822279, dvrr_stack+175144, dvrr_stack+89277);
 tmp = dvrr_stack + 822279;
 target_ptr = Libderiv->deriv2_classes[7][7][22];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+823575, dvrr_stack+464954, dvrr_stack+52807);
 tmp = dvrr_stack + 823575;
 target_ptr = Libderiv->deriv2_classes[7][8][22];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+825195, dvrr_stack+466979, dvrr_stack+54067);
 tmp = dvrr_stack + 825195;
 target_ptr = Libderiv->deriv2_classes[7][9][22];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+827175, dvrr_stack+64526, dvrr_stack+469454);
 tmp = dvrr_stack + 827175;
 target_ptr = Libderiv->deriv2_classes[4][5][21];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+827490, dvrr_stack+322204, dvrr_stack+306504);
 tmp = dvrr_stack + 827490;
 target_ptr = Libderiv->deriv2_classes[4][6][21];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+827910, dvrr_stack+61331, dvrr_stack+306784);
 tmp = dvrr_stack + 827910;
 target_ptr = Libderiv->deriv2_classes[4][7][21];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+828450, dvrr_stack+15345, dvrr_stack+307144);
 tmp = dvrr_stack + 828450;
 target_ptr = Libderiv->deriv2_classes[4][8][21];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+829125, dvrr_stack+83019, dvrr_stack+411604);
 tmp = dvrr_stack + 829125;
 target_ptr = Libderiv->deriv2_classes[4][9][21];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+829950, dvrr_stack+134198, dvrr_stack+7560);
 tmp = dvrr_stack + 829950;
 target_ptr = Libderiv->deriv2_classes[5][5][21];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+830391, dvrr_stack+77135, dvrr_stack+317074);
 tmp = dvrr_stack + 830391;
 target_ptr = Libderiv->deriv2_classes[5][6][21];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+830979, dvrr_stack+129770, dvrr_stack+4203);
 tmp = dvrr_stack + 830979;
 target_ptr = Libderiv->deriv2_classes[5][7][21];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+831735, dvrr_stack+145172, dvrr_stack+14670);
 tmp = dvrr_stack + 831735;
 target_ptr = Libderiv->deriv2_classes[5][8][21];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+832680, dvrr_stack+159322, dvrr_stack+23755);
 tmp = dvrr_stack + 832680;
 target_ptr = Libderiv->deriv2_classes[5][9][21];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+833835, dvrr_stack+130778, dvrr_stack+64526);
 tmp = dvrr_stack + 833835;
 target_ptr = Libderiv->deriv2_classes[6][5][21];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+834423, dvrr_stack+198550, dvrr_stack+322204);
 tmp = dvrr_stack + 834423;
 target_ptr = Libderiv->deriv2_classes[6][6][21];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+835207, dvrr_stack+222314, dvrr_stack+61331);
 tmp = dvrr_stack + 835207;
 target_ptr = Libderiv->deriv2_classes[6][7][21];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+836215, dvrr_stack+242510, dvrr_stack+15345);
 tmp = dvrr_stack + 836215;
 target_ptr = Libderiv->deriv2_classes[6][8][21];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+837475, dvrr_stack+260970, dvrr_stack+83019);
 tmp = dvrr_stack + 837475;
 target_ptr = Libderiv->deriv2_classes[6][9][21];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+839015, dvrr_stack+412154, dvrr_stack+134198);
 tmp = dvrr_stack + 839015;
 target_ptr = Libderiv->deriv2_classes[7][5][21];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+839771, dvrr_stack+418349, dvrr_stack+77135);
 tmp = dvrr_stack + 839771;
 target_ptr = Libderiv->deriv2_classes[7][6][21];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+840779, dvrr_stack+426089, dvrr_stack+129770);
 tmp = dvrr_stack + 840779;
 target_ptr = Libderiv->deriv2_classes[7][7][21];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+842075, dvrr_stack+436079, dvrr_stack+145172);
 tmp = dvrr_stack + 842075;
 target_ptr = Libderiv->deriv2_classes[7][8][21];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+843695, dvrr_stack+448939, dvrr_stack+159322);
 tmp = dvrr_stack + 843695;
 target_ptr = Libderiv->deriv2_classes[7][9][21];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+845675, dvrr_stack+315262, dvrr_stack+457039);
 tmp = dvrr_stack + 845675;
 target_ptr = Libderiv->deriv2_classes[4][5][20];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+845990, dvrr_stack+314674, dvrr_stack+457249);
 tmp = dvrr_stack + 845990;
 target_ptr = Libderiv->deriv2_classes[4][6][20];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+846410, dvrr_stack+315703, dvrr_stack+457529);
 tmp = dvrr_stack + 846410;
 target_ptr = Libderiv->deriv2_classes[4][7][20];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+846950, dvrr_stack+7875, dvrr_stack+457889);
 tmp = dvrr_stack + 846950;
 target_ptr = Libderiv->deriv2_classes[4][8][20];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+847625, dvrr_stack+286470, dvrr_stack+458339);
 tmp = dvrr_stack + 847625;
 target_ptr = Libderiv->deriv2_classes[4][9][20];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+848450, dvrr_stack+289431, dvrr_stack+310714);
 tmp = dvrr_stack + 848450;
 target_ptr = Libderiv->deriv2_classes[5][5][20];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+848891, dvrr_stack+262950, dvrr_stack+310294);
 tmp = dvrr_stack + 848891;
 target_ptr = Libderiv->deriv2_classes[5][6][20];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+849479, dvrr_stack+263734, dvrr_stack+311029);
 tmp = dvrr_stack + 849479;
 target_ptr = Libderiv->deriv2_classes[5][7][20];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+850235, dvrr_stack+244130, dvrr_stack+311569);
 tmp = dvrr_stack + 850235;
 target_ptr = Libderiv->deriv2_classes[5][8][20];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+851180, dvrr_stack+228182, dvrr_stack+312244);
 tmp = dvrr_stack + 851180;
 target_ptr = Libderiv->deriv2_classes[5][9][20];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+852335, dvrr_stack+223610, dvrr_stack+315262);
 tmp = dvrr_stack + 852335;
 target_ptr = Libderiv->deriv2_classes[6][5][20];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+852923, dvrr_stack+245390, dvrr_stack+314674);
 tmp = dvrr_stack + 852923;
 target_ptr = Libderiv->deriv2_classes[6][6][20];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+853707, dvrr_stack+229722, dvrr_stack+315703);
 tmp = dvrr_stack + 853707;
 target_ptr = Libderiv->deriv2_classes[6][7][20];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+854715, dvrr_stack+201406, dvrr_stack+7875);
 tmp = dvrr_stack + 854715;
 target_ptr = Libderiv->deriv2_classes[6][8][20];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+855975, dvrr_stack+203026, dvrr_stack+286470);
 tmp = dvrr_stack + 855975;
 target_ptr = Libderiv->deriv2_classes[6][9][20];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+857515, dvrr_stack+460155, dvrr_stack+289431);
 tmp = dvrr_stack + 857515;
 target_ptr = Libderiv->deriv2_classes[7][5][20];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+858271, dvrr_stack+461100, dvrr_stack+262950);
 tmp = dvrr_stack + 858271;
 target_ptr = Libderiv->deriv2_classes[7][6][20];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+859279, dvrr_stack+462360, dvrr_stack+263734);
 tmp = dvrr_stack + 859279;
 target_ptr = Libderiv->deriv2_classes[7][7][20];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+860575, dvrr_stack+451414, dvrr_stack+244130);
 tmp = dvrr_stack + 860575;
 target_ptr = Libderiv->deriv2_classes[7][8][20];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+862195, dvrr_stack+438104, dvrr_stack+228182);
 tmp = dvrr_stack + 862195;
 target_ptr = Libderiv->deriv2_classes[7][9][20];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+864175, dvrr_stack+135776, dvrr_stack+234230);
 tmp = dvrr_stack + 864175;
 target_ptr = Libderiv->deriv2_classes[4][5][19];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+864490, dvrr_stack+147257, dvrr_stack+234440);
 tmp = dvrr_stack + 864490;
 target_ptr = Libderiv->deriv2_classes[4][6][19];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+864910, dvrr_stack+112536, dvrr_stack+440579);
 tmp = dvrr_stack + 864910;
 target_ptr = Libderiv->deriv2_classes[4][7][19];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+865450, dvrr_stack+113292, dvrr_stack+458889);
 tmp = dvrr_stack + 865450;
 target_ptr = Libderiv->deriv2_classes[4][8][19];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+866125, dvrr_stack+114237, dvrr_stack+327349);
 tmp = dvrr_stack + 866125;
 target_ptr = Libderiv->deriv2_classes[4][9][19];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+866950, dvrr_stack+98862, dvrr_stack+181282);
 tmp = dvrr_stack + 866950;
 target_ptr = Libderiv->deriv2_classes[5][5][19];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+867391, dvrr_stack+115392, dvrr_stack+160862);
 tmp = dvrr_stack + 867391;
 target_ptr = Libderiv->deriv2_classes[5][6][19];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+867979, dvrr_stack+84174, dvrr_stack+161282);
 tmp = dvrr_stack + 867979;
 target_ptr = Libderiv->deriv2_classes[5][7][19];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+868735, dvrr_stack+72599, dvrr_stack+161822);
 tmp = dvrr_stack + 868735;
 target_ptr = Libderiv->deriv2_classes[5][8][19];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+869680, dvrr_stack+48829, dvrr_stack+146432);
 tmp = dvrr_stack + 869680;
 target_ptr = Libderiv->deriv2_classes[5][9][19];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+870835, dvrr_stack+64967, dvrr_stack+135776);
 tmp = dvrr_stack + 870835;
 target_ptr = Libderiv->deriv2_classes[6][5][19];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+871423, dvrr_stack+73859, dvrr_stack+147257);
 tmp = dvrr_stack + 871423;
 target_ptr = Libderiv->deriv2_classes[6][6][19];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+872207, dvrr_stack+36118, dvrr_stack+112536);
 tmp = dvrr_stack + 872207;
 target_ptr = Libderiv->deriv2_classes[6][7][19];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+873215, dvrr_stack+392553, dvrr_stack+113292);
 tmp = dvrr_stack + 873215;
 target_ptr = Libderiv->deriv2_classes[6][8][19];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+874475, dvrr_stack+394173, dvrr_stack+114237);
 tmp = dvrr_stack + 874475;
 target_ptr = Libderiv->deriv2_classes[6][9][19];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+876015, dvrr_stack+453439, dvrr_stack+98862);
 tmp = dvrr_stack + 876015;
 target_ptr = Libderiv->deriv2_classes[7][5][19];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+876771, dvrr_stack+427709, dvrr_stack+115392);
 tmp = dvrr_stack + 876771;
 target_ptr = Libderiv->deriv2_classes[7][6][19];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+877779, dvrr_stack+80159, dvrr_stack+84174);
 tmp = dvrr_stack + 877779;
 target_ptr = Libderiv->deriv2_classes[7][7][19];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+879075, dvrr_stack+469664, dvrr_stack+72599);
 tmp = dvrr_stack + 879075;
 target_ptr = Libderiv->deriv2_classes[7][8][19];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+880695, dvrr_stack+471689, dvrr_stack+48829);
 tmp = dvrr_stack + 880695;
 target_ptr = Libderiv->deriv2_classes[7][9][19];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+882675, dvrr_stack+41086, dvrr_stack+234720);
 tmp = dvrr_stack + 882675;
 target_ptr = Libderiv->deriv2_classes[4][5][18];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+882990, dvrr_stack+55832, dvrr_stack+252134);
 tmp = dvrr_stack + 882990;
 target_ptr = Libderiv->deriv2_classes[4][6][18];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+883410, dvrr_stack+27805, dvrr_stack+463980);
 tmp = dvrr_stack + 883410;
 target_ptr = Libderiv->deriv2_classes[4][7][18];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+883950, dvrr_stack+47333, dvrr_stack+454384);
 tmp = dvrr_stack + 883950;
 target_ptr = Libderiv->deriv2_classes[4][8][18];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+884625, dvrr_stack+398529, dvrr_stack+428969);
 tmp = dvrr_stack + 884625;
 target_ptr = Libderiv->deriv2_classes[4][9][18];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+885450, dvrr_stack+10080, dvrr_stack+147845);
 tmp = dvrr_stack + 885450;
 target_ptr = Libderiv->deriv2_classes[5][5][18];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+885891, dvrr_stack+17910, dvrr_stack+62087);
 tmp = dvrr_stack + 885891;
 target_ptr = Libderiv->deriv2_classes[5][6][18];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+886479, dvrr_stack+110085, dvrr_stack+65723);
 tmp = dvrr_stack + 886479;
 target_ptr = Libderiv->deriv2_classes[5][7][18];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+887235, dvrr_stack+399684, dvrr_stack+50369);
 tmp = dvrr_stack + 887235;
 target_ptr = Libderiv->deriv2_classes[5][8][18];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+888180, dvrr_stack+400944, dvrr_stack+24580);
 tmp = dvrr_stack + 888180;
 target_ptr = Libderiv->deriv2_classes[5][9][18];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+889335, dvrr_stack+197149, dvrr_stack+41086);
 tmp = dvrr_stack + 889335;
 target_ptr = Libderiv->deriv2_classes[6][5][18];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+889923, dvrr_stack+196141, dvrr_stack+55832);
 tmp = dvrr_stack + 889923;
 target_ptr = Libderiv->deriv2_classes[6][6][18];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+890707, dvrr_stack+404332, dvrr_stack+27805);
 tmp = dvrr_stack + 890707;
 target_ptr = Libderiv->deriv2_classes[6][7][18];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+891715, dvrr_stack+405628, dvrr_stack+47333);
 tmp = dvrr_stack + 891715;
 target_ptr = Libderiv->deriv2_classes[6][8][18];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+892975, dvrr_stack+407248, dvrr_stack+398529);
 tmp = dvrr_stack + 892975;
 target_ptr = Libderiv->deriv2_classes[6][9][18];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+894515, dvrr_stack+419609, dvrr_stack+10080);
 tmp = dvrr_stack + 894515;
 target_ptr = Libderiv->deriv2_classes[7][5][18];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+895271, dvrr_stack+413099, dvrr_stack+17910);
 tmp = dvrr_stack + 895271;
 target_ptr = Libderiv->deriv2_classes[7][6][18];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+896279, dvrr_stack+474164, dvrr_stack+110085);
 tmp = dvrr_stack + 896279;
 target_ptr = Libderiv->deriv2_classes[7][7][18];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+897575, dvrr_stack+475784, dvrr_stack+399684);
 tmp = dvrr_stack + 897575;
 target_ptr = Libderiv->deriv2_classes[7][8][18];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+899195, dvrr_stack+477809, dvrr_stack+400944);
 tmp = dvrr_stack + 899195;
 target_ptr = Libderiv->deriv2_classes[7][9][18];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+901175, dvrr_stack+172384, dvrr_stack+172174);
 tmp = dvrr_stack + 901175;
 target_ptr = Libderiv->deriv2_classes[4][5][14];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+901490, dvrr_stack+173105, dvrr_stack+172825);
 tmp = dvrr_stack + 901490;
 target_ptr = Libderiv->deriv2_classes[4][6][14];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+901910, dvrr_stack+174053, dvrr_stack+173693);
 tmp = dvrr_stack + 901910;
 target_ptr = Libderiv->deriv2_classes[4][7][14];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+902450, dvrr_stack+307594, dvrr_stack+459339);
 tmp = dvrr_stack + 902450;
 target_ptr = Libderiv->deriv2_classes[4][8][14];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+903125, dvrr_stack+480284, dvrr_stack+420554);
 tmp = dvrr_stack + 903125;
 target_ptr = Libderiv->deriv2_classes[4][9][14];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+903950, dvrr_stack+21335, dvrr_stack+20406);
 tmp = dvrr_stack + 903950;
 target_ptr = Libderiv->deriv2_classes[5][5][14];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+904391, dvrr_stack+33308, dvrr_stack+308539);
 tmp = dvrr_stack + 904391;
 target_ptr = Libderiv->deriv2_classes[5][6][14];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+904979, dvrr_stack+481979, dvrr_stack+481439);
 tmp = dvrr_stack + 904979;
 target_ptr = Libderiv->deriv2_classes[5][7][14];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+905735, dvrr_stack+482987, dvrr_stack+12690);
 tmp = dvrr_stack + 905735;
 target_ptr = Libderiv->deriv2_classes[5][8][14];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+906680, dvrr_stack+485072, dvrr_stack+484247);
 tmp = dvrr_stack + 906680;
 target_ptr = Libderiv->deriv2_classes[5][9][14];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+907835, dvrr_stack+486612, dvrr_stack+172384);
 tmp = dvrr_stack + 907835;
 target_ptr = Libderiv->deriv2_classes[6][5][14];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+908423, dvrr_stack+487368, dvrr_stack+173105);
 tmp = dvrr_stack + 908423;
 target_ptr = Libderiv->deriv2_classes[6][6][14];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+909207, dvrr_stack+488376, dvrr_stack+174053);
 tmp = dvrr_stack + 909207;
 target_ptr = Libderiv->deriv2_classes[6][7][14];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+910215, dvrr_stack+489672, dvrr_stack+307594);
 tmp = dvrr_stack + 910215;
 target_ptr = Libderiv->deriv2_classes[6][8][14];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+911475, dvrr_stack+491292, dvrr_stack+480284);
 tmp = dvrr_stack + 911475;
 target_ptr = Libderiv->deriv2_classes[6][9][14];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+913015, dvrr_stack+43678, dvrr_stack+21335);
 tmp = dvrr_stack + 913015;
 target_ptr = Libderiv->deriv2_classes[7][5][14];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+913771, dvrr_stack+417089, dvrr_stack+33308);
 tmp = dvrr_stack + 913771;
 target_ptr = Libderiv->deriv2_classes[7][6][14];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+914779, dvrr_stack+44623, dvrr_stack+481979);
 tmp = dvrr_stack + 914779;
 target_ptr = Libderiv->deriv2_classes[7][7][14];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+916075, dvrr_stack+433154, dvrr_stack+482987);
 tmp = dvrr_stack + 916075;
 target_ptr = Libderiv->deriv2_classes[7][8][14];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+917695, dvrr_stack+442559, dvrr_stack+485072);
 tmp = dvrr_stack + 917695;
 target_ptr = Libderiv->deriv2_classes[7][9][14];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+919675, dvrr_stack+126669, dvrr_stack+431129);
 tmp = dvrr_stack + 919675;
 target_ptr = Libderiv->deriv2_classes[4][5][13];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+919990, dvrr_stack+431619, dvrr_stack+431339);
 tmp = dvrr_stack + 919990;
 target_ptr = Libderiv->deriv2_classes[4][6][13];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+920410, dvrr_stack+445034, dvrr_stack+432207);
 tmp = dvrr_stack + 920410;
 target_ptr = Libderiv->deriv2_classes[4][7][13];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+920950, dvrr_stack+445790, dvrr_stack+432567);
 tmp = dvrr_stack + 920950;
 target_ptr = Libderiv->deriv2_classes[4][8][13];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+921625, dvrr_stack+447285, dvrr_stack+446735);
 tmp = dvrr_stack + 921625;
 target_ptr = Libderiv->deriv2_classes[4][9][13];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+922450, dvrr_stack+219514, dvrr_stack+448440);
 tmp = dvrr_stack + 922450;
 target_ptr = Libderiv->deriv2_classes[5][5][13];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+922891, dvrr_stack+220522, dvrr_stack+220102);
 tmp = dvrr_stack + 922891;
 target_ptr = Libderiv->deriv2_classes[5][6][13];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+923479, dvrr_stack+493272, dvrr_stack+226346);
 tmp = dvrr_stack + 923479;
 target_ptr = Libderiv->deriv2_classes[5][7][13];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+924235, dvrr_stack+255470, dvrr_stack+425154);
 tmp = dvrr_stack + 924235;
 target_ptr = Libderiv->deriv2_classes[5][8][13];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+925180, dvrr_stack+494280, dvrr_stack+256730);
 tmp = dvrr_stack + 925180;
 target_ptr = Libderiv->deriv2_classes[5][9][13];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+926335, dvrr_stack+257555, dvrr_stack+126669);
 tmp = dvrr_stack + 926335;
 target_ptr = Libderiv->deriv2_classes[6][5][13];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+926923, dvrr_stack+46243, dvrr_stack+431619);
 tmp = dvrr_stack + 926923;
 target_ptr = Libderiv->deriv2_classes[6][6][13];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+927707, dvrr_stack+70259, dvrr_stack+445034);
 tmp = dvrr_stack + 927707;
 target_ptr = Libderiv->deriv2_classes[6][7][13];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+928715, dvrr_stack+495820, dvrr_stack+445790);
 tmp = dvrr_stack + 928715;
 target_ptr = Libderiv->deriv2_classes[6][8][13];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+929975, dvrr_stack+497440, dvrr_stack+447285);
 tmp = dvrr_stack + 929975;
 target_ptr = Libderiv->deriv2_classes[6][9][13];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+931515, dvrr_stack+111093, dvrr_stack+219514);
 tmp = dvrr_stack + 931515;
 target_ptr = Libderiv->deriv2_classes[7][5][13];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+932271, dvrr_stack+62507, dvrr_stack+220522);
 tmp = dvrr_stack + 932271;
 target_ptr = Libderiv->deriv2_classes[7][6][13];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+933279, dvrr_stack+499420, dvrr_stack+493272);
 tmp = dvrr_stack + 933279;
 target_ptr = Libderiv->deriv2_classes[7][7][13];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+934575, dvrr_stack+501040, dvrr_stack+255470);
 tmp = dvrr_stack + 934575;
 target_ptr = Libderiv->deriv2_classes[7][8][13];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+936195, dvrr_stack+503065, dvrr_stack+494280);
 tmp = dvrr_stack + 936195;
 target_ptr = Libderiv->deriv2_classes[7][9][13];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,21,dvrr_stack+938175, dvrr_stack+324052, dvrr_stack+264742);
 tmp = dvrr_stack + 938175;
 target_ptr = Libderiv->deriv2_classes[4][5][11];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,28,dvrr_stack+938490, dvrr_stack+323464, dvrr_stack+316459);
 tmp = dvrr_stack + 938490;
 target_ptr = Libderiv->deriv2_classes[4][6][11];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,36,dvrr_stack+938910, dvrr_stack+324493, dvrr_stack+51044);
 tmp = dvrr_stack + 938910;
 target_ptr = Libderiv->deriv2_classes[4][7][11];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,45,dvrr_stack+939450, dvrr_stack+325249, dvrr_stack+28561);
 tmp = dvrr_stack + 939450;
 target_ptr = Libderiv->deriv2_classes[4][8][11];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_g(Data,55,dvrr_stack+940125, dvrr_stack+326194, dvrr_stack+309054);
 tmp = dvrr_stack + 940125;
 target_ptr = Libderiv->deriv2_classes[4][9][11];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,21,dvrr_stack+28561, dvrr_stack+298144, dvrr_stack+318394);
 tmp = dvrr_stack + 28561;
 target_ptr = Libderiv->deriv2_classes[5][5][11];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,28,dvrr_stack+308959, dvrr_stack+297360, dvrr_stack+317974);
 tmp = dvrr_stack + 308959;
 target_ptr = Libderiv->deriv2_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,36,dvrr_stack+317914, dvrr_stack+298732, dvrr_stack+318709);
 tmp = dvrr_stack + 317914;
 target_ptr = Libderiv->deriv2_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,45,dvrr_stack+940950, dvrr_stack+270690, dvrr_stack+319249);
 tmp = dvrr_stack + 940950;
 target_ptr = Libderiv->deriv2_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,55,dvrr_stack+318670, dvrr_stack+271950, dvrr_stack+319924);
 tmp = dvrr_stack + 318670;
 target_ptr = Libderiv->deriv2_classes[5][9][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,21,dvrr_stack+319825, dvrr_stack+206182, dvrr_stack+324052);
 tmp = dvrr_stack + 319825;
 target_ptr = Libderiv->deriv2_classes[6][5][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,28,dvrr_stack+941895, dvrr_stack+205174, dvrr_stack+323464);
 tmp = dvrr_stack + 941895;
 target_ptr = Libderiv->deriv2_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,36,dvrr_stack+205006, dvrr_stack+206938, dvrr_stack+324493);
 tmp = dvrr_stack + 205006;
 target_ptr = Libderiv->deriv2_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,45,dvrr_stack+206014, dvrr_stack+208234, dvrr_stack+325249);
 tmp = dvrr_stack + 206014;
 target_ptr = Libderiv->deriv2_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,55,dvrr_stack+207274, dvrr_stack+209854, dvrr_stack+326194);
 tmp = dvrr_stack + 207274;
 target_ptr = Libderiv->deriv2_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,21,dvrr_stack+208814, dvrr_stack+421184, dvrr_stack+298144);
 tmp = dvrr_stack + 208814;
 target_ptr = Libderiv->deriv2_classes[7][5][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,28,dvrr_stack+209570, dvrr_stack+429869, dvrr_stack+297360);
 tmp = dvrr_stack + 209570;
 target_ptr = Libderiv->deriv2_classes[7][6][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,36,dvrr_stack+210578, dvrr_stack+440939, dvrr_stack+298732);
 tmp = dvrr_stack + 210578;
 target_ptr = Libderiv->deriv2_classes[7][7][11];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,45,dvrr_stack+440939, dvrr_stack+455014, dvrr_stack+270690);
 tmp = dvrr_stack + 440939;
 target_ptr = Libderiv->deriv2_classes[7][8][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,55,dvrr_stack+323107, dvrr_stack+277494, dvrr_stack+271950);
 tmp = dvrr_stack + 323107;
 target_ptr = Libderiv->deriv2_classes[7][9][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+51044, dvrr_stack+118941, dvrr_stack+464464);
 tmp = dvrr_stack + 51044;
 target_ptr = Libderiv->deriv2_classes[4][5][10];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+325087, dvrr_stack+118353, dvrr_stack+464674);
 tmp = dvrr_stack + 325087;
 target_ptr = Libderiv->deriv2_classes[4][6][10];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+325507, dvrr_stack+119382, dvrr_stack+279969);
 tmp = dvrr_stack + 325507;
 target_ptr = Libderiv->deriv2_classes[4][7][10];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+326047, dvrr_stack+120138, dvrr_stack+280329);
 tmp = dvrr_stack + 326047;
 target_ptr = Libderiv->deriv2_classes[4][8][10];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+429834, dvrr_stack+121083, dvrr_stack+280779);
 tmp = dvrr_stack + 429834;
 target_ptr = Libderiv->deriv2_classes[4][9][10];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+326722, dvrr_stack+88689, dvrr_stack+212479);
 tmp = dvrr_stack + 326722;
 target_ptr = Libderiv->deriv2_classes[5][5][10];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+270412, dvrr_stack+104406, dvrr_stack+212059);
 tmp = dvrr_stack + 270412;
 target_ptr = Libderiv->deriv2_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+211874, dvrr_stack+89277, dvrr_stack+188674);
 tmp = dvrr_stack + 211874;
 target_ptr = Libderiv->deriv2_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+271000, dvrr_stack+52807, dvrr_stack+151220);
 tmp = dvrr_stack + 271000;
 target_ptr = Libderiv->deriv2_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+271945, dvrr_stack+54067, dvrr_stack+151895);
 tmp = dvrr_stack + 271945;
 target_ptr = Libderiv->deriv2_classes[5][9][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+297089, dvrr_stack+68054, dvrr_stack+118941);
 tmp = dvrr_stack + 297089;
 target_ptr = Libderiv->deriv2_classes[6][5][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+297677, dvrr_stack+40078, dvrr_stack+118353);
 tmp = dvrr_stack + 297677;
 target_ptr = Libderiv->deriv2_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+298461, dvrr_stack+32012, dvrr_stack+119382);
 tmp = dvrr_stack + 298461;
 target_ptr = Libderiv->deriv2_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+454834, dvrr_stack+384729, dvrr_stack+120138);
 tmp = dvrr_stack + 454834;
 target_ptr = Libderiv->deriv2_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+151130, dvrr_stack+386349, dvrr_stack+121083);
 tmp = dvrr_stack + 151130;
 target_ptr = Libderiv->deriv2_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+456094, dvrr_stack+281329, dvrr_stack+88689);
 tmp = dvrr_stack + 456094;
 target_ptr = Libderiv->deriv2_classes[7][5][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+421104, dvrr_stack+282274, dvrr_stack+104406);
 tmp = dvrr_stack + 421104;
 target_ptr = Libderiv->deriv2_classes[7][6][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+118031, dvrr_stack+175144, dvrr_stack+89277);
 tmp = dvrr_stack + 118031;
 target_ptr = Libderiv->deriv2_classes[7][7][10];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+175124, dvrr_stack+464954, dvrr_stack+52807);
 tmp = dvrr_stack + 175124;
 target_ptr = Libderiv->deriv2_classes[7][8][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+464340, dvrr_stack+466979, dvrr_stack+54067);
 tmp = dvrr_stack + 464340;
 target_ptr = Libderiv->deriv2_classes[7][9][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+942679, dvrr_stack+64526, dvrr_stack+469454);
 tmp = dvrr_stack + 942679;
 target_ptr = Libderiv->deriv2_classes[4][5][9];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+430659, dvrr_stack+322204, dvrr_stack+306504);
 tmp = dvrr_stack + 430659;
 target_ptr = Libderiv->deriv2_classes[4][6][9];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+466320, dvrr_stack+61331, dvrr_stack+306784);
 tmp = dvrr_stack + 466320;
 target_ptr = Libderiv->deriv2_classes[4][7][9];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+466860, dvrr_stack+15345, dvrr_stack+307144);
 tmp = dvrr_stack + 466860;
 target_ptr = Libderiv->deriv2_classes[4][8][9];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+467535, dvrr_stack+83019, dvrr_stack+411604);
 tmp = dvrr_stack + 467535;
 target_ptr = Libderiv->deriv2_classes[4][9][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+411304, dvrr_stack+134198, dvrr_stack+7560);
 tmp = dvrr_stack + 411304;
 target_ptr = Libderiv->deriv2_classes[5][5][9];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+468360, dvrr_stack+77135, dvrr_stack+317074);
 tmp = dvrr_stack + 468360;
 target_ptr = Libderiv->deriv2_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+188341, dvrr_stack+129770, dvrr_stack+4203);
 tmp = dvrr_stack + 188341;
 target_ptr = Libderiv->deriv2_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+119327, dvrr_stack+145172, dvrr_stack+14670);
 tmp = dvrr_stack + 119327;
 target_ptr = Libderiv->deriv2_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+120272, dvrr_stack+159322, dvrr_stack+23755);
 tmp = dvrr_stack + 120272;
 target_ptr = Libderiv->deriv2_classes[5][9][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+23665, dvrr_stack+130778, dvrr_stack+64526);
 tmp = dvrr_stack + 23665;
 target_ptr = Libderiv->deriv2_classes[6][5][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+14545, dvrr_stack+198550, dvrr_stack+322204);
 tmp = dvrr_stack + 14545;
 target_ptr = Libderiv->deriv2_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+198493, dvrr_stack+222314, dvrr_stack+61331);
 tmp = dvrr_stack + 198493;
 target_ptr = Libderiv->deriv2_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+222090, dvrr_stack+242510, dvrr_stack+15345);
 tmp = dvrr_stack + 222090;
 target_ptr = Libderiv->deriv2_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+242270, dvrr_stack+260970, dvrr_stack+83019);
 tmp = dvrr_stack + 242270;
 target_ptr = Libderiv->deriv2_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+130778, dvrr_stack+412154, dvrr_stack+134198);
 tmp = dvrr_stack + 130778;
 target_ptr = Libderiv->deriv2_classes[7][5][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+411745, dvrr_stack+418349, dvrr_stack+77135);
 tmp = dvrr_stack + 411745;
 target_ptr = Libderiv->deriv2_classes[7][6][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+260931, dvrr_stack+426089, dvrr_stack+129770);
 tmp = dvrr_stack + 260931;
 target_ptr = Libderiv->deriv2_classes[7][7][9];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+426039, dvrr_stack+436079, dvrr_stack+145172);
 tmp = dvrr_stack + 426039;
 target_ptr = Libderiv->deriv2_classes[7][8][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+435963, dvrr_stack+448939, dvrr_stack+159322);
 tmp = dvrr_stack + 435963;
 target_ptr = Libderiv->deriv2_classes[7][9][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+418349, dvrr_stack+315262, dvrr_stack+457039);
 tmp = dvrr_stack + 418349;
 target_ptr = Libderiv->deriv2_classes[4][5][8];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+418664, dvrr_stack+314674, dvrr_stack+457249);
 tmp = dvrr_stack + 418664;
 target_ptr = Libderiv->deriv2_classes[4][6][8];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+322093, dvrr_stack+315703, dvrr_stack+457529);
 tmp = dvrr_stack + 322093;
 target_ptr = Libderiv->deriv2_classes[4][7][8];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+76967, dvrr_stack+7875, dvrr_stack+457889);
 tmp = dvrr_stack + 76967;
 target_ptr = Libderiv->deriv2_classes[4][8][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+159245, dvrr_stack+286470, dvrr_stack+458339);
 tmp = dvrr_stack + 159245;
 target_ptr = Libderiv->deriv2_classes[4][9][8];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+419084, dvrr_stack+289431, dvrr_stack+310714);
 tmp = dvrr_stack + 419084;
 target_ptr = Libderiv->deriv2_classes[5][5][8];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+160070, dvrr_stack+262950, dvrr_stack+310294);
 tmp = dvrr_stack + 160070;
 target_ptr = Libderiv->deriv2_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+145082, dvrr_stack+263734, dvrr_stack+311029);
 tmp = dvrr_stack + 145082;
 target_ptr = Libderiv->deriv2_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+129702, dvrr_stack+244130, dvrr_stack+311569);
 tmp = dvrr_stack + 129702;
 target_ptr = Libderiv->deriv2_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+448755, dvrr_stack+228182, dvrr_stack+312244);
 tmp = dvrr_stack + 448755;
 target_ptr = Libderiv->deriv2_classes[5][9][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+145838, dvrr_stack+223610, dvrr_stack+315262);
 tmp = dvrr_stack + 145838;
 target_ptr = Libderiv->deriv2_classes[6][5][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+223350, dvrr_stack+245390, dvrr_stack+314674);
 tmp = dvrr_stack + 223350;
 target_ptr = Libderiv->deriv2_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+245390, dvrr_stack+229722, dvrr_stack+315703);
 tmp = dvrr_stack + 245390;
 target_ptr = Libderiv->deriv2_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+229722, dvrr_stack+201406, dvrr_stack+7875);
 tmp = dvrr_stack + 229722;
 target_ptr = Libderiv->deriv2_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+201322, dvrr_stack+203026, dvrr_stack+286470);
 tmp = dvrr_stack + 201322;
 target_ptr = Libderiv->deriv2_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+202862, dvrr_stack+460155, dvrr_stack+289431);
 tmp = dvrr_stack + 202862;
 target_ptr = Libderiv->deriv2_classes[7][5][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+203618, dvrr_stack+461100, dvrr_stack+262950);
 tmp = dvrr_stack + 203618;
 target_ptr = Libderiv->deriv2_classes[7][6][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+314518, dvrr_stack+462360, dvrr_stack+263734);
 tmp = dvrr_stack + 314518;
 target_ptr = Libderiv->deriv2_classes[7][7][8];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+262227, dvrr_stack+451414, dvrr_stack+244130);
 tmp = dvrr_stack + 262227;
 target_ptr = Libderiv->deriv2_classes[7][8][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+449910, dvrr_stack+438104, dvrr_stack+228182);
 tmp = dvrr_stack + 449910;
 target_ptr = Libderiv->deriv2_classes[7][9][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+412753, dvrr_stack+135776, dvrr_stack+234230);
 tmp = dvrr_stack + 412753;
 target_ptr = Libderiv->deriv2_classes[4][5][7];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+289312, dvrr_stack+147257, dvrr_stack+234440);
 tmp = dvrr_stack + 289312;
 target_ptr = Libderiv->deriv2_classes[4][6][7];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+315814, dvrr_stack+112536, dvrr_stack+440579);
 tmp = dvrr_stack + 315814;
 target_ptr = Libderiv->deriv2_classes[4][7][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+243810, dvrr_stack+113292, dvrr_stack+458889);
 tmp = dvrr_stack + 243810;
 target_ptr = Libderiv->deriv2_classes[4][8][7];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+244485, dvrr_stack+114237, dvrr_stack+327349);
 tmp = dvrr_stack + 244485;
 target_ptr = Libderiv->deriv2_classes[4][9][7];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+228146, dvrr_stack+98862, dvrr_stack+181282);
 tmp = dvrr_stack + 228146;
 target_ptr = Libderiv->deriv2_classes[5][5][7];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+228587, dvrr_stack+115392, dvrr_stack+160862);
 tmp = dvrr_stack + 228587;
 target_ptr = Libderiv->deriv2_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+15329, dvrr_stack+84174, dvrr_stack+161282);
 tmp = dvrr_stack + 15329;
 target_ptr = Libderiv->deriv2_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+160658, dvrr_stack+72599, dvrr_stack+161822);
 tmp = dvrr_stack + 160658;
 target_ptr = Libderiv->deriv2_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+7470, dvrr_stack+48829, dvrr_stack+146432);
 tmp = dvrr_stack + 7470;
 target_ptr = Libderiv->deriv2_classes[5][9][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+161603, dvrr_stack+64967, dvrr_stack+135776);
 tmp = dvrr_stack + 161603;
 target_ptr = Libderiv->deriv2_classes[6][5][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+146426, dvrr_stack+73859, dvrr_stack+147257);
 tmp = dvrr_stack + 146426;
 target_ptr = Libderiv->deriv2_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+73859, dvrr_stack+36118, dvrr_stack+112536);
 tmp = dvrr_stack + 73859;
 target_ptr = Libderiv->deriv2_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+35884, dvrr_stack+392553, dvrr_stack+113292);
 tmp = dvrr_stack + 35884;
 target_ptr = Libderiv->deriv2_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+392463, dvrr_stack+394173, dvrr_stack+114237);
 tmp = dvrr_stack + 392463;
 target_ptr = Libderiv->deriv2_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+394003, dvrr_stack+453439, dvrr_stack+98862);
 tmp = dvrr_stack + 394003;
 target_ptr = Libderiv->deriv2_classes[7][5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+394759, dvrr_stack+427709, dvrr_stack+115392);
 tmp = dvrr_stack + 394759;
 target_ptr = Libderiv->deriv2_classes[7][6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+451890, dvrr_stack+80159, dvrr_stack+84174);
 tmp = dvrr_stack + 451890;
 target_ptr = Libderiv->deriv2_classes[7][7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+112353, dvrr_stack+469664, dvrr_stack+72599);
 tmp = dvrr_stack + 112353;
 target_ptr = Libderiv->deriv2_classes[7][8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+113973, dvrr_stack+471689, dvrr_stack+48829);
 tmp = dvrr_stack + 113973;
 target_ptr = Libderiv->deriv2_classes[7][9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+135647, dvrr_stack+41086, dvrr_stack+234720);
 tmp = dvrr_stack + 135647;
 target_ptr = Libderiv->deriv2_classes[4][5][6];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+229175, dvrr_stack+55832, dvrr_stack+252134);
 tmp = dvrr_stack + 229175;
 target_ptr = Libderiv->deriv2_classes[4][6][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+147210, dvrr_stack+27805, dvrr_stack+463980);
 tmp = dvrr_stack + 147210;
 target_ptr = Libderiv->deriv2_classes[4][7][6];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+453186, dvrr_stack+47333, dvrr_stack+454384);
 tmp = dvrr_stack + 453186;
 target_ptr = Libderiv->deriv2_classes[4][8][6];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+453861, dvrr_stack+398529, dvrr_stack+428969);
 tmp = dvrr_stack + 453861;
 target_ptr = Libderiv->deriv2_classes[4][9][6];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+134162, dvrr_stack+10080, dvrr_stack+147845);
 tmp = dvrr_stack + 134162;
 target_ptr = Libderiv->deriv2_classes[5][5][6];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+4143, dvrr_stack+17910, dvrr_stack+62087);
 tmp = dvrr_stack + 4143;
 target_ptr = Libderiv->deriv2_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+427659, dvrr_stack+110085, dvrr_stack+65723);
 tmp = dvrr_stack + 427659;
 target_ptr = Libderiv->deriv2_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+428415, dvrr_stack+399684, dvrr_stack+50369);
 tmp = dvrr_stack + 428415;
 target_ptr = Libderiv->deriv2_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+72380, dvrr_stack+400944, dvrr_stack+24580);
 tmp = dvrr_stack + 72380;
 target_ptr = Libderiv->deriv2_classes[5][9][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+24253, dvrr_stack+197149, dvrr_stack+41086);
 tmp = dvrr_stack + 24253;
 target_ptr = Libderiv->deriv2_classes[6][5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+263847, dvrr_stack+196141, dvrr_stack+55832);
 tmp = dvrr_stack + 263847;
 target_ptr = Libderiv->deriv2_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+286114, dvrr_stack+404332, dvrr_stack+27805);
 tmp = dvrr_stack + 286114;
 target_ptr = Libderiv->deriv2_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+404248, dvrr_stack+405628, dvrr_stack+47333);
 tmp = dvrr_stack + 404248;
 target_ptr = Libderiv->deriv2_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+405508, dvrr_stack+407248, dvrr_stack+398529);
 tmp = dvrr_stack + 405508;
 target_ptr = Libderiv->deriv2_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+407048, dvrr_stack+419609, dvrr_stack+10080);
 tmp = dvrr_stack + 407048;
 target_ptr = Libderiv->deriv2_classes[7][5][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+419525, dvrr_stack+413099, dvrr_stack+17910);
 tmp = dvrr_stack + 419525;
 target_ptr = Libderiv->deriv2_classes[7][6][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+407804, dvrr_stack+474164, dvrr_stack+110085);
 tmp = dvrr_stack + 407804;
 target_ptr = Libderiv->deriv2_classes[7][7][6];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+437943, dvrr_stack+475784, dvrr_stack+399684);
 tmp = dvrr_stack + 437943;
 target_ptr = Libderiv->deriv2_classes[7][8][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+398409, dvrr_stack+477809, dvrr_stack+400944);
 tmp = dvrr_stack + 398409;
 target_ptr = Libderiv->deriv2_classes[7][9][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+413068, dvrr_stack+172384, dvrr_stack+172174);
 tmp = dvrr_stack + 413068;
 target_ptr = Libderiv->deriv2_classes[4][5][2];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+413383, dvrr_stack+173105, dvrr_stack+172825);
 tmp = dvrr_stack + 413383;
 target_ptr = Libderiv->deriv2_classes[4][6][2];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+413803, dvrr_stack+174053, dvrr_stack+173693);
 tmp = dvrr_stack + 413803;
 target_ptr = Libderiv->deriv2_classes[4][7][2];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+400389, dvrr_stack+307594, dvrr_stack+459339);
 tmp = dvrr_stack + 400389;
 target_ptr = Libderiv->deriv2_classes[4][8][2];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+401064, dvrr_stack+480284, dvrr_stack+420554);
 tmp = dvrr_stack + 401064;
 target_ptr = Libderiv->deriv2_classes[4][9][2];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+420533, dvrr_stack+21335, dvrr_stack+20406);
 tmp = dvrr_stack + 420533;
 target_ptr = Libderiv->deriv2_classes[5][5][2];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+401889, dvrr_stack+33308, dvrr_stack+308539);
 tmp = dvrr_stack + 401889;
 target_ptr = Libderiv->deriv2_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+17790, dvrr_stack+481979, dvrr_stack+481439);
 tmp = dvrr_stack + 17790;
 target_ptr = Libderiv->deriv2_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+47251, dvrr_stack+482987, dvrr_stack+12690);
 tmp = dvrr_stack + 47251;
 target_ptr = Libderiv->deriv2_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+439563, dvrr_stack+485072, dvrr_stack+484247);
 tmp = dvrr_stack + 439563;
 target_ptr = Libderiv->deriv2_classes[5][9][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+484247, dvrr_stack+486612, dvrr_stack+172384);
 tmp = dvrr_stack + 484247;
 target_ptr = Libderiv->deriv2_classes[6][5][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+9801, dvrr_stack+487368, dvrr_stack+173105);
 tmp = dvrr_stack + 9801;
 target_ptr = Libderiv->deriv2_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+486612, dvrr_stack+488376, dvrr_stack+174053);
 tmp = dvrr_stack + 486612;
 target_ptr = Libderiv->deriv2_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+487620, dvrr_stack+489672, dvrr_stack+307594);
 tmp = dvrr_stack + 487620;
 target_ptr = Libderiv->deriv2_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+488880, dvrr_stack+491292, dvrr_stack+480284);
 tmp = dvrr_stack + 488880;
 target_ptr = Libderiv->deriv2_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+490420, dvrr_stack+43678, dvrr_stack+21335);
 tmp = dvrr_stack + 490420;
 target_ptr = Libderiv->deriv2_classes[7][5][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+491176, dvrr_stack+417089, dvrr_stack+33308);
 tmp = dvrr_stack + 491176;
 target_ptr = Libderiv->deriv2_classes[7][6][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+171950, dvrr_stack+44623, dvrr_stack+481979);
 tmp = dvrr_stack + 171950;
 target_ptr = Libderiv->deriv2_classes[7][7][2];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+43381, dvrr_stack+433154, dvrr_stack+482987);
 tmp = dvrr_stack + 43381;
 target_ptr = Libderiv->deriv2_classes[7][8][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+433017, dvrr_stack+442559, dvrr_stack+485072);
 tmp = dvrr_stack + 433017;
 target_ptr = Libderiv->deriv2_classes[7][9][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+442559, dvrr_stack+126669, dvrr_stack+431129);
 tmp = dvrr_stack + 442559;
 target_ptr = Libderiv->deriv2_classes[4][5][1];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+442874, dvrr_stack+431619, dvrr_stack+431339);
 tmp = dvrr_stack + 442874;
 target_ptr = Libderiv->deriv2_classes[4][6][1];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+431079, dvrr_stack+445034, dvrr_stack+432207);
 tmp = dvrr_stack + 431079;
 target_ptr = Libderiv->deriv2_classes[4][7][1];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+443294, dvrr_stack+445790, dvrr_stack+432567);
 tmp = dvrr_stack + 443294;
 target_ptr = Libderiv->deriv2_classes[4][8][1];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+443969, dvrr_stack+447285, dvrr_stack+446735);
 tmp = dvrr_stack + 443969;
 target_ptr = Libderiv->deriv2_classes[4][9][1];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+446735, dvrr_stack+219514, dvrr_stack+448440);
 tmp = dvrr_stack + 446735;
 target_ptr = Libderiv->deriv2_classes[5][5][1];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+432207, dvrr_stack+220522, dvrr_stack+220102);
 tmp = dvrr_stack + 432207;
 target_ptr = Libderiv->deriv2_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+492184, dvrr_stack+493272, dvrr_stack+226346);
 tmp = dvrr_stack + 492184;
 target_ptr = Libderiv->deriv2_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+484835, dvrr_stack+255470, dvrr_stack+425154);
 tmp = dvrr_stack + 484835;
 target_ptr = Libderiv->deriv2_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+173246, dvrr_stack+494280, dvrr_stack+256730);
 tmp = dvrr_stack + 173246;
 target_ptr = Libderiv->deriv2_classes[5][9][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+256730, dvrr_stack+257555, dvrr_stack+126669);
 tmp = dvrr_stack + 256730;
 target_ptr = Libderiv->deriv2_classes[6][5][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+257318, dvrr_stack+46243, dvrr_stack+431619);
 tmp = dvrr_stack + 257318;
 target_ptr = Libderiv->deriv2_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+61267, dvrr_stack+70259, dvrr_stack+445034);
 tmp = dvrr_stack + 61267;
 target_ptr = Libderiv->deriv2_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+70154, dvrr_stack+495820, dvrr_stack+445790);
 tmp = dvrr_stack + 70154;
 target_ptr = Libderiv->deriv2_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+495820, dvrr_stack+497440, dvrr_stack+447285);
 tmp = dvrr_stack + 495820;
 target_ptr = Libderiv->deriv2_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+497360, dvrr_stack+111093, dvrr_stack+219514);
 tmp = dvrr_stack + 497360;
 target_ptr = Libderiv->deriv2_classes[7][5][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+498116, dvrr_stack+62507, dvrr_stack+220522);
 tmp = dvrr_stack + 498116;
 target_ptr = Libderiv->deriv2_classes[7][6][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+447176, dvrr_stack+499420, dvrr_stack+493272);
 tmp = dvrr_stack + 447176;
 target_ptr = Libderiv->deriv2_classes[7][7][1];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+499124, dvrr_stack+501040, dvrr_stack+255470);
 tmp = dvrr_stack + 499124;
 target_ptr = Libderiv->deriv2_classes[7][8][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+500744, dvrr_stack+503065, dvrr_stack+494280);
 tmp = dvrr_stack + 500744;
 target_ptr = Libderiv->deriv2_classes[7][9][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+502724, dvrr_stack+505540, dvrr_stack+425829);
 tmp = dvrr_stack + 502724;
 target_ptr = Libderiv->deriv2_classes[4][5][0];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+503039, dvrr_stack+2264, dvrr_stack+1984);
 tmp = dvrr_stack + 503039;
 target_ptr = Libderiv->deriv2_classes[4][6][0];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+503459, dvrr_stack+4743, dvrr_stack+3783);
 tmp = dvrr_stack + 503459;
 target_ptr = Libderiv->deriv2_classes[4][7][0];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+503999, dvrr_stack+5499, dvrr_stack+7020);
 tmp = dvrr_stack + 503999;
 target_ptr = Libderiv->deriv2_classes[4][8][0];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+504674, dvrr_stack+0, dvrr_stack+13995);
 tmp = dvrr_stack + 504674;
 target_ptr = Libderiv->deriv2_classes[4][9][0];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+431619, dvrr_stack+2852, dvrr_stack+22930);
 tmp = dvrr_stack + 431619;
 target_ptr = Libderiv->deriv2_classes[5][5][0];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+444794, dvrr_stack+435179, dvrr_stack+23245);
 tmp = dvrr_stack + 444794;
 target_ptr = Libderiv->deriv2_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+445382, dvrr_stack+58909, dvrr_stack+258311);
 tmp = dvrr_stack + 445382;
 target_ptr = Libderiv->deriv2_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+492940, dvrr_stack+30640, dvrr_stack+59917);
 tmp = dvrr_stack + 492940;
 target_ptr = Libderiv->deriv2_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+493885, dvrr_stack+505981, dvrr_stack+71555);
 tmp = dvrr_stack + 493885;
 target_ptr = Libderiv->deriv2_classes[5][9][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+59917, dvrr_stack+81779, dvrr_stack+505540);
 tmp = dvrr_stack + 59917;
 target_ptr = Libderiv->deriv2_classes[6][5][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+485780, dvrr_stack+414359, dvrr_stack+2264);
 tmp = dvrr_stack + 485780;
 target_ptr = Libderiv->deriv2_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+414343, dvrr_stack+127110, dvrr_stack+4743);
 tmp = dvrr_stack + 414343;
 target_ptr = Libderiv->deriv2_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+219430, dvrr_stack+131534, dvrr_stack+5499);
 tmp = dvrr_stack + 219430;
 target_ptr = Libderiv->deriv2_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+131534, dvrr_stack+141842, dvrr_stack+0);
 tmp = dvrr_stack + 131534;
 target_ptr = Libderiv->deriv2_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+0, dvrr_stack+155252, dvrr_stack+2852);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv2_classes[7][5][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+424904, dvrr_stack+217414, dvrr_stack+435179);
 tmp = dvrr_stack + 424904;
 target_ptr = Libderiv->deriv2_classes[7][6][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+217129, dvrr_stack+156197, dvrr_stack+58909);
 tmp = dvrr_stack + 217129;
 target_ptr = Libderiv->deriv2_classes[7][7][0];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+4731, dvrr_stack+507521, dvrr_stack+30640);
 tmp = dvrr_stack + 4731;
 target_ptr = Libderiv->deriv2_classes[7][8][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+507521, dvrr_stack+238010, dvrr_stack+505981);
 tmp = dvrr_stack + 507521;
 target_ptr = Libderiv->deriv2_classes[7][9][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];


}

