/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (hf|hg) integrals */

void d12vrr_order_hfhg(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+6, dvrr_stack+3, dvrr_stack+0, NULL, NULL, Data->F+5);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+21, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+24, dvrr_stack+21, dvrr_stack+3, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+30, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+33, dvrr_stack+0, dvrr_stack+30, Data->F+5, Data->F+6, NULL);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+39, dvrr_stack+15, dvrr_stack+33, NULL, NULL, dvrr_stack+0);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+57, dvrr_stack+24, dvrr_stack+15, NULL, NULL, dvrr_stack+3);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+75, dvrr_stack+57, dvrr_stack+39, dvrr_stack+24, dvrr_stack+15, dvrr_stack+6);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+111, dvrr_stack+15, dvrr_stack+33, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+121, dvrr_stack+24, dvrr_stack+15, dvrr_stack+21, dvrr_stack+3, NULL);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+131, dvrr_stack+121, dvrr_stack+111, NULL, NULL, dvrr_stack+15);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+161, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+164, dvrr_stack+161, dvrr_stack+21, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+170, dvrr_stack+164, dvrr_stack+24, dvrr_stack+161, dvrr_stack+21, NULL);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+180, dvrr_stack+170, dvrr_stack+121, NULL, NULL, dvrr_stack+24);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+210, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+213, dvrr_stack+30, dvrr_stack+210, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+219, dvrr_stack+33, dvrr_stack+213, dvrr_stack+0, dvrr_stack+30, NULL);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+229, dvrr_stack+111, dvrr_stack+219, NULL, NULL, dvrr_stack+33);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+259, dvrr_stack+131, dvrr_stack+229, dvrr_stack+121, dvrr_stack+111, dvrr_stack+39);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+319, dvrr_stack+180, dvrr_stack+131, dvrr_stack+170, dvrr_stack+121, dvrr_stack+57);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+379, dvrr_stack+319, dvrr_stack+259, dvrr_stack+180, dvrr_stack+131, dvrr_stack+75);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+479, dvrr_stack+121, dvrr_stack+111, dvrr_stack+24, dvrr_stack+15, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+494, dvrr_stack+170, dvrr_stack+121, dvrr_stack+164, dvrr_stack+24, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+509, dvrr_stack+111, dvrr_stack+219, dvrr_stack+15, dvrr_stack+33, NULL);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+524, dvrr_stack+479, dvrr_stack+509, NULL, NULL, dvrr_stack+111);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+569, dvrr_stack+494, dvrr_stack+479, NULL, NULL, dvrr_stack+121);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+614, dvrr_stack+569, dvrr_stack+524, dvrr_stack+494, dvrr_stack+479, dvrr_stack+131);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+704, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+707, dvrr_stack+704, dvrr_stack+161, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+713, dvrr_stack+707, dvrr_stack+164, dvrr_stack+704, dvrr_stack+161, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+723, dvrr_stack+713, dvrr_stack+170, dvrr_stack+707, dvrr_stack+164, NULL);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+738, dvrr_stack+723, dvrr_stack+494, NULL, NULL, dvrr_stack+170);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+783, dvrr_stack+738, dvrr_stack+569, dvrr_stack+723, dvrr_stack+494, dvrr_stack+180);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+873, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+876, dvrr_stack+210, dvrr_stack+873, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+882, dvrr_stack+213, dvrr_stack+876, dvrr_stack+30, dvrr_stack+210, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+892, dvrr_stack+219, dvrr_stack+882, dvrr_stack+33, dvrr_stack+213, NULL);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+907, dvrr_stack+509, dvrr_stack+892, NULL, NULL, dvrr_stack+219);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+952, dvrr_stack+524, dvrr_stack+907, dvrr_stack+479, dvrr_stack+509, dvrr_stack+229);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+1042, dvrr_stack+614, dvrr_stack+952, dvrr_stack+569, dvrr_stack+524, dvrr_stack+259);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+1192, dvrr_stack+783, dvrr_stack+614, dvrr_stack+738, dvrr_stack+569, dvrr_stack+319);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+1342, dvrr_stack+1192, dvrr_stack+1042, dvrr_stack+783, dvrr_stack+614, dvrr_stack+379);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1567, dvrr_stack+479, dvrr_stack+509, dvrr_stack+121, dvrr_stack+111, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1588, dvrr_stack+494, dvrr_stack+479, dvrr_stack+170, dvrr_stack+121, NULL);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1609, dvrr_stack+1588, dvrr_stack+1567, NULL, NULL, dvrr_stack+479);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1672, dvrr_stack+723, dvrr_stack+494, dvrr_stack+713, dvrr_stack+170, NULL);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1693, dvrr_stack+1672, dvrr_stack+1588, NULL, NULL, dvrr_stack+494);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1756, dvrr_stack+509, dvrr_stack+892, dvrr_stack+111, dvrr_stack+219, NULL);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1777, dvrr_stack+1567, dvrr_stack+1756, NULL, NULL, dvrr_stack+509);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1840, dvrr_stack+1609, dvrr_stack+1777, dvrr_stack+1588, dvrr_stack+1567, dvrr_stack+524);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1966, dvrr_stack+1693, dvrr_stack+1609, dvrr_stack+1672, dvrr_stack+1588, dvrr_stack+569);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2092, dvrr_stack+1966, dvrr_stack+1840, dvrr_stack+1693, dvrr_stack+1609, dvrr_stack+614);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+569, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+572, dvrr_stack+569, dvrr_stack+704, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+121, dvrr_stack+572, dvrr_stack+707, dvrr_stack+569, dvrr_stack+704, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+578, dvrr_stack+121, dvrr_stack+713, dvrr_stack+572, dvrr_stack+707, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+593, dvrr_stack+578, dvrr_stack+723, dvrr_stack+121, dvrr_stack+713, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+2302, dvrr_stack+593, dvrr_stack+1672, NULL, NULL, dvrr_stack+723);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+2365, dvrr_stack+2302, dvrr_stack+1693, dvrr_stack+593, dvrr_stack+1672, dvrr_stack+738);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2491, dvrr_stack+2365, dvrr_stack+1966, dvrr_stack+2302, dvrr_stack+1693, dvrr_stack+783);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+704, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+2302, dvrr_stack+873, dvrr_stack+704, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2308, dvrr_stack+876, dvrr_stack+2302, dvrr_stack+210, dvrr_stack+873, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2318, dvrr_stack+882, dvrr_stack+2308, dvrr_stack+213, dvrr_stack+876, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2333, dvrr_stack+892, dvrr_stack+2318, dvrr_stack+219, dvrr_stack+882, NULL);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+2701, dvrr_stack+1756, dvrr_stack+2333, NULL, NULL, dvrr_stack+892);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+2764, dvrr_stack+1777, dvrr_stack+2701, dvrr_stack+1567, dvrr_stack+1756, dvrr_stack+907);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2890, dvrr_stack+1840, dvrr_stack+2764, dvrr_stack+1609, dvrr_stack+1777, dvrr_stack+952);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+3100, dvrr_stack+2092, dvrr_stack+2890, dvrr_stack+1966, dvrr_stack+1840, dvrr_stack+1042);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+3415, dvrr_stack+2491, dvrr_stack+2092, dvrr_stack+2365, dvrr_stack+1966, dvrr_stack+1192);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+3730, dvrr_stack+3415, dvrr_stack+3100, dvrr_stack+2491, dvrr_stack+2092, dvrr_stack+1342);
 tmp = dvrr_stack + 3730;
 target_ptr = Libderiv->dvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2354, dvrr_stack+1567, dvrr_stack+1756, dvrr_stack+479, dvrr_stack+509, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2382, dvrr_stack+1588, dvrr_stack+1567, dvrr_stack+494, dvrr_stack+479, NULL);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4171, dvrr_stack+2382, dvrr_stack+2354, NULL, NULL, dvrr_stack+1567);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2410, dvrr_stack+1672, dvrr_stack+1588, dvrr_stack+723, dvrr_stack+494, NULL);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4255, dvrr_stack+2410, dvrr_stack+2382, NULL, NULL, dvrr_stack+1588);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+479, dvrr_stack+1756, dvrr_stack+2333, dvrr_stack+509, dvrr_stack+892, NULL);

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4339, dvrr_stack+2354, dvrr_stack+479, NULL, NULL, dvrr_stack+1756);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+4423, dvrr_stack+4171, dvrr_stack+4339, dvrr_stack+2382, dvrr_stack+2354, dvrr_stack+1777);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+4591, dvrr_stack+4255, dvrr_stack+4171, dvrr_stack+2410, dvrr_stack+2382, dvrr_stack+1609);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+4759, dvrr_stack+4591, dvrr_stack+4423, dvrr_stack+4255, dvrr_stack+4171, dvrr_stack+1840);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1609, dvrr_stack+593, dvrr_stack+1672, dvrr_stack+578, dvrr_stack+723, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+5039, dvrr_stack+1609, dvrr_stack+2410, NULL, NULL, dvrr_stack+1672);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+5123, dvrr_stack+5039, dvrr_stack+4255, dvrr_stack+1609, dvrr_stack+2410, dvrr_stack+1693);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+5291, dvrr_stack+5123, dvrr_stack+4591, dvrr_stack+5039, dvrr_stack+4255, dvrr_stack+1966);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1966, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1969, dvrr_stack+704, dvrr_stack+1966, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1975, dvrr_stack+2302, dvrr_stack+1969, dvrr_stack+873, dvrr_stack+704, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1985, dvrr_stack+2308, dvrr_stack+1975, dvrr_stack+876, dvrr_stack+2302, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2000, dvrr_stack+2318, dvrr_stack+1985, dvrr_stack+882, dvrr_stack+2308, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2021, dvrr_stack+2333, dvrr_stack+2000, dvrr_stack+892, dvrr_stack+2318, NULL);

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+5039, dvrr_stack+479, dvrr_stack+2021, NULL, NULL, dvrr_stack+2333);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+5571, dvrr_stack+4339, dvrr_stack+5039, dvrr_stack+2354, dvrr_stack+479, dvrr_stack+2701);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+5739, dvrr_stack+4423, dvrr_stack+5571, dvrr_stack+4171, dvrr_stack+4339, dvrr_stack+2764);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+6019, dvrr_stack+4759, dvrr_stack+5739, dvrr_stack+4591, dvrr_stack+4423, dvrr_stack+2890);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+6439, dvrr_stack+5291, dvrr_stack+4759, dvrr_stack+5123, dvrr_stack+4591, dvrr_stack+2092);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+6859, dvrr_stack+6439, dvrr_stack+6019, dvrr_stack+5291, dvrr_stack+4759, dvrr_stack+3100);
 tmp = dvrr_stack + 6859;
 target_ptr = Libderiv->dvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+7447,dvrr_stack+6859,dvrr_stack+3730,21);


 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5123, dvrr_stack+2354, dvrr_stack+479, dvrr_stack+1567, dvrr_stack+1756, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5159, dvrr_stack+2382, dvrr_stack+2354, dvrr_stack+1588, dvrr_stack+1567, NULL);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8770, dvrr_stack+5159, dvrr_stack+5123, NULL, NULL, dvrr_stack+2354);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5195, dvrr_stack+2410, dvrr_stack+2382, dvrr_stack+1672, dvrr_stack+1588, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8878, dvrr_stack+5195, dvrr_stack+5159, NULL, NULL, dvrr_stack+2382);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1567, dvrr_stack+479, dvrr_stack+2021, dvrr_stack+1756, dvrr_stack+2333, NULL);

 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8986, dvrr_stack+5123, dvrr_stack+1567, NULL, NULL, dvrr_stack+479);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9094, dvrr_stack+8770, dvrr_stack+8986, dvrr_stack+5159, dvrr_stack+5123, dvrr_stack+4339);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9310, dvrr_stack+8878, dvrr_stack+8770, dvrr_stack+5195, dvrr_stack+5159, dvrr_stack+4171);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9526, dvrr_stack+9310, dvrr_stack+9094, dvrr_stack+8878, dvrr_stack+8770, dvrr_stack+4423);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4171, dvrr_stack+1609, dvrr_stack+2410, dvrr_stack+593, dvrr_stack+1672, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1637, dvrr_stack+4171, dvrr_stack+5195, NULL, NULL, dvrr_stack+2410);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9886, dvrr_stack+1637, dvrr_stack+8878, dvrr_stack+4171, dvrr_stack+5195, dvrr_stack+4255);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10102, dvrr_stack+9886, dvrr_stack+9310, dvrr_stack+1637, dvrr_stack+8878, dvrr_stack+4591);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+4591, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1603, dvrr_stack+1966, dvrr_stack+4591, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+4594, dvrr_stack+1969, dvrr_stack+1603, dvrr_stack+704, dvrr_stack+1966, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+4604, dvrr_stack+1975, dvrr_stack+4594, dvrr_stack+2302, dvrr_stack+1969, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+593, dvrr_stack+1985, dvrr_stack+4604, dvrr_stack+2308, dvrr_stack+1975, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+4619, dvrr_stack+2000, dvrr_stack+593, dvrr_stack+2318, dvrr_stack+1985, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4647, dvrr_stack+2021, dvrr_stack+4619, dvrr_stack+2333, dvrr_stack+2000, NULL);

 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1637, dvrr_stack+1567, dvrr_stack+4647, NULL, NULL, dvrr_stack+2021);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10462, dvrr_stack+8986, dvrr_stack+1637, dvrr_stack+5123, dvrr_stack+1567, dvrr_stack+5039);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10678, dvrr_stack+9094, dvrr_stack+10462, dvrr_stack+8770, dvrr_stack+8986, dvrr_stack+5571);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11038, dvrr_stack+9526, dvrr_stack+10678, dvrr_stack+9310, dvrr_stack+9094, dvrr_stack+5739);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11578, dvrr_stack+10102, dvrr_stack+9526, dvrr_stack+9886, dvrr_stack+9310, dvrr_stack+4759);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+12118, dvrr_stack+11578, dvrr_stack+11038, dvrr_stack+10102, dvrr_stack+9526, dvrr_stack+6019);
 tmp = dvrr_stack + 12118;
 target_ptr = Libderiv->dvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+12874,dvrr_stack+12118,dvrr_stack+6859,21);


 /* compute (5 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+14638,dvrr_stack+12874,dvrr_stack+7447,21);


 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,441,dvrr_stack+17284, dvrr_stack+14638, dvrr_stack+3730);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9886, dvrr_stack+5123, dvrr_stack+1567, dvrr_stack+2354, dvrr_stack+479, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9931, dvrr_stack+5159, dvrr_stack+5123, dvrr_stack+2382, dvrr_stack+2354, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+9931, dvrr_stack+9886, NULL, NULL, dvrr_stack+5123);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9976, dvrr_stack+5195, dvrr_stack+5159, dvrr_stack+2410, dvrr_stack+2382, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18742, dvrr_stack+9976, dvrr_stack+9931, NULL, NULL, dvrr_stack+5159);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2354, dvrr_stack+1567, dvrr_stack+4647, dvrr_stack+479, dvrr_stack+2021, NULL);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18877, dvrr_stack+9886, dvrr_stack+2354, NULL, NULL, dvrr_stack+1567);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19012, dvrr_stack+18607, dvrr_stack+18877, dvrr_stack+9931, dvrr_stack+9886, dvrr_stack+8986);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19282, dvrr_stack+18742, dvrr_stack+18607, dvrr_stack+9976, dvrr_stack+9931, dvrr_stack+8770);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19552, dvrr_stack+19282, dvrr_stack+19012, dvrr_stack+18742, dvrr_stack+18607, dvrr_stack+9094);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8770, dvrr_stack+4171, dvrr_stack+5195, dvrr_stack+1609, dvrr_stack+2410, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20002, dvrr_stack+8770, dvrr_stack+9976, NULL, NULL, dvrr_stack+5195);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20137, dvrr_stack+20002, dvrr_stack+18742, dvrr_stack+8770, dvrr_stack+9976, dvrr_stack+8878);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20407, dvrr_stack+20137, dvrr_stack+19282, dvrr_stack+20002, dvrr_stack+18742, dvrr_stack+9310);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+9310, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+9313, dvrr_stack+4591, dvrr_stack+9310, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+9319, dvrr_stack+1603, dvrr_stack+9313, dvrr_stack+1966, dvrr_stack+4591, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+9329, dvrr_stack+4594, dvrr_stack+9319, dvrr_stack+1969, dvrr_stack+1603, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+9344, dvrr_stack+4604, dvrr_stack+9329, dvrr_stack+1975, dvrr_stack+4594, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1609, dvrr_stack+593, dvrr_stack+9344, dvrr_stack+1985, dvrr_stack+4604, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9365, dvrr_stack+4619, dvrr_stack+1609, dvrr_stack+2000, dvrr_stack+593, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9401, dvrr_stack+4647, dvrr_stack+9365, dvrr_stack+2021, dvrr_stack+4619, NULL);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20002, dvrr_stack+2354, dvrr_stack+9401, NULL, NULL, dvrr_stack+4647);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20857, dvrr_stack+18877, dvrr_stack+20002, dvrr_stack+9886, dvrr_stack+2354, dvrr_stack+1637);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+21127, dvrr_stack+19012, dvrr_stack+20857, dvrr_stack+18607, dvrr_stack+18877, dvrr_stack+10462);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+21577, dvrr_stack+19552, dvrr_stack+21127, dvrr_stack+19282, dvrr_stack+19012, dvrr_stack+10678);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+22252, dvrr_stack+20407, dvrr_stack+19552, dvrr_stack+20137, dvrr_stack+19282, dvrr_stack+9526);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+22927, dvrr_stack+22252, dvrr_stack+21577, dvrr_stack+20407, dvrr_stack+19552, dvrr_stack+11038);
 tmp = dvrr_stack + 22927;
 target_ptr = Libderiv->dvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+23872,dvrr_stack+22927,dvrr_stack+12118,21);


 /* compute (5 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+26140,dvrr_stack+23872,dvrr_stack+12874,21);


 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,588,dvrr_stack+29668, dvrr_stack+26140, dvrr_stack+6859);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20137, dvrr_stack+9886, dvrr_stack+2354, dvrr_stack+5123, dvrr_stack+1567, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20192, dvrr_stack+9931, dvrr_stack+9886, dvrr_stack+5159, dvrr_stack+5123, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+8815, dvrr_stack+20192, dvrr_stack+20137, NULL, NULL, dvrr_stack+9886);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20247, dvrr_stack+9976, dvrr_stack+9931, dvrr_stack+5195, dvrr_stack+5159, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31432, dvrr_stack+20247, dvrr_stack+20192, NULL, NULL, dvrr_stack+9931);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+5123, dvrr_stack+2354, dvrr_stack+9401, dvrr_stack+1567, dvrr_stack+4647, NULL);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31597, dvrr_stack+20137, dvrr_stack+5123, NULL, NULL, dvrr_stack+2354);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31762, dvrr_stack+8815, dvrr_stack+31597, dvrr_stack+20192, dvrr_stack+20137, dvrr_stack+18877);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32092, dvrr_stack+31432, dvrr_stack+8815, dvrr_stack+20247, dvrr_stack+20192, dvrr_stack+18607);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32422, dvrr_stack+32092, dvrr_stack+31762, dvrr_stack+31432, dvrr_stack+8815, dvrr_stack+19012);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+8770, dvrr_stack+9976, dvrr_stack+4171, dvrr_stack+5195, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4171, dvrr_stack+18607, dvrr_stack+20247, NULL, NULL, dvrr_stack+9976);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32972, dvrr_stack+4171, dvrr_stack+31432, dvrr_stack+18607, dvrr_stack+20247, dvrr_stack+18742);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+33302, dvrr_stack+32972, dvrr_stack+32092, dvrr_stack+4171, dvrr_stack+31432, dvrr_stack+19282);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+19282, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+8980, dvrr_stack+9310, dvrr_stack+19282, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+19285, dvrr_stack+9313, dvrr_stack+8980, dvrr_stack+4591, dvrr_stack+9310, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+19295, dvrr_stack+9319, dvrr_stack+19285, dvrr_stack+1603, dvrr_stack+9313, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+19310, dvrr_stack+9329, dvrr_stack+19295, dvrr_stack+4594, dvrr_stack+9319, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+19331, dvrr_stack+9344, dvrr_stack+19310, dvrr_stack+4604, dvrr_stack+9329, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+19359, dvrr_stack+1609, dvrr_stack+19331, dvrr_stack+593, dvrr_stack+9344, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19395, dvrr_stack+9365, dvrr_stack+19359, dvrr_stack+4619, dvrr_stack+1609, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19440, dvrr_stack+9401, dvrr_stack+19395, dvrr_stack+4647, dvrr_stack+9365, NULL);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4171, dvrr_stack+5123, dvrr_stack+19440, NULL, NULL, dvrr_stack+9401);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+33852, dvrr_stack+31597, dvrr_stack+4171, dvrr_stack+20137, dvrr_stack+5123, dvrr_stack+20002);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+34182, dvrr_stack+31762, dvrr_stack+33852, dvrr_stack+8815, dvrr_stack+31597, dvrr_stack+20857);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+34732, dvrr_stack+32422, dvrr_stack+34182, dvrr_stack+32092, dvrr_stack+31762, dvrr_stack+21127);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+35557, dvrr_stack+33302, dvrr_stack+32422, dvrr_stack+32972, dvrr_stack+32092, dvrr_stack+19552);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+36382, dvrr_stack+35557, dvrr_stack+34732, dvrr_stack+33302, dvrr_stack+32422, dvrr_stack+21577);
 tmp = dvrr_stack + 36382;
 target_ptr = Libderiv->dvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+37537,dvrr_stack+36382,dvrr_stack+22927,21);


 /* compute (5 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+40372,dvrr_stack+37537,dvrr_stack+23872,21);


 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,756,dvrr_stack+44908, dvrr_stack+40372, dvrr_stack+12118);

 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32972, dvrr_stack+20137, dvrr_stack+5123, dvrr_stack+9886, dvrr_stack+2354, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33038, dvrr_stack+20192, dvrr_stack+20137, dvrr_stack+9931, dvrr_stack+9886, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33104, dvrr_stack+33038, dvrr_stack+32972, NULL, NULL, dvrr_stack+20137);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18662, dvrr_stack+20247, dvrr_stack+20192, dvrr_stack+9976, dvrr_stack+9931, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47176, dvrr_stack+18662, dvrr_stack+33038, NULL, NULL, dvrr_stack+20192);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+9886, dvrr_stack+5123, dvrr_stack+19440, dvrr_stack+2354, dvrr_stack+9401, NULL);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47374, dvrr_stack+32972, dvrr_stack+9886, NULL, NULL, dvrr_stack+5123);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47572, dvrr_stack+33104, dvrr_stack+47374, dvrr_stack+33038, dvrr_stack+32972, dvrr_stack+31597);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47968, dvrr_stack+47176, dvrr_stack+33104, dvrr_stack+18662, dvrr_stack+33038, dvrr_stack+8815);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+48364, dvrr_stack+47968, dvrr_stack+47572, dvrr_stack+47176, dvrr_stack+33104, dvrr_stack+31762);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+8815, dvrr_stack+18607, dvrr_stack+20247, dvrr_stack+8770, dvrr_stack+9976, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49024, dvrr_stack+8815, dvrr_stack+18662, NULL, NULL, dvrr_stack+20247);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49222, dvrr_stack+49024, dvrr_stack+47176, dvrr_stack+8815, dvrr_stack+18662, dvrr_stack+31432);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49618, dvrr_stack+49222, dvrr_stack+47968, dvrr_stack+49024, dvrr_stack+47176, dvrr_stack+32092);

 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+4591, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+32092, dvrr_stack+19282, dvrr_stack+4591, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+32098, dvrr_stack+8980, dvrr_stack+32092, dvrr_stack+9310, dvrr_stack+19282, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+32108, dvrr_stack+19285, dvrr_stack+32098, dvrr_stack+9313, dvrr_stack+8980, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+32123, dvrr_stack+19295, dvrr_stack+32108, dvrr_stack+9319, dvrr_stack+19285, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+32144, dvrr_stack+19310, dvrr_stack+32123, dvrr_stack+9329, dvrr_stack+19295, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+32172, dvrr_stack+19331, dvrr_stack+32144, dvrr_stack+9344, dvrr_stack+19310, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8770, dvrr_stack+19359, dvrr_stack+32172, dvrr_stack+1609, dvrr_stack+19331, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32208, dvrr_stack+19395, dvrr_stack+8770, dvrr_stack+9365, dvrr_stack+19359, NULL);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32263, dvrr_stack+19440, dvrr_stack+32208, dvrr_stack+9401, dvrr_stack+19395, NULL);

 /* compute (1 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49024, dvrr_stack+9886, dvrr_stack+32263, NULL, NULL, dvrr_stack+19440);

 /* compute (2 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+50278, dvrr_stack+47374, dvrr_stack+49024, dvrr_stack+32972, dvrr_stack+9886, dvrr_stack+4171);

 /* compute (3 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+50674, dvrr_stack+47572, dvrr_stack+50278, dvrr_stack+33104, dvrr_stack+47374, dvrr_stack+33852);

 /* compute (4 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+51334, dvrr_stack+48364, dvrr_stack+50674, dvrr_stack+47968, dvrr_stack+47572, dvrr_stack+34182);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+52324, dvrr_stack+49618, dvrr_stack+48364, dvrr_stack+49222, dvrr_stack+47968, dvrr_stack+32422);

 /* compute (5 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+53314, dvrr_stack+52324, dvrr_stack+51334, dvrr_stack+49618, dvrr_stack+48364, dvrr_stack+34732);

 /* compute (5 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+54700,dvrr_stack+53314,dvrr_stack+36382,21);


 /* compute (5 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+58165,dvrr_stack+54700,dvrr_stack+37537,21);


 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,945,dvrr_stack+63835, dvrr_stack+58165, dvrr_stack+22927);

 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49222, dvrr_stack+32972, dvrr_stack+9886, dvrr_stack+20137, dvrr_stack+5123, NULL);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49300, dvrr_stack+33038, dvrr_stack+32972, dvrr_stack+20192, dvrr_stack+20137, NULL);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49378, dvrr_stack+49300, dvrr_stack+49222, NULL, NULL, dvrr_stack+32972);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49612, dvrr_stack+18662, dvrr_stack+33038, dvrr_stack+20247, dvrr_stack+20192, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49690, dvrr_stack+49612, dvrr_stack+49300, NULL, NULL, dvrr_stack+33038);

 /* compute (0 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32972, dvrr_stack+9886, dvrr_stack+32263, dvrr_stack+5123, dvrr_stack+19440, NULL);

 /* compute (1 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49924, dvrr_stack+49222, dvrr_stack+32972, NULL, NULL, dvrr_stack+9886);

 /* compute (2 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+66670, dvrr_stack+49378, dvrr_stack+49924, dvrr_stack+49300, dvrr_stack+49222, dvrr_stack+47374);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+67138, dvrr_stack+49690, dvrr_stack+49378, dvrr_stack+49612, dvrr_stack+49300, dvrr_stack+33104);

 /* compute (3 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+67606, dvrr_stack+67138, dvrr_stack+66670, dvrr_stack+49690, dvrr_stack+49378, dvrr_stack+47572);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49300, dvrr_stack+8815, dvrr_stack+18662, dvrr_stack+18607, dvrr_stack+20247, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+33050, dvrr_stack+49300, dvrr_stack+49612, NULL, NULL, dvrr_stack+18662);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+68386, dvrr_stack+33050, dvrr_stack+49690, dvrr_stack+49300, dvrr_stack+49612, dvrr_stack+47176);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+68854, dvrr_stack+68386, dvrr_stack+67138, dvrr_stack+33050, dvrr_stack+49690, dvrr_stack+47968);

 /* compute (0 0 | 1 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+4336, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+47968, dvrr_stack+4591, dvrr_stack+4336, Data->F+14, Data->F+15, NULL);

 /* compute (0 0 | 3 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+47974, dvrr_stack+32092, dvrr_stack+47968, dvrr_stack+19282, dvrr_stack+4591, NULL);

 /* compute (0 0 | 4 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+47984, dvrr_stack+32098, dvrr_stack+47974, dvrr_stack+8980, dvrr_stack+32092, NULL);

 /* compute (0 0 | 5 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+47999, dvrr_stack+32108, dvrr_stack+47984, dvrr_stack+19285, dvrr_stack+32098, NULL);

 /* compute (0 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+48020, dvrr_stack+32123, dvrr_stack+47999, dvrr_stack+19295, dvrr_stack+32108, NULL);

 /* compute (0 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+48048, dvrr_stack+32144, dvrr_stack+48020, dvrr_stack+19310, dvrr_stack+32123, NULL);

 /* compute (0 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+48084, dvrr_stack+32172, dvrr_stack+48048, dvrr_stack+19331, dvrr_stack+32144, NULL);

 /* compute (0 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+48129, dvrr_stack+8770, dvrr_stack+48084, dvrr_stack+19359, dvrr_stack+32172, NULL);

 /* compute (0 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+48184, dvrr_stack+32208, dvrr_stack+48129, dvrr_stack+19395, dvrr_stack+8770, NULL);

 /* compute (0 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49300, dvrr_stack+32263, dvrr_stack+48184, dvrr_stack+19440, dvrr_stack+32208, NULL);

 /* compute (1 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+33050, dvrr_stack+32972, dvrr_stack+49300, NULL, NULL, dvrr_stack+32263);

 /* compute (2 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+69634, dvrr_stack+49924, dvrr_stack+33050, dvrr_stack+49222, dvrr_stack+32972, dvrr_stack+49024);

 /* compute (3 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+70102, dvrr_stack+66670, dvrr_stack+69634, dvrr_stack+49378, dvrr_stack+49924, dvrr_stack+50278);

 /* compute (4 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+70882, dvrr_stack+67606, dvrr_stack+70102, dvrr_stack+67138, dvrr_stack+66670, dvrr_stack+50674);

 /* compute (4 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+72052, dvrr_stack+68854, dvrr_stack+67606, dvrr_stack+68386, dvrr_stack+67138, dvrr_stack+48364);

 /* compute (5 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+73222, dvrr_stack+72052, dvrr_stack+70882, dvrr_stack+68854, dvrr_stack+67606, dvrr_stack+51334);

 /* compute (5 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+74860,dvrr_stack+73222,dvrr_stack+53314,21);


 /* compute (5 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+79018,dvrr_stack+74860,dvrr_stack+54700,21);


 /* compute (5 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1155,dvrr_stack+85948, dvrr_stack+79018, dvrr_stack+36382);

 /* compute (1 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+67138, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+9310, dvrr_stack+0, dvrr_stack+30, NULL, NULL, Data->F+6);

 /* compute (2 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+33284, dvrr_stack+6, dvrr_stack+9310, dvrr_stack+3, dvrr_stack+0, dvrr_stack+67138);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+67141, dvrr_stack+33, dvrr_stack+213, NULL, NULL, dvrr_stack+30);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+67159, dvrr_stack+39, dvrr_stack+67141, dvrr_stack+15, dvrr_stack+33, dvrr_stack+9310);

 /* compute (3 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+67195, dvrr_stack+75, dvrr_stack+67159, dvrr_stack+57, dvrr_stack+39, dvrr_stack+33284);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+67255, dvrr_stack+219, dvrr_stack+882, NULL, NULL, dvrr_stack+213);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+67285, dvrr_stack+229, dvrr_stack+67255, dvrr_stack+111, dvrr_stack+219, dvrr_stack+67141);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+67345, dvrr_stack+259, dvrr_stack+67285, dvrr_stack+131, dvrr_stack+229, dvrr_stack+67159);

 /* compute (4 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+9952, dvrr_stack+379, dvrr_stack+67345, dvrr_stack+319, dvrr_stack+259, dvrr_stack+67195);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+67445, dvrr_stack+892, dvrr_stack+2318, NULL, NULL, dvrr_stack+882);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+67490, dvrr_stack+907, dvrr_stack+67445, dvrr_stack+509, dvrr_stack+892, dvrr_stack+67255);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+68386, dvrr_stack+952, dvrr_stack+67490, dvrr_stack+524, dvrr_stack+907, dvrr_stack+67285);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+68536, dvrr_stack+1042, dvrr_stack+68386, dvrr_stack+614, dvrr_stack+952, dvrr_stack+67345);

 /* compute (5 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+68761, dvrr_stack+1342, dvrr_stack+68536, dvrr_stack+1192, dvrr_stack+1042, dvrr_stack+9952);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+614, dvrr_stack+2333, dvrr_stack+2000, NULL, NULL, dvrr_stack+2318);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+69076, dvrr_stack+2701, dvrr_stack+614, dvrr_stack+1756, dvrr_stack+2333, dvrr_stack+67445);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+69202, dvrr_stack+2764, dvrr_stack+69076, dvrr_stack+1777, dvrr_stack+2701, dvrr_stack+67490);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+49378, dvrr_stack+2890, dvrr_stack+69202, dvrr_stack+1840, dvrr_stack+2764, dvrr_stack+68386);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+89413, dvrr_stack+3100, dvrr_stack+49378, dvrr_stack+2092, dvrr_stack+2890, dvrr_stack+68536);

 /* compute (6 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+89854, dvrr_stack+3730, dvrr_stack+89413, dvrr_stack+3415, dvrr_stack+3100, dvrr_stack+68761);
 tmp = dvrr_stack + 89854;
 target_ptr = Libderiv->dvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+69412, dvrr_stack+2021, dvrr_stack+4619, NULL, NULL, dvrr_stack+2000);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+49693, dvrr_stack+5039, dvrr_stack+69412, dvrr_stack+479, dvrr_stack+2021, dvrr_stack+614);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+90442, dvrr_stack+5571, dvrr_stack+49693, dvrr_stack+4339, dvrr_stack+5039, dvrr_stack+69076);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+90722, dvrr_stack+5739, dvrr_stack+90442, dvrr_stack+4423, dvrr_stack+5571, dvrr_stack+69202);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+91142, dvrr_stack+6019, dvrr_stack+90722, dvrr_stack+4759, dvrr_stack+5739, dvrr_stack+49378);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+91730, dvrr_stack+6859, dvrr_stack+91142, dvrr_stack+6439, dvrr_stack+6019, dvrr_stack+89413);
 tmp = dvrr_stack + 91730;
 target_ptr = Libderiv->dvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+92514,dvrr_stack+91730,dvrr_stack+89854,28);


 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4339, dvrr_stack+4647, dvrr_stack+9365, NULL, NULL, dvrr_stack+4619);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+1637, dvrr_stack+4339, dvrr_stack+1567, dvrr_stack+4647, dvrr_stack+69412);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+94278, dvrr_stack+10462, dvrr_stack+18607, dvrr_stack+8986, dvrr_stack+1637, dvrr_stack+49693);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+94638, dvrr_stack+10678, dvrr_stack+94278, dvrr_stack+9094, dvrr_stack+10462, dvrr_stack+90442);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+95178, dvrr_stack+11038, dvrr_stack+94638, dvrr_stack+9526, dvrr_stack+10678, dvrr_stack+90722);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+95934, dvrr_stack+12118, dvrr_stack+95178, dvrr_stack+11578, dvrr_stack+11038, dvrr_stack+91142);
 tmp = dvrr_stack + 95934;
 target_ptr = Libderiv->dvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+96942,dvrr_stack+95934,dvrr_stack+91730,28);


 /* compute (6 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+99294,dvrr_stack+96942,dvrr_stack+92514,28);


 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,588,dvrr_stack+102822, dvrr_stack+99294, dvrr_stack+89854);

 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4447, dvrr_stack+9401, dvrr_stack+19395, NULL, NULL, dvrr_stack+9365);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20137, dvrr_stack+20002, dvrr_stack+4447, dvrr_stack+2354, dvrr_stack+9401, dvrr_stack+4339);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8815, dvrr_stack+20857, dvrr_stack+20137, dvrr_stack+18877, dvrr_stack+20002, dvrr_stack+18607);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+104586, dvrr_stack+21127, dvrr_stack+8815, dvrr_stack+19012, dvrr_stack+20857, dvrr_stack+94278);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+105261, dvrr_stack+21577, dvrr_stack+104586, dvrr_stack+19552, dvrr_stack+21127, dvrr_stack+94638);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+106206, dvrr_stack+22927, dvrr_stack+105261, dvrr_stack+22252, dvrr_stack+21577, dvrr_stack+95178);
 tmp = dvrr_stack + 106206;
 target_ptr = Libderiv->dvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+107466,dvrr_stack+106206,dvrr_stack+95934,28);


 /* compute (6 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+110490,dvrr_stack+107466,dvrr_stack+96942,28);


 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,784,dvrr_stack+115194, dvrr_stack+110490, dvrr_stack+91730);

 /* compute (1 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31432, dvrr_stack+19440, dvrr_stack+32208, NULL, NULL, dvrr_stack+19395);

 /* compute (2 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18823, dvrr_stack+4171, dvrr_stack+31432, dvrr_stack+5123, dvrr_stack+19440, dvrr_stack+4447);

 /* compute (3 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+117546, dvrr_stack+33852, dvrr_stack+18823, dvrr_stack+31597, dvrr_stack+4171, dvrr_stack+20137);

 /* compute (4 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+118096, dvrr_stack+34182, dvrr_stack+117546, dvrr_stack+31762, dvrr_stack+33852, dvrr_stack+8815);

 /* compute (5 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+118921, dvrr_stack+34732, dvrr_stack+118096, dvrr_stack+32422, dvrr_stack+34182, dvrr_stack+104586);

 /* compute (6 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+120076, dvrr_stack+36382, dvrr_stack+118921, dvrr_stack+35557, dvrr_stack+34732, dvrr_stack+105261);
 tmp = dvrr_stack + 120076;
 target_ptr = Libderiv->dvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+121616,dvrr_stack+120076,dvrr_stack+106206,28);


 /* compute (6 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+125396,dvrr_stack+121616,dvrr_stack+107466,28);


 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1008,dvrr_stack+131444, dvrr_stack+125396, dvrr_stack+95934);

 /* compute (1 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47176, dvrr_stack+32263, dvrr_stack+48184, NULL, NULL, dvrr_stack+32208);

 /* compute (2 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31597, dvrr_stack+49024, dvrr_stack+47176, dvrr_stack+9886, dvrr_stack+32263, dvrr_stack+31432);

 /* compute (3 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+134468, dvrr_stack+50278, dvrr_stack+31597, dvrr_stack+47374, dvrr_stack+49024, dvrr_stack+18823);

 /* compute (4 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+135128, dvrr_stack+50674, dvrr_stack+134468, dvrr_stack+47572, dvrr_stack+50278, dvrr_stack+117546);

 /* compute (5 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+136118, dvrr_stack+51334, dvrr_stack+135128, dvrr_stack+48364, dvrr_stack+50674, dvrr_stack+118096);

 /* compute (6 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+137504, dvrr_stack+53314, dvrr_stack+136118, dvrr_stack+52324, dvrr_stack+51334, dvrr_stack+118921);

 /* compute (6 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+139352,dvrr_stack+137504,dvrr_stack+120076,28);


 /* compute (6 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+143972,dvrr_stack+139352,dvrr_stack+121616,28);


 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1260,dvrr_stack+151532, dvrr_stack+143972, dvrr_stack+106206);

 /* compute (0 0 | 1 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+47374, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+4336, dvrr_stack+47374, Data->F+15, Data->F+16, NULL);

 /* compute (0 0 | 3 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+111, dvrr_stack+47968, dvrr_stack+15, dvrr_stack+4591, dvrr_stack+4336, NULL);

 /* compute (0 0 | 4 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+47377, dvrr_stack+47974, dvrr_stack+111, dvrr_stack+32092, dvrr_stack+47968, NULL);

 /* compute (0 0 | 5 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+47392, dvrr_stack+47984, dvrr_stack+47377, dvrr_stack+32098, dvrr_stack+47974, NULL);

 /* compute (0 0 | 6 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+47413, dvrr_stack+47999, dvrr_stack+47392, dvrr_stack+32108, dvrr_stack+47984, NULL);

 /* compute (0 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1567, dvrr_stack+48020, dvrr_stack+47413, dvrr_stack+32123, dvrr_stack+47999, NULL);

 /* compute (0 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9265, dvrr_stack+48048, dvrr_stack+1567, dvrr_stack+32144, dvrr_stack+48020, NULL);

 /* compute (0 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+47441, dvrr_stack+48084, dvrr_stack+9265, dvrr_stack+32172, dvrr_stack+48048, NULL);

 /* compute (0 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47496, dvrr_stack+48129, dvrr_stack+47441, dvrr_stack+8770, dvrr_stack+48084, NULL);

 /* compute (0 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+49222, dvrr_stack+48184, dvrr_stack+47496, dvrr_stack+32208, dvrr_stack+48129, NULL);

 /* compute (1 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+47562, dvrr_stack+49300, dvrr_stack+49222, NULL, NULL, dvrr_stack+48184);

 /* compute (2 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+48250, dvrr_stack+33050, dvrr_stack+47562, dvrr_stack+32972, dvrr_stack+49300, dvrr_stack+47176);

 /* compute (3 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+155312, dvrr_stack+69634, dvrr_stack+48250, dvrr_stack+49924, dvrr_stack+33050, dvrr_stack+31597);

 /* compute (4 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+156092, dvrr_stack+70102, dvrr_stack+155312, dvrr_stack+66670, dvrr_stack+69634, dvrr_stack+134468);

 /* compute (5 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+157262, dvrr_stack+70882, dvrr_stack+156092, dvrr_stack+67606, dvrr_stack+70102, dvrr_stack+135128);

 /* compute (6 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+158900, dvrr_stack+73222, dvrr_stack+157262, dvrr_stack+72052, dvrr_stack+70882, dvrr_stack+136118);

 /* compute (6 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+161084,dvrr_stack+158900,dvrr_stack+137504,28);


 /* compute (6 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+166628,dvrr_stack+161084,dvrr_stack+139352,28);


 /* compute (6 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1540,dvrr_stack+175868, dvrr_stack+166628, dvrr_stack+120076);

 /* compute (1 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+72052, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+72055, dvrr_stack+67138, dvrr_stack+72052, Data->F+5, Data->F+6, NULL);

 /* compute (1 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+72061, dvrr_stack+30, dvrr_stack+210, NULL, NULL, Data->F+7);

 /* compute (2 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+72070, dvrr_stack+9310, dvrr_stack+72061, dvrr_stack+0, dvrr_stack+30, dvrr_stack+72052);

 /* compute (3 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+131, dvrr_stack+33284, dvrr_stack+72070, dvrr_stack+6, dvrr_stack+9310, dvrr_stack+72055);

 /* compute (1 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+72088, dvrr_stack+213, dvrr_stack+876, NULL, NULL, dvrr_stack+210);

 /* compute (2 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+72106, dvrr_stack+67141, dvrr_stack+72088, dvrr_stack+33, dvrr_stack+213, dvrr_stack+72061);

 /* compute (3 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+72142, dvrr_stack+67159, dvrr_stack+72106, dvrr_stack+39, dvrr_stack+67141, dvrr_stack+72070);

 /* compute (4 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+72202, dvrr_stack+67195, dvrr_stack+72142, dvrr_stack+75, dvrr_stack+67159, dvrr_stack+131);

 /* compute (1 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+72292, dvrr_stack+882, dvrr_stack+2308, NULL, NULL, dvrr_stack+876);

 /* compute (2 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+72322, dvrr_stack+67255, dvrr_stack+72292, dvrr_stack+219, dvrr_stack+882, dvrr_stack+72088);

 /* compute (3 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+72382, dvrr_stack+67285, dvrr_stack+72322, dvrr_stack+229, dvrr_stack+67255, dvrr_stack+72106);

 /* compute (4 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+72482, dvrr_stack+67345, dvrr_stack+72382, dvrr_stack+259, dvrr_stack+67285, dvrr_stack+72142);

 /* compute (5 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+72632, dvrr_stack+9952, dvrr_stack+72482, dvrr_stack+379, dvrr_stack+67345, dvrr_stack+72202);

 /* compute (1 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+219, dvrr_stack+2318, dvrr_stack+1985, NULL, NULL, dvrr_stack+2308);

 /* compute (2 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+72842, dvrr_stack+67445, dvrr_stack+219, dvrr_stack+892, dvrr_stack+2318, dvrr_stack+72292);

 /* compute (3 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+72932, dvrr_stack+67490, dvrr_stack+72842, dvrr_stack+907, dvrr_stack+67445, dvrr_stack+72322);

 /* compute (4 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+66670, dvrr_stack+68386, dvrr_stack+72932, dvrr_stack+952, dvrr_stack+67490, dvrr_stack+72382);

 /* compute (5 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+67580, dvrr_stack+68536, dvrr_stack+66670, dvrr_stack+1042, dvrr_stack+68386, dvrr_stack+72482);

 /* compute (6 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+67895, dvrr_stack+68761, dvrr_stack+67580, dvrr_stack+1342, dvrr_stack+68536, dvrr_stack+72632);

 /* compute (1 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+892, dvrr_stack+2000, dvrr_stack+593, NULL, NULL, dvrr_stack+1985);

 /* compute (2 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+955, dvrr_stack+614, dvrr_stack+892, dvrr_stack+2333, dvrr_stack+2000, dvrr_stack+219);

 /* compute (3 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+66895, dvrr_stack+69076, dvrr_stack+955, dvrr_stack+2701, dvrr_stack+614, dvrr_stack+72842);

 /* compute (4 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+49861, dvrr_stack+69202, dvrr_stack+66895, dvrr_stack+2764, dvrr_stack+69076, dvrr_stack+72932);

 /* compute (5 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+32329, dvrr_stack+49378, dvrr_stack+49861, dvrr_stack+2890, dvrr_stack+69202, dvrr_stack+66670);

 /* compute (6 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+180488, dvrr_stack+89413, dvrr_stack+32329, dvrr_stack+3100, dvrr_stack+49378, dvrr_stack+67580);

 /* compute (7 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+181076, dvrr_stack+89854, dvrr_stack+180488, dvrr_stack+3730, dvrr_stack+89413, dvrr_stack+67895);
 tmp = dvrr_stack + 181076;
 target_ptr = Libderiv->dvrr_classes[7][5];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2701, dvrr_stack+4619, dvrr_stack+1609, NULL, NULL, dvrr_stack+593);

 /* compute (2 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+5123, dvrr_stack+69412, dvrr_stack+2701, dvrr_stack+2021, dvrr_stack+4619, dvrr_stack+892);

 /* compute (3 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+32770, dvrr_stack+49693, dvrr_stack+5123, dvrr_stack+5039, dvrr_stack+69412, dvrr_stack+955);

 /* compute (4 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+2785, dvrr_stack+90442, dvrr_stack+32770, dvrr_stack+5571, dvrr_stack+49693, dvrr_stack+66895);

 /* compute (5 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+181832, dvrr_stack+90722, dvrr_stack+2785, dvrr_stack+5739, dvrr_stack+90442, dvrr_stack+49861);

 /* compute (6 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+182420, dvrr_stack+91142, dvrr_stack+181832, dvrr_stack+6019, dvrr_stack+90722, dvrr_stack+32329);

 /* compute (7 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+183204, dvrr_stack+91730, dvrr_stack+182420, dvrr_stack+6859, dvrr_stack+91142, dvrr_stack+180488);
 tmp = dvrr_stack + 183204;
 target_ptr = Libderiv->dvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+184212,dvrr_stack+183204,dvrr_stack+181076,36);


 /* compute (1 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5571, dvrr_stack+9365, dvrr_stack+19359, NULL, NULL, dvrr_stack+1609);

 /* compute (2 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5679, dvrr_stack+4339, dvrr_stack+5571, dvrr_stack+4647, dvrr_stack+9365, dvrr_stack+2701);

 /* compute (3 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4647, dvrr_stack+18607, dvrr_stack+5679, dvrr_stack+1637, dvrr_stack+4339, dvrr_stack+5123);

 /* compute (4 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5895, dvrr_stack+94278, dvrr_stack+4647, dvrr_stack+10462, dvrr_stack+18607, dvrr_stack+32770);

 /* compute (5 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+186480, dvrr_stack+94638, dvrr_stack+5895, dvrr_stack+10678, dvrr_stack+94278, dvrr_stack+2785);

 /* compute (6 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+187236, dvrr_stack+95178, dvrr_stack+186480, dvrr_stack+11038, dvrr_stack+94638, dvrr_stack+181832);

 /* compute (7 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+188244, dvrr_stack+95934, dvrr_stack+187236, dvrr_stack+12118, dvrr_stack+95178, dvrr_stack+182420);
 tmp = dvrr_stack + 188244;
 target_ptr = Libderiv->dvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+189540,dvrr_stack+188244,dvrr_stack+183204,36);


 /* compute (7 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+192564,dvrr_stack+189540,dvrr_stack+184212,36);


 /* compute (7 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,756,dvrr_stack+197100, dvrr_stack+192564, dvrr_stack+181076);

 /* compute (1 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10462, dvrr_stack+19395, dvrr_stack+8770, NULL, NULL, dvrr_stack+19359);

 /* compute (2 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10597, dvrr_stack+4447, dvrr_stack+10462, dvrr_stack+9401, dvrr_stack+19395, dvrr_stack+5571);

 /* compute (3 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+9401, dvrr_stack+20137, dvrr_stack+10597, dvrr_stack+20002, dvrr_stack+4447, dvrr_stack+5679);

 /* compute (4 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10867, dvrr_stack+8815, dvrr_stack+9401, dvrr_stack+20857, dvrr_stack+20137, dvrr_stack+4647);

 /* compute (5 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+199368, dvrr_stack+104586, dvrr_stack+10867, dvrr_stack+21127, dvrr_stack+8815, dvrr_stack+5895);

 /* compute (6 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+200313, dvrr_stack+105261, dvrr_stack+199368, dvrr_stack+21577, dvrr_stack+104586, dvrr_stack+186480);

 /* compute (7 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+201573, dvrr_stack+106206, dvrr_stack+200313, dvrr_stack+22927, dvrr_stack+105261, dvrr_stack+187236);
 tmp = dvrr_stack + 201573;
 target_ptr = Libderiv->dvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+203193,dvrr_stack+201573,dvrr_stack+188244,36);


 /* compute (7 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+207081,dvrr_stack+203193,dvrr_stack+189540,36);


 /* compute (7 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1008,dvrr_stack+213129, dvrr_stack+207081, dvrr_stack+183204);

 /* compute (1 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20857, dvrr_stack+32208, dvrr_stack+48129, NULL, NULL, dvrr_stack+8770);

 /* compute (2 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21022, dvrr_stack+31432, dvrr_stack+20857, dvrr_stack+19440, dvrr_stack+32208, dvrr_stack+10462);

 /* compute (3 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19440, dvrr_stack+18823, dvrr_stack+21022, dvrr_stack+4171, dvrr_stack+31432, dvrr_stack+10597);

 /* compute (4 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21352, dvrr_stack+117546, dvrr_stack+19440, dvrr_stack+33852, dvrr_stack+18823, dvrr_stack+9401);

 /* compute (5 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+216153, dvrr_stack+118096, dvrr_stack+21352, dvrr_stack+34182, dvrr_stack+117546, dvrr_stack+10867);

 /* compute (6 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+217308, dvrr_stack+118921, dvrr_stack+216153, dvrr_stack+34732, dvrr_stack+118096, dvrr_stack+199368);

 /* compute (7 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+218848, dvrr_stack+120076, dvrr_stack+217308, dvrr_stack+36382, dvrr_stack+118921, dvrr_stack+200313);
 tmp = dvrr_stack + 218848;
 target_ptr = Libderiv->dvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+220828,dvrr_stack+218848,dvrr_stack+201573,36);


 /* compute (7 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+225688,dvrr_stack+220828,dvrr_stack+203193,36);


 /* compute (7 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1296,dvrr_stack+233464, dvrr_stack+225688, dvrr_stack+188244);

 /* compute (1 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33852, dvrr_stack+48184, dvrr_stack+47496, NULL, NULL, dvrr_stack+48129);

 /* compute (2 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+34050, dvrr_stack+47176, dvrr_stack+33852, dvrr_stack+32263, dvrr_stack+48184, dvrr_stack+20857);

 /* compute (3 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+34446, dvrr_stack+31597, dvrr_stack+34050, dvrr_stack+49024, dvrr_stack+47176, dvrr_stack+21022);

 /* compute (4 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+237352, dvrr_stack+134468, dvrr_stack+34446, dvrr_stack+50278, dvrr_stack+31597, dvrr_stack+19440);

 /* compute (5 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+238342, dvrr_stack+135128, dvrr_stack+237352, dvrr_stack+50674, dvrr_stack+134468, dvrr_stack+21352);

 /* compute (6 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+239728, dvrr_stack+136118, dvrr_stack+238342, dvrr_stack+51334, dvrr_stack+135128, dvrr_stack+216153);

 /* compute (7 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+241576, dvrr_stack+137504, dvrr_stack+239728, dvrr_stack+53314, dvrr_stack+136118, dvrr_stack+217308);

 /* compute (7 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+243952,dvrr_stack+241576,dvrr_stack+218848,36);


 /* compute (7 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+249892,dvrr_stack+243952,dvrr_stack+220828,36);


 /* compute (7 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1620,dvrr_stack+259612, dvrr_stack+249892, dvrr_stack+201573);

 /* compute (0 0 | 1 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+17, Data->F+18, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+32263, dvrr_stack+47374, dvrr_stack+0, Data->F+16, Data->F+17, NULL);

 /* compute (0 0 | 3 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+32269, dvrr_stack+15, dvrr_stack+32263, dvrr_stack+4336, dvrr_stack+47374, NULL);

 /* compute (0 0 | 4 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+32279, dvrr_stack+111, dvrr_stack+32269, dvrr_stack+47968, dvrr_stack+15, NULL);

 /* compute (0 0 | 5 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+32294, dvrr_stack+47377, dvrr_stack+32279, dvrr_stack+47974, dvrr_stack+111, NULL);

 /* compute (0 0 | 6 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+35106, dvrr_stack+47392, dvrr_stack+32294, dvrr_stack+47984, dvrr_stack+47377, NULL);

 /* compute (0 0 | 7 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11542, dvrr_stack+47413, dvrr_stack+35106, dvrr_stack+47999, dvrr_stack+47392, NULL);

 /* compute (0 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+35134, dvrr_stack+1567, dvrr_stack+11542, dvrr_stack+48020, dvrr_stack+47413, NULL);

 /* compute (0 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+264, dvrr_stack+9265, dvrr_stack+35134, dvrr_stack+48048, dvrr_stack+1567, NULL);

 /* compute (0 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+35179, dvrr_stack+47441, dvrr_stack+264, dvrr_stack+48084, dvrr_stack+9265, NULL);

 /* compute (0 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+35245, dvrr_stack+47496, dvrr_stack+35179, dvrr_stack+48129, dvrr_stack+47441, NULL);

 /* compute (1 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+35323, dvrr_stack+49222, dvrr_stack+35245, NULL, NULL, dvrr_stack+47496);

 /* compute (2 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+50176, dvrr_stack+47562, dvrr_stack+35323, dvrr_stack+49300, dvrr_stack+49222, dvrr_stack+33852);

 /* compute (3 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+50644, dvrr_stack+48250, dvrr_stack+50176, dvrr_stack+33050, dvrr_stack+47562, dvrr_stack+34050);

 /* compute (4 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+264472, dvrr_stack+155312, dvrr_stack+50644, dvrr_stack+69634, dvrr_stack+48250, dvrr_stack+34446);

 /* compute (5 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+265642, dvrr_stack+156092, dvrr_stack+264472, dvrr_stack+70102, dvrr_stack+155312, dvrr_stack+237352);

 /* compute (6 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+267280, dvrr_stack+157262, dvrr_stack+265642, dvrr_stack+70882, dvrr_stack+156092, dvrr_stack+238342);

 /* compute (7 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+269464, dvrr_stack+158900, dvrr_stack+267280, dvrr_stack+73222, dvrr_stack+157262, dvrr_stack+239728);

 /* compute (7 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+272272,dvrr_stack+269464,dvrr_stack+241576,36);


 /* compute (7 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+279400,dvrr_stack+272272,dvrr_stack+243952,36);


 /* compute (7 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1980,dvrr_stack+291280, dvrr_stack+279400, dvrr_stack+218848);

 /* compute (1 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+33050, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+33053, dvrr_stack+72052, dvrr_stack+33050, Data->F+6, Data->F+7, NULL);

 /* compute (3 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+33059, dvrr_stack+72055, dvrr_stack+33053, dvrr_stack+67138, dvrr_stack+72052, NULL);

 /* compute (1 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+33069, dvrr_stack+210, dvrr_stack+873, NULL, NULL, Data->F+8);

 /* compute (2 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+33078, dvrr_stack+72061, dvrr_stack+33069, dvrr_stack+30, dvrr_stack+210, dvrr_stack+33050);

 /* compute (3 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+33096, dvrr_stack+72070, dvrr_stack+33078, dvrr_stack+9310, dvrr_stack+72061, dvrr_stack+33053);

 /* compute (4 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+33126, dvrr_stack+131, dvrr_stack+33096, dvrr_stack+33284, dvrr_stack+72070, dvrr_stack+33059);

 /* compute (1 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+30, dvrr_stack+876, dvrr_stack+2302, NULL, NULL, dvrr_stack+873);

 /* compute (2 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+33171, dvrr_stack+72088, dvrr_stack+30, dvrr_stack+213, dvrr_stack+876, dvrr_stack+33069);

 /* compute (3 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+33207, dvrr_stack+72106, dvrr_stack+33171, dvrr_stack+67141, dvrr_stack+72088, dvrr_stack+33078);

 /* compute (4 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+4171, dvrr_stack+72142, dvrr_stack+33207, dvrr_stack+67159, dvrr_stack+72106, dvrr_stack+33096);

 /* compute (5 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+19990, dvrr_stack+72202, dvrr_stack+4171, dvrr_stack+67195, dvrr_stack+72142, dvrr_stack+33126);

 /* compute (1 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+67141, dvrr_stack+2308, dvrr_stack+1975, NULL, NULL, dvrr_stack+2302);

 /* compute (2 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+49300, dvrr_stack+72292, dvrr_stack+67141, dvrr_stack+882, dvrr_stack+2308, dvrr_stack+30);

 /* compute (3 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+9851, dvrr_stack+72322, dvrr_stack+49300, dvrr_stack+67255, dvrr_stack+72292, dvrr_stack+33171);

 /* compute (4 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+1637, dvrr_stack+72382, dvrr_stack+9851, dvrr_stack+67285, dvrr_stack+72322, dvrr_stack+33207);

 /* compute (5 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+3205, dvrr_stack+72482, dvrr_stack+1637, dvrr_stack+67345, dvrr_stack+72382, dvrr_stack+4171);

 /* compute (6 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+2021, dvrr_stack+72632, dvrr_stack+3205, dvrr_stack+9952, dvrr_stack+72482, dvrr_stack+19990);

 /* compute (1 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+67255, dvrr_stack+1985, dvrr_stack+4604, NULL, NULL, dvrr_stack+1975);

 /* compute (2 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+67300, dvrr_stack+219, dvrr_stack+67255, dvrr_stack+2318, dvrr_stack+1985, dvrr_stack+67141);

 /* compute (3 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+2318, dvrr_stack+72842, dvrr_stack+67300, dvrr_stack+67445, dvrr_stack+219, dvrr_stack+49300);

 /* compute (4 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+69496, dvrr_stack+72932, dvrr_stack+2318, dvrr_stack+67490, dvrr_stack+72842, dvrr_stack+9851);

 /* compute (5 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+69721, dvrr_stack+66670, dvrr_stack+69496, dvrr_stack+68386, dvrr_stack+72932, dvrr_stack+1637);

 /* compute (6 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+70036, dvrr_stack+67580, dvrr_stack+69721, dvrr_stack+68536, dvrr_stack+66670, dvrr_stack+3205);

 /* compute (7 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+70456, dvrr_stack+67895, dvrr_stack+70036, dvrr_stack+68761, dvrr_stack+67580, dvrr_stack+2021);

 /* compute (1 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+67390, dvrr_stack+593, dvrr_stack+9344, NULL, NULL, dvrr_stack+4604);

 /* compute (2 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+67453, dvrr_stack+892, dvrr_stack+67390, dvrr_stack+2000, dvrr_stack+593, dvrr_stack+67255);

 /* compute (3 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+47796, dvrr_stack+955, dvrr_stack+67453, dvrr_stack+614, dvrr_stack+892, dvrr_stack+67300);

 /* compute (4 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+68315, dvrr_stack+66895, dvrr_stack+47796, dvrr_stack+69076, dvrr_stack+955, dvrr_stack+2318);

 /* compute (5 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+70996, dvrr_stack+49861, dvrr_stack+68315, dvrr_stack+69202, dvrr_stack+66895, dvrr_stack+69496);

 /* compute (6 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+71437, dvrr_stack+32329, dvrr_stack+70996, dvrr_stack+49378, dvrr_stack+49861, dvrr_stack+69721);

 /* compute (7 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+51424, dvrr_stack+180488, dvrr_stack+71437, dvrr_stack+89413, dvrr_stack+32329, dvrr_stack+70036);

 /* compute (8 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+297220, dvrr_stack+181076, dvrr_stack+51424, dvrr_stack+89854, dvrr_stack+180488, dvrr_stack+70456);
 tmp = dvrr_stack + 297220;
 target_ptr = Libderiv->dvrr_classes[8][5];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+89413, dvrr_stack+1609, dvrr_stack+19331, NULL, NULL, dvrr_stack+9344);

 /* compute (2 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+89497, dvrr_stack+2701, dvrr_stack+89413, dvrr_stack+4619, dvrr_stack+1609, dvrr_stack+67390);

 /* compute (3 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+69076, dvrr_stack+5123, dvrr_stack+89497, dvrr_stack+69412, dvrr_stack+2701, dvrr_stack+67453);

 /* compute (4 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+48718, dvrr_stack+32770, dvrr_stack+69076, dvrr_stack+49693, dvrr_stack+5123, dvrr_stack+47796);

 /* compute (5 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+298165, dvrr_stack+2785, dvrr_stack+48718, dvrr_stack+90442, dvrr_stack+32770, dvrr_stack+68315);

 /* compute (6 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+298753, dvrr_stack+181832, dvrr_stack+298165, dvrr_stack+90722, dvrr_stack+2785, dvrr_stack+70996);

 /* compute (7 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+299537, dvrr_stack+182420, dvrr_stack+298753, dvrr_stack+91142, dvrr_stack+181832, dvrr_stack+71437);

 /* compute (8 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+90442, dvrr_stack+183204, dvrr_stack+299537, dvrr_stack+91730, dvrr_stack+182420, dvrr_stack+51424);
 tmp = dvrr_stack + 90442;
 target_ptr = Libderiv->dvrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+300545,dvrr_stack+90442,dvrr_stack+297220,45);


 /* compute (1 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+89665, dvrr_stack+19359, dvrr_stack+32172, NULL, NULL, dvrr_stack+19331);

 /* compute (2 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+49360, dvrr_stack+5571, dvrr_stack+89665, dvrr_stack+9365, dvrr_stack+19359, dvrr_stack+89413);

 /* compute (3 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+303380, dvrr_stack+5679, dvrr_stack+49360, dvrr_stack+4339, dvrr_stack+5571, dvrr_stack+89497);

 /* compute (4 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+303740, dvrr_stack+4647, dvrr_stack+303380, dvrr_stack+18607, dvrr_stack+5679, dvrr_stack+69076);

 /* compute (5 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+304280, dvrr_stack+5895, dvrr_stack+303740, dvrr_stack+94278, dvrr_stack+4647, dvrr_stack+48718);

 /* compute (6 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+305036, dvrr_stack+186480, dvrr_stack+304280, dvrr_stack+94638, dvrr_stack+5895, dvrr_stack+298165);

 /* compute (7 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+306044, dvrr_stack+187236, dvrr_stack+305036, dvrr_stack+95178, dvrr_stack+186480, dvrr_stack+298753);

 /* compute (8 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+94278, dvrr_stack+188244, dvrr_stack+306044, dvrr_stack+95934, dvrr_stack+187236, dvrr_stack+299537);
 tmp = dvrr_stack + 94278;
 target_ptr = Libderiv->dvrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+307340,dvrr_stack+94278,dvrr_stack+90442,45);


 /* compute (8 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+311120,dvrr_stack+307340,dvrr_stack+300545,45);


 /* compute (8 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,945,dvrr_stack+316790, dvrr_stack+311120, dvrr_stack+297220);

 /* compute (1 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+8770, dvrr_stack+48084, NULL, NULL, dvrr_stack+32172);

 /* compute (2 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+49576, dvrr_stack+10462, dvrr_stack+18607, dvrr_stack+19395, dvrr_stack+8770, dvrr_stack+89665);

 /* compute (3 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+319625, dvrr_stack+10597, dvrr_stack+49576, dvrr_stack+4447, dvrr_stack+10462, dvrr_stack+49360);

 /* compute (4 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+320075, dvrr_stack+9401, dvrr_stack+319625, dvrr_stack+20137, dvrr_stack+10597, dvrr_stack+303380);

 /* compute (5 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+320750, dvrr_stack+10867, dvrr_stack+320075, dvrr_stack+8815, dvrr_stack+9401, dvrr_stack+303740);

 /* compute (6 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+321695, dvrr_stack+199368, dvrr_stack+320750, dvrr_stack+104586, dvrr_stack+10867, dvrr_stack+304280);

 /* compute (7 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+322955, dvrr_stack+200313, dvrr_stack+321695, dvrr_stack+105261, dvrr_stack+199368, dvrr_stack+305036);

 /* compute (8 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+324575, dvrr_stack+201573, dvrr_stack+322955, dvrr_stack+106206, dvrr_stack+200313, dvrr_stack+306044);
 tmp = dvrr_stack + 324575;
 target_ptr = Libderiv->dvrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+326600,dvrr_stack+324575,dvrr_stack+94278,45);


 /* compute (8 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+331460,dvrr_stack+326600,dvrr_stack+307340,45);


 /* compute (8 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1260,dvrr_stack+339020, dvrr_stack+331460, dvrr_stack+90442);

 /* compute (1 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+104586, dvrr_stack+48129, dvrr_stack+47441, NULL, NULL, dvrr_stack+48084);

 /* compute (2 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+104751, dvrr_stack+20857, dvrr_stack+104586, dvrr_stack+32208, dvrr_stack+48129, dvrr_stack+18607);

 /* compute (3 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+105081, dvrr_stack+21022, dvrr_stack+104751, dvrr_stack+31432, dvrr_stack+20857, dvrr_stack+49576);

 /* compute (4 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+342800, dvrr_stack+19440, dvrr_stack+105081, dvrr_stack+18823, dvrr_stack+21022, dvrr_stack+319625);

 /* compute (5 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+343625, dvrr_stack+21352, dvrr_stack+342800, dvrr_stack+117546, dvrr_stack+19440, dvrr_stack+320075);

 /* compute (6 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+344780, dvrr_stack+216153, dvrr_stack+343625, dvrr_stack+118096, dvrr_stack+21352, dvrr_stack+320750);

 /* compute (7 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+346320, dvrr_stack+217308, dvrr_stack+344780, dvrr_stack+118921, dvrr_stack+216153, dvrr_stack+321695);

 /* compute (8 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+117546, dvrr_stack+218848, dvrr_stack+346320, dvrr_stack+120076, dvrr_stack+217308, dvrr_stack+322955);

 /* compute (8 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+348300,dvrr_stack+117546,dvrr_stack+324575,45);


 /* compute (8 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+354375,dvrr_stack+348300,dvrr_stack+326600,45);


 /* compute (8 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,1620,dvrr_stack+364095, dvrr_stack+354375, dvrr_stack+94278);

 /* compute (1 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+105631, dvrr_stack+47496, dvrr_stack+35179, NULL, NULL, dvrr_stack+47441);

 /* compute (2 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+8815, dvrr_stack+33852, dvrr_stack+105631, dvrr_stack+48184, dvrr_stack+47496, dvrr_stack+104586);

 /* compute (3 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+368955, dvrr_stack+34050, dvrr_stack+8815, dvrr_stack+47176, dvrr_stack+33852, dvrr_stack+104751);

 /* compute (4 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+369615, dvrr_stack+34446, dvrr_stack+368955, dvrr_stack+31597, dvrr_stack+34050, dvrr_stack+105081);

 /* compute (5 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+370605, dvrr_stack+237352, dvrr_stack+369615, dvrr_stack+134468, dvrr_stack+34446, dvrr_stack+342800);

 /* compute (6 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+371991, dvrr_stack+238342, dvrr_stack+370605, dvrr_stack+135128, dvrr_stack+237352, dvrr_stack+343625);

 /* compute (7 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+373839, dvrr_stack+239728, dvrr_stack+371991, dvrr_stack+136118, dvrr_stack+238342, dvrr_stack+344780);

 /* compute (8 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+134468, dvrr_stack+241576, dvrr_stack+373839, dvrr_stack+137504, dvrr_stack+239728, dvrr_stack+346320);

 /* compute (8 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+376215,dvrr_stack+134468,dvrr_stack+117546,45);


 /* compute (8 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+383640,dvrr_stack+376215,dvrr_stack+348300,45);


 /* compute (8 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,2025,dvrr_stack+395790, dvrr_stack+383640, dvrr_stack+324575);

 /* compute (0 0 | 1 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+137438, Data->F+18, Data->F+19, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+213, dvrr_stack+0, dvrr_stack+137438, Data->F+17, Data->F+18, NULL);

 /* compute (0 0 | 3 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+882, dvrr_stack+32263, dvrr_stack+213, dvrr_stack+47374, dvrr_stack+0, NULL);

 /* compute (0 0 | 4 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+49846, dvrr_stack+32269, dvrr_stack+882, dvrr_stack+15, dvrr_stack+32263, NULL);

 /* compute (0 0 | 5 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2000, dvrr_stack+32279, dvrr_stack+49846, dvrr_stack+111, dvrr_stack+32269, NULL);

 /* compute (0 0 | 6 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+91702, dvrr_stack+32294, dvrr_stack+2000, dvrr_stack+47377, dvrr_stack+32279, NULL);

 /* compute (0 0 | 7 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+95898, dvrr_stack+35106, dvrr_stack+91702, dvrr_stack+47392, dvrr_stack+32294, NULL);

 /* compute (0 0 | 8 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19395, dvrr_stack+11542, dvrr_stack+95898, dvrr_stack+47413, dvrr_stack+35106, NULL);

 /* compute (0 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+120021, dvrr_stack+35134, dvrr_stack+19395, dvrr_stack+1567, dvrr_stack+11542, NULL);

 /* compute (0 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+137438, dvrr_stack+264, dvrr_stack+120021, dvrr_stack+9265, dvrr_stack+35134, NULL);

 /* compute (0 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+47176, dvrr_stack+35179, dvrr_stack+137438, dvrr_stack+47441, dvrr_stack+264, NULL);

 /* compute (1 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31432, dvrr_stack+35245, dvrr_stack+47176, NULL, NULL, dvrr_stack+35179);

 /* compute (2 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+18742, dvrr_stack+35323, dvrr_stack+31432, dvrr_stack+49222, dvrr_stack+35245, dvrr_stack+105631);

 /* compute (3 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+401865, dvrr_stack+50176, dvrr_stack+18742, dvrr_stack+47562, dvrr_stack+35323, dvrr_stack+8815);

 /* compute (4 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+402645, dvrr_stack+50644, dvrr_stack+401865, dvrr_stack+48250, dvrr_stack+50176, dvrr_stack+368955);

 /* compute (5 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+403815, dvrr_stack+264472, dvrr_stack+402645, dvrr_stack+155312, dvrr_stack+50644, dvrr_stack+369615);

 /* compute (6 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+405453, dvrr_stack+265642, dvrr_stack+403815, dvrr_stack+156092, dvrr_stack+264472, dvrr_stack+370605);

 /* compute (7 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+401865, dvrr_stack+267280, dvrr_stack+405453, dvrr_stack+157262, dvrr_stack+265642, dvrr_stack+371991);

 /* compute (8 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+155312, dvrr_stack+269464, dvrr_stack+401865, dvrr_stack+158900, dvrr_stack+267280, dvrr_stack+373839);

 /* compute (8 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+401865,dvrr_stack+155312,dvrr_stack+134468,45);


 /* compute (8 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+410775,dvrr_stack+401865,dvrr_stack+376215,45);


 /* compute (8 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,2475,dvrr_stack+425625, dvrr_stack+410775, dvrr_stack+117546);

 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,441,dvrr_stack+264472, dvrr_stack+14638, dvrr_stack+3730);

 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,588,dvrr_stack+265795, dvrr_stack+26140, dvrr_stack+6859);

 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,756,dvrr_stack+433050, dvrr_stack+40372, dvrr_stack+12118);

 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,945,dvrr_stack+435318, dvrr_stack+58165, dvrr_stack+22927);

 /* compute (5 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1155,dvrr_stack+438153, dvrr_stack+79018, dvrr_stack+36382);

 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,588,dvrr_stack+267559, dvrr_stack+99294, dvrr_stack+89854);

 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,784,dvrr_stack+441618, dvrr_stack+110490, dvrr_stack+91730);

 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1008,dvrr_stack+443970, dvrr_stack+125396, dvrr_stack+95934);

 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1260,dvrr_stack+446994, dvrr_stack+143972, dvrr_stack+106206);

 /* compute (6 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1540,dvrr_stack+450774, dvrr_stack+166628, dvrr_stack+120076);

 /* compute (7 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,756,dvrr_stack+455394, dvrr_stack+192564, dvrr_stack+181076);

 /* compute (7 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1008,dvrr_stack+457662, dvrr_stack+207081, dvrr_stack+183204);

 /* compute (7 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1296,dvrr_stack+460686, dvrr_stack+225688, dvrr_stack+188244);

 /* compute (7 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1620,dvrr_stack+464574, dvrr_stack+249892, dvrr_stack+201573);

 /* compute (7 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1980,dvrr_stack+469434, dvrr_stack+279400, dvrr_stack+218848);

 /* compute (8 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,945,dvrr_stack+475374, dvrr_stack+311120, dvrr_stack+297220);

 /* compute (8 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1260,dvrr_stack+478209, dvrr_stack+331460, dvrr_stack+90442);

 /* compute (8 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,1620,dvrr_stack+481989, dvrr_stack+354375, dvrr_stack+94278);

 /* compute (8 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,2025,dvrr_stack+486849, dvrr_stack+383640, dvrr_stack+324575);

 /* compute (8 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,2475,dvrr_stack+492924, dvrr_stack+410775, dvrr_stack+117546);

 /* compute (5 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,441,dvrr_stack+500349, dvrr_stack+14638, dvrr_stack+3730);

 /* compute (5 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,588,dvrr_stack+14638, dvrr_stack+26140, dvrr_stack+6859);

 /* compute (5 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,756,dvrr_stack+26140, dvrr_stack+40372, dvrr_stack+12118);

 /* compute (5 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,945,dvrr_stack+40372, dvrr_stack+58165, dvrr_stack+22927);

 /* compute (5 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1155,dvrr_stack+58165, dvrr_stack+79018, dvrr_stack+36382);

 /* compute (6 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,588,dvrr_stack+79018, dvrr_stack+99294, dvrr_stack+89854);

 /* compute (6 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,784,dvrr_stack+99294, dvrr_stack+110490, dvrr_stack+91730);

 /* compute (6 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1008,dvrr_stack+110490, dvrr_stack+125396, dvrr_stack+95934);

 /* compute (6 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1260,dvrr_stack+125396, dvrr_stack+143972, dvrr_stack+106206);

 /* compute (6 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1540,dvrr_stack+143972, dvrr_stack+166628, dvrr_stack+120076);

 /* compute (7 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,756,dvrr_stack+129176, dvrr_stack+192564, dvrr_stack+181076);

 /* compute (7 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1008,dvrr_stack+192564, dvrr_stack+207081, dvrr_stack+183204);

 /* compute (7 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1296,dvrr_stack+207081, dvrr_stack+225688, dvrr_stack+188244);

 /* compute (7 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1620,dvrr_stack+225688, dvrr_stack+249892, dvrr_stack+201573);

 /* compute (7 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1980,dvrr_stack+249892, dvrr_stack+279400, dvrr_stack+218848);

 /* compute (8 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,945,dvrr_stack+279400, dvrr_stack+311120, dvrr_stack+297220);

 /* compute (8 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1260,dvrr_stack+255832, dvrr_stack+331460, dvrr_stack+90442);

 /* compute (8 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,1620,dvrr_stack+331460, dvrr_stack+354375, dvrr_stack+94278);

 /* compute (8 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,2025,dvrr_stack+354375, dvrr_stack+383640, dvrr_stack+324575);

 /* compute (8 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,2475,dvrr_stack+383640, dvrr_stack+410775, dvrr_stack+117546);

 /* compute (1 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+9310, dvrr_stack+21, dvrr_stack+3, NULL, NULL, Data->F+4);

 /* compute (2 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+410775, dvrr_stack+9310, dvrr_stack+6, dvrr_stack+21, dvrr_stack+3, dvrr_stack+0);

 /* compute (1 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+410793, dvrr_stack+164, dvrr_stack+24, NULL, NULL, dvrr_stack+21);

 /* compute (2 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+11542, dvrr_stack+410793, dvrr_stack+57, dvrr_stack+164, dvrr_stack+24, dvrr_stack+9310);

 /* compute (3 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+410811, dvrr_stack+11542, dvrr_stack+75, dvrr_stack+410793, dvrr_stack+57, dvrr_stack+410775);

 /* compute (1 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+410871, dvrr_stack+713, dvrr_stack+170, NULL, NULL, dvrr_stack+164);

 /* compute (2 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+410901, dvrr_stack+410871, dvrr_stack+180, dvrr_stack+713, dvrr_stack+170, dvrr_stack+410793);

 /* compute (3 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+410961, dvrr_stack+410901, dvrr_stack+319, dvrr_stack+410871, dvrr_stack+180, dvrr_stack+11542);

 /* compute (4 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+411061, dvrr_stack+410961, dvrr_stack+379, dvrr_stack+410901, dvrr_stack+319, dvrr_stack+410811);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+19395, dvrr_stack+578, dvrr_stack+723, NULL, NULL, dvrr_stack+713);

 /* compute (2 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+614, dvrr_stack+19395, dvrr_stack+738, dvrr_stack+578, dvrr_stack+723, dvrr_stack+410871);

 /* compute (3 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+411211, dvrr_stack+614, dvrr_stack+783, dvrr_stack+19395, dvrr_stack+738, dvrr_stack+410901);

 /* compute (4 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+411361, dvrr_stack+411211, dvrr_stack+1192, dvrr_stack+614, dvrr_stack+783, dvrr_stack+410961);

 /* compute (5 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+411586, dvrr_stack+411361, dvrr_stack+1342, dvrr_stack+411211, dvrr_stack+1192, dvrr_stack+411061);

 /* compute (5 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+411901,dvrr_stack+3730,dvrr_stack+411586,21);


 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+412846, dvrr_stack+411901, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+413161, dvrr_stack+12874, NULL);
 tmp = dvrr_stack + 413161;
 target_ptr = Libderiv->deriv_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,441,dvrr_stack+413749, dvrr_stack+7447, NULL);
 tmp = dvrr_stack + 413749;
 target_ptr = Libderiv->deriv_classes[5][5][11];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+414190, dvrr_stack+23872, NULL);
 tmp = dvrr_stack + 414190;
 target_ptr = Libderiv->deriv_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+414946, dvrr_stack+37537, NULL);
 tmp = dvrr_stack + 414946;
 target_ptr = Libderiv->deriv_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+415891, dvrr_stack+54700, NULL);
 tmp = dvrr_stack + 415891;
 target_ptr = Libderiv->deriv_classes[5][9][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+417046, dvrr_stack+74860, NULL);

 /* compute (2 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+24, dvrr_stack+0, dvrr_stack+67138, Data->F+4, Data->F+5, NULL);

 /* compute (3 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+411211, dvrr_stack+410775, dvrr_stack+33284, dvrr_stack+9310, dvrr_stack+6, dvrr_stack+24);

 /* compute (4 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+614, dvrr_stack+410811, dvrr_stack+67195, dvrr_stack+11542, dvrr_stack+75, dvrr_stack+411211);

 /* compute (5 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+418432, dvrr_stack+411061, dvrr_stack+9952, dvrr_stack+410961, dvrr_stack+379, dvrr_stack+614);

 /* compute (6 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+418642, dvrr_stack+411586, dvrr_stack+68761, dvrr_stack+411361, dvrr_stack+1342, dvrr_stack+418432);

 /* compute (6 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+28408,dvrr_stack+89854,dvrr_stack+418642,28);


 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+419062, dvrr_stack+28408, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,784,dvrr_stack+419482, dvrr_stack+96942, NULL);
 tmp = dvrr_stack + 419482;
 target_ptr = Libderiv->deriv_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+420266, dvrr_stack+92514, NULL);
 tmp = dvrr_stack + 420266;
 target_ptr = Libderiv->deriv_classes[6][5][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+420854, dvrr_stack+107466, NULL);
 tmp = dvrr_stack + 420854;
 target_ptr = Libderiv->deriv_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+421862, dvrr_stack+121616, NULL);
 tmp = dvrr_stack + 421862;
 target_ptr = Libderiv->deriv_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+423122, dvrr_stack+139352, NULL);
 tmp = dvrr_stack + 423122;
 target_ptr = Libderiv->deriv_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+391065, dvrr_stack+161084, NULL);

 /* compute (3 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+882, dvrr_stack+24, dvrr_stack+72055, dvrr_stack+0, dvrr_stack+67138, NULL);

 /* compute (4 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+19395, dvrr_stack+411211, dvrr_stack+131, dvrr_stack+410775, dvrr_stack+33284, dvrr_stack+882);

 /* compute (5 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+723, dvrr_stack+614, dvrr_stack+72202, dvrr_stack+410811, dvrr_stack+67195, dvrr_stack+19395);

 /* compute (6 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+424662, dvrr_stack+418432, dvrr_stack+72632, dvrr_stack+411061, dvrr_stack+9952, dvrr_stack+723);

 /* compute (7 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+424942, dvrr_stack+418642, dvrr_stack+67895, dvrr_stack+411586, dvrr_stack+68761, dvrr_stack+424662);

 /* compute (7 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+392913,dvrr_stack+181076,dvrr_stack+424942,36);


 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,540,dvrr_stack+394533, dvrr_stack+392913, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+360450, dvrr_stack+189540, NULL);
 tmp = dvrr_stack + 360450;
 target_ptr = Libderiv->deriv_classes[7][6][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+361458, dvrr_stack+184212, NULL);
 tmp = dvrr_stack + 361458;
 target_ptr = Libderiv->deriv_classes[7][5][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+362214, dvrr_stack+203193, NULL);
 tmp = dvrr_stack + 362214;
 target_ptr = Libderiv->deriv_classes[7][7][11];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+336320, dvrr_stack+220828, NULL);
 tmp = dvrr_stack + 336320;
 target_ptr = Libderiv->deriv_classes[7][8][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+311120, dvrr_stack+243952, NULL);
 tmp = dvrr_stack + 311120;
 target_ptr = Libderiv->deriv_classes[7][9][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+313100, dvrr_stack+272272, NULL);

 /* compute (4 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+49846, dvrr_stack+882, dvrr_stack+33059, dvrr_stack+24, dvrr_stack+72055, NULL);

 /* compute (5 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+411241, dvrr_stack+19395, dvrr_stack+33126, dvrr_stack+411211, dvrr_stack+131, dvrr_stack+49846);

 /* compute (6 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+319, dvrr_stack+723, dvrr_stack+19990, dvrr_stack+614, dvrr_stack+72202, dvrr_stack+411241);

 /* compute (7 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+395073, dvrr_stack+424662, dvrr_stack+2021, dvrr_stack+418432, dvrr_stack+72632, dvrr_stack+319);

 /* compute (8 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+337940, dvrr_stack+424942, dvrr_stack+70456, dvrr_stack+418642, dvrr_stack+67895, dvrr_stack+395073);

 /* compute (8 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+282235,dvrr_stack+297220,dvrr_stack+337940,45);


 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,675,dvrr_stack+315476, dvrr_stack+282235, NULL);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+284260, dvrr_stack+307340, NULL);
 tmp = dvrr_stack + 284260;
 target_ptr = Libderiv->deriv_classes[8][6][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+285520, dvrr_stack+300545, NULL);
 tmp = dvrr_stack + 285520;
 target_ptr = Libderiv->deriv_classes[8][5][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+286465, dvrr_stack+326600, NULL);
 tmp = dvrr_stack + 286465;
 target_ptr = Libderiv->deriv_classes[8][7][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2025,dvrr_stack+288085, dvrr_stack+348300, NULL);
 tmp = dvrr_stack + 288085;
 target_ptr = Libderiv->deriv_classes[8][8][11];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+230548, dvrr_stack+376215, NULL);
 tmp = dvrr_stack + 230548;
 target_ptr = Libderiv->deriv_classes[8][9][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+166628, dvrr_stack+401865, NULL);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+395433, dvrr_stack+411901, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+316151, dvrr_stack+12874, NULL);
 tmp = dvrr_stack + 316151;
 target_ptr = Libderiv->deriv_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+233023, dvrr_stack+7447, NULL);
 tmp = dvrr_stack + 233023;
 target_ptr = Libderiv->deriv_classes[5][5][10];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+290110, dvrr_stack+23872, NULL);
 tmp = dvrr_stack + 290110;
 target_ptr = Libderiv->deriv_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+210969, dvrr_stack+37537, NULL);
 tmp = dvrr_stack + 210969;
 target_ptr = Libderiv->deriv_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+211914, dvrr_stack+54700, NULL);
 tmp = dvrr_stack + 211914;
 target_ptr = Libderiv->deriv_classes[5][9][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+195588, dvrr_stack+74860, NULL);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+363510, dvrr_stack+28408, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+169598, dvrr_stack+96942, NULL);
 tmp = dvrr_stack + 169598;
 target_ptr = Libderiv->deriv_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+170382, dvrr_stack+92514, NULL);
 tmp = dvrr_stack + 170382;
 target_ptr = Libderiv->deriv_classes[6][5][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+170970, dvrr_stack+107466, NULL);
 tmp = dvrr_stack + 170970;
 target_ptr = Libderiv->deriv_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+171978, dvrr_stack+121616, NULL);
 tmp = dvrr_stack + 171978;
 target_ptr = Libderiv->deriv_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+173238, dvrr_stack+139352, NULL);
 tmp = dvrr_stack + 173238;
 target_ptr = Libderiv->deriv_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+148592, dvrr_stack+161084, NULL);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+174778, dvrr_stack+392913, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+150440, dvrr_stack+189540, NULL);
 tmp = dvrr_stack + 150440;
 target_ptr = Libderiv->deriv_classes[7][6][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+113514, dvrr_stack+184212, NULL);
 tmp = dvrr_stack + 113514;
 target_ptr = Libderiv->deriv_classes[7][5][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+80782, dvrr_stack+203193, NULL);
 tmp = dvrr_stack + 80782;
 target_ptr = Libderiv->deriv_classes[7][7][10];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+82078, dvrr_stack+220828, NULL);
 tmp = dvrr_stack + 82078;
 target_ptr = Libderiv->deriv_classes[7][8][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+83698, dvrr_stack+243952, NULL);
 tmp = dvrr_stack + 83698;
 target_ptr = Libderiv->deriv_classes[7][9][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+501672, dvrr_stack+272272, NULL);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+114270, dvrr_stack+282235, NULL);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+61630, dvrr_stack+307340, NULL);
 tmp = dvrr_stack + 61630;
 target_ptr = Libderiv->deriv_classes[8][6][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+62890, dvrr_stack+300545, NULL);
 tmp = dvrr_stack + 62890;
 target_ptr = Libderiv->deriv_classes[8][5][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+43207, dvrr_stack+326600, NULL);
 tmp = dvrr_stack + 43207;
 target_ptr = Libderiv->deriv_classes[8][7][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2025,dvrr_stack+504048, dvrr_stack+348300, NULL);
 tmp = dvrr_stack + 504048;
 target_ptr = Libderiv->deriv_classes[8][8][10];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+506073, dvrr_stack+376215, NULL);
 tmp = dvrr_stack + 506073;
 target_ptr = Libderiv->deriv_classes[8][9][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+508548, dvrr_stack+401865, NULL);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+338615, dvrr_stack+411901, NULL);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+411901, dvrr_stack+12874, NULL);
 tmp = dvrr_stack + 411901;
 target_ptr = Libderiv->deriv_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+12874, dvrr_stack+7447, NULL);
 tmp = dvrr_stack + 12874;
 target_ptr = Libderiv->deriv_classes[5][5][9];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+7447, dvrr_stack+23872, NULL);
 tmp = dvrr_stack + 7447;
 target_ptr = Libderiv->deriv_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+23872, dvrr_stack+37537, NULL);
 tmp = dvrr_stack + 23872;
 target_ptr = Libderiv->deriv_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+37537, dvrr_stack+54700, NULL);
 tmp = dvrr_stack + 37537;
 target_ptr = Libderiv->deriv_classes[5][9][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+54700, dvrr_stack+74860, NULL);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+74860, dvrr_stack+28408, NULL);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+28408, dvrr_stack+96942, NULL);
 tmp = dvrr_stack + 28408;
 target_ptr = Libderiv->deriv_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+96942, dvrr_stack+92514, NULL);
 tmp = dvrr_stack + 96942;
 target_ptr = Libderiv->deriv_classes[6][5][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+92514, dvrr_stack+107466, NULL);
 tmp = dvrr_stack + 92514;
 target_ptr = Libderiv->deriv_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+107466, dvrr_stack+121616, NULL);
 tmp = dvrr_stack + 107466;
 target_ptr = Libderiv->deriv_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+121616, dvrr_stack+139352, NULL);
 tmp = dvrr_stack + 121616;
 target_ptr = Libderiv->deriv_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+139352, dvrr_stack+161084, NULL);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+161084, dvrr_stack+392913, NULL);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+392913, dvrr_stack+189540, NULL);
 tmp = dvrr_stack + 392913;
 target_ptr = Libderiv->deriv_classes[7][6][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+93522, dvrr_stack+184212, NULL);
 tmp = dvrr_stack + 93522;
 target_ptr = Libderiv->deriv_classes[7][5][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+184212, dvrr_stack+203193, NULL);
 tmp = dvrr_stack + 184212;
 target_ptr = Libderiv->deriv_classes[7][7][9];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+203193, dvrr_stack+220828, NULL);
 tmp = dvrr_stack + 203193;
 target_ptr = Libderiv->deriv_classes[7][8][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+220828, dvrr_stack+243952, NULL);
 tmp = dvrr_stack + 220828;
 target_ptr = Libderiv->deriv_classes[7][9][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+243952, dvrr_stack+272272, NULL);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+272272, dvrr_stack+282235, NULL);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+282235, dvrr_stack+307340, NULL);
 tmp = dvrr_stack + 282235;
 target_ptr = Libderiv->deriv_classes[8][6][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+307340, dvrr_stack+300545, NULL);
 tmp = dvrr_stack + 307340;
 target_ptr = Libderiv->deriv_classes[8][5][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+300545, dvrr_stack+326600, NULL);
 tmp = dvrr_stack + 300545;
 target_ptr = Libderiv->deriv_classes[8][7][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+326600, dvrr_stack+348300, NULL);
 tmp = dvrr_stack + 326600;
 target_ptr = Libderiv->deriv_classes[8][8][9];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+348300, dvrr_stack+376215, NULL);
 tmp = dvrr_stack + 348300;
 target_ptr = Libderiv->deriv_classes[8][9][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+376215, dvrr_stack+401865, NULL);

 /* compute (1 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+401865, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+213, dvrr_stack+401865, dvrr_stack+0, Data->F+3, Data->F+4, NULL);

 /* compute (1 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+401868, dvrr_stack+161, dvrr_stack+21, NULL, NULL, Data->F+3);

 /* compute (2 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+3, dvrr_stack+401868, dvrr_stack+9310, dvrr_stack+161, dvrr_stack+21, dvrr_stack+401865);

 /* compute (3 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+401877, dvrr_stack+3, dvrr_stack+410775, dvrr_stack+401868, dvrr_stack+9310, dvrr_stack+213);

 /* compute (1 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+401907, dvrr_stack+707, dvrr_stack+164, NULL, NULL, dvrr_stack+161);

 /* compute (2 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+95898, dvrr_stack+401907, dvrr_stack+410793, dvrr_stack+707, dvrr_stack+164, dvrr_stack+401868);

 /* compute (3 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+213069, dvrr_stack+95898, dvrr_stack+11542, dvrr_stack+401907, dvrr_stack+410793, dvrr_stack+3);

 /* compute (4 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+338930, dvrr_stack+213069, dvrr_stack+410811, dvrr_stack+95898, dvrr_stack+11542, dvrr_stack+401877);

 /* compute (1 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+11542, dvrr_stack+121, dvrr_stack+713, NULL, NULL, dvrr_stack+707);

 /* compute (2 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+401925, dvrr_stack+11542, dvrr_stack+410871, dvrr_stack+121, dvrr_stack+713, dvrr_stack+401907);

 /* compute (3 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+401985, dvrr_stack+401925, dvrr_stack+410901, dvrr_stack+11542, dvrr_stack+410871, dvrr_stack+95898);

 /* compute (4 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+402085, dvrr_stack+401985, dvrr_stack+410961, dvrr_stack+401925, dvrr_stack+410901, dvrr_stack+213069);

 /* compute (5 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+402235, dvrr_stack+402085, dvrr_stack+411061, dvrr_stack+401985, dvrr_stack+410961, dvrr_stack+338930);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,21,1,dvrr_stack+402445, dvrr_stack+3730, dvrr_stack+402235);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+402760, dvrr_stack+12118, dvrr_stack+3730);
 tmp = dvrr_stack + 402760;
 target_ptr = Libderiv->deriv_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+403348, dvrr_stack+6859, dvrr_stack+411586);
 tmp = dvrr_stack + 403348;
 target_ptr = Libderiv->deriv_classes[5][5][8];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+403789, dvrr_stack+22927, dvrr_stack+6859);
 tmp = dvrr_stack + 403789;
 target_ptr = Libderiv->deriv_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+404545, dvrr_stack+36382, dvrr_stack+12118);
 tmp = dvrr_stack + 404545;
 target_ptr = Libderiv->deriv_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+405490, dvrr_stack+53314, dvrr_stack+22927);
 tmp = dvrr_stack + 405490;
 target_ptr = Libderiv->deriv_classes[5][9][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+406645, dvrr_stack+73222, dvrr_stack+36382);

 /* compute (3 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+95898, dvrr_stack+213, dvrr_stack+24, dvrr_stack+401865, dvrr_stack+0, NULL);

 /* compute (4 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+410871, dvrr_stack+401877, dvrr_stack+411211, dvrr_stack+3, dvrr_stack+410775, dvrr_stack+95898);

 /* compute (5 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+196974, dvrr_stack+338930, dvrr_stack+614, dvrr_stack+213069, dvrr_stack+410811, dvrr_stack+410871);

 /* compute (6 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+408031, dvrr_stack+402235, dvrr_stack+418432, dvrr_stack+402085, dvrr_stack+411061, dvrr_stack+196974);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,28,1,dvrr_stack+408311, dvrr_stack+89854, dvrr_stack+408031);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+408731, dvrr_stack+95934, dvrr_stack+89854);
 tmp = dvrr_stack + 408731;
 target_ptr = Libderiv->deriv_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+409515, dvrr_stack+91730, dvrr_stack+418642);
 tmp = dvrr_stack + 409515;
 target_ptr = Libderiv->deriv_classes[6][5][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+379185, dvrr_stack+106206, dvrr_stack+91730);
 tmp = dvrr_stack + 379185;
 target_ptr = Libderiv->deriv_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+380193, dvrr_stack+120076, dvrr_stack+95934);
 tmp = dvrr_stack + 380193;
 target_ptr = Libderiv->deriv_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+381453, dvrr_stack+137504, dvrr_stack+106206);
 tmp = dvrr_stack + 381453;
 target_ptr = Libderiv->deriv_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+350775, dvrr_stack+158900, dvrr_stack+120076);

 /* compute (4 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+213069, dvrr_stack+95898, dvrr_stack+882, dvrr_stack+213, dvrr_stack+24, NULL);

 /* compute (5 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+410916, dvrr_stack+410871, dvrr_stack+19395, dvrr_stack+401877, dvrr_stack+411211, dvrr_stack+213069);

 /* compute (6 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+401865, dvrr_stack+196974, dvrr_stack+723, dvrr_stack+338930, dvrr_stack+614, dvrr_stack+410916);

 /* compute (7 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+410103, dvrr_stack+408031, dvrr_stack+424662, dvrr_stack+402235, dvrr_stack+418432, dvrr_stack+401865);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,36,1,dvrr_stack+382993, dvrr_stack+181076, dvrr_stack+410103);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+352623, dvrr_stack+188244, dvrr_stack+181076);
 tmp = dvrr_stack + 352623;
 target_ptr = Libderiv->deriv_classes[7][6][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+328625, dvrr_stack+183204, dvrr_stack+424942);
 tmp = dvrr_stack + 328625;
 target_ptr = Libderiv->deriv_classes[7][5][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+329381, dvrr_stack+201573, dvrr_stack+183204);
 tmp = dvrr_stack + 329381;
 target_ptr = Libderiv->deriv_classes[7][7][8];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+308285, dvrr_stack+218848, dvrr_stack+188244);
 tmp = dvrr_stack + 308285;
 target_ptr = Libderiv->deriv_classes[7][8][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+272947, dvrr_stack+241576, dvrr_stack+201573);
 tmp = dvrr_stack + 272947;
 target_ptr = Libderiv->deriv_classes[7][9][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+274927, dvrr_stack+269464, dvrr_stack+218848);

 /* compute (5 0 | 0 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+2000, dvrr_stack+213069, dvrr_stack+49846, dvrr_stack+95898, dvrr_stack+882, NULL);

 /* compute (6 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+151448, dvrr_stack+410916, dvrr_stack+411241, dvrr_stack+410871, dvrr_stack+19395, dvrr_stack+2000);

 /* compute (7 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+410463, dvrr_stack+401865, dvrr_stack+319, dvrr_stack+196974, dvrr_stack+723, dvrr_stack+151448);

 /* compute (8 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+410679, dvrr_stack+410103, dvrr_stack+395073, dvrr_stack+408031, dvrr_stack+424662, dvrr_stack+410463);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,45,1,dvrr_stack+353631, dvrr_stack+297220, dvrr_stack+410679);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+277303, dvrr_stack+94278, dvrr_stack+297220);
 tmp = dvrr_stack + 277303;
 target_ptr = Libderiv->deriv_classes[8][6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+302165, dvrr_stack+90442, dvrr_stack+337940);
 tmp = dvrr_stack + 302165;
 target_ptr = Libderiv->deriv_classes[8][5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+246328, dvrr_stack+324575, dvrr_stack+90442);
 tmp = dvrr_stack + 246328;
 target_ptr = Libderiv->deriv_classes[8][7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+222808, dvrr_stack+117546, dvrr_stack+94278);
 tmp = dvrr_stack + 222808;
 target_ptr = Libderiv->deriv_classes[8][8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+189540, dvrr_stack+134468, dvrr_stack+324575);
 tmp = dvrr_stack + 189540;
 target_ptr = Libderiv->deriv_classes[8][9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,45,1,dvrr_stack+161624, dvrr_stack+155312, dvrr_stack+117546);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,21,1,dvrr_stack+401865, dvrr_stack+3730, dvrr_stack+402235);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+330677, dvrr_stack+12118, dvrr_stack+3730);
 tmp = dvrr_stack + 330677;
 target_ptr = Libderiv->deriv_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+309905, dvrr_stack+6859, dvrr_stack+411586);
 tmp = dvrr_stack + 309905;
 target_ptr = Libderiv->deriv_classes[5][5][7];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+310346, dvrr_stack+22927, dvrr_stack+6859);
 tmp = dvrr_stack + 310346;
 target_ptr = Libderiv->deriv_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+247948, dvrr_stack+36382, dvrr_stack+12118);
 tmp = dvrr_stack + 247948;
 target_ptr = Libderiv->deriv_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+204813, dvrr_stack+53314, dvrr_stack+22927);
 tmp = dvrr_stack + 204813;
 target_ptr = Libderiv->deriv_classes[5][9][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+164594, dvrr_stack+73222, dvrr_stack+36382);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,28,1,dvrr_stack+283495, dvrr_stack+89854, dvrr_stack+408031);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+278563, dvrr_stack+95934, dvrr_stack+89854);
 tmp = dvrr_stack + 278563;
 target_ptr = Libderiv->deriv_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+248893, dvrr_stack+91730, dvrr_stack+418642);
 tmp = dvrr_stack + 248893;
 target_ptr = Libderiv->deriv_classes[6][5][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+205968, dvrr_stack+106206, dvrr_stack+91730);
 tmp = dvrr_stack + 205968;
 target_ptr = Libderiv->deriv_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+141200, dvrr_stack+120076, dvrr_stack+95934);
 tmp = dvrr_stack + 141200;
 target_ptr = Libderiv->deriv_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+123156, dvrr_stack+137504, dvrr_stack+106206);
 tmp = dvrr_stack + 123156;
 target_ptr = Libderiv->deriv_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+75280, dvrr_stack+158900, dvrr_stack+120076);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,36,1,dvrr_stack+224833, dvrr_stack+181076, dvrr_stack+410103);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+142460, dvrr_stack+188244, dvrr_stack+181076);
 tmp = dvrr_stack + 142460;
 target_ptr = Libderiv->deriv_classes[7][6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+185508, dvrr_stack+183204, dvrr_stack+424942);
 tmp = dvrr_stack + 185508;
 target_ptr = Libderiv->deriv_classes[7][5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+108726, dvrr_stack+201573, dvrr_stack+183204);
 tmp = dvrr_stack + 108726;
 target_ptr = Libderiv->deriv_classes[7][7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+97530, dvrr_stack+218848, dvrr_stack+188244);
 tmp = dvrr_stack + 97530;
 target_ptr = Libderiv->deriv_classes[7][8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+56086, dvrr_stack+241576, dvrr_stack+201573);
 tmp = dvrr_stack + 56086;
 target_ptr = Libderiv->deriv_classes[7][9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+511518, dvrr_stack+269464, dvrr_stack+218848);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,45,1,dvrr_stack+124696, dvrr_stack+297220, dvrr_stack+410679);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+77128, dvrr_stack+94278, dvrr_stack+297220);
 tmp = dvrr_stack + 77128;
 target_ptr = Libderiv->deriv_classes[8][6][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+38692, dvrr_stack+90442, dvrr_stack+337940);
 tmp = dvrr_stack + 38692;
 target_ptr = Libderiv->deriv_classes[8][5][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+513894, dvrr_stack+324575, dvrr_stack+90442);
 tmp = dvrr_stack + 513894;
 target_ptr = Libderiv->deriv_classes[8][7][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+515514, dvrr_stack+117546, dvrr_stack+94278);
 tmp = dvrr_stack + 515514;
 target_ptr = Libderiv->deriv_classes[8][8][7];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+517539, dvrr_stack+134468, dvrr_stack+324575);
 tmp = dvrr_stack + 517539;
 target_ptr = Libderiv->deriv_classes[8][9][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+520014, dvrr_stack+155312, dvrr_stack+117546);

 /* compute (5 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,21,1,dvrr_stack+225373, dvrr_stack+3730, dvrr_stack+402235);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+393921, dvrr_stack+12118, dvrr_stack+3730);
 tmp = dvrr_stack + 393921;
 target_ptr = Libderiv->deriv_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+192015, dvrr_stack+6859, dvrr_stack+411586);
 tmp = dvrr_stack + 192015;
 target_ptr = Libderiv->deriv_classes[5][5][6];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+24817, dvrr_stack+22927, dvrr_stack+6859);
 tmp = dvrr_stack + 24817;
 target_ptr = Libderiv->deriv_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+13315, dvrr_stack+36382, dvrr_stack+12118);
 tmp = dvrr_stack + 13315;
 target_ptr = Libderiv->deriv_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+101646, dvrr_stack+53314, dvrr_stack+22927);
 tmp = dvrr_stack + 101646;
 target_ptr = Libderiv->deriv_classes[5][9][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+53314, dvrr_stack+73222, dvrr_stack+36382);

 /* compute (6 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,28,1,dvrr_stack+165980, dvrr_stack+89854, dvrr_stack+408031);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+16402, dvrr_stack+95934, dvrr_stack+89854);
 tmp = dvrr_stack + 16402;
 target_ptr = Libderiv->deriv_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+78388, dvrr_stack+91730, dvrr_stack+418642);
 tmp = dvrr_stack + 78388;
 target_ptr = Libderiv->deriv_classes[6][5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+50176, dvrr_stack+106206, dvrr_stack+91730);
 tmp = dvrr_stack + 50176;
 target_ptr = Libderiv->deriv_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+73082, dvrr_stack+120076, dvrr_stack+95934);
 tmp = dvrr_stack + 73082;
 target_ptr = Libderiv->deriv_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+522984, dvrr_stack+137504, dvrr_stack+106206);
 tmp = dvrr_stack + 522984;
 target_ptr = Libderiv->deriv_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+137504, dvrr_stack+158900, dvrr_stack+120076);

 /* compute (7 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,36,1,dvrr_stack+418432, dvrr_stack+181076, dvrr_stack+410103);

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+158822, dvrr_stack+188244, dvrr_stack+181076);
 tmp = dvrr_stack + 158822;
 target_ptr = Libderiv->deriv_classes[7][6][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+159830, dvrr_stack+183204, dvrr_stack+424942);
 tmp = dvrr_stack + 159830;
 target_ptr = Libderiv->deriv_classes[7][5][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+524524, dvrr_stack+201573, dvrr_stack+183204);
 tmp = dvrr_stack + 524524;
 target_ptr = Libderiv->deriv_classes[7][7][6];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+525820, dvrr_stack+218848, dvrr_stack+188244);
 tmp = dvrr_stack + 525820;
 target_ptr = Libderiv->deriv_classes[7][8][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+527440, dvrr_stack+241576, dvrr_stack+201573);
 tmp = dvrr_stack + 527440;
 target_ptr = Libderiv->deriv_classes[7][9][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+529420, dvrr_stack+269464, dvrr_stack+218848);

 /* compute (8 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,45,1,dvrr_stack+39637, dvrr_stack+297220, dvrr_stack+410679);

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+269323, dvrr_stack+94278, dvrr_stack+297220);
 tmp = dvrr_stack + 269323;
 target_ptr = Libderiv->deriv_classes[8][6][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+410103, dvrr_stack+90442, dvrr_stack+337940);
 tmp = dvrr_stack + 410103;
 target_ptr = Libderiv->deriv_classes[8][5][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+270583, dvrr_stack+324575, dvrr_stack+90442);
 tmp = dvrr_stack + 270583;
 target_ptr = Libderiv->deriv_classes[8][7][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+531796, dvrr_stack+117546, dvrr_stack+94278);
 tmp = dvrr_stack + 531796;
 target_ptr = Libderiv->deriv_classes[8][8][6];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+533821, dvrr_stack+134468, dvrr_stack+324575);
 tmp = dvrr_stack + 533821;
 target_ptr = Libderiv->deriv_classes[8][9][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+536296, dvrr_stack+155312, dvrr_stack+117546);

 /* compute (4 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+155312,dvrr_stack+6439,dvrr_stack+3415,15);


 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,315,dvrr_stack+411586, dvrr_stack+155312, NULL);

 /* compute (4 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+156257,dvrr_stack+11578,dvrr_stack+6439,15);


 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,420,dvrr_stack+157517, dvrr_stack+156257, NULL);

 /* compute (4 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+539266,dvrr_stack+22252,dvrr_stack+11578,15);


 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,540,dvrr_stack+157937, dvrr_stack+539266, NULL);

 /* compute (4 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+540886,dvrr_stack+35557,dvrr_stack+22252,15);


 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,675,dvrr_stack+31432, dvrr_stack+540886, NULL);

 /* compute (4 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+542911,dvrr_stack+52324,dvrr_stack+35557,15);


 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,825,dvrr_stack+545386, dvrr_stack+542911, NULL);

 /* compute (1 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+158477, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+213, dvrr_stack+33050, dvrr_stack+158477, Data->F+7, Data->F+8, NULL);

 /* compute (3 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+158480, dvrr_stack+33053, dvrr_stack+213, dvrr_stack+72052, dvrr_stack+33050, NULL);

 /* compute (4 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+158490, dvrr_stack+33059, dvrr_stack+158480, dvrr_stack+72055, dvrr_stack+33053, NULL);

 /* compute (1 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+9310, dvrr_stack+873, dvrr_stack+704, NULL, NULL, Data->F+9);

 /* compute (2 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+311102, dvrr_stack+33069, dvrr_stack+9310, dvrr_stack+210, dvrr_stack+873, dvrr_stack+158477);

 /* compute (3 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+0, dvrr_stack+33078, dvrr_stack+311102, dvrr_stack+72061, dvrr_stack+33069, dvrr_stack+213);

 /* compute (4 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+72025, dvrr_stack+33096, dvrr_stack+0, dvrr_stack+72070, dvrr_stack+33078, dvrr_stack+158480);

 /* compute (5 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+158505, dvrr_stack+33126, dvrr_stack+72025, dvrr_stack+131, dvrr_stack+33096, dvrr_stack+158490);

 /* compute (1 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+72070, dvrr_stack+2302, dvrr_stack+1969, NULL, NULL, dvrr_stack+704);

 /* compute (2 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+95898, dvrr_stack+30, dvrr_stack+72070, dvrr_stack+876, dvrr_stack+2302, dvrr_stack+9310);

 /* compute (3 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+213069, dvrr_stack+33171, dvrr_stack+95898, dvrr_stack+72088, dvrr_stack+30, dvrr_stack+311102);

 /* compute (4 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+418972, dvrr_stack+33207, dvrr_stack+213069, dvrr_stack+72106, dvrr_stack+33171, dvrr_stack+0);

 /* compute (5 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+196974, dvrr_stack+4171, dvrr_stack+418972, dvrr_stack+72142, dvrr_stack+33207, dvrr_stack+72025);

 /* compute (6 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+158568, dvrr_stack+19990, dvrr_stack+196974, dvrr_stack+72202, dvrr_stack+4171, dvrr_stack+158505);

 /* compute (1 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+72088, dvrr_stack+1975, dvrr_stack+4594, NULL, NULL, dvrr_stack+1969);

 /* compute (2 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+40312, dvrr_stack+67141, dvrr_stack+72088, dvrr_stack+2308, dvrr_stack+1975, dvrr_stack+72070);

 /* compute (3 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+72118, dvrr_stack+49300, dvrr_stack+40312, dvrr_stack+72292, dvrr_stack+67141, dvrr_stack+95898);

 /* compute (4 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+411048, dvrr_stack+9851, dvrr_stack+72118, dvrr_stack+72322, dvrr_stack+49300, dvrr_stack+213069);

 /* compute (5 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+408031, dvrr_stack+1637, dvrr_stack+411048, dvrr_stack+72382, dvrr_stack+9851, dvrr_stack+418972);

 /* compute (6 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+283915, dvrr_stack+3205, dvrr_stack+408031, dvrr_stack+72482, dvrr_stack+1637, dvrr_stack+196974);

 /* compute (7 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+72218, dvrr_stack+2021, dvrr_stack+283915, dvrr_stack+72632, dvrr_stack+3205, dvrr_stack+158568);

 /* compute (1 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+72578, dvrr_stack+4604, dvrr_stack+9329, NULL, NULL, dvrr_stack+4594);

 /* compute (2 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+614, dvrr_stack+67255, dvrr_stack+72578, dvrr_stack+1985, dvrr_stack+4604, dvrr_stack+72088);

 /* compute (3 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+72623, dvrr_stack+67300, dvrr_stack+614, dvrr_stack+219, dvrr_stack+67255, dvrr_stack+40312);

 /* compute (4 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+402180, dvrr_stack+2318, dvrr_stack+72623, dvrr_stack+72842, dvrr_stack+67300, dvrr_stack+72118);

 /* compute (5 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+249481, dvrr_stack+69496, dvrr_stack+402180, dvrr_stack+72932, dvrr_stack+2318, dvrr_stack+411048);

 /* compute (6 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+143468, dvrr_stack+69721, dvrr_stack+249481, dvrr_stack+66670, dvrr_stack+69496, dvrr_stack+408031);

 /* compute (7 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+25573, dvrr_stack+70036, dvrr_stack+143468, dvrr_stack+67580, dvrr_stack+69721, dvrr_stack+283915);

 /* compute (8 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+546211, dvrr_stack+70456, dvrr_stack+25573, dvrr_stack+67895, dvrr_stack+70036, dvrr_stack+72218);

 /* compute (1 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+66670, dvrr_stack+9344, dvrr_stack+19310, NULL, NULL, dvrr_stack+9329);

 /* compute (2 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+66733, dvrr_stack+67390, dvrr_stack+66670, dvrr_stack+593, dvrr_stack+9344, dvrr_stack+72578);

 /* compute (3 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+72773, dvrr_stack+67453, dvrr_stack+66733, dvrr_stack+892, dvrr_stack+67390, dvrr_stack+614);

 /* compute (4 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+110022, dvrr_stack+47796, dvrr_stack+72773, dvrr_stack+955, dvrr_stack+67453, dvrr_stack+72623);

 /* compute (5 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+892, dvrr_stack+68315, dvrr_stack+110022, dvrr_stack+66895, dvrr_stack+47796, dvrr_stack+402180);

 /* compute (6 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+67579, dvrr_stack+70996, dvrr_stack+892, dvrr_stack+49861, dvrr_stack+68315, dvrr_stack+249481);

 /* compute (7 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+546886, dvrr_stack+71437, dvrr_stack+67579, dvrr_stack+32329, dvrr_stack+70996, dvrr_stack+143468);

 /* compute (8 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+547642, dvrr_stack+51424, dvrr_stack+546886, dvrr_stack+180488, dvrr_stack+71437, dvrr_stack+25573);

 /* compute (9 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+548587, dvrr_stack+297220, dvrr_stack+547642, dvrr_stack+181076, dvrr_stack+51424, dvrr_stack+546211);

 /* compute (1 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+151448, dvrr_stack+19331, dvrr_stack+32144, NULL, NULL, dvrr_stack+19310);

 /* compute (2 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+180488, dvrr_stack+89413, dvrr_stack+151448, dvrr_stack+1609, dvrr_stack+19331, dvrr_stack+66670);

 /* compute (3 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+180656, dvrr_stack+89497, dvrr_stack+180488, dvrr_stack+2701, dvrr_stack+89413, dvrr_stack+66733);

 /* compute (4 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+29192, dvrr_stack+69076, dvrr_stack+180656, dvrr_stack+5123, dvrr_stack+89497, dvrr_stack+72773);

 /* compute (5 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+549742, dvrr_stack+48718, dvrr_stack+29192, dvrr_stack+32770, dvrr_stack+69076, dvrr_stack+110022);

 /* compute (6 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+32208, dvrr_stack+298165, dvrr_stack+549742, dvrr_stack+2785, dvrr_stack+48718, dvrr_stack+892);

 /* compute (7 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+550330, dvrr_stack+298753, dvrr_stack+32208, dvrr_stack+181832, dvrr_stack+298165, dvrr_stack+67579);

 /* compute (8 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+551338, dvrr_stack+299537, dvrr_stack+550330, dvrr_stack+182420, dvrr_stack+298753, dvrr_stack+546886);

 /* compute (9 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+552598, dvrr_stack+90442, dvrr_stack+551338, dvrr_stack+183204, dvrr_stack+299537, dvrr_stack+547642);

 /* compute (9 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+554138,dvrr_stack+552598,dvrr_stack+548587,55);


 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+181832, dvrr_stack+554138, NULL);

 /* compute (1 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+192456, dvrr_stack+32172, dvrr_stack+48048, NULL, NULL, dvrr_stack+32144);

 /* compute (2 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+186264, dvrr_stack+89665, dvrr_stack+192456, dvrr_stack+19359, dvrr_stack+32172, dvrr_stack+151448);

 /* compute (3 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2701, dvrr_stack+49360, dvrr_stack+186264, dvrr_stack+5571, dvrr_stack+89665, dvrr_stack+180488);

 /* compute (4 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8203, dvrr_stack+303380, dvrr_stack+2701, dvrr_stack+5679, dvrr_stack+49360, dvrr_stack+180656);

 /* compute (5 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+557603, dvrr_stack+303740, dvrr_stack+8203, dvrr_stack+4647, dvrr_stack+303380, dvrr_stack+29192);

 /* compute (6 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+558359, dvrr_stack+304280, dvrr_stack+557603, dvrr_stack+5895, dvrr_stack+303740, dvrr_stack+549742);

 /* compute (7 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+559367, dvrr_stack+305036, dvrr_stack+558359, dvrr_stack+186480, dvrr_stack+304280, dvrr_stack+32208);

 /* compute (8 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+560663, dvrr_stack+306044, dvrr_stack+559367, dvrr_stack+187236, dvrr_stack+305036, dvrr_stack+550330);

 /* compute (9 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+562283, dvrr_stack+94278, dvrr_stack+560663, dvrr_stack+188244, dvrr_stack+306044, dvrr_stack+551338);

 /* compute (9 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+564263,dvrr_stack+562283,dvrr_stack+552598,55);


 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+186480, dvrr_stack+564263, NULL);

 /* compute (1 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+188020, dvrr_stack+48084, dvrr_stack+9265, NULL, NULL, dvrr_stack+48048);

 /* compute (2 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+303110, dvrr_stack+18607, dvrr_stack+188020, dvrr_stack+8770, dvrr_stack+48084, dvrr_stack+192456);

 /* compute (3 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+5571, dvrr_stack+49576, dvrr_stack+303110, dvrr_stack+10462, dvrr_stack+18607, dvrr_stack+186264);

 /* compute (4 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+568883, dvrr_stack+319625, dvrr_stack+5571, dvrr_stack+10597, dvrr_stack+49576, dvrr_stack+2701);

 /* compute (5 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+569558, dvrr_stack+320075, dvrr_stack+568883, dvrr_stack+9401, dvrr_stack+319625, dvrr_stack+8203);

 /* compute (6 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+570503, dvrr_stack+320750, dvrr_stack+569558, dvrr_stack+10867, dvrr_stack+320075, dvrr_stack+557603);

 /* compute (7 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+571763, dvrr_stack+321695, dvrr_stack+570503, dvrr_stack+199368, dvrr_stack+320750, dvrr_stack+558359);

 /* compute (8 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+573383, dvrr_stack+322955, dvrr_stack+571763, dvrr_stack+200313, dvrr_stack+321695, dvrr_stack+559367);

 /* compute (9 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+575408, dvrr_stack+324575, dvrr_stack+573383, dvrr_stack+201573, dvrr_stack+322955, dvrr_stack+560663);

 /* compute (9 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+577883,dvrr_stack+575408,dvrr_stack+562283,55);


 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+199368, dvrr_stack+577883, NULL);

 /* compute (1 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+363930, dvrr_stack+47441, dvrr_stack+264, NULL, NULL, dvrr_stack+9265);

 /* compute (2 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+10462, dvrr_stack+104586, dvrr_stack+363930, dvrr_stack+48129, dvrr_stack+47441, dvrr_stack+188020);

 /* compute (3 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+175318, dvrr_stack+104751, dvrr_stack+10462, dvrr_stack+20857, dvrr_stack+104586, dvrr_stack+303110);

 /* compute (4 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+583823, dvrr_stack+105081, dvrr_stack+175318, dvrr_stack+21022, dvrr_stack+104751, dvrr_stack+5571);

 /* compute (5 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+584648, dvrr_stack+342800, dvrr_stack+583823, dvrr_stack+19440, dvrr_stack+105081, dvrr_stack+568883);

 /* compute (6 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+585803, dvrr_stack+343625, dvrr_stack+584648, dvrr_stack+21352, dvrr_stack+342800, dvrr_stack+569558);

 /* compute (7 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+587343, dvrr_stack+344780, dvrr_stack+585803, dvrr_stack+216153, dvrr_stack+343625, dvrr_stack+570503);

 /* compute (8 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+589323, dvrr_stack+346320, dvrr_stack+587343, dvrr_stack+217308, dvrr_stack+344780, dvrr_stack+571763);

 /* compute (9 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+591798, dvrr_stack+117546, dvrr_stack+589323, dvrr_stack+218848, dvrr_stack+346320, dvrr_stack+573383);

 /* compute (9 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+594823,dvrr_stack+591798,dvrr_stack+575408,55);


 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+216153, dvrr_stack+594823, NULL);

 /* compute (1 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+218628, dvrr_stack+35179, dvrr_stack+137438, NULL, NULL, dvrr_stack+264);

 /* compute (2 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19440, dvrr_stack+105631, dvrr_stack+218628, dvrr_stack+47496, dvrr_stack+35179, dvrr_stack+363930);

 /* compute (3 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20857, dvrr_stack+8815, dvrr_stack+19440, dvrr_stack+33852, dvrr_stack+105631, dvrr_stack+10462);

 /* compute (4 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+602248, dvrr_stack+368955, dvrr_stack+20857, dvrr_stack+34050, dvrr_stack+8815, dvrr_stack+175318);

 /* compute (5 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20857, dvrr_stack+369615, dvrr_stack+602248, dvrr_stack+34446, dvrr_stack+368955, dvrr_stack+583823);

 /* compute (6 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+602248, dvrr_stack+370605, dvrr_stack+20857, dvrr_stack+237352, dvrr_stack+369615, dvrr_stack+584648);

 /* compute (7 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+604096, dvrr_stack+371991, dvrr_stack+602248, dvrr_stack+238342, dvrr_stack+370605, dvrr_stack+585803);

 /* compute (8 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+368955, dvrr_stack+373839, dvrr_stack+604096, dvrr_stack+239728, dvrr_stack+371991, dvrr_stack+587343);

 /* compute (9 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+602248, dvrr_stack+134468, dvrr_stack+368955, dvrr_stack+241576, dvrr_stack+373839, dvrr_stack+589323);

 /* compute (9 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+605878,dvrr_stack+602248,dvrr_stack+591798,55);


 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3025,dvrr_stack+368955, dvrr_stack+605878, NULL);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,315,dvrr_stack+49861, dvrr_stack+155312, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,420,dvrr_stack+371980, dvrr_stack+156257, NULL);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,540,dvrr_stack+372400, dvrr_stack+539266, NULL);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,675,dvrr_stack+372940, dvrr_stack+540886, NULL);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,825,dvrr_stack+373615, dvrr_stack+542911, NULL);

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+374440, dvrr_stack+554138, NULL);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+134468, dvrr_stack+564263, NULL);

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+237352, dvrr_stack+577883, NULL);

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+239332, dvrr_stack+594823, NULL);

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3025,dvrr_stack+614953, dvrr_stack+605878, NULL);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,315,dvrr_stack+375595, dvrr_stack+155312, NULL);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,420,dvrr_stack+155312, dvrr_stack+156257, NULL);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,540,dvrr_stack+155732, dvrr_stack+539266, NULL);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,675,dvrr_stack+539266, dvrr_stack+540886, NULL);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,825,dvrr_stack+539941, dvrr_stack+542911, NULL);

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+540766, dvrr_stack+554138, NULL);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+554138, dvrr_stack+564263, NULL);

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+564263, dvrr_stack+577883, NULL);

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+577883, dvrr_stack+594823, NULL);

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3025,dvrr_stack+594823, dvrr_stack+605878, NULL);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,15,1,dvrr_stack+605878, dvrr_stack+6439, dvrr_stack+411361);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,15,1,dvrr_stack+606193, dvrr_stack+11578, dvrr_stack+3415);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,15,1,dvrr_stack+606613, dvrr_stack+22252, dvrr_stack+6439);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,15,1,dvrr_stack+607153, dvrr_stack+35557, dvrr_stack+11578);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,15,1,dvrr_stack+607828, dvrr_stack+52324, dvrr_stack+22252);

 /* compute (5 0 | 0 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+102801, dvrr_stack+49846, dvrr_stack+158490, dvrr_stack+882, dvrr_stack+33059, NULL);

 /* compute (6 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+143888, dvrr_stack+411241, dvrr_stack+158505, dvrr_stack+19395, dvrr_stack+33126, dvrr_stack+102801);

 /* compute (7 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+608653, dvrr_stack+319, dvrr_stack+158568, dvrr_stack+723, dvrr_stack+19990, dvrr_stack+143888);

 /* compute (8 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+608869, dvrr_stack+395073, dvrr_stack+72218, dvrr_stack+424662, dvrr_stack+2021, dvrr_stack+608653);

 /* compute (9 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+609319, dvrr_stack+337940, dvrr_stack+546211, dvrr_stack+424942, dvrr_stack+70456, dvrr_stack+608869);

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,55,1,dvrr_stack+610144, dvrr_stack+552598, dvrr_stack+609319);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+611299, dvrr_stack+562283, dvrr_stack+548587);

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+612839, dvrr_stack+575408, dvrr_stack+552598);

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+597848, dvrr_stack+591798, dvrr_stack+562283);

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+580358, dvrr_stack+602248, dvrr_stack+575408);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,15,1,dvrr_stack+337940, dvrr_stack+6439, dvrr_stack+411361);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,15,1,dvrr_stack+608653, dvrr_stack+11578, dvrr_stack+3415);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,15,1,dvrr_stack+424662, dvrr_stack+22252, dvrr_stack+6439);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,15,1,dvrr_stack+600323, dvrr_stack+35557, dvrr_stack+11578);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,15,1,dvrr_stack+600998, dvrr_stack+52324, dvrr_stack+22252);

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,55,1,dvrr_stack+566243, dvrr_stack+552598, dvrr_stack+609319);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+555678, dvrr_stack+562283, dvrr_stack+548587);

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+541921, dvrr_stack+575408, dvrr_stack+552598);

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+617978, dvrr_stack+591798, dvrr_stack+562283);

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+620453, dvrr_stack+602248, dvrr_stack+575408);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,15,1,dvrr_stack+338255, dvrr_stack+6439, dvrr_stack+411361);

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,15,1,dvrr_stack+425202, dvrr_stack+11578, dvrr_stack+3415);

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,15,1,dvrr_stack+567398, dvrr_stack+22252, dvrr_stack+6439);

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,15,1,dvrr_stack+567938, dvrr_stack+35557, dvrr_stack+11578);

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,15,1,dvrr_stack+543901, dvrr_stack+52324, dvrr_stack+22252);

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,55,1,dvrr_stack+156272, dvrr_stack+552598, dvrr_stack+609319);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+241807, dvrr_stack+562283, dvrr_stack+548587);

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+623478, dvrr_stack+575408, dvrr_stack+552598);

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+625458, dvrr_stack+591798, dvrr_stack+562283);

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+627933, dvrr_stack+602248, dvrr_stack+575408);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,21,dvrr_stack+609073, dvrr_stack+3730, dvrr_stack+2491);

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+609388, dvrr_stack+181076, dvrr_stack+3730);
 tmp = dvrr_stack + 609388;
 target_ptr = Libderiv->deriv_classes[6][5][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,28,dvrr_stack+601823, dvrr_stack+6859, dvrr_stack+5291);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+602243, dvrr_stack+183204, dvrr_stack+6859);
 tmp = dvrr_stack + 602243;
 target_ptr = Libderiv->deriv_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,36,dvrr_stack+603027, dvrr_stack+12118, dvrr_stack+10102);

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+603567, dvrr_stack+188244, dvrr_stack+12118);
 tmp = dvrr_stack + 603567;
 target_ptr = Libderiv->deriv_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,45,dvrr_stack+604575, dvrr_stack+22927, dvrr_stack+20407);

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+136008, dvrr_stack+201573, dvrr_stack+22927);
 tmp = dvrr_stack + 136008;
 target_ptr = Libderiv->deriv_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_g(Data,55,dvrr_stack+20857, dvrr_stack+36382, dvrr_stack+33302);

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+630958, dvrr_stack+218848, dvrr_stack+36382);
 tmp = dvrr_stack + 630958;
 target_ptr = Libderiv->deriv_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+605250, dvrr_stack+89854, dvrr_stack+3415);
 tmp = dvrr_stack + 605250;
 target_ptr = Libderiv->deriv_classes[5][5][2];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+33852, dvrr_stack+297220, dvrr_stack+89854);
 tmp = dvrr_stack + 33852;
 target_ptr = Libderiv->deriv_classes[7][5][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+544726, dvrr_stack+91730, dvrr_stack+6439);
 tmp = dvrr_stack + 544726;
 target_ptr = Libderiv->deriv_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+52180, dvrr_stack+90442, dvrr_stack+91730);
 tmp = dvrr_stack + 52180;
 target_ptr = Libderiv->deriv_classes[7][6][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+10792, dvrr_stack+95934, dvrr_stack+11578);
 tmp = dvrr_stack + 10792;
 target_ptr = Libderiv->deriv_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+632498, dvrr_stack+94278, dvrr_stack+95934);
 tmp = dvrr_stack + 632498;
 target_ptr = Libderiv->deriv_classes[7][7][2];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+633794, dvrr_stack+106206, dvrr_stack+22252);
 tmp = dvrr_stack + 633794;
 target_ptr = Libderiv->deriv_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+634739, dvrr_stack+324575, dvrr_stack+106206);
 tmp = dvrr_stack + 634739;
 target_ptr = Libderiv->deriv_classes[7][8][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+636359, dvrr_stack+120076, dvrr_stack+35557);
 tmp = dvrr_stack + 636359;
 target_ptr = Libderiv->deriv_classes[5][9][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+637514, dvrr_stack+117546, dvrr_stack+120076);
 tmp = dvrr_stack + 637514;
 target_ptr = Libderiv->deriv_classes[7][9][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+639494, dvrr_stack+548587, dvrr_stack+181076);
 tmp = dvrr_stack + 639494;
 target_ptr = Libderiv->deriv_classes[8][5][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+640439, dvrr_stack+552598, dvrr_stack+183204);
 tmp = dvrr_stack + 640439;
 target_ptr = Libderiv->deriv_classes[8][6][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+641699, dvrr_stack+562283, dvrr_stack+188244);
 tmp = dvrr_stack + 641699;
 target_ptr = Libderiv->deriv_classes[8][7][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+643319, dvrr_stack+575408, dvrr_stack+201573);
 tmp = dvrr_stack + 643319;
 target_ptr = Libderiv->deriv_classes[8][8][2];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+645344, dvrr_stack+591798, dvrr_stack+218848);
 tmp = dvrr_stack + 645344;
 target_ptr = Libderiv->deriv_classes[8][9][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+425622, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+338570, dvrr_stack+158477, dvrr_stack+425622, Data->F+8, Data->F+9, NULL);

 /* compute (3 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+2308, dvrr_stack+213, dvrr_stack+338570, dvrr_stack+33050, dvrr_stack+158477, NULL);

 /* compute (4 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+49846, dvrr_stack+158480, dvrr_stack+2308, dvrr_stack+33053, dvrr_stack+213, NULL);

 /* compute (5 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+102801, dvrr_stack+158490, dvrr_stack+49846, dvrr_stack+33059, dvrr_stack+158480, NULL);

 /* compute (1 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+158477, dvrr_stack+704, dvrr_stack+1966, NULL, NULL, Data->F+10);

 /* compute (2 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+158486, dvrr_stack+9310, dvrr_stack+158477, dvrr_stack+873, dvrr_stack+704, dvrr_stack+425622);

 /* compute (3 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+11548, dvrr_stack+311102, dvrr_stack+158486, dvrr_stack+33069, dvrr_stack+9310, dvrr_stack+338570);

 /* compute (4 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+338570, dvrr_stack+0, dvrr_stack+11548, dvrr_stack+33078, dvrr_stack+311102, dvrr_stack+2308);

 /* compute (5 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+704, dvrr_stack+72025, dvrr_stack+338570, dvrr_stack+33096, dvrr_stack+0, dvrr_stack+49846);

 /* compute (6 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+143888, dvrr_stack+158505, dvrr_stack+704, dvrr_stack+33126, dvrr_stack+72025, dvrr_stack+102801);

 /* compute (1 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+311102, dvrr_stack+1969, dvrr_stack+1603, NULL, NULL, dvrr_stack+1966);

 /* compute (2 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+1985, dvrr_stack+72070, dvrr_stack+311102, dvrr_stack+2302, dvrr_stack+1969, dvrr_stack+158477);

 /* compute (3 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+767, dvrr_stack+95898, dvrr_stack+1985, dvrr_stack+30, dvrr_stack+72070, dvrr_stack+158486);

 /* compute (4 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+157427, dvrr_stack+213069, dvrr_stack+767, dvrr_stack+33171, dvrr_stack+95898, dvrr_stack+11548);

 /* compute (5 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+53188, dvrr_stack+418972, dvrr_stack+157427, dvrr_stack+33207, dvrr_stack+213069, dvrr_stack+338570);

 /* compute (6 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+609976, dvrr_stack+196974, dvrr_stack+53188, dvrr_stack+4171, dvrr_stack+418972, dvrr_stack+704);

 /* compute (7 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+4171, dvrr_stack+158568, dvrr_stack+609976, dvrr_stack+19990, dvrr_stack+196974, dvrr_stack+143888);

 /* compute (1 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+11548, dvrr_stack+4594, dvrr_stack+9319, NULL, NULL, dvrr_stack+1603);

 /* compute (2 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+213069, dvrr_stack+72088, dvrr_stack+11548, dvrr_stack+1975, dvrr_stack+4594, dvrr_stack+311102);

 /* compute (3 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+196974, dvrr_stack+40312, dvrr_stack+213069, dvrr_stack+67141, dvrr_stack+72088, dvrr_stack+1985);

 /* compute (4 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+4387, dvrr_stack+72118, dvrr_stack+196974, dvrr_stack+49300, dvrr_stack+40312, dvrr_stack+767);

 /* compute (5 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+158477, dvrr_stack+411048, dvrr_stack+4387, dvrr_stack+9851, dvrr_stack+72118, dvrr_stack+157427);

 /* compute (6 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+395073, dvrr_stack+408031, dvrr_stack+158477, dvrr_stack+1637, dvrr_stack+411048, dvrr_stack+53188);

 /* compute (7 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+411048, dvrr_stack+283915, dvrr_stack+395073, dvrr_stack+3205, dvrr_stack+408031, dvrr_stack+609976);

 /* compute (8 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+243347, dvrr_stack+72218, dvrr_stack+411048, dvrr_stack+2021, dvrr_stack+283915, dvrr_stack+4171);

 /* compute (1 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+338570, dvrr_stack+9329, dvrr_stack+19295, NULL, NULL, dvrr_stack+9319);

 /* compute (2 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+157427, dvrr_stack+72578, dvrr_stack+338570, dvrr_stack+4604, dvrr_stack+9329, dvrr_stack+11548);

 /* compute (3 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+4171, dvrr_stack+614, dvrr_stack+157427, dvrr_stack+67255, dvrr_stack+72578, dvrr_stack+213069);

 /* compute (4 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+201348, dvrr_stack+72623, dvrr_stack+4171, dvrr_stack+67300, dvrr_stack+614, dvrr_stack+196974);

 /* compute (5 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+283915, dvrr_stack+402180, dvrr_stack+201348, dvrr_stack+2318, dvrr_stack+72623, dvrr_stack+4387);

 /* compute (6 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+4321, dvrr_stack+249481, dvrr_stack+283915, dvrr_stack+69496, dvrr_stack+402180, dvrr_stack+158477);

 /* compute (7 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+4741, dvrr_stack+143468, dvrr_stack+4321, dvrr_stack+69721, dvrr_stack+249481, dvrr_stack+395073);

 /* compute (8 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+1603, dvrr_stack+25573, dvrr_stack+4741, dvrr_stack+70036, dvrr_stack+143468, dvrr_stack+411048);

 /* compute (9 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+19359, dvrr_stack+546211, dvrr_stack+1603, dvrr_stack+70456, dvrr_stack+25573, dvrr_stack+243347);

 /* compute (1 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+243347, dvrr_stack+19310, dvrr_stack+32123, NULL, NULL, dvrr_stack+19295);

 /* compute (2 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+196974, dvrr_stack+66670, dvrr_stack+243347, dvrr_stack+9344, dvrr_stack+19310, dvrr_stack+338570);

 /* compute (3 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+243410, dvrr_stack+66733, dvrr_stack+196974, dvrr_stack+67390, dvrr_stack+66670, dvrr_stack+157427);

 /* compute (4 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+243620, dvrr_stack+72773, dvrr_stack+243410, dvrr_stack+67453, dvrr_stack+66733, dvrr_stack+4171);

 /* compute (5 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+66670, dvrr_stack+110022, dvrr_stack+243620, dvrr_stack+47796, dvrr_stack+72773, dvrr_stack+201348);

 /* compute (6 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+546211, dvrr_stack+892, dvrr_stack+66670, dvrr_stack+68315, dvrr_stack+110022, dvrr_stack+283915);

 /* compute (7 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+72025, dvrr_stack+67579, dvrr_stack+546211, dvrr_stack+70996, dvrr_stack+892, dvrr_stack+4321);

 /* compute (8 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+319, dvrr_stack+546886, dvrr_stack+72025, dvrr_stack+71437, dvrr_stack+67579, dvrr_stack+4741);

 /* compute (9 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+67111, dvrr_stack+547642, dvrr_stack+319, dvrr_stack+51424, dvrr_stack+546886, dvrr_stack+1603);

 /* compute (10 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+69356, dvrr_stack+548587, dvrr_stack+67111, dvrr_stack+297220, dvrr_stack+547642, dvrr_stack+19359);

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,21,dvrr_stack+546799, dvrr_stack+69356, dvrr_stack+297220);

 /* compute (1 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+19359, dvrr_stack+32144, dvrr_stack+48020, NULL, NULL, dvrr_stack+32123);

 /* compute (2 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+609976, dvrr_stack+151448, dvrr_stack+19359, dvrr_stack+19331, dvrr_stack+32144, dvrr_stack+243347);

 /* compute (3 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+408031, dvrr_stack+180488, dvrr_stack+609976, dvrr_stack+89413, dvrr_stack+151448, dvrr_stack+196974);

 /* compute (4 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+19443, dvrr_stack+180656, dvrr_stack+408031, dvrr_stack+89497, dvrr_stack+180488, dvrr_stack+243410);

 /* compute (5 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+1603, dvrr_stack+29192, dvrr_stack+19443, dvrr_stack+69076, dvrr_stack+180656, dvrr_stack+243620);

 /* compute (6 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+4171, dvrr_stack+549742, dvrr_stack+1603, dvrr_stack+48718, dvrr_stack+29192, dvrr_stack+66670);

 /* compute (7 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+68266, dvrr_stack+32208, dvrr_stack+4171, dvrr_stack+298165, dvrr_stack+549742, dvrr_stack+546211);

 /* compute (8 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+70742, dvrr_stack+550330, dvrr_stack+68266, dvrr_stack+298753, dvrr_stack+32208, dvrr_stack+72025);

 /* compute (9 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+647819, dvrr_stack+551338, dvrr_stack+70742, dvrr_stack+299537, dvrr_stack+550330, dvrr_stack+319);

 /* compute (10 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+298165, dvrr_stack+552598, dvrr_stack+647819, dvrr_stack+90442, dvrr_stack+551338, dvrr_stack+67111);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+549742, dvrr_stack+298165, dvrr_stack+90442);

 /* compute (1 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+319, dvrr_stack+48048, dvrr_stack+1567, NULL, NULL, dvrr_stack+48020);

 /* compute (2 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+427, dvrr_stack+192456, dvrr_stack+319, dvrr_stack+32172, dvrr_stack+48048, dvrr_stack+19359);

 /* compute (3 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+395073, dvrr_stack+186264, dvrr_stack+427, dvrr_stack+89665, dvrr_stack+192456, dvrr_stack+609976);

 /* compute (4 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+643, dvrr_stack+2701, dvrr_stack+395073, dvrr_stack+49360, dvrr_stack+186264, dvrr_stack+408031);

 /* compute (5 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+551282, dvrr_stack+8203, dvrr_stack+643, dvrr_stack+303380, dvrr_stack+2701, dvrr_stack+19443);

 /* compute (6 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+66670, dvrr_stack+557603, dvrr_stack+551282, dvrr_stack+303740, dvrr_stack+8203, dvrr_stack+1603);

 /* compute (7 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+48129, dvrr_stack+558359, dvrr_stack+66670, dvrr_stack+304280, dvrr_stack+557603, dvrr_stack+4171);

 /* compute (8 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+303380, dvrr_stack+559367, dvrr_stack+48129, dvrr_stack+305036, dvrr_stack+558359, dvrr_stack+68266);

 /* compute (9 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+557218, dvrr_stack+560663, dvrr_stack+303380, dvrr_stack+306044, dvrr_stack+559367, dvrr_stack+70742);

 /* compute (10 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+649359, dvrr_stack+562283, dvrr_stack+557218, dvrr_stack+94278, dvrr_stack+560663, dvrr_stack+647819);

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+70742, dvrr_stack+649359, dvrr_stack+94278);

 /* compute (1 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+647819, dvrr_stack+9265, dvrr_stack+35134, NULL, NULL, dvrr_stack+1567);

 /* compute (2 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+568613, dvrr_stack+188020, dvrr_stack+647819, dvrr_stack+48084, dvrr_stack+9265, dvrr_stack+319);

 /* compute (3 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+647954, dvrr_stack+303110, dvrr_stack+568613, dvrr_stack+18607, dvrr_stack+188020, dvrr_stack+427);

 /* compute (4 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18607, dvrr_stack+5571, dvrr_stack+647954, dvrr_stack+49576, dvrr_stack+303110, dvrr_stack+395073);

 /* compute (5 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19282, dvrr_stack+568883, dvrr_stack+18607, dvrr_stack+319625, dvrr_stack+5571, dvrr_stack+643);

 /* compute (6 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+319, dvrr_stack+569558, dvrr_stack+19282, dvrr_stack+320075, dvrr_stack+568883, dvrr_stack+551282);

 /* compute (7 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8203, dvrr_stack+570503, dvrr_stack+319, dvrr_stack+320750, dvrr_stack+569558, dvrr_stack+66670);

 /* compute (8 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+66670, dvrr_stack+571763, dvrr_stack+8203, dvrr_stack+321695, dvrr_stack+570503, dvrr_stack+48129);

 /* compute (9 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+568883, dvrr_stack+573383, dvrr_stack+66670, dvrr_stack+322955, dvrr_stack+571763, dvrr_stack+303380);

 /* compute (10 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+319625, dvrr_stack+575408, dvrr_stack+568883, dvrr_stack+324575, dvrr_stack+573383, dvrr_stack+557218);

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+557218, dvrr_stack+319625, dvrr_stack+324575);

 /* compute (1 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+559693, dvrr_stack+264, dvrr_stack+120021, NULL, NULL, dvrr_stack+35134);

 /* compute (2 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+559858, dvrr_stack+363930, dvrr_stack+559693, dvrr_stack+47441, dvrr_stack+264, dvrr_stack+647819);

 /* compute (3 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+560188, dvrr_stack+10462, dvrr_stack+559858, dvrr_stack+104586, dvrr_stack+363930, dvrr_stack+568613);

 /* compute (4 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+560738, dvrr_stack+175318, dvrr_stack+560188, dvrr_stack+104751, dvrr_stack+10462, dvrr_stack+647954);

 /* compute (5 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+647819, dvrr_stack+583823, dvrr_stack+560738, dvrr_stack+105081, dvrr_stack+175318, dvrr_stack+18607);

 /* compute (6 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+104586, dvrr_stack+584648, dvrr_stack+647819, dvrr_stack+342800, dvrr_stack+583823, dvrr_stack+19282);

 /* compute (7 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+322595, dvrr_stack+585803, dvrr_stack+104586, dvrr_stack+343625, dvrr_stack+584648, dvrr_stack+319);

 /* compute (8 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+559693, dvrr_stack+587343, dvrr_stack+322595, dvrr_stack+344780, dvrr_stack+585803, dvrr_stack+8203);

 /* compute (9 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+342800, dvrr_stack+589323, dvrr_stack+559693, dvrr_stack+346320, dvrr_stack+587343, dvrr_stack+66670);

 /* compute (10 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+571358, dvrr_stack+591798, dvrr_stack+342800, dvrr_stack+117546, dvrr_stack+589323, dvrr_stack+568883);

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+342800, dvrr_stack+571358, dvrr_stack+117546);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,21,dvrr_stack+345825, dvrr_stack+3730, dvrr_stack+2491);

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+546211, dvrr_stack+181076, dvrr_stack+3730);
 tmp = dvrr_stack + 546211;
 target_ptr = Libderiv->deriv_classes[6][5][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,28,dvrr_stack+574988, dvrr_stack+6859, dvrr_stack+5291);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+346140, dvrr_stack+183204, dvrr_stack+6859);
 tmp = dvrr_stack + 346140;
 target_ptr = Libderiv->deriv_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,36,dvrr_stack+346924, dvrr_stack+12118, dvrr_stack+10102);

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+66670, dvrr_stack+188244, dvrr_stack+12118);
 tmp = dvrr_stack + 66670;
 target_ptr = Libderiv->deriv_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,45,dvrr_stack+347464, dvrr_stack+22927, dvrr_stack+20407);

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+67678, dvrr_stack+201573, dvrr_stack+22927);
 tmp = dvrr_stack + 67678;
 target_ptr = Libderiv->deriv_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_g(Data,55,dvrr_stack+559693, dvrr_stack+36382, dvrr_stack+33302);

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+647819, dvrr_stack+218848, dvrr_stack+36382);
 tmp = dvrr_stack + 647819;
 target_ptr = Libderiv->deriv_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+89413, dvrr_stack+89854, dvrr_stack+3415);
 tmp = dvrr_stack + 89413;
 target_ptr = Libderiv->deriv_classes[5][5][1];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+560518, dvrr_stack+297220, dvrr_stack+89854);
 tmp = dvrr_stack + 560518;
 target_ptr = Libderiv->deriv_classes[7][5][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+180488, dvrr_stack+91730, dvrr_stack+6439);
 tmp = dvrr_stack + 180488;
 target_ptr = Libderiv->deriv_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+561274, dvrr_stack+90442, dvrr_stack+91730);
 tmp = dvrr_stack + 561274;
 target_ptr = Libderiv->deriv_classes[7][6][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+8203, dvrr_stack+95934, dvrr_stack+11578);
 tmp = dvrr_stack + 8203;
 target_ptr = Libderiv->deriv_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+322595, dvrr_stack+94278, dvrr_stack+95934);
 tmp = dvrr_stack + 322595;
 target_ptr = Libderiv->deriv_classes[7][7][1];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+8959, dvrr_stack+106206, dvrr_stack+22252);
 tmp = dvrr_stack + 8959;
 target_ptr = Libderiv->deriv_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+104586, dvrr_stack+324575, dvrr_stack+106206);
 tmp = dvrr_stack + 104586;
 target_ptr = Libderiv->deriv_classes[7][8][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+18607, dvrr_stack+120076, dvrr_stack+35557);
 tmp = dvrr_stack + 18607;
 target_ptr = Libderiv->deriv_classes[5][9][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+568613, dvrr_stack+117546, dvrr_stack+120076);
 tmp = dvrr_stack + 568613;
 target_ptr = Libderiv->deriv_classes[7][9][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+551282, dvrr_stack+548587, dvrr_stack+181076);
 tmp = dvrr_stack + 551282;
 target_ptr = Libderiv->deriv_classes[8][5][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+303110, dvrr_stack+552598, dvrr_stack+183204);
 tmp = dvrr_stack + 303110;
 target_ptr = Libderiv->deriv_classes[8][6][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+304370, dvrr_stack+562283, dvrr_stack+188244);
 tmp = dvrr_stack + 304370;
 target_ptr = Libderiv->deriv_classes[8][7][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+0, dvrr_stack+575408, dvrr_stack+201573);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv_classes[8][8][1];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+583383, dvrr_stack+591798, dvrr_stack+218848);
 tmp = dvrr_stack + 583383;
 target_ptr = Libderiv->deriv_classes[8][9][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,21,dvrr_stack+305990, dvrr_stack+69356, dvrr_stack+297220);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+585858, dvrr_stack+298165, dvrr_stack+90442);

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+587398, dvrr_stack+649359, dvrr_stack+94278);

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+47176, dvrr_stack+319625, dvrr_stack+324575);

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+651735, dvrr_stack+571358, dvrr_stack+117546);

 /* compute (4 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,21,dvrr_stack+68938, dvrr_stack+3730, dvrr_stack+2491);

 /* compute (6 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+323891, dvrr_stack+181076, dvrr_stack+3730);
 tmp = dvrr_stack + 323891;
 target_ptr = Libderiv->deriv_classes[6][5][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,28,dvrr_stack+3730, dvrr_stack+6859, dvrr_stack+5291);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+4150, dvrr_stack+183204, dvrr_stack+6859);
 tmp = dvrr_stack + 4150;
 target_ptr = Libderiv->deriv_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,36,dvrr_stack+6859, dvrr_stack+12118, dvrr_stack+10102);

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+4934, dvrr_stack+188244, dvrr_stack+12118);
 tmp = dvrr_stack + 4934;
 target_ptr = Libderiv->deriv_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,45,dvrr_stack+12118, dvrr_stack+22927, dvrr_stack+20407);

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+2025, dvrr_stack+201573, dvrr_stack+22927);
 tmp = dvrr_stack + 2025;
 target_ptr = Libderiv->deriv_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (4 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_g(Data,55,dvrr_stack+22927, dvrr_stack+36382, dvrr_stack+33302);

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+589378, dvrr_stack+218848, dvrr_stack+36382);
 tmp = dvrr_stack + 589378;
 target_ptr = Libderiv->deriv_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+36382, dvrr_stack+89854, dvrr_stack+3415);
 tmp = dvrr_stack + 36382;
 target_ptr = Libderiv->deriv_classes[5][5][0];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+9904, dvrr_stack+297220, dvrr_stack+89854);
 tmp = dvrr_stack + 9904;
 target_ptr = Libderiv->deriv_classes[7][5][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+89854, dvrr_stack+91730, dvrr_stack+6439);
 tmp = dvrr_stack + 89854;
 target_ptr = Libderiv->deriv_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+19762, dvrr_stack+90442, dvrr_stack+91730);
 tmp = dvrr_stack + 19762;
 target_ptr = Libderiv->deriv_classes[7][6][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+5942, dvrr_stack+95934, dvrr_stack+11578);
 tmp = dvrr_stack + 5942;
 target_ptr = Libderiv->deriv_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+32107, dvrr_stack+94278, dvrr_stack+95934);
 tmp = dvrr_stack + 32107;
 target_ptr = Libderiv->deriv_classes[7][7][0];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+95898, dvrr_stack+106206, dvrr_stack+22252);
 tmp = dvrr_stack + 95898;
 target_ptr = Libderiv->deriv_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+654760, dvrr_stack+324575, dvrr_stack+106206);
 tmp = dvrr_stack + 654760;
 target_ptr = Libderiv->deriv_classes[7][8][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+106206, dvrr_stack+120076, dvrr_stack+35557);
 tmp = dvrr_stack + 106206;
 target_ptr = Libderiv->deriv_classes[5][9][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+656380, dvrr_stack+117546, dvrr_stack+120076);
 tmp = dvrr_stack + 656380;
 target_ptr = Libderiv->deriv_classes[7][9][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+120021, dvrr_stack+548587, dvrr_stack+181076);
 tmp = dvrr_stack + 120021;
 target_ptr = Libderiv->deriv_classes[8][5][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+547954, dvrr_stack+552598, dvrr_stack+183204);
 tmp = dvrr_stack + 547954;
 target_ptr = Libderiv->deriv_classes[8][6][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+552227, dvrr_stack+562283, dvrr_stack+188244);
 tmp = dvrr_stack + 552227;
 target_ptr = Libderiv->deriv_classes[8][7][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+658360, dvrr_stack+575408, dvrr_stack+201573);
 tmp = dvrr_stack + 658360;
 target_ptr = Libderiv->deriv_classes[8][8][0];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+575408, dvrr_stack+591798, dvrr_stack+218848);
 tmp = dvrr_stack + 575408;
 target_ptr = Libderiv->deriv_classes[8][9][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,21,dvrr_stack+562282, dvrr_stack+69356, dvrr_stack+297220);

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+201348, dvrr_stack+298165, dvrr_stack+90442);

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+90442, dvrr_stack+649359, dvrr_stack+94278);

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+297220, dvrr_stack+319625, dvrr_stack+324575);

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+590918, dvrr_stack+571358, dvrr_stack+117546);

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,441,dvrr_stack+117546, dvrr_stack+17284, NULL);
 tmp = dvrr_stack + 117546;
 target_ptr = Libderiv->deriv2_classes[5][5][143];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,588,dvrr_stack+117987, dvrr_stack+29668, NULL);
 tmp = dvrr_stack + 117987;
 target_ptr = Libderiv->deriv2_classes[5][6][143];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,756,dvrr_stack+181076, dvrr_stack+44908, NULL);
 tmp = dvrr_stack + 181076;
 target_ptr = Libderiv->deriv2_classes[5][7][143];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,945,dvrr_stack+118575, dvrr_stack+63835, NULL);
 tmp = dvrr_stack + 118575;
 target_ptr = Libderiv->deriv2_classes[5][8][143];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+319625, dvrr_stack+85948, NULL);
 tmp = dvrr_stack + 319625;
 target_ptr = Libderiv->deriv2_classes[5][9][143];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,588,dvrr_stack+320780, dvrr_stack+102822, NULL);
 tmp = dvrr_stack + 320780;
 target_ptr = Libderiv->deriv2_classes[6][5][143];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,784,dvrr_stack+321368, dvrr_stack+115194, NULL);
 tmp = dvrr_stack + 321368;
 target_ptr = Libderiv->deriv2_classes[6][6][143];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+94278, dvrr_stack+131444, NULL);
 tmp = dvrr_stack + 94278;
 target_ptr = Libderiv->deriv2_classes[6][7][143];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+649359, dvrr_stack+151532, NULL);
 tmp = dvrr_stack + 649359;
 target_ptr = Libderiv->deriv2_classes[6][8][143];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+324479, dvrr_stack+175868, NULL);
 tmp = dvrr_stack + 324479;
 target_ptr = Libderiv->deriv2_classes[6][9][143];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,756,dvrr_stack+650619, dvrr_stack+197100, NULL);
 tmp = dvrr_stack + 650619;
 target_ptr = Libderiv->deriv2_classes[7][5][143];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+69253, dvrr_stack+213129, NULL);
 tmp = dvrr_stack + 69253;
 target_ptr = Libderiv->deriv2_classes[7][6][143];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+570593, dvrr_stack+233464, NULL);
 tmp = dvrr_stack + 570593;
 target_ptr = Libderiv->deriv2_classes[7][7][143];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+571889, dvrr_stack+259612, NULL);
 tmp = dvrr_stack + 571889;
 target_ptr = Libderiv->deriv2_classes[7][8][143];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+218628, dvrr_stack+291280, NULL);
 tmp = dvrr_stack + 218628;
 target_ptr = Libderiv->deriv2_classes[7][9][143];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,945,dvrr_stack+573509, dvrr_stack+316790, NULL);
 tmp = dvrr_stack + 573509;
 target_ptr = Libderiv->deriv2_classes[8][5][143];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+188020, dvrr_stack+339020, NULL);
 tmp = dvrr_stack + 188020;
 target_ptr = Libderiv->deriv2_classes[8][6][143];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+34608, dvrr_stack+364095, NULL);
 tmp = dvrr_stack + 34608;
 target_ptr = Libderiv->deriv2_classes[8][7][143];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,2025,dvrr_stack+660385, dvrr_stack+395790, NULL);
 tmp = dvrr_stack + 660385;
 target_ptr = Libderiv->deriv2_classes[8][8][143];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+662410, dvrr_stack+425625, NULL);
 tmp = dvrr_stack + 662410;
 target_ptr = Libderiv->deriv2_classes[8][9][143];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,441,dvrr_stack+119520, dvrr_stack+17284, NULL);
 tmp = dvrr_stack + 119520;
 target_ptr = Libderiv->deriv2_classes[5][5][131];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,588,dvrr_stack+95286, dvrr_stack+29668, NULL);
 tmp = dvrr_stack + 95286;
 target_ptr = Libderiv->deriv2_classes[5][6][131];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,756,dvrr_stack+299695, dvrr_stack+44908, NULL);
 tmp = dvrr_stack + 299695;
 target_ptr = Libderiv->deriv2_classes[5][7][131];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,945,dvrr_stack+21682, dvrr_stack+63835, NULL);
 tmp = dvrr_stack + 21682;
 target_ptr = Libderiv->deriv2_classes[5][8][131];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1155,dvrr_stack+182987, dvrr_stack+85948, NULL);
 tmp = dvrr_stack + 182987;
 target_ptr = Libderiv->deriv2_classes[5][9][131];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,588,dvrr_stack+36823, dvrr_stack+102822, NULL);
 tmp = dvrr_stack + 36823;
 target_ptr = Libderiv->deriv2_classes[6][5][131];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,784,dvrr_stack+563437, dvrr_stack+115194, NULL);
 tmp = dvrr_stack + 563437;
 target_ptr = Libderiv->deriv2_classes[6][6][131];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1008,dvrr_stack+664885, dvrr_stack+131444, NULL);
 tmp = dvrr_stack + 664885;
 target_ptr = Libderiv->deriv2_classes[6][7][131];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1260,dvrr_stack+665893, dvrr_stack+151532, NULL);
 tmp = dvrr_stack + 665893;
 target_ptr = Libderiv->deriv2_classes[6][8][131];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1540,dvrr_stack+667153, dvrr_stack+175868, NULL);
 tmp = dvrr_stack + 667153;
 target_ptr = Libderiv->deriv2_classes[6][9][131];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,756,dvrr_stack+593943, dvrr_stack+197100, NULL);
 tmp = dvrr_stack + 593943;
 target_ptr = Libderiv->deriv2_classes[7][5][131];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1008,dvrr_stack+668693, dvrr_stack+213129, NULL);
 tmp = dvrr_stack + 668693;
 target_ptr = Libderiv->deriv2_classes[7][6][131];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1296,dvrr_stack+669701, dvrr_stack+233464, NULL);
 tmp = dvrr_stack + 669701;
 target_ptr = Libderiv->deriv2_classes[7][7][131];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1620,dvrr_stack+670997, dvrr_stack+259612, NULL);
 tmp = dvrr_stack + 670997;
 target_ptr = Libderiv->deriv2_classes[7][8][131];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1980,dvrr_stack+672617, dvrr_stack+291280, NULL);
 tmp = dvrr_stack + 672617;
 target_ptr = Libderiv->deriv2_classes[7][9][131];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,945,dvrr_stack+51184, dvrr_stack+316790, NULL);
 tmp = dvrr_stack + 51184;
 target_ptr = Libderiv->deriv2_classes[8][5][131];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1260,dvrr_stack+674597, dvrr_stack+339020, NULL);
 tmp = dvrr_stack + 674597;
 target_ptr = Libderiv->deriv2_classes[8][6][131];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,1620,dvrr_stack+675857, dvrr_stack+364095, NULL);
 tmp = dvrr_stack + 675857;
 target_ptr = Libderiv->deriv2_classes[8][7][131];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,2025,dvrr_stack+677477, dvrr_stack+395790, NULL);
 tmp = dvrr_stack + 677477;
 target_ptr = Libderiv->deriv2_classes[8][8][131];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,2475,dvrr_stack+679502, dvrr_stack+425625, NULL);
 tmp = dvrr_stack + 679502;
 target_ptr = Libderiv->deriv2_classes[8][9][131];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,441,dvrr_stack+322152, dvrr_stack+264472, NULL);
 tmp = dvrr_stack + 322152;
 target_ptr = Libderiv->deriv2_classes[5][5][130];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+120966, dvrr_stack+265795, NULL);
 tmp = dvrr_stack + 120966;
 target_ptr = Libderiv->deriv2_classes[5][6][130];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+681977, dvrr_stack+433050, NULL);
 tmp = dvrr_stack + 681977;
 target_ptr = Libderiv->deriv2_classes[5][7][130];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+682733, dvrr_stack+435318, NULL);
 tmp = dvrr_stack + 682733;
 target_ptr = Libderiv->deriv2_classes[5][8][130];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+683678, dvrr_stack+438153, NULL);
 tmp = dvrr_stack + 683678;
 target_ptr = Libderiv->deriv2_classes[5][9][130];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+243347, dvrr_stack+267559, NULL);
 tmp = dvrr_stack + 243347;
 target_ptr = Libderiv->deriv2_classes[6][5][130];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+684833, dvrr_stack+441618, NULL);
 tmp = dvrr_stack + 684833;
 target_ptr = Libderiv->deriv2_classes[6][6][130];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+685617, dvrr_stack+443970, NULL);
 tmp = dvrr_stack + 685617;
 target_ptr = Libderiv->deriv2_classes[6][7][130];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+686625, dvrr_stack+446994, NULL);
 tmp = dvrr_stack + 686625;
 target_ptr = Libderiv->deriv2_classes[6][8][130];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+687885, dvrr_stack+450774, NULL);
 tmp = dvrr_stack + 687885;
 target_ptr = Libderiv->deriv2_classes[6][9][130];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+689425, dvrr_stack+455394, NULL);
 tmp = dvrr_stack + 689425;
 target_ptr = Libderiv->deriv2_classes[7][5][130];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+690181, dvrr_stack+457662, NULL);
 tmp = dvrr_stack + 690181;
 target_ptr = Libderiv->deriv2_classes[7][6][130];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+691189, dvrr_stack+460686, NULL);
 tmp = dvrr_stack + 691189;
 target_ptr = Libderiv->deriv2_classes[7][7][130];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+692485, dvrr_stack+464574, NULL);
 tmp = dvrr_stack + 692485;
 target_ptr = Libderiv->deriv2_classes[7][8][130];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+694105, dvrr_stack+469434, NULL);
 tmp = dvrr_stack + 694105;
 target_ptr = Libderiv->deriv2_classes[7][9][130];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+696085, dvrr_stack+475374, NULL);
 tmp = dvrr_stack + 696085;
 target_ptr = Libderiv->deriv2_classes[8][5][130];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+697030, dvrr_stack+478209, NULL);
 tmp = dvrr_stack + 697030;
 target_ptr = Libderiv->deriv2_classes[8][6][130];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+698290, dvrr_stack+481989, NULL);
 tmp = dvrr_stack + 698290;
 target_ptr = Libderiv->deriv2_classes[8][7][130];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,2025,dvrr_stack+699910, dvrr_stack+486849, NULL);
 tmp = dvrr_stack + 699910;
 target_ptr = Libderiv->deriv2_classes[8][8][130];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+701935, dvrr_stack+492924, NULL);
 tmp = dvrr_stack + 701935;
 target_ptr = Libderiv->deriv2_classes[8][9][130];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,441,dvrr_stack+70261, dvrr_stack+17284, NULL);
 tmp = dvrr_stack + 70261;
 target_ptr = Libderiv->deriv2_classes[5][5][119];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,588,dvrr_stack+704410, dvrr_stack+29668, NULL);
 tmp = dvrr_stack + 704410;
 target_ptr = Libderiv->deriv2_classes[5][6][119];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,756,dvrr_stack+29192, dvrr_stack+44908, NULL);
 tmp = dvrr_stack + 29192;
 target_ptr = Libderiv->deriv2_classes[5][7][119];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,945,dvrr_stack+29948, dvrr_stack+63835, NULL);
 tmp = dvrr_stack + 29948;
 target_ptr = Libderiv->deriv2_classes[5][8][119];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1155,dvrr_stack+63835, dvrr_stack+85948, NULL);
 tmp = dvrr_stack + 63835;
 target_ptr = Libderiv->deriv2_classes[5][9][119];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,588,dvrr_stack+64990, dvrr_stack+102822, NULL);
 tmp = dvrr_stack + 64990;
 target_ptr = Libderiv->deriv2_classes[6][5][119];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,784,dvrr_stack+65578, dvrr_stack+115194, NULL);
 tmp = dvrr_stack + 65578;
 target_ptr = Libderiv->deriv2_classes[6][6][119];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1008,dvrr_stack+102801, dvrr_stack+131444, NULL);
 tmp = dvrr_stack + 102801;
 target_ptr = Libderiv->deriv2_classes[6][7][119];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1260,dvrr_stack+131444, dvrr_stack+151532, NULL);
 tmp = dvrr_stack + 131444;
 target_ptr = Libderiv->deriv2_classes[6][8][119];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1540,dvrr_stack+132704, dvrr_stack+175868, NULL);
 tmp = dvrr_stack + 132704;
 target_ptr = Libderiv->deriv2_classes[6][9][119];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,756,dvrr_stack+175318, dvrr_stack+197100, NULL);
 tmp = dvrr_stack + 175318;
 target_ptr = Libderiv->deriv2_classes[7][5][119];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1008,dvrr_stack+176074, dvrr_stack+213129, NULL);
 tmp = dvrr_stack + 176074;
 target_ptr = Libderiv->deriv2_classes[7][6][119];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1296,dvrr_stack+177082, dvrr_stack+233464, NULL);
 tmp = dvrr_stack + 177082;
 target_ptr = Libderiv->deriv2_classes[7][7][119];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1620,dvrr_stack+233464, dvrr_stack+259612, NULL);
 tmp = dvrr_stack + 233464;
 target_ptr = Libderiv->deriv2_classes[7][8][119];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1980,dvrr_stack+259612, dvrr_stack+291280, NULL);
 tmp = dvrr_stack + 259612;
 target_ptr = Libderiv->deriv2_classes[7][9][119];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,945,dvrr_stack+261592, dvrr_stack+316790, NULL);
 tmp = dvrr_stack + 261592;
 target_ptr = Libderiv->deriv2_classes[8][5][119];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1260,dvrr_stack+262537, dvrr_stack+339020, NULL);
 tmp = dvrr_stack + 262537;
 target_ptr = Libderiv->deriv2_classes[8][6][119];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,1620,dvrr_stack+235084, dvrr_stack+364095, NULL);
 tmp = dvrr_stack + 235084;
 target_ptr = Libderiv->deriv2_classes[8][7][119];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,2025,dvrr_stack+178378, dvrr_stack+395790, NULL);
 tmp = dvrr_stack + 178378;
 target_ptr = Libderiv->deriv2_classes[8][8][119];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,2475,dvrr_stack+363930, dvrr_stack+425625, NULL);
 tmp = dvrr_stack + 363930;
 target_ptr = Libderiv->deriv2_classes[8][9][119];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+263797, dvrr_stack+264472, NULL);
 tmp = dvrr_stack + 263797;
 target_ptr = Libderiv->deriv2_classes[5][5][118];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+264238, dvrr_stack+265795, NULL);
 tmp = dvrr_stack + 264238;
 target_ptr = Libderiv->deriv2_classes[5][6][118];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+264826, dvrr_stack+433050, NULL);
 tmp = dvrr_stack + 264826;
 target_ptr = Libderiv->deriv2_classes[5][7][118];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+265582, dvrr_stack+435318, NULL);
 tmp = dvrr_stack + 265582;
 target_ptr = Libderiv->deriv2_classes[5][8][118];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+366405, dvrr_stack+438153, NULL);
 tmp = dvrr_stack + 366405;
 target_ptr = Libderiv->deriv2_classes[5][9][118];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+266527, dvrr_stack+267559, NULL);
 tmp = dvrr_stack + 266527;
 target_ptr = Libderiv->deriv2_classes[6][5][118];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+267115, dvrr_stack+441618, NULL);
 tmp = dvrr_stack + 267115;
 target_ptr = Libderiv->deriv2_classes[6][6][118];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+267899, dvrr_stack+443970, NULL);
 tmp = dvrr_stack + 267899;
 target_ptr = Libderiv->deriv2_classes[6][7][118];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+367560, dvrr_stack+446994, NULL);
 tmp = dvrr_stack + 367560;
 target_ptr = Libderiv->deriv2_classes[6][8][118];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+196974, dvrr_stack+450774, NULL);
 tmp = dvrr_stack + 196974;
 target_ptr = Libderiv->deriv2_classes[6][9][118];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+198514, dvrr_stack+455394, NULL);
 tmp = dvrr_stack + 198514;
 target_ptr = Libderiv->deriv2_classes[7][5][118];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+151448, dvrr_stack+457662, NULL);
 tmp = dvrr_stack + 151448;
 target_ptr = Libderiv->deriv2_classes[7][6][118];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+152456, dvrr_stack+460686, NULL);
 tmp = dvrr_stack + 152456;
 target_ptr = Libderiv->deriv2_classes[7][7][118];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+213069, dvrr_stack+464574, NULL);
 tmp = dvrr_stack + 213069;
 target_ptr = Libderiv->deriv2_classes[7][8][118];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+425622, dvrr_stack+469434, NULL);
 tmp = dvrr_stack + 425622;
 target_ptr = Libderiv->deriv2_classes[7][9][118];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+153752, dvrr_stack+475374, NULL);
 tmp = dvrr_stack + 153752;
 target_ptr = Libderiv->deriv2_classes[8][5][118];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+214689, dvrr_stack+478209, NULL);
 tmp = dvrr_stack + 214689;
 target_ptr = Libderiv->deriv2_classes[8][6][118];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+427602, dvrr_stack+481989, NULL);
 tmp = dvrr_stack + 427602;
 target_ptr = Libderiv->deriv2_classes[8][7][118];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+429222, dvrr_stack+486849, NULL);
 tmp = dvrr_stack + 429222;
 target_ptr = Libderiv->deriv2_classes[8][8][118];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+431247, dvrr_stack+492924, NULL);
 tmp = dvrr_stack + 431247;
 target_ptr = Libderiv->deriv2_classes[8][9][118];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,441,dvrr_stack+236704, dvrr_stack+500349, NULL);
 tmp = dvrr_stack + 236704;
 target_ptr = Libderiv->deriv2_classes[5][5][117];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+154697, dvrr_stack+14638, NULL);
 tmp = dvrr_stack + 154697;
 target_ptr = Libderiv->deriv2_classes[5][6][117];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+103809, dvrr_stack+26140, NULL);
 tmp = dvrr_stack + 103809;
 target_ptr = Libderiv->deriv2_classes[5][7][117];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+25573, dvrr_stack+40372, NULL);
 tmp = dvrr_stack + 25573;
 target_ptr = Libderiv->deriv2_classes[5][8][117];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+26518, dvrr_stack+58165, NULL);
 tmp = dvrr_stack + 26518;
 target_ptr = Libderiv->deriv2_classes[5][9][117];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+27673, dvrr_stack+79018, NULL);
 tmp = dvrr_stack + 27673;
 target_ptr = Libderiv->deriv2_classes[6][5][117];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+40312, dvrr_stack+99294, NULL);
 tmp = dvrr_stack + 40312;
 target_ptr = Libderiv->deriv2_classes[6][6][117];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+41096, dvrr_stack+110490, NULL);
 tmp = dvrr_stack + 41096;
 target_ptr = Libderiv->deriv2_classes[6][7][117];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+110022, dvrr_stack+125396, NULL);
 tmp = dvrr_stack + 110022;
 target_ptr = Libderiv->deriv2_classes[6][8][117];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+111282, dvrr_stack+143972, NULL);
 tmp = dvrr_stack + 111282;
 target_ptr = Libderiv->deriv2_classes[6][9][117];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+143468, dvrr_stack+129176, NULL);
 tmp = dvrr_stack + 143468;
 target_ptr = Libderiv->deriv2_classes[7][5][117];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+144224, dvrr_stack+192564, NULL);
 tmp = dvrr_stack + 144224;
 target_ptr = Libderiv->deriv2_classes[7][6][117];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+192456, dvrr_stack+207081, NULL);
 tmp = dvrr_stack + 192456;
 target_ptr = Libderiv->deriv2_classes[7][7][117];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+193752, dvrr_stack+225688, NULL);
 tmp = dvrr_stack + 193752;
 target_ptr = Libderiv->deriv2_classes[7][8][117];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+225688, dvrr_stack+249892, NULL);
 tmp = dvrr_stack + 225688;
 target_ptr = Libderiv->deriv2_classes[7][9][117];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+227668, dvrr_stack+279400, NULL);
 tmp = dvrr_stack + 227668;
 target_ptr = Libderiv->deriv2_classes[8][5][117];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+228613, dvrr_stack+255832, NULL);
 tmp = dvrr_stack + 228613;
 target_ptr = Libderiv->deriv2_classes[8][6][117];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+145232, dvrr_stack+331460, NULL);
 tmp = dvrr_stack + 145232;
 target_ptr = Libderiv->deriv2_classes[8][7][117];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+249481, dvrr_stack+354375, NULL);
 tmp = dvrr_stack + 249481;
 target_ptr = Libderiv->deriv2_classes[8][8][117];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+251506, dvrr_stack+383640, NULL);
 tmp = dvrr_stack + 251506;
 target_ptr = Libderiv->deriv2_classes[8][9][117];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+229873, dvrr_stack+413161, dvrr_stack+412846);
 tmp = dvrr_stack + 229873;
 target_ptr = Libderiv->deriv2_classes[5][5][107];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+112822, dvrr_stack+414190, dvrr_stack+413749);
 tmp = dvrr_stack + 112822;
 target_ptr = Libderiv->deriv2_classes[5][6][107];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+146852, dvrr_stack+414946, dvrr_stack+413161);
 tmp = dvrr_stack + 146852;
 target_ptr = Libderiv->deriv2_classes[5][7][107];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+147608, dvrr_stack+415891, dvrr_stack+414190);
 tmp = dvrr_stack + 147608;
 target_ptr = Libderiv->deriv2_classes[5][8][107];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+253981, dvrr_stack+417046, dvrr_stack+414946);
 tmp = dvrr_stack + 253981;
 target_ptr = Libderiv->deriv2_classes[5][9][107];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+255136, dvrr_stack+419482, dvrr_stack+419062);
 tmp = dvrr_stack + 255136;
 target_ptr = Libderiv->deriv2_classes[6][5][107];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+255724, dvrr_stack+420854, dvrr_stack+420266);
 tmp = dvrr_stack + 255724;
 target_ptr = Libderiv->deriv2_classes[6][6][107];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+256508, dvrr_stack+421862, dvrr_stack+419482);
 tmp = dvrr_stack + 256508;
 target_ptr = Libderiv->deriv2_classes[6][7][107];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+257516, dvrr_stack+423122, dvrr_stack+420854);
 tmp = dvrr_stack + 257516;
 target_ptr = Libderiv->deriv2_classes[6][8][107];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+433722, dvrr_stack+391065, dvrr_stack+421862);
 tmp = dvrr_stack + 433722;
 target_ptr = Libderiv->deriv2_classes[6][9][107];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+258776, dvrr_stack+360450, dvrr_stack+394533);
 tmp = dvrr_stack + 258776;
 target_ptr = Libderiv->deriv2_classes[7][5][107];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+42104, dvrr_stack+362214, dvrr_stack+361458);
 tmp = dvrr_stack + 42104;
 target_ptr = Libderiv->deriv2_classes[7][6][107];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+435262, dvrr_stack+336320, dvrr_stack+360450);
 tmp = dvrr_stack + 435262;
 target_ptr = Libderiv->deriv2_classes[7][7][107];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+436558, dvrr_stack+311120, dvrr_stack+362214);
 tmp = dvrr_stack + 436558;
 target_ptr = Libderiv->deriv2_classes[7][8][107];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+438178, dvrr_stack+313100, dvrr_stack+336320);
 tmp = dvrr_stack + 438178;
 target_ptr = Libderiv->deriv2_classes[7][9][107];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+440158, dvrr_stack+284260, dvrr_stack+315476);
 tmp = dvrr_stack + 440158;
 target_ptr = Libderiv->deriv2_classes[8][5][107];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+441103, dvrr_stack+286465, dvrr_stack+285520);
 tmp = dvrr_stack + 441103;
 target_ptr = Libderiv->deriv2_classes[8][6][107];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+442363, dvrr_stack+288085, dvrr_stack+284260);
 tmp = dvrr_stack + 442363;
 target_ptr = Libderiv->deriv2_classes[8][7][107];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+443983, dvrr_stack+230548, dvrr_stack+286465);
 tmp = dvrr_stack + 443983;
 target_ptr = Libderiv->deriv2_classes[8][8][107];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+446008, dvrr_stack+166628, dvrr_stack+288085);
 tmp = dvrr_stack + 446008;
 target_ptr = Libderiv->deriv2_classes[8][9][107];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+326019, dvrr_stack+316151, dvrr_stack+395433);
 tmp = dvrr_stack + 326019;
 target_ptr = Libderiv->deriv2_classes[5][5][106];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+448483, dvrr_stack+290110, dvrr_stack+233023);
 tmp = dvrr_stack + 448483;
 target_ptr = Libderiv->deriv2_classes[5][6][106];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+449071, dvrr_stack+210969, dvrr_stack+316151);
 tmp = dvrr_stack + 449071;
 target_ptr = Libderiv->deriv2_classes[5][7][106];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+449827, dvrr_stack+211914, dvrr_stack+290110);
 tmp = dvrr_stack + 449827;
 target_ptr = Libderiv->deriv2_classes[5][8][106];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+450772, dvrr_stack+195588, dvrr_stack+210969);
 tmp = dvrr_stack + 450772;
 target_ptr = Libderiv->deriv2_classes[5][9][106];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+451927, dvrr_stack+169598, dvrr_stack+363510);
 tmp = dvrr_stack + 451927;
 target_ptr = Libderiv->deriv2_classes[6][5][106];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+452515, dvrr_stack+170970, dvrr_stack+170382);
 tmp = dvrr_stack + 452515;
 target_ptr = Libderiv->deriv2_classes[6][6][106];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+453299, dvrr_stack+171978, dvrr_stack+169598);
 tmp = dvrr_stack + 453299;
 target_ptr = Libderiv->deriv2_classes[6][7][106];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+454307, dvrr_stack+173238, dvrr_stack+170970);
 tmp = dvrr_stack + 454307;
 target_ptr = Libderiv->deriv2_classes[6][8][106];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+455567, dvrr_stack+148592, dvrr_stack+171978);
 tmp = dvrr_stack + 455567;
 target_ptr = Libderiv->deriv2_classes[6][9][106];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+457107, dvrr_stack+150440, dvrr_stack+174778);
 tmp = dvrr_stack + 457107;
 target_ptr = Libderiv->deriv2_classes[7][5][106];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+457863, dvrr_stack+80782, dvrr_stack+113514);
 tmp = dvrr_stack + 457863;
 target_ptr = Libderiv->deriv2_classes[7][6][106];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+458871, dvrr_stack+82078, dvrr_stack+150440);
 tmp = dvrr_stack + 458871;
 target_ptr = Libderiv->deriv2_classes[7][7][106];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+460167, dvrr_stack+83698, dvrr_stack+80782);
 tmp = dvrr_stack + 460167;
 target_ptr = Libderiv->deriv2_classes[7][8][106];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+461787, dvrr_stack+501672, dvrr_stack+82078);
 tmp = dvrr_stack + 461787;
 target_ptr = Libderiv->deriv2_classes[7][9][106];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+463767, dvrr_stack+61630, dvrr_stack+114270);
 tmp = dvrr_stack + 463767;
 target_ptr = Libderiv->deriv2_classes[8][5][106];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+464712, dvrr_stack+43207, dvrr_stack+62890);
 tmp = dvrr_stack + 464712;
 target_ptr = Libderiv->deriv2_classes[8][6][106];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+465972, dvrr_stack+504048, dvrr_stack+61630);
 tmp = dvrr_stack + 465972;
 target_ptr = Libderiv->deriv2_classes[8][7][106];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+467592, dvrr_stack+506073, dvrr_stack+43207);
 tmp = dvrr_stack + 467592;
 target_ptr = Libderiv->deriv2_classes[8][8][106];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+469617, dvrr_stack+508548, dvrr_stack+504048);
 tmp = dvrr_stack + 469617;
 target_ptr = Libderiv->deriv2_classes[8][9][106];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+574454, dvrr_stack+411901, dvrr_stack+338615);
 tmp = dvrr_stack + 574454;
 target_ptr = Libderiv->deriv2_classes[5][5][105];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+472092, dvrr_stack+7447, dvrr_stack+12874);
 tmp = dvrr_stack + 472092;
 target_ptr = Libderiv->deriv2_classes[5][6][105];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+472680, dvrr_stack+23872, dvrr_stack+411901);
 tmp = dvrr_stack + 472680;
 target_ptr = Libderiv->deriv2_classes[5][7][105];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+473436, dvrr_stack+37537, dvrr_stack+7447);
 tmp = dvrr_stack + 473436;
 target_ptr = Libderiv->deriv2_classes[5][8][105];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+474381, dvrr_stack+54700, dvrr_stack+23872);
 tmp = dvrr_stack + 474381;
 target_ptr = Libderiv->deriv2_classes[5][9][105];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+475536, dvrr_stack+28408, dvrr_stack+74860);
 tmp = dvrr_stack + 475536;
 target_ptr = Libderiv->deriv2_classes[6][5][105];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+476124, dvrr_stack+92514, dvrr_stack+96942);
 tmp = dvrr_stack + 476124;
 target_ptr = Libderiv->deriv2_classes[6][6][105];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+476908, dvrr_stack+107466, dvrr_stack+28408);
 tmp = dvrr_stack + 476908;
 target_ptr = Libderiv->deriv2_classes[6][7][105];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+477916, dvrr_stack+121616, dvrr_stack+92514);
 tmp = dvrr_stack + 477916;
 target_ptr = Libderiv->deriv2_classes[6][8][105];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+479176, dvrr_stack+139352, dvrr_stack+107466);
 tmp = dvrr_stack + 479176;
 target_ptr = Libderiv->deriv2_classes[6][9][105];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+480716, dvrr_stack+392913, dvrr_stack+161084);
 tmp = dvrr_stack + 480716;
 target_ptr = Libderiv->deriv2_classes[7][5][105];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+481472, dvrr_stack+184212, dvrr_stack+93522);
 tmp = dvrr_stack + 481472;
 target_ptr = Libderiv->deriv2_classes[7][6][105];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+482480, dvrr_stack+203193, dvrr_stack+392913);
 tmp = dvrr_stack + 482480;
 target_ptr = Libderiv->deriv2_classes[7][7][105];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+483776, dvrr_stack+220828, dvrr_stack+184212);
 tmp = dvrr_stack + 483776;
 target_ptr = Libderiv->deriv2_classes[7][8][105];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+485396, dvrr_stack+243952, dvrr_stack+203193);
 tmp = dvrr_stack + 485396;
 target_ptr = Libderiv->deriv2_classes[7][9][105];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+487376, dvrr_stack+282235, dvrr_stack+272272);
 tmp = dvrr_stack + 487376;
 target_ptr = Libderiv->deriv2_classes[8][5][105];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+488321, dvrr_stack+300545, dvrr_stack+307340);
 tmp = dvrr_stack + 488321;
 target_ptr = Libderiv->deriv2_classes[8][6][105];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+489581, dvrr_stack+326600, dvrr_stack+282235);
 tmp = dvrr_stack + 489581;
 target_ptr = Libderiv->deriv2_classes[8][7][105];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+491201, dvrr_stack+348300, dvrr_stack+300545);
 tmp = dvrr_stack + 491201;
 target_ptr = Libderiv->deriv2_classes[8][8][105];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+493226, dvrr_stack+376215, dvrr_stack+326600);
 tmp = dvrr_stack + 493226;
 target_ptr = Libderiv->deriv2_classes[8][9][105];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,21,1,dvrr_stack+30893, dvrr_stack+402760, dvrr_stack+402445);
 tmp = dvrr_stack + 30893;
 target_ptr = Libderiv->deriv2_classes[5][5][104];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+495701, dvrr_stack+403789, dvrr_stack+403348);
 tmp = dvrr_stack + 495701;
 target_ptr = Libderiv->deriv2_classes[5][6][104];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+496289, dvrr_stack+404545, dvrr_stack+402760);
 tmp = dvrr_stack + 496289;
 target_ptr = Libderiv->deriv2_classes[5][7][104];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+497045, dvrr_stack+405490, dvrr_stack+403789);
 tmp = dvrr_stack + 497045;
 target_ptr = Libderiv->deriv2_classes[5][8][104];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+497990, dvrr_stack+406645, dvrr_stack+404545);
 tmp = dvrr_stack + 497990;
 target_ptr = Libderiv->deriv2_classes[5][9][104];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,28,1,dvrr_stack+499145, dvrr_stack+408731, dvrr_stack+408311);
 tmp = dvrr_stack + 499145;
 target_ptr = Libderiv->deriv2_classes[6][5][104];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+499733, dvrr_stack+379185, dvrr_stack+409515);
 tmp = dvrr_stack + 499733;
 target_ptr = Libderiv->deriv2_classes[6][6][104];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+500517, dvrr_stack+380193, dvrr_stack+408731);
 tmp = dvrr_stack + 500517;
 target_ptr = Libderiv->deriv2_classes[6][7][104];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+338930, dvrr_stack+381453, dvrr_stack+379185);
 tmp = dvrr_stack + 338930;
 target_ptr = Libderiv->deriv2_classes[6][8][104];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+340190, dvrr_stack+350775, dvrr_stack+380193);
 tmp = dvrr_stack + 340190;
 target_ptr = Libderiv->deriv2_classes[6][9][104];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,36,1,dvrr_stack+341730, dvrr_stack+352623, dvrr_stack+382993);
 tmp = dvrr_stack + 341730;
 target_ptr = Libderiv->deriv2_classes[7][5][104];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+383533, dvrr_stack+329381, dvrr_stack+328625);
 tmp = dvrr_stack + 383533;
 target_ptr = Libderiv->deriv2_classes[7][6][104];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+384541, dvrr_stack+308285, dvrr_stack+352623);
 tmp = dvrr_stack + 384541;
 target_ptr = Libderiv->deriv2_classes[7][7][104];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+385837, dvrr_stack+272947, dvrr_stack+329381);
 tmp = dvrr_stack + 385837;
 target_ptr = Libderiv->deriv2_classes[7][8][104];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+387457, dvrr_stack+274927, dvrr_stack+308285);
 tmp = dvrr_stack + 387457;
 target_ptr = Libderiv->deriv2_classes[7][9][104];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,45,1,dvrr_stack+389437, dvrr_stack+277303, dvrr_stack+353631);
 tmp = dvrr_stack + 389437;
 target_ptr = Libderiv->deriv2_classes[8][5][104];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+354306, dvrr_stack+246328, dvrr_stack+302165);
 tmp = dvrr_stack + 354306;
 target_ptr = Libderiv->deriv2_classes[8][6][104];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+355566, dvrr_stack+222808, dvrr_stack+277303);
 tmp = dvrr_stack + 355566;
 target_ptr = Libderiv->deriv2_classes[8][7][104];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+357186, dvrr_stack+189540, dvrr_stack+246328);
 tmp = dvrr_stack + 357186;
 target_ptr = Libderiv->deriv2_classes[8][8][104];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+331265, dvrr_stack+161624, dvrr_stack+222808);
 tmp = dvrr_stack + 331265;
 target_ptr = Libderiv->deriv2_classes[8][9][104];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+549214, dvrr_stack+413161, dvrr_stack+412846);
 tmp = dvrr_stack + 549214;
 target_ptr = Libderiv->deriv2_classes[5][5][95];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+390382, dvrr_stack+414190, dvrr_stack+413749);
 tmp = dvrr_stack + 390382;
 target_ptr = Libderiv->deriv2_classes[5][6][95];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+359211, dvrr_stack+414946, dvrr_stack+413161);
 tmp = dvrr_stack + 359211;
 target_ptr = Libderiv->deriv2_classes[5][7][95];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+333740, dvrr_stack+415891, dvrr_stack+414190);
 tmp = dvrr_stack + 333740;
 target_ptr = Libderiv->deriv2_classes[5][8][95];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+334685, dvrr_stack+417046, dvrr_stack+414946);
 tmp = dvrr_stack + 334685;
 target_ptr = Libderiv->deriv2_classes[5][9][95];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+279347, dvrr_stack+419482, dvrr_stack+419062);
 tmp = dvrr_stack + 279347;
 target_ptr = Libderiv->deriv2_classes[6][5][95];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+279935, dvrr_stack+420854, dvrr_stack+420266);
 tmp = dvrr_stack + 279935;
 target_ptr = Libderiv->deriv2_classes[6][6][95];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+280719, dvrr_stack+421862, dvrr_stack+419482);
 tmp = dvrr_stack + 280719;
 target_ptr = Libderiv->deriv2_classes[6][7][95];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+206976, dvrr_stack+423122, dvrr_stack+420854);
 tmp = dvrr_stack + 206976;
 target_ptr = Libderiv->deriv2_classes[6][8][95];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+208236, dvrr_stack+391065, dvrr_stack+421862);
 tmp = dvrr_stack + 208236;
 target_ptr = Libderiv->deriv2_classes[6][9][95];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+209776, dvrr_stack+360450, dvrr_stack+394533);
 tmp = dvrr_stack + 209776;
 target_ptr = Libderiv->deriv2_classes[7][5][95];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+125371, dvrr_stack+362214, dvrr_stack+361458);
 tmp = dvrr_stack + 125371;
 target_ptr = Libderiv->deriv2_classes[7][6][95];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+126379, dvrr_stack+336320, dvrr_stack+360450);
 tmp = dvrr_stack + 126379;
 target_ptr = Libderiv->deriv2_classes[7][7][95];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+127675, dvrr_stack+311120, dvrr_stack+362214);
 tmp = dvrr_stack + 127675;
 target_ptr = Libderiv->deriv2_classes[7][8][95];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+129295, dvrr_stack+313100, dvrr_stack+336320);
 tmp = dvrr_stack + 129295;
 target_ptr = Libderiv->deriv2_classes[7][9][95];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+99150, dvrr_stack+284260, dvrr_stack+315476);
 tmp = dvrr_stack + 99150;
 target_ptr = Libderiv->deriv2_classes[8][5][95];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+100095, dvrr_stack+286465, dvrr_stack+285520);
 tmp = dvrr_stack + 100095;
 target_ptr = Libderiv->deriv2_classes[8][6][95];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+78976, dvrr_stack+288085, dvrr_stack+284260);
 tmp = dvrr_stack + 78976;
 target_ptr = Libderiv->deriv2_classes[8][7][95];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+58066, dvrr_stack+230548, dvrr_stack+286465);
 tmp = dvrr_stack + 58066;
 target_ptr = Libderiv->deriv2_classes[8][8][95];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+395748, dvrr_stack+166628, dvrr_stack+288085);
 tmp = dvrr_stack + 395748;
 target_ptr = Libderiv->deriv2_classes[8][9][95];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+411048, dvrr_stack+316151, dvrr_stack+395433);
 tmp = dvrr_stack + 411048;
 target_ptr = Libderiv->deriv2_classes[5][5][94];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+60091, dvrr_stack+290110, dvrr_stack+233023);
 tmp = dvrr_stack + 60091;
 target_ptr = Libderiv->deriv2_classes[5][6][94];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+60679, dvrr_stack+210969, dvrr_stack+316151);
 tmp = dvrr_stack + 60679;
 target_ptr = Libderiv->deriv2_classes[5][7][94];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+14260, dvrr_stack+211914, dvrr_stack+290110);
 tmp = dvrr_stack + 14260;
 target_ptr = Libderiv->deriv2_classes[5][8][94];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+15205, dvrr_stack+195588, dvrr_stack+210969);
 tmp = dvrr_stack + 15205;
 target_ptr = Libderiv->deriv2_classes[5][9][94];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+398223, dvrr_stack+169598, dvrr_stack+363510);
 tmp = dvrr_stack + 398223;
 target_ptr = Libderiv->deriv2_classes[6][5][94];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+398811, dvrr_stack+170970, dvrr_stack+170382);
 tmp = dvrr_stack + 398811;
 target_ptr = Libderiv->deriv2_classes[6][6][94];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+399595, dvrr_stack+171978, dvrr_stack+169598);
 tmp = dvrr_stack + 399595;
 target_ptr = Libderiv->deriv2_classes[6][7][94];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+400603, dvrr_stack+173238, dvrr_stack+170970);
 tmp = dvrr_stack + 400603;
 target_ptr = Libderiv->deriv2_classes[6][8][94];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+316739, dvrr_stack+148592, dvrr_stack+171978);
 tmp = dvrr_stack + 316739;
 target_ptr = Libderiv->deriv2_classes[6][9][94];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+318279, dvrr_stack+150440, dvrr_stack+174778);
 tmp = dvrr_stack + 318279;
 target_ptr = Libderiv->deriv2_classes[7][5][94];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+290866, dvrr_stack+80782, dvrr_stack+113514);
 tmp = dvrr_stack + 290866;
 target_ptr = Libderiv->deriv2_classes[7][6][94];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+291874, dvrr_stack+82078, dvrr_stack+150440);
 tmp = dvrr_stack + 291874;
 target_ptr = Libderiv->deriv2_classes[7][7][94];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+293170, dvrr_stack+83698, dvrr_stack+80782);
 tmp = dvrr_stack + 293170;
 target_ptr = Libderiv->deriv2_classes[7][8][94];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+294790, dvrr_stack+501672, dvrr_stack+82078);
 tmp = dvrr_stack + 294790;
 target_ptr = Libderiv->deriv2_classes[7][9][94];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+114945, dvrr_stack+61630, dvrr_stack+114270);
 tmp = dvrr_stack + 114945;
 target_ptr = Libderiv->deriv2_classes[8][5][94];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+115890, dvrr_stack+43207, dvrr_stack+62890);
 tmp = dvrr_stack + 115890;
 target_ptr = Libderiv->deriv2_classes[8][6][94];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+85678, dvrr_stack+504048, dvrr_stack+61630);
 tmp = dvrr_stack + 85678;
 target_ptr = Libderiv->deriv2_classes[8][7][94];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+87298, dvrr_stack+506073, dvrr_stack+43207);
 tmp = dvrr_stack + 87298;
 target_ptr = Libderiv->deriv2_classes[8][8][94];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+704998, dvrr_stack+508548, dvrr_stack+504048);
 tmp = dvrr_stack + 704998;
 target_ptr = Libderiv->deriv2_classes[8][9][94];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+11548, dvrr_stack+411901, dvrr_stack+338615);
 tmp = dvrr_stack + 11548;
 target_ptr = Libderiv->deriv2_classes[5][5][93];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+319035, dvrr_stack+7447, dvrr_stack+12874);
 tmp = dvrr_stack + 319035;
 target_ptr = Libderiv->deriv2_classes[5][6][93];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+44827, dvrr_stack+23872, dvrr_stack+411901);
 tmp = dvrr_stack + 44827;
 target_ptr = Libderiv->deriv2_classes[5][7][93];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+45583, dvrr_stack+37537, dvrr_stack+7447);
 tmp = dvrr_stack + 45583;
 target_ptr = Libderiv->deriv2_classes[5][8][93];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+17186, dvrr_stack+54700, dvrr_stack+23872);
 tmp = dvrr_stack + 17186;
 target_ptr = Libderiv->deriv2_classes[5][9][93];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+46528, dvrr_stack+28408, dvrr_stack+74860);
 tmp = dvrr_stack + 46528;
 target_ptr = Libderiv->deriv2_classes[6][5][93];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+707473, dvrr_stack+92514, dvrr_stack+96942);
 tmp = dvrr_stack + 707473;
 target_ptr = Libderiv->deriv2_classes[6][6][93];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+708257, dvrr_stack+107466, dvrr_stack+28408);
 tmp = dvrr_stack + 708257;
 target_ptr = Libderiv->deriv2_classes[6][7][93];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+709265, dvrr_stack+121616, dvrr_stack+92514);
 tmp = dvrr_stack + 709265;
 target_ptr = Libderiv->deriv2_classes[6][8][93];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+710525, dvrr_stack+139352, dvrr_stack+107466);
 tmp = dvrr_stack + 710525;
 target_ptr = Libderiv->deriv2_classes[6][9][93];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+712065, dvrr_stack+392913, dvrr_stack+161084);
 tmp = dvrr_stack + 712065;
 target_ptr = Libderiv->deriv2_classes[7][5][93];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+712821, dvrr_stack+184212, dvrr_stack+93522);
 tmp = dvrr_stack + 712821;
 target_ptr = Libderiv->deriv2_classes[7][6][93];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+713829, dvrr_stack+203193, dvrr_stack+392913);
 tmp = dvrr_stack + 713829;
 target_ptr = Libderiv->deriv2_classes[7][7][93];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+715125, dvrr_stack+220828, dvrr_stack+184212);
 tmp = dvrr_stack + 715125;
 target_ptr = Libderiv->deriv2_classes[7][8][93];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+716745, dvrr_stack+243952, dvrr_stack+203193);
 tmp = dvrr_stack + 716745;
 target_ptr = Libderiv->deriv2_classes[7][9][93];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+718725, dvrr_stack+282235, dvrr_stack+272272);
 tmp = dvrr_stack + 718725;
 target_ptr = Libderiv->deriv2_classes[8][5][93];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+719670, dvrr_stack+300545, dvrr_stack+307340);
 tmp = dvrr_stack + 719670;
 target_ptr = Libderiv->deriv2_classes[8][6][93];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+720930, dvrr_stack+326600, dvrr_stack+282235);
 tmp = dvrr_stack + 720930;
 target_ptr = Libderiv->deriv2_classes[8][7][93];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+722550, dvrr_stack+348300, dvrr_stack+300545);
 tmp = dvrr_stack + 722550;
 target_ptr = Libderiv->deriv2_classes[8][8][93];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+724575, dvrr_stack+376215, dvrr_stack+326600);
 tmp = dvrr_stack + 724575;
 target_ptr = Libderiv->deriv2_classes[8][9][93];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+3285, dvrr_stack+402760, dvrr_stack+402445);
 tmp = dvrr_stack + 3285;
 target_ptr = Libderiv->deriv2_classes[5][5][92];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+727050, dvrr_stack+403789, dvrr_stack+403348);
 tmp = dvrr_stack + 727050;
 target_ptr = Libderiv->deriv2_classes[5][6][92];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+727638, dvrr_stack+404545, dvrr_stack+402760);
 tmp = dvrr_stack + 727638;
 target_ptr = Libderiv->deriv2_classes[5][7][92];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+728394, dvrr_stack+405490, dvrr_stack+403789);
 tmp = dvrr_stack + 728394;
 target_ptr = Libderiv->deriv2_classes[5][8][92];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+729339, dvrr_stack+406645, dvrr_stack+404545);
 tmp = dvrr_stack + 729339;
 target_ptr = Libderiv->deriv2_classes[5][9][92];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+730494, dvrr_stack+408731, dvrr_stack+408311);
 tmp = dvrr_stack + 730494;
 target_ptr = Libderiv->deriv2_classes[6][5][92];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+731082, dvrr_stack+379185, dvrr_stack+409515);
 tmp = dvrr_stack + 731082;
 target_ptr = Libderiv->deriv2_classes[6][6][92];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+731866, dvrr_stack+380193, dvrr_stack+408731);
 tmp = dvrr_stack + 731866;
 target_ptr = Libderiv->deriv2_classes[6][7][92];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+732874, dvrr_stack+381453, dvrr_stack+379185);
 tmp = dvrr_stack + 732874;
 target_ptr = Libderiv->deriv2_classes[6][8][92];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+734134, dvrr_stack+350775, dvrr_stack+380193);
 tmp = dvrr_stack + 734134;
 target_ptr = Libderiv->deriv2_classes[6][9][92];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+735674, dvrr_stack+352623, dvrr_stack+382993);
 tmp = dvrr_stack + 735674;
 target_ptr = Libderiv->deriv2_classes[7][5][92];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+736430, dvrr_stack+329381, dvrr_stack+328625);
 tmp = dvrr_stack + 736430;
 target_ptr = Libderiv->deriv2_classes[7][6][92];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+737438, dvrr_stack+308285, dvrr_stack+352623);
 tmp = dvrr_stack + 737438;
 target_ptr = Libderiv->deriv2_classes[7][7][92];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+738734, dvrr_stack+272947, dvrr_stack+329381);
 tmp = dvrr_stack + 738734;
 target_ptr = Libderiv->deriv2_classes[7][8][92];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+740354, dvrr_stack+274927, dvrr_stack+308285);
 tmp = dvrr_stack + 740354;
 target_ptr = Libderiv->deriv2_classes[7][9][92];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+742334, dvrr_stack+277303, dvrr_stack+353631);
 tmp = dvrr_stack + 742334;
 target_ptr = Libderiv->deriv2_classes[8][5][92];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+743279, dvrr_stack+246328, dvrr_stack+302165);
 tmp = dvrr_stack + 743279;
 target_ptr = Libderiv->deriv2_classes[8][6][92];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+744539, dvrr_stack+222808, dvrr_stack+277303);
 tmp = dvrr_stack + 744539;
 target_ptr = Libderiv->deriv2_classes[8][7][92];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+746159, dvrr_stack+189540, dvrr_stack+246328);
 tmp = dvrr_stack + 746159;
 target_ptr = Libderiv->deriv2_classes[8][8][92];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+748184, dvrr_stack+161624, dvrr_stack+222808);
 tmp = dvrr_stack + 748184;
 target_ptr = Libderiv->deriv2_classes[8][9][92];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,21,1,dvrr_stack+359967, dvrr_stack+330677, dvrr_stack+401865);
 tmp = dvrr_stack + 359967;
 target_ptr = Libderiv->deriv2_classes[5][5][91];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+750659, dvrr_stack+310346, dvrr_stack+309905);
 tmp = dvrr_stack + 750659;
 target_ptr = Libderiv->deriv2_classes[5][6][91];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+751247, dvrr_stack+247948, dvrr_stack+330677);
 tmp = dvrr_stack + 751247;
 target_ptr = Libderiv->deriv2_classes[5][7][91];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+752003, dvrr_stack+204813, dvrr_stack+310346);
 tmp = dvrr_stack + 752003;
 target_ptr = Libderiv->deriv2_classes[5][8][91];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+752948, dvrr_stack+164594, dvrr_stack+247948);
 tmp = dvrr_stack + 752948;
 target_ptr = Libderiv->deriv2_classes[5][9][91];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,28,1,dvrr_stack+754103, dvrr_stack+278563, dvrr_stack+283495);
 tmp = dvrr_stack + 754103;
 target_ptr = Libderiv->deriv2_classes[6][5][91];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+754691, dvrr_stack+205968, dvrr_stack+248893);
 tmp = dvrr_stack + 754691;
 target_ptr = Libderiv->deriv2_classes[6][6][91];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+755475, dvrr_stack+141200, dvrr_stack+278563);
 tmp = dvrr_stack + 755475;
 target_ptr = Libderiv->deriv2_classes[6][7][91];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+756483, dvrr_stack+123156, dvrr_stack+205968);
 tmp = dvrr_stack + 756483;
 target_ptr = Libderiv->deriv2_classes[6][8][91];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+757743, dvrr_stack+75280, dvrr_stack+141200);
 tmp = dvrr_stack + 757743;
 target_ptr = Libderiv->deriv2_classes[6][9][91];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,36,1,dvrr_stack+759283, dvrr_stack+142460, dvrr_stack+224833);
 tmp = dvrr_stack + 759283;
 target_ptr = Libderiv->deriv2_classes[7][5][91];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+760039, dvrr_stack+108726, dvrr_stack+185508);
 tmp = dvrr_stack + 760039;
 target_ptr = Libderiv->deriv2_classes[7][6][91];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+761047, dvrr_stack+97530, dvrr_stack+142460);
 tmp = dvrr_stack + 761047;
 target_ptr = Libderiv->deriv2_classes[7][7][91];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+762343, dvrr_stack+56086, dvrr_stack+108726);
 tmp = dvrr_stack + 762343;
 target_ptr = Libderiv->deriv2_classes[7][8][91];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+763963, dvrr_stack+511518, dvrr_stack+97530);
 tmp = dvrr_stack + 763963;
 target_ptr = Libderiv->deriv2_classes[7][9][91];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,45,1,dvrr_stack+765943, dvrr_stack+77128, dvrr_stack+124696);
 tmp = dvrr_stack + 765943;
 target_ptr = Libderiv->deriv2_classes[8][5][91];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+766888, dvrr_stack+513894, dvrr_stack+38692);
 tmp = dvrr_stack + 766888;
 target_ptr = Libderiv->deriv2_classes[8][6][91];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+768148, dvrr_stack+515514, dvrr_stack+77128);
 tmp = dvrr_stack + 768148;
 target_ptr = Libderiv->deriv2_classes[8][7][91];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+769768, dvrr_stack+517539, dvrr_stack+513894);
 tmp = dvrr_stack + 769768;
 target_ptr = Libderiv->deriv2_classes[8][8][91];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+771793, dvrr_stack+520014, dvrr_stack+515514);
 tmp = dvrr_stack + 771793;
 target_ptr = Libderiv->deriv2_classes[8][9][91];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+774268, dvrr_stack+413161, dvrr_stack+412846);
 tmp = dvrr_stack + 774268;
 target_ptr = Libderiv->deriv2_classes[5][5][83];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+412489, dvrr_stack+414190, dvrr_stack+413749);
 tmp = dvrr_stack + 412489;
 target_ptr = Libderiv->deriv2_classes[5][6][83];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+774709, dvrr_stack+414946, dvrr_stack+413161);
 tmp = dvrr_stack + 774709;
 target_ptr = Libderiv->deriv2_classes[5][7][83];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+775465, dvrr_stack+415891, dvrr_stack+414190);
 tmp = dvrr_stack + 775465;
 target_ptr = Libderiv->deriv2_classes[5][8][83];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+776410, dvrr_stack+417046, dvrr_stack+414946);
 tmp = dvrr_stack + 776410;
 target_ptr = Libderiv->deriv2_classes[5][9][83];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+417046, dvrr_stack+419482, dvrr_stack+419062);
 tmp = dvrr_stack + 417046;
 target_ptr = Libderiv->deriv2_classes[6][5][83];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+417634, dvrr_stack+420854, dvrr_stack+420266);
 tmp = dvrr_stack + 417634;
 target_ptr = Libderiv->deriv2_classes[6][6][83];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+777565, dvrr_stack+421862, dvrr_stack+419482);
 tmp = dvrr_stack + 777565;
 target_ptr = Libderiv->deriv2_classes[6][7][83];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+778573, dvrr_stack+423122, dvrr_stack+420854);
 tmp = dvrr_stack + 778573;
 target_ptr = Libderiv->deriv2_classes[6][8][83];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+779833, dvrr_stack+391065, dvrr_stack+421862);
 tmp = dvrr_stack + 779833;
 target_ptr = Libderiv->deriv2_classes[6][9][83];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+390970, dvrr_stack+360450, dvrr_stack+394533);
 tmp = dvrr_stack + 390970;
 target_ptr = Libderiv->deriv2_classes[7][5][83];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+391726, dvrr_stack+362214, dvrr_stack+361458);
 tmp = dvrr_stack + 391726;
 target_ptr = Libderiv->deriv2_classes[7][6][83];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+781373, dvrr_stack+336320, dvrr_stack+360450);
 tmp = dvrr_stack + 781373;
 target_ptr = Libderiv->deriv2_classes[7][7][83];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+782669, dvrr_stack+311120, dvrr_stack+362214);
 tmp = dvrr_stack + 782669;
 target_ptr = Libderiv->deriv2_classes[7][8][83];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+784289, dvrr_stack+313100, dvrr_stack+336320);
 tmp = dvrr_stack + 784289;
 target_ptr = Libderiv->deriv2_classes[7][9][83];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+313100, dvrr_stack+284260, dvrr_stack+315476);
 tmp = dvrr_stack + 313100;
 target_ptr = Libderiv->deriv2_classes[8][5][83];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+314045, dvrr_stack+286465, dvrr_stack+285520);
 tmp = dvrr_stack + 314045;
 target_ptr = Libderiv->deriv2_classes[8][6][83];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+786269, dvrr_stack+288085, dvrr_stack+284260);
 tmp = dvrr_stack + 786269;
 target_ptr = Libderiv->deriv2_classes[8][7][83];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+787889, dvrr_stack+230548, dvrr_stack+286465);
 tmp = dvrr_stack + 787889;
 target_ptr = Libderiv->deriv2_classes[8][8][83];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+789914, dvrr_stack+166628, dvrr_stack+288085);
 tmp = dvrr_stack + 789914;
 target_ptr = Libderiv->deriv2_classes[8][9][83];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+315305, dvrr_stack+316151, dvrr_stack+395433);
 tmp = dvrr_stack + 315305;
 target_ptr = Libderiv->deriv2_classes[5][5][82];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+792389, dvrr_stack+290110, dvrr_stack+233023);
 tmp = dvrr_stack + 792389;
 target_ptr = Libderiv->deriv2_classes[5][6][82];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+394509, dvrr_stack+210969, dvrr_stack+316151);
 tmp = dvrr_stack + 394509;
 target_ptr = Libderiv->deriv2_classes[5][7][82];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+166400, dvrr_stack+211914, dvrr_stack+290110);
 tmp = dvrr_stack + 166400;
 target_ptr = Libderiv->deriv2_classes[5][8][82];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+167345, dvrr_stack+195588, dvrr_stack+210969);
 tmp = dvrr_stack + 167345;
 target_ptr = Libderiv->deriv2_classes[5][9][82];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+195372, dvrr_stack+169598, dvrr_stack+363510);
 tmp = dvrr_stack + 195372;
 target_ptr = Libderiv->deriv2_classes[6][5][82];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+195960, dvrr_stack+170970, dvrr_stack+170382);
 tmp = dvrr_stack + 195960;
 target_ptr = Libderiv->deriv2_classes[6][6][82];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+168500, dvrr_stack+171978, dvrr_stack+169598);
 tmp = dvrr_stack + 168500;
 target_ptr = Libderiv->deriv2_classes[6][7][82];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+792977, dvrr_stack+173238, dvrr_stack+170970);
 tmp = dvrr_stack + 792977;
 target_ptr = Libderiv->deriv2_classes[6][8][82];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+794237, dvrr_stack+148592, dvrr_stack+171978);
 tmp = dvrr_stack + 794237;
 target_ptr = Libderiv->deriv2_classes[6][9][82];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+148553, dvrr_stack+150440, dvrr_stack+174778);
 tmp = dvrr_stack + 148553;
 target_ptr = Libderiv->deriv2_classes[7][5][82];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+149309, dvrr_stack+80782, dvrr_stack+113514);
 tmp = dvrr_stack + 149309;
 target_ptr = Libderiv->deriv2_classes[7][6][82];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+795777, dvrr_stack+82078, dvrr_stack+150440);
 tmp = dvrr_stack + 795777;
 target_ptr = Libderiv->deriv2_classes[7][7][82];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+797073, dvrr_stack+83698, dvrr_stack+80782);
 tmp = dvrr_stack + 797073;
 target_ptr = Libderiv->deriv2_classes[7][8][82];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+798693, dvrr_stack+501672, dvrr_stack+82078);
 tmp = dvrr_stack + 798693;
 target_ptr = Libderiv->deriv2_classes[7][9][82];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+501525, dvrr_stack+61630, dvrr_stack+114270);
 tmp = dvrr_stack + 501525;
 target_ptr = Libderiv->deriv2_classes[8][5][82];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+502470, dvrr_stack+43207, dvrr_stack+62890);
 tmp = dvrr_stack + 502470;
 target_ptr = Libderiv->deriv2_classes[8][6][82];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+800673, dvrr_stack+504048, dvrr_stack+61630);
 tmp = dvrr_stack + 800673;
 target_ptr = Libderiv->deriv2_classes[8][7][82];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+802293, dvrr_stack+506073, dvrr_stack+43207);
 tmp = dvrr_stack + 802293;
 target_ptr = Libderiv->deriv2_classes[8][8][82];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+804318, dvrr_stack+508548, dvrr_stack+504048);
 tmp = dvrr_stack + 804318;
 target_ptr = Libderiv->deriv2_classes[8][9][82];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+508548, dvrr_stack+411901, dvrr_stack+338615);
 tmp = dvrr_stack + 508548;
 target_ptr = Libderiv->deriv2_classes[5][5][81];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+508989, dvrr_stack+7447, dvrr_stack+12874);
 tmp = dvrr_stack + 508989;
 target_ptr = Libderiv->deriv2_classes[5][6][81];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+509577, dvrr_stack+23872, dvrr_stack+411901);
 tmp = dvrr_stack + 509577;
 target_ptr = Libderiv->deriv2_classes[5][7][81];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+510333, dvrr_stack+37537, dvrr_stack+7447);
 tmp = dvrr_stack + 510333;
 target_ptr = Libderiv->deriv2_classes[5][8][81];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+806793, dvrr_stack+54700, dvrr_stack+23872);
 tmp = dvrr_stack + 806793;
 target_ptr = Libderiv->deriv2_classes[5][9][81];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+54700, dvrr_stack+28408, dvrr_stack+74860);
 tmp = dvrr_stack + 54700;
 target_ptr = Libderiv->deriv2_classes[6][5][81];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+55288, dvrr_stack+92514, dvrr_stack+96942);
 tmp = dvrr_stack + 55288;
 target_ptr = Libderiv->deriv2_classes[6][6][81];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+807948, dvrr_stack+107466, dvrr_stack+28408);
 tmp = dvrr_stack + 807948;
 target_ptr = Libderiv->deriv2_classes[6][7][81];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+808956, dvrr_stack+121616, dvrr_stack+92514);
 tmp = dvrr_stack + 808956;
 target_ptr = Libderiv->deriv2_classes[6][8][81];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+810216, dvrr_stack+139352, dvrr_stack+107466);
 tmp = dvrr_stack + 810216;
 target_ptr = Libderiv->deriv2_classes[6][9][81];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+139352, dvrr_stack+392913, dvrr_stack+161084);
 tmp = dvrr_stack + 139352;
 target_ptr = Libderiv->deriv2_classes[7][5][81];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+140108, dvrr_stack+184212, dvrr_stack+93522);
 tmp = dvrr_stack + 140108;
 target_ptr = Libderiv->deriv2_classes[7][6][81];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+811756, dvrr_stack+203193, dvrr_stack+392913);
 tmp = dvrr_stack + 811756;
 target_ptr = Libderiv->deriv2_classes[7][7][81];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+813052, dvrr_stack+220828, dvrr_stack+184212);
 tmp = dvrr_stack + 813052;
 target_ptr = Libderiv->deriv2_classes[7][8][81];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+814672, dvrr_stack+243952, dvrr_stack+203193);
 tmp = dvrr_stack + 814672;
 target_ptr = Libderiv->deriv2_classes[7][9][81];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+243935, dvrr_stack+282235, dvrr_stack+272272);
 tmp = dvrr_stack + 243935;
 target_ptr = Libderiv->deriv2_classes[8][5][81];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+244880, dvrr_stack+300545, dvrr_stack+307340);
 tmp = dvrr_stack + 244880;
 target_ptr = Libderiv->deriv2_classes[8][6][81];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+816652, dvrr_stack+326600, dvrr_stack+282235);
 tmp = dvrr_stack + 816652;
 target_ptr = Libderiv->deriv2_classes[8][7][81];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+818272, dvrr_stack+348300, dvrr_stack+300545);
 tmp = dvrr_stack + 818272;
 target_ptr = Libderiv->deriv2_classes[8][8][81];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+820297, dvrr_stack+376215, dvrr_stack+326600);
 tmp = dvrr_stack + 820297;
 target_ptr = Libderiv->deriv2_classes[8][9][81];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+114270, dvrr_stack+402760, dvrr_stack+402445);
 tmp = dvrr_stack + 114270;
 target_ptr = Libderiv->deriv2_classes[5][5][80];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+375910, dvrr_stack+403789, dvrr_stack+403348);
 tmp = dvrr_stack + 375910;
 target_ptr = Libderiv->deriv2_classes[5][6][80];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+376498, dvrr_stack+404545, dvrr_stack+402760);
 tmp = dvrr_stack + 376498;
 target_ptr = Libderiv->deriv2_classes[5][7][80];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+377254, dvrr_stack+405490, dvrr_stack+403789);
 tmp = dvrr_stack + 377254;
 target_ptr = Libderiv->deriv2_classes[5][8][80];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+822772, dvrr_stack+406645, dvrr_stack+404545);
 tmp = dvrr_stack + 822772;
 target_ptr = Libderiv->deriv2_classes[5][9][80];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+406645, dvrr_stack+408731, dvrr_stack+408311);
 tmp = dvrr_stack + 406645;
 target_ptr = Libderiv->deriv2_classes[6][5][80];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+407233, dvrr_stack+379185, dvrr_stack+409515);
 tmp = dvrr_stack + 407233;
 target_ptr = Libderiv->deriv2_classes[6][6][80];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+160586, dvrr_stack+380193, dvrr_stack+408731);
 tmp = dvrr_stack + 160586;
 target_ptr = Libderiv->deriv2_classes[6][7][80];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+823927, dvrr_stack+381453, dvrr_stack+379185);
 tmp = dvrr_stack + 823927;
 target_ptr = Libderiv->deriv2_classes[6][8][80];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+825187, dvrr_stack+350775, dvrr_stack+380193);
 tmp = dvrr_stack + 825187;
 target_ptr = Libderiv->deriv2_classes[6][9][80];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+350775, dvrr_stack+352623, dvrr_stack+382993);
 tmp = dvrr_stack + 350775;
 target_ptr = Libderiv->deriv2_classes[7][5][80];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+351531, dvrr_stack+329381, dvrr_stack+328625);
 tmp = dvrr_stack + 351531;
 target_ptr = Libderiv->deriv2_classes[7][6][80];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+826727, dvrr_stack+308285, dvrr_stack+352623);
 tmp = dvrr_stack + 826727;
 target_ptr = Libderiv->deriv2_classes[7][7][80];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+828023, dvrr_stack+272947, dvrr_stack+329381);
 tmp = dvrr_stack + 828023;
 target_ptr = Libderiv->deriv2_classes[7][8][80];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+829643, dvrr_stack+274927, dvrr_stack+308285);
 tmp = dvrr_stack + 829643;
 target_ptr = Libderiv->deriv2_classes[7][9][80];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+274927, dvrr_stack+277303, dvrr_stack+353631);
 tmp = dvrr_stack + 274927;
 target_ptr = Libderiv->deriv2_classes[8][5][80];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+275872, dvrr_stack+246328, dvrr_stack+302165);
 tmp = dvrr_stack + 275872;
 target_ptr = Libderiv->deriv2_classes[8][6][80];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+831623, dvrr_stack+222808, dvrr_stack+277303);
 tmp = dvrr_stack + 831623;
 target_ptr = Libderiv->deriv2_classes[8][7][80];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+833243, dvrr_stack+189540, dvrr_stack+246328);
 tmp = dvrr_stack + 833243;
 target_ptr = Libderiv->deriv2_classes[8][8][80];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+835268, dvrr_stack+161624, dvrr_stack+222808);
 tmp = dvrr_stack + 835268;
 target_ptr = Libderiv->deriv2_classes[8][9][80];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+353631, dvrr_stack+330677, dvrr_stack+401865);
 tmp = dvrr_stack + 353631;
 target_ptr = Libderiv->deriv2_classes[5][5][79];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+408017, dvrr_stack+310346, dvrr_stack+309905);
 tmp = dvrr_stack + 408017;
 target_ptr = Libderiv->deriv2_classes[5][6][79];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+378199, dvrr_stack+247948, dvrr_stack+330677);
 tmp = dvrr_stack + 378199;
 target_ptr = Libderiv->deriv2_classes[5][7][79];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+161594, dvrr_stack+204813, dvrr_stack+310346);
 tmp = dvrr_stack + 161594;
 target_ptr = Libderiv->deriv2_classes[5][8][79];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+162539, dvrr_stack+164594, dvrr_stack+247948);
 tmp = dvrr_stack + 162539;
 target_ptr = Libderiv->deriv2_classes[5][9][79];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+401863, dvrr_stack+278563, dvrr_stack+283495);
 tmp = dvrr_stack + 401863;
 target_ptr = Libderiv->deriv2_classes[6][5][79];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+163694, dvrr_stack+205968, dvrr_stack+248893);
 tmp = dvrr_stack + 163694;
 target_ptr = Libderiv->deriv2_classes[6][6][79];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+164478, dvrr_stack+141200, dvrr_stack+278563);
 tmp = dvrr_stack + 164478;
 target_ptr = Libderiv->deriv2_classes[6][7][79];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+837743, dvrr_stack+123156, dvrr_stack+205968);
 tmp = dvrr_stack + 837743;
 target_ptr = Libderiv->deriv2_classes[6][8][79];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+839003, dvrr_stack+75280, dvrr_stack+141200);
 tmp = dvrr_stack + 839003;
 target_ptr = Libderiv->deriv2_classes[6][9][79];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+283495, dvrr_stack+142460, dvrr_stack+224833);
 tmp = dvrr_stack + 283495;
 target_ptr = Libderiv->deriv2_classes[7][5][79];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+74342, dvrr_stack+108726, dvrr_stack+185508);
 tmp = dvrr_stack + 74342;
 target_ptr = Libderiv->deriv2_classes[7][6][79];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+75350, dvrr_stack+97530, dvrr_stack+142460);
 tmp = dvrr_stack + 75350;
 target_ptr = Libderiv->deriv2_classes[7][7][79];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+840543, dvrr_stack+56086, dvrr_stack+108726);
 tmp = dvrr_stack + 840543;
 target_ptr = Libderiv->deriv2_classes[7][8][79];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+842163, dvrr_stack+511518, dvrr_stack+97530);
 tmp = dvrr_stack + 842163;
 target_ptr = Libderiv->deriv2_classes[7][9][79];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+511278, dvrr_stack+77128, dvrr_stack+124696);
 tmp = dvrr_stack + 511278;
 target_ptr = Libderiv->deriv2_classes[8][5][79];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+512223, dvrr_stack+513894, dvrr_stack+38692);
 tmp = dvrr_stack + 512223;
 target_ptr = Libderiv->deriv2_classes[8][6][79];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+844143, dvrr_stack+515514, dvrr_stack+77128);
 tmp = dvrr_stack + 844143;
 target_ptr = Libderiv->deriv2_classes[8][7][79];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+845763, dvrr_stack+517539, dvrr_stack+513894);
 tmp = dvrr_stack + 845763;
 target_ptr = Libderiv->deriv2_classes[8][8][79];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+847788, dvrr_stack+520014, dvrr_stack+515514);
 tmp = dvrr_stack + 847788;
 target_ptr = Libderiv->deriv2_classes[8][9][79];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,21,1,dvrr_stack+520014, dvrr_stack+393921, dvrr_stack+225373);
 tmp = dvrr_stack + 520014;
 target_ptr = Libderiv->deriv2_classes[5][5][78];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+520455, dvrr_stack+24817, dvrr_stack+192015);
 tmp = dvrr_stack + 520455;
 target_ptr = Libderiv->deriv2_classes[5][6][78];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+521043, dvrr_stack+13315, dvrr_stack+393921);
 tmp = dvrr_stack + 521043;
 target_ptr = Libderiv->deriv2_classes[5][7][78];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+521799, dvrr_stack+101646, dvrr_stack+24817);
 tmp = dvrr_stack + 521799;
 target_ptr = Libderiv->deriv2_classes[5][8][78];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+850263, dvrr_stack+53314, dvrr_stack+13315);
 tmp = dvrr_stack + 850263;
 target_ptr = Libderiv->deriv2_classes[5][9][78];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,28,1,dvrr_stack+124696, dvrr_stack+16402, dvrr_stack+165980);
 tmp = dvrr_stack + 124696;
 target_ptr = Libderiv->deriv2_classes[6][5][78];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+224833, dvrr_stack+50176, dvrr_stack+78388);
 tmp = dvrr_stack + 224833;
 target_ptr = Libderiv->deriv2_classes[6][6][78];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+53188, dvrr_stack+73082, dvrr_stack+16402);
 tmp = dvrr_stack + 53188;
 target_ptr = Libderiv->deriv2_classes[6][7][78];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+851418, dvrr_stack+522984, dvrr_stack+50176);
 tmp = dvrr_stack + 851418;
 target_ptr = Libderiv->deriv2_classes[6][8][78];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+852678, dvrr_stack+137504, dvrr_stack+73082);
 tmp = dvrr_stack + 852678;
 target_ptr = Libderiv->deriv2_classes[6][9][78];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,36,1,dvrr_stack+137268, dvrr_stack+158822, dvrr_stack+418432);
 tmp = dvrr_stack + 137268;
 target_ptr = Libderiv->deriv2_classes[7][5][78];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+418418, dvrr_stack+524524, dvrr_stack+159830);
 tmp = dvrr_stack + 418418;
 target_ptr = Libderiv->deriv2_classes[7][6][78];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+138024, dvrr_stack+525820, dvrr_stack+158822);
 tmp = dvrr_stack + 138024;
 target_ptr = Libderiv->deriv2_classes[7][7][78];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+854218, dvrr_stack+527440, dvrr_stack+524524);
 tmp = dvrr_stack + 854218;
 target_ptr = Libderiv->deriv2_classes[7][8][78];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+855838, dvrr_stack+529420, dvrr_stack+525820);
 tmp = dvrr_stack + 855838;
 target_ptr = Libderiv->deriv2_classes[7][9][78];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,45,1,dvrr_stack+529420, dvrr_stack+269323, dvrr_stack+39637);
 tmp = dvrr_stack + 529420;
 target_ptr = Libderiv->deriv2_classes[8][5][78];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+530365, dvrr_stack+270583, dvrr_stack+410103);
 tmp = dvrr_stack + 530365;
 target_ptr = Libderiv->deriv2_classes[8][6][78];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+857818, dvrr_stack+531796, dvrr_stack+269323);
 tmp = dvrr_stack + 857818;
 target_ptr = Libderiv->deriv2_classes[8][7][78];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+859438, dvrr_stack+533821, dvrr_stack+270583);
 tmp = dvrr_stack + 859438;
 target_ptr = Libderiv->deriv2_classes[8][8][78];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+861463, dvrr_stack+536296, dvrr_stack+531796);
 tmp = dvrr_stack + 861463;
 target_ptr = Libderiv->deriv2_classes[8][9][78];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,21,dvrr_stack+536296, dvrr_stack+420266, dvrr_stack+411586);
 tmp = dvrr_stack + 536296;
 target_ptr = Libderiv->deriv2_classes[5][5][35];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,28,dvrr_stack+536737, dvrr_stack+419482, dvrr_stack+157517);
 tmp = dvrr_stack + 536737;
 target_ptr = Libderiv->deriv2_classes[5][6][35];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,36,dvrr_stack+537325, dvrr_stack+420854, dvrr_stack+157937);
 tmp = dvrr_stack + 537325;
 target_ptr = Libderiv->deriv2_classes[5][7][35];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,45,dvrr_stack+538081, dvrr_stack+421862, dvrr_stack+31432);
 tmp = dvrr_stack + 538081;
 target_ptr = Libderiv->deriv2_classes[5][8][35];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_h(Data,55,dvrr_stack+863938, dvrr_stack+423122, dvrr_stack+545386);
 tmp = dvrr_stack + 863938;
 target_ptr = Libderiv->deriv2_classes[5][9][35];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,21,dvrr_stack+39637, dvrr_stack+361458, dvrr_stack+413749);
 tmp = dvrr_stack + 39637;
 target_ptr = Libderiv->deriv2_classes[6][5][35];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,28,dvrr_stack+865093, dvrr_stack+360450, dvrr_stack+413161);
 tmp = dvrr_stack + 865093;
 target_ptr = Libderiv->deriv2_classes[6][6][35];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,36,dvrr_stack+865877, dvrr_stack+362214, dvrr_stack+414190);
 tmp = dvrr_stack + 865877;
 target_ptr = Libderiv->deriv2_classes[6][7][35];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,45,dvrr_stack+866885, dvrr_stack+336320, dvrr_stack+414946);
 tmp = dvrr_stack + 866885;
 target_ptr = Libderiv->deriv2_classes[6][8][35];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_i(Data,55,dvrr_stack+868145, dvrr_stack+311120, dvrr_stack+415891);
 tmp = dvrr_stack + 868145;
 target_ptr = Libderiv->deriv2_classes[6][9][35];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,21,dvrr_stack+165486, dvrr_stack+285520, dvrr_stack+420266);
 tmp = dvrr_stack + 165486;
 target_ptr = Libderiv->deriv2_classes[7][5][35];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,28,dvrr_stack+869685, dvrr_stack+284260, dvrr_stack+419482);
 tmp = dvrr_stack + 869685;
 target_ptr = Libderiv->deriv2_classes[7][6][35];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,36,dvrr_stack+870693, dvrr_stack+286465, dvrr_stack+420854);
 tmp = dvrr_stack + 870693;
 target_ptr = Libderiv->deriv2_classes[7][7][35];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,45,dvrr_stack+871989, dvrr_stack+288085, dvrr_stack+421862);
 tmp = dvrr_stack + 871989;
 target_ptr = Libderiv->deriv2_classes[7][8][35];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_k(Data,55,dvrr_stack+873609, dvrr_stack+230548, dvrr_stack+423122);
 tmp = dvrr_stack + 873609;
 target_ptr = Libderiv->deriv2_classes[7][9][35];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,21,dvrr_stack+875589, dvrr_stack+181832, dvrr_stack+361458);
 tmp = dvrr_stack + 875589;
 target_ptr = Libderiv->deriv2_classes[8][5][35];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,28,dvrr_stack+876534, dvrr_stack+186480, dvrr_stack+360450);
 tmp = dvrr_stack + 876534;
 target_ptr = Libderiv->deriv2_classes[8][6][35];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,36,dvrr_stack+877794, dvrr_stack+199368, dvrr_stack+362214);
 tmp = dvrr_stack + 877794;
 target_ptr = Libderiv->deriv2_classes[8][7][35];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,45,dvrr_stack+879414, dvrr_stack+216153, dvrr_stack+336320);
 tmp = dvrr_stack + 879414;
 target_ptr = Libderiv->deriv2_classes[8][8][35];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_l(Data,55,dvrr_stack+881439, dvrr_stack+368955, dvrr_stack+311120);
 tmp = dvrr_stack + 881439;
 target_ptr = Libderiv->deriv2_classes[8][9][35];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+382993, dvrr_stack+170382, dvrr_stack+49861);
 tmp = dvrr_stack + 382993;
 target_ptr = Libderiv->deriv2_classes[5][5][34];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+272203, dvrr_stack+169598, dvrr_stack+371980);
 tmp = dvrr_stack + 272203;
 target_ptr = Libderiv->deriv2_classes[5][6][34];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+883914, dvrr_stack+170970, dvrr_stack+372400);
 tmp = dvrr_stack + 883914;
 target_ptr = Libderiv->deriv2_classes[5][7][34];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+884670, dvrr_stack+171978, dvrr_stack+372940);
 tmp = dvrr_stack + 884670;
 target_ptr = Libderiv->deriv2_classes[5][8][34];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+885615, dvrr_stack+173238, dvrr_stack+373615);
 tmp = dvrr_stack + 885615;
 target_ptr = Libderiv->deriv2_classes[5][9][34];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+886770, dvrr_stack+113514, dvrr_stack+233023);
 tmp = dvrr_stack + 886770;
 target_ptr = Libderiv->deriv2_classes[6][5][34];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+887358, dvrr_stack+150440, dvrr_stack+316151);
 tmp = dvrr_stack + 887358;
 target_ptr = Libderiv->deriv2_classes[6][6][34];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+888142, dvrr_stack+80782, dvrr_stack+290110);
 tmp = dvrr_stack + 888142;
 target_ptr = Libderiv->deriv2_classes[6][7][34];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+889150, dvrr_stack+82078, dvrr_stack+210969);
 tmp = dvrr_stack + 889150;
 target_ptr = Libderiv->deriv2_classes[6][8][34];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+890410, dvrr_stack+83698, dvrr_stack+211914);
 tmp = dvrr_stack + 890410;
 target_ptr = Libderiv->deriv2_classes[6][9][34];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+891950, dvrr_stack+62890, dvrr_stack+170382);
 tmp = dvrr_stack + 891950;
 target_ptr = Libderiv->deriv2_classes[7][5][34];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+892706, dvrr_stack+61630, dvrr_stack+169598);
 tmp = dvrr_stack + 892706;
 target_ptr = Libderiv->deriv2_classes[7][6][34];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+893714, dvrr_stack+43207, dvrr_stack+170970);
 tmp = dvrr_stack + 893714;
 target_ptr = Libderiv->deriv2_classes[7][7][34];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+895010, dvrr_stack+504048, dvrr_stack+171978);
 tmp = dvrr_stack + 895010;
 target_ptr = Libderiv->deriv2_classes[7][8][34];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+896630, dvrr_stack+506073, dvrr_stack+173238);
 tmp = dvrr_stack + 896630;
 target_ptr = Libderiv->deriv2_classes[7][9][34];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+898610, dvrr_stack+374440, dvrr_stack+113514);
 tmp = dvrr_stack + 898610;
 target_ptr = Libderiv->deriv2_classes[8][5][34];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+899555, dvrr_stack+134468, dvrr_stack+150440);
 tmp = dvrr_stack + 899555;
 target_ptr = Libderiv->deriv2_classes[8][6][34];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+900815, dvrr_stack+237352, dvrr_stack+80782);
 tmp = dvrr_stack + 900815;
 target_ptr = Libderiv->deriv2_classes[8][7][34];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+902435, dvrr_stack+239332, dvrr_stack+82078);
 tmp = dvrr_stack + 902435;
 target_ptr = Libderiv->deriv2_classes[8][8][34];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+904460, dvrr_stack+614953, dvrr_stack+83698);
 tmp = dvrr_stack + 904460;
 target_ptr = Libderiv->deriv2_classes[8][9][34];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+174778, dvrr_stack+96942, dvrr_stack+375595);
 tmp = dvrr_stack + 174778;
 target_ptr = Libderiv->deriv2_classes[5][5][33];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+906935, dvrr_stack+28408, dvrr_stack+155312);
 tmp = dvrr_stack + 906935;
 target_ptr = Libderiv->deriv2_classes[5][6][33];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+907523, dvrr_stack+92514, dvrr_stack+155732);
 tmp = dvrr_stack + 907523;
 target_ptr = Libderiv->deriv2_classes[5][7][33];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+908279, dvrr_stack+107466, dvrr_stack+539266);
 tmp = dvrr_stack + 908279;
 target_ptr = Libderiv->deriv2_classes[5][8][33];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+909224, dvrr_stack+121616, dvrr_stack+539941);
 tmp = dvrr_stack + 909224;
 target_ptr = Libderiv->deriv2_classes[5][9][33];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+910379, dvrr_stack+93522, dvrr_stack+12874);
 tmp = dvrr_stack + 910379;
 target_ptr = Libderiv->deriv2_classes[6][5][33];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+910967, dvrr_stack+392913, dvrr_stack+411901);
 tmp = dvrr_stack + 910967;
 target_ptr = Libderiv->deriv2_classes[6][6][33];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+911751, dvrr_stack+184212, dvrr_stack+7447);
 tmp = dvrr_stack + 911751;
 target_ptr = Libderiv->deriv2_classes[6][7][33];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+912759, dvrr_stack+203193, dvrr_stack+23872);
 tmp = dvrr_stack + 912759;
 target_ptr = Libderiv->deriv2_classes[6][8][33];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+914019, dvrr_stack+220828, dvrr_stack+37537);
 tmp = dvrr_stack + 914019;
 target_ptr = Libderiv->deriv2_classes[6][9][33];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+915559, dvrr_stack+307340, dvrr_stack+96942);
 tmp = dvrr_stack + 915559;
 target_ptr = Libderiv->deriv2_classes[7][5][33];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+916315, dvrr_stack+282235, dvrr_stack+28408);
 tmp = dvrr_stack + 916315;
 target_ptr = Libderiv->deriv2_classes[7][6][33];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+917323, dvrr_stack+300545, dvrr_stack+92514);
 tmp = dvrr_stack + 917323;
 target_ptr = Libderiv->deriv2_classes[7][7][33];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+918619, dvrr_stack+326600, dvrr_stack+107466);
 tmp = dvrr_stack + 918619;
 target_ptr = Libderiv->deriv2_classes[7][8][33];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+920239, dvrr_stack+348300, dvrr_stack+121616);
 tmp = dvrr_stack + 920239;
 target_ptr = Libderiv->deriv2_classes[7][9][33];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+922219, dvrr_stack+540766, dvrr_stack+93522);
 tmp = dvrr_stack + 922219;
 target_ptr = Libderiv->deriv2_classes[8][5][33];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+923164, dvrr_stack+554138, dvrr_stack+392913);
 tmp = dvrr_stack + 923164;
 target_ptr = Libderiv->deriv2_classes[8][6][33];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+924424, dvrr_stack+564263, dvrr_stack+184212);
 tmp = dvrr_stack + 924424;
 target_ptr = Libderiv->deriv2_classes[8][7][33];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+926044, dvrr_stack+577883, dvrr_stack+203193);
 tmp = dvrr_stack + 926044;
 target_ptr = Libderiv->deriv2_classes[8][8][33];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+928069, dvrr_stack+594823, dvrr_stack+220828);
 tmp = dvrr_stack + 928069;
 target_ptr = Libderiv->deriv2_classes[8][9][33];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+54196, dvrr_stack+409515, dvrr_stack+605878);
 tmp = dvrr_stack + 54196;
 target_ptr = Libderiv->deriv2_classes[5][5][32];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+930544, dvrr_stack+408731, dvrr_stack+606193);
 tmp = dvrr_stack + 930544;
 target_ptr = Libderiv->deriv2_classes[5][6][32];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+931132, dvrr_stack+379185, dvrr_stack+606613);
 tmp = dvrr_stack + 931132;
 target_ptr = Libderiv->deriv2_classes[5][7][32];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+931888, dvrr_stack+380193, dvrr_stack+607153);
 tmp = dvrr_stack + 931888;
 target_ptr = Libderiv->deriv2_classes[5][8][32];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+932833, dvrr_stack+381453, dvrr_stack+607828);
 tmp = dvrr_stack + 932833;
 target_ptr = Libderiv->deriv2_classes[5][9][32];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+933988, dvrr_stack+328625, dvrr_stack+403348);
 tmp = dvrr_stack + 933988;
 target_ptr = Libderiv->deriv2_classes[6][5][32];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+934576, dvrr_stack+352623, dvrr_stack+402760);
 tmp = dvrr_stack + 934576;
 target_ptr = Libderiv->deriv2_classes[6][6][32];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+935360, dvrr_stack+329381, dvrr_stack+403789);
 tmp = dvrr_stack + 935360;
 target_ptr = Libderiv->deriv2_classes[6][7][32];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+936368, dvrr_stack+308285, dvrr_stack+404545);
 tmp = dvrr_stack + 936368;
 target_ptr = Libderiv->deriv2_classes[6][8][32];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+937628, dvrr_stack+272947, dvrr_stack+405490);
 tmp = dvrr_stack + 937628;
 target_ptr = Libderiv->deriv2_classes[6][9][32];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+939168, dvrr_stack+302165, dvrr_stack+409515);
 tmp = dvrr_stack + 939168;
 target_ptr = Libderiv->deriv2_classes[7][5][32];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+939924, dvrr_stack+277303, dvrr_stack+408731);
 tmp = dvrr_stack + 939924;
 target_ptr = Libderiv->deriv2_classes[7][6][32];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+940932, dvrr_stack+246328, dvrr_stack+379185);
 tmp = dvrr_stack + 940932;
 target_ptr = Libderiv->deriv2_classes[7][7][32];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+942228, dvrr_stack+222808, dvrr_stack+380193);
 tmp = dvrr_stack + 942228;
 target_ptr = Libderiv->deriv2_classes[7][8][32];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+943848, dvrr_stack+189540, dvrr_stack+381453);
 tmp = dvrr_stack + 943848;
 target_ptr = Libderiv->deriv2_classes[7][9][32];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+945828, dvrr_stack+610144, dvrr_stack+328625);
 tmp = dvrr_stack + 945828;
 target_ptr = Libderiv->deriv2_classes[8][5][32];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+946773, dvrr_stack+611299, dvrr_stack+352623);
 tmp = dvrr_stack + 946773;
 target_ptr = Libderiv->deriv2_classes[8][6][32];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+948033, dvrr_stack+612839, dvrr_stack+329381);
 tmp = dvrr_stack + 948033;
 target_ptr = Libderiv->deriv2_classes[8][7][32];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+949653, dvrr_stack+597848, dvrr_stack+308285);
 tmp = dvrr_stack + 949653;
 target_ptr = Libderiv->deriv2_classes[8][8][32];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+951678, dvrr_stack+580358, dvrr_stack+272947);
 tmp = dvrr_stack + 951678;
 target_ptr = Libderiv->deriv2_classes[8][9][32];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+954153, dvrr_stack+248893, dvrr_stack+337940);
 tmp = dvrr_stack + 954153;
 target_ptr = Libderiv->deriv2_classes[5][5][31];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+954594, dvrr_stack+278563, dvrr_stack+608653);
 tmp = dvrr_stack + 954594;
 target_ptr = Libderiv->deriv2_classes[5][6][31];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+955182, dvrr_stack+205968, dvrr_stack+424662);
 tmp = dvrr_stack + 955182;
 target_ptr = Libderiv->deriv2_classes[5][7][31];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+955938, dvrr_stack+141200, dvrr_stack+600323);
 tmp = dvrr_stack + 955938;
 target_ptr = Libderiv->deriv2_classes[5][8][31];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+956883, dvrr_stack+123156, dvrr_stack+600998);
 tmp = dvrr_stack + 956883;
 target_ptr = Libderiv->deriv2_classes[5][9][31];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+958038, dvrr_stack+185508, dvrr_stack+309905);
 tmp = dvrr_stack + 958038;
 target_ptr = Libderiv->deriv2_classes[6][5][31];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+958626, dvrr_stack+142460, dvrr_stack+330677);
 tmp = dvrr_stack + 958626;
 target_ptr = Libderiv->deriv2_classes[6][6][31];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+959410, dvrr_stack+108726, dvrr_stack+310346);
 tmp = dvrr_stack + 959410;
 target_ptr = Libderiv->deriv2_classes[6][7][31];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+960418, dvrr_stack+97530, dvrr_stack+247948);
 tmp = dvrr_stack + 960418;
 target_ptr = Libderiv->deriv2_classes[6][8][31];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+961678, dvrr_stack+56086, dvrr_stack+204813);
 tmp = dvrr_stack + 961678;
 target_ptr = Libderiv->deriv2_classes[6][9][31];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+963218, dvrr_stack+38692, dvrr_stack+248893);
 tmp = dvrr_stack + 963218;
 target_ptr = Libderiv->deriv2_classes[7][5][31];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+963974, dvrr_stack+77128, dvrr_stack+278563);
 tmp = dvrr_stack + 963974;
 target_ptr = Libderiv->deriv2_classes[7][6][31];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+964982, dvrr_stack+513894, dvrr_stack+205968);
 tmp = dvrr_stack + 964982;
 target_ptr = Libderiv->deriv2_classes[7][7][31];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+966278, dvrr_stack+515514, dvrr_stack+141200);
 tmp = dvrr_stack + 966278;
 target_ptr = Libderiv->deriv2_classes[7][8][31];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+967898, dvrr_stack+517539, dvrr_stack+123156);
 tmp = dvrr_stack + 967898;
 target_ptr = Libderiv->deriv2_classes[7][9][31];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+969878, dvrr_stack+566243, dvrr_stack+185508);
 tmp = dvrr_stack + 969878;
 target_ptr = Libderiv->deriv2_classes[8][5][31];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+970823, dvrr_stack+555678, dvrr_stack+142460);
 tmp = dvrr_stack + 970823;
 target_ptr = Libderiv->deriv2_classes[8][6][31];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+972083, dvrr_stack+541921, dvrr_stack+108726);
 tmp = dvrr_stack + 972083;
 target_ptr = Libderiv->deriv2_classes[8][7][31];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+973703, dvrr_stack+617978, dvrr_stack+97530);
 tmp = dvrr_stack + 973703;
 target_ptr = Libderiv->deriv2_classes[8][8][31];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+975728, dvrr_stack+620453, dvrr_stack+56086);
 tmp = dvrr_stack + 975728;
 target_ptr = Libderiv->deriv2_classes[8][9][31];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+978203, dvrr_stack+78388, dvrr_stack+338255);
 tmp = dvrr_stack + 978203;
 target_ptr = Libderiv->deriv2_classes[5][5][30];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+978644, dvrr_stack+16402, dvrr_stack+425202);
 tmp = dvrr_stack + 978644;
 target_ptr = Libderiv->deriv2_classes[5][6][30];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+979232, dvrr_stack+50176, dvrr_stack+567398);
 tmp = dvrr_stack + 979232;
 target_ptr = Libderiv->deriv2_classes[5][7][30];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+979988, dvrr_stack+73082, dvrr_stack+567938);
 tmp = dvrr_stack + 979988;
 target_ptr = Libderiv->deriv2_classes[5][8][30];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+980933, dvrr_stack+522984, dvrr_stack+543901);
 tmp = dvrr_stack + 980933;
 target_ptr = Libderiv->deriv2_classes[5][9][30];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+982088, dvrr_stack+159830, dvrr_stack+192015);
 tmp = dvrr_stack + 982088;
 target_ptr = Libderiv->deriv2_classes[6][5][30];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+982676, dvrr_stack+158822, dvrr_stack+393921);
 tmp = dvrr_stack + 982676;
 target_ptr = Libderiv->deriv2_classes[6][6][30];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+983460, dvrr_stack+524524, dvrr_stack+24817);
 tmp = dvrr_stack + 983460;
 target_ptr = Libderiv->deriv2_classes[6][7][30];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+984468, dvrr_stack+525820, dvrr_stack+13315);
 tmp = dvrr_stack + 984468;
 target_ptr = Libderiv->deriv2_classes[6][8][30];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+985728, dvrr_stack+527440, dvrr_stack+101646);
 tmp = dvrr_stack + 985728;
 target_ptr = Libderiv->deriv2_classes[6][9][30];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+987268, dvrr_stack+410103, dvrr_stack+78388);
 tmp = dvrr_stack + 987268;
 target_ptr = Libderiv->deriv2_classes[7][5][30];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+988024, dvrr_stack+269323, dvrr_stack+16402);
 tmp = dvrr_stack + 988024;
 target_ptr = Libderiv->deriv2_classes[7][6][30];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+989032, dvrr_stack+270583, dvrr_stack+50176);
 tmp = dvrr_stack + 989032;
 target_ptr = Libderiv->deriv2_classes[7][7][30];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+990328, dvrr_stack+531796, dvrr_stack+73082);
 tmp = dvrr_stack + 990328;
 target_ptr = Libderiv->deriv2_classes[7][8][30];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+991948, dvrr_stack+533821, dvrr_stack+522984);
 tmp = dvrr_stack + 991948;
 target_ptr = Libderiv->deriv2_classes[7][9][30];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+993928, dvrr_stack+156272, dvrr_stack+159830);
 tmp = dvrr_stack + 993928;
 target_ptr = Libderiv->deriv2_classes[8][5][30];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+994873, dvrr_stack+241807, dvrr_stack+158822);
 tmp = dvrr_stack + 994873;
 target_ptr = Libderiv->deriv2_classes[8][6][30];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+996133, dvrr_stack+623478, dvrr_stack+524524);
 tmp = dvrr_stack + 996133;
 target_ptr = Libderiv->deriv2_classes[8][7][30];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+997753, dvrr_stack+625458, dvrr_stack+525820);
 tmp = dvrr_stack + 997753;
 target_ptr = Libderiv->deriv2_classes[8][8][30];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+999778, dvrr_stack+627933, dvrr_stack+527440);
 tmp = dvrr_stack + 999778;
 target_ptr = Libderiv->deriv2_classes[8][9][30];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,21,dvrr_stack+1002253, dvrr_stack+609388, dvrr_stack+609073);
 tmp = dvrr_stack + 1002253;
 target_ptr = Libderiv->deriv2_classes[5][5][26];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+1002694, dvrr_stack+602243, dvrr_stack+601823);
 tmp = dvrr_stack + 1002694;
 target_ptr = Libderiv->deriv2_classes[5][6][26];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+1003282, dvrr_stack+603567, dvrr_stack+603027);
 tmp = dvrr_stack + 1003282;
 target_ptr = Libderiv->deriv2_classes[5][7][26];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+1004038, dvrr_stack+136008, dvrr_stack+604575);
 tmp = dvrr_stack + 1004038;
 target_ptr = Libderiv->deriv2_classes[5][8][26];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+1004983, dvrr_stack+630958, dvrr_stack+20857);
 tmp = dvrr_stack + 1004983;
 target_ptr = Libderiv->deriv2_classes[5][9][26];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,21,dvrr_stack+1006138, dvrr_stack+33852, dvrr_stack+605250);
 tmp = dvrr_stack + 1006138;
 target_ptr = Libderiv->deriv2_classes[6][5][26];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+1006726, dvrr_stack+52180, dvrr_stack+544726);
 tmp = dvrr_stack + 1006726;
 target_ptr = Libderiv->deriv2_classes[6][6][26];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+1007510, dvrr_stack+632498, dvrr_stack+10792);
 tmp = dvrr_stack + 1007510;
 target_ptr = Libderiv->deriv2_classes[6][7][26];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+1008518, dvrr_stack+634739, dvrr_stack+633794);
 tmp = dvrr_stack + 1008518;
 target_ptr = Libderiv->deriv2_classes[6][8][26];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+1009778, dvrr_stack+637514, dvrr_stack+636359);
 tmp = dvrr_stack + 1009778;
 target_ptr = Libderiv->deriv2_classes[6][9][26];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,21,dvrr_stack+1011318, dvrr_stack+639494, dvrr_stack+609388);
 tmp = dvrr_stack + 1011318;
 target_ptr = Libderiv->deriv2_classes[7][5][26];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+1012074, dvrr_stack+640439, dvrr_stack+602243);
 tmp = dvrr_stack + 1012074;
 target_ptr = Libderiv->deriv2_classes[7][6][26];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+1013082, dvrr_stack+641699, dvrr_stack+603567);
 tmp = dvrr_stack + 1013082;
 target_ptr = Libderiv->deriv2_classes[7][7][26];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+1014378, dvrr_stack+643319, dvrr_stack+136008);
 tmp = dvrr_stack + 1014378;
 target_ptr = Libderiv->deriv2_classes[7][8][26];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+1015998, dvrr_stack+645344, dvrr_stack+630958);
 tmp = dvrr_stack + 1015998;
 target_ptr = Libderiv->deriv2_classes[7][9][26];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,21,dvrr_stack+1017978, dvrr_stack+546799, dvrr_stack+33852);
 tmp = dvrr_stack + 1017978;
 target_ptr = Libderiv->deriv2_classes[8][5][26];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+1018923, dvrr_stack+549742, dvrr_stack+52180);
 tmp = dvrr_stack + 1018923;
 target_ptr = Libderiv->deriv2_classes[8][6][26];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+1020183, dvrr_stack+70742, dvrr_stack+632498);
 tmp = dvrr_stack + 1020183;
 target_ptr = Libderiv->deriv2_classes[8][7][26];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+1021803, dvrr_stack+557218, dvrr_stack+634739);
 tmp = dvrr_stack + 1021803;
 target_ptr = Libderiv->deriv2_classes[8][8][26];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+1023828, dvrr_stack+342800, dvrr_stack+637514);
 tmp = dvrr_stack + 1023828;
 target_ptr = Libderiv->deriv2_classes[8][9][26];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,21,dvrr_stack+1026303, dvrr_stack+420266, dvrr_stack+411586);
 tmp = dvrr_stack + 1026303;
 target_ptr = Libderiv->deriv2_classes[5][5][23];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,28,dvrr_stack+1026744, dvrr_stack+419482, dvrr_stack+157517);
 tmp = dvrr_stack + 1026744;
 target_ptr = Libderiv->deriv2_classes[5][6][23];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,36,dvrr_stack+1027332, dvrr_stack+420854, dvrr_stack+157937);
 tmp = dvrr_stack + 1027332;
 target_ptr = Libderiv->deriv2_classes[5][7][23];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,45,dvrr_stack+1028088, dvrr_stack+421862, dvrr_stack+31432);
 tmp = dvrr_stack + 1028088;
 target_ptr = Libderiv->deriv2_classes[5][8][23];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_h(Data,55,dvrr_stack+1029033, dvrr_stack+423122, dvrr_stack+545386);
 tmp = dvrr_stack + 1029033;
 target_ptr = Libderiv->deriv2_classes[5][9][23];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,21,dvrr_stack+1030188, dvrr_stack+361458, dvrr_stack+413749);
 tmp = dvrr_stack + 1030188;
 target_ptr = Libderiv->deriv2_classes[6][5][23];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,28,dvrr_stack+1030776, dvrr_stack+360450, dvrr_stack+413161);
 tmp = dvrr_stack + 1030776;
 target_ptr = Libderiv->deriv2_classes[6][6][23];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,36,dvrr_stack+1031560, dvrr_stack+362214, dvrr_stack+414190);
 tmp = dvrr_stack + 1031560;
 target_ptr = Libderiv->deriv2_classes[6][7][23];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,45,dvrr_stack+1032568, dvrr_stack+336320, dvrr_stack+414946);
 tmp = dvrr_stack + 1032568;
 target_ptr = Libderiv->deriv2_classes[6][8][23];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_i(Data,55,dvrr_stack+1033828, dvrr_stack+311120, dvrr_stack+415891);
 tmp = dvrr_stack + 1033828;
 target_ptr = Libderiv->deriv2_classes[6][9][23];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,21,dvrr_stack+1035368, dvrr_stack+285520, dvrr_stack+420266);
 tmp = dvrr_stack + 1035368;
 target_ptr = Libderiv->deriv2_classes[7][5][23];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,28,dvrr_stack+1036124, dvrr_stack+284260, dvrr_stack+419482);
 tmp = dvrr_stack + 1036124;
 target_ptr = Libderiv->deriv2_classes[7][6][23];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,36,dvrr_stack+1037132, dvrr_stack+286465, dvrr_stack+420854);
 tmp = dvrr_stack + 1037132;
 target_ptr = Libderiv->deriv2_classes[7][7][23];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,45,dvrr_stack+1038428, dvrr_stack+288085, dvrr_stack+421862);
 tmp = dvrr_stack + 1038428;
 target_ptr = Libderiv->deriv2_classes[7][8][23];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_k(Data,55,dvrr_stack+1040048, dvrr_stack+230548, dvrr_stack+423122);
 tmp = dvrr_stack + 1040048;
 target_ptr = Libderiv->deriv2_classes[7][9][23];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,21,dvrr_stack+1042028, dvrr_stack+181832, dvrr_stack+361458);
 tmp = dvrr_stack + 1042028;
 target_ptr = Libderiv->deriv2_classes[8][5][23];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,28,dvrr_stack+1042973, dvrr_stack+186480, dvrr_stack+360450);
 tmp = dvrr_stack + 1042973;
 target_ptr = Libderiv->deriv2_classes[8][6][23];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,36,dvrr_stack+1044233, dvrr_stack+199368, dvrr_stack+362214);
 tmp = dvrr_stack + 1044233;
 target_ptr = Libderiv->deriv2_classes[8][7][23];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,45,dvrr_stack+1045853, dvrr_stack+216153, dvrr_stack+336320);
 tmp = dvrr_stack + 1045853;
 target_ptr = Libderiv->deriv2_classes[8][8][23];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_l(Data,55,dvrr_stack+1047878, dvrr_stack+368955, dvrr_stack+311120);
 tmp = dvrr_stack + 1047878;
 target_ptr = Libderiv->deriv2_classes[8][9][23];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+1050353, dvrr_stack+170382, dvrr_stack+49861);
 tmp = dvrr_stack + 1050353;
 target_ptr = Libderiv->deriv2_classes[5][5][22];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+1050794, dvrr_stack+169598, dvrr_stack+371980);
 tmp = dvrr_stack + 1050794;
 target_ptr = Libderiv->deriv2_classes[5][6][22];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+1051382, dvrr_stack+170970, dvrr_stack+372400);
 tmp = dvrr_stack + 1051382;
 target_ptr = Libderiv->deriv2_classes[5][7][22];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+1052138, dvrr_stack+171978, dvrr_stack+372940);
 tmp = dvrr_stack + 1052138;
 target_ptr = Libderiv->deriv2_classes[5][8][22];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+1053083, dvrr_stack+173238, dvrr_stack+373615);
 tmp = dvrr_stack + 1053083;
 target_ptr = Libderiv->deriv2_classes[5][9][22];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+1054238, dvrr_stack+113514, dvrr_stack+233023);
 tmp = dvrr_stack + 1054238;
 target_ptr = Libderiv->deriv2_classes[6][5][22];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+1054826, dvrr_stack+150440, dvrr_stack+316151);
 tmp = dvrr_stack + 1054826;
 target_ptr = Libderiv->deriv2_classes[6][6][22];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+1055610, dvrr_stack+80782, dvrr_stack+290110);
 tmp = dvrr_stack + 1055610;
 target_ptr = Libderiv->deriv2_classes[6][7][22];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+1056618, dvrr_stack+82078, dvrr_stack+210969);
 tmp = dvrr_stack + 1056618;
 target_ptr = Libderiv->deriv2_classes[6][8][22];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+1057878, dvrr_stack+83698, dvrr_stack+211914);
 tmp = dvrr_stack + 1057878;
 target_ptr = Libderiv->deriv2_classes[6][9][22];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+1059418, dvrr_stack+62890, dvrr_stack+170382);
 tmp = dvrr_stack + 1059418;
 target_ptr = Libderiv->deriv2_classes[7][5][22];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+1060174, dvrr_stack+61630, dvrr_stack+169598);
 tmp = dvrr_stack + 1060174;
 target_ptr = Libderiv->deriv2_classes[7][6][22];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+1061182, dvrr_stack+43207, dvrr_stack+170970);
 tmp = dvrr_stack + 1061182;
 target_ptr = Libderiv->deriv2_classes[7][7][22];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+1062478, dvrr_stack+504048, dvrr_stack+171978);
 tmp = dvrr_stack + 1062478;
 target_ptr = Libderiv->deriv2_classes[7][8][22];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+1064098, dvrr_stack+506073, dvrr_stack+173238);
 tmp = dvrr_stack + 1064098;
 target_ptr = Libderiv->deriv2_classes[7][9][22];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+1066078, dvrr_stack+374440, dvrr_stack+113514);
 tmp = dvrr_stack + 1066078;
 target_ptr = Libderiv->deriv2_classes[8][5][22];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+1067023, dvrr_stack+134468, dvrr_stack+150440);
 tmp = dvrr_stack + 1067023;
 target_ptr = Libderiv->deriv2_classes[8][6][22];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+1068283, dvrr_stack+237352, dvrr_stack+80782);
 tmp = dvrr_stack + 1068283;
 target_ptr = Libderiv->deriv2_classes[8][7][22];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+1069903, dvrr_stack+239332, dvrr_stack+82078);
 tmp = dvrr_stack + 1069903;
 target_ptr = Libderiv->deriv2_classes[8][8][22];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+1071928, dvrr_stack+614953, dvrr_stack+83698);
 tmp = dvrr_stack + 1071928;
 target_ptr = Libderiv->deriv2_classes[8][9][22];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+1074403, dvrr_stack+96942, dvrr_stack+375595);
 tmp = dvrr_stack + 1074403;
 target_ptr = Libderiv->deriv2_classes[5][5][21];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+1074844, dvrr_stack+28408, dvrr_stack+155312);
 tmp = dvrr_stack + 1074844;
 target_ptr = Libderiv->deriv2_classes[5][6][21];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+1075432, dvrr_stack+92514, dvrr_stack+155732);
 tmp = dvrr_stack + 1075432;
 target_ptr = Libderiv->deriv2_classes[5][7][21];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+1076188, dvrr_stack+107466, dvrr_stack+539266);
 tmp = dvrr_stack + 1076188;
 target_ptr = Libderiv->deriv2_classes[5][8][21];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+1077133, dvrr_stack+121616, dvrr_stack+539941);
 tmp = dvrr_stack + 1077133;
 target_ptr = Libderiv->deriv2_classes[5][9][21];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+1078288, dvrr_stack+93522, dvrr_stack+12874);
 tmp = dvrr_stack + 1078288;
 target_ptr = Libderiv->deriv2_classes[6][5][21];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+1078876, dvrr_stack+392913, dvrr_stack+411901);
 tmp = dvrr_stack + 1078876;
 target_ptr = Libderiv->deriv2_classes[6][6][21];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+1079660, dvrr_stack+184212, dvrr_stack+7447);
 tmp = dvrr_stack + 1079660;
 target_ptr = Libderiv->deriv2_classes[6][7][21];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+1080668, dvrr_stack+203193, dvrr_stack+23872);
 tmp = dvrr_stack + 1080668;
 target_ptr = Libderiv->deriv2_classes[6][8][21];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+1081928, dvrr_stack+220828, dvrr_stack+37537);
 tmp = dvrr_stack + 1081928;
 target_ptr = Libderiv->deriv2_classes[6][9][21];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+1083468, dvrr_stack+307340, dvrr_stack+96942);
 tmp = dvrr_stack + 1083468;
 target_ptr = Libderiv->deriv2_classes[7][5][21];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+1084224, dvrr_stack+282235, dvrr_stack+28408);
 tmp = dvrr_stack + 1084224;
 target_ptr = Libderiv->deriv2_classes[7][6][21];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+1085232, dvrr_stack+300545, dvrr_stack+92514);
 tmp = dvrr_stack + 1085232;
 target_ptr = Libderiv->deriv2_classes[7][7][21];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+1086528, dvrr_stack+326600, dvrr_stack+107466);
 tmp = dvrr_stack + 1086528;
 target_ptr = Libderiv->deriv2_classes[7][8][21];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+1088148, dvrr_stack+348300, dvrr_stack+121616);
 tmp = dvrr_stack + 1088148;
 target_ptr = Libderiv->deriv2_classes[7][9][21];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+1090128, dvrr_stack+540766, dvrr_stack+93522);
 tmp = dvrr_stack + 1090128;
 target_ptr = Libderiv->deriv2_classes[8][5][21];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+1091073, dvrr_stack+554138, dvrr_stack+392913);
 tmp = dvrr_stack + 1091073;
 target_ptr = Libderiv->deriv2_classes[8][6][21];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+1092333, dvrr_stack+564263, dvrr_stack+184212);
 tmp = dvrr_stack + 1092333;
 target_ptr = Libderiv->deriv2_classes[8][7][21];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+1093953, dvrr_stack+577883, dvrr_stack+203193);
 tmp = dvrr_stack + 1093953;
 target_ptr = Libderiv->deriv2_classes[8][8][21];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+1095978, dvrr_stack+594823, dvrr_stack+220828);
 tmp = dvrr_stack + 1095978;
 target_ptr = Libderiv->deriv2_classes[8][9][21];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+1098453, dvrr_stack+409515, dvrr_stack+605878);
 tmp = dvrr_stack + 1098453;
 target_ptr = Libderiv->deriv2_classes[5][5][20];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+1098894, dvrr_stack+408731, dvrr_stack+606193);
 tmp = dvrr_stack + 1098894;
 target_ptr = Libderiv->deriv2_classes[5][6][20];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+1099482, dvrr_stack+379185, dvrr_stack+606613);
 tmp = dvrr_stack + 1099482;
 target_ptr = Libderiv->deriv2_classes[5][7][20];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+1100238, dvrr_stack+380193, dvrr_stack+607153);
 tmp = dvrr_stack + 1100238;
 target_ptr = Libderiv->deriv2_classes[5][8][20];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+1101183, dvrr_stack+381453, dvrr_stack+607828);
 tmp = dvrr_stack + 1101183;
 target_ptr = Libderiv->deriv2_classes[5][9][20];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+1102338, dvrr_stack+328625, dvrr_stack+403348);
 tmp = dvrr_stack + 1102338;
 target_ptr = Libderiv->deriv2_classes[6][5][20];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+1102926, dvrr_stack+352623, dvrr_stack+402760);
 tmp = dvrr_stack + 1102926;
 target_ptr = Libderiv->deriv2_classes[6][6][20];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+1103710, dvrr_stack+329381, dvrr_stack+403789);
 tmp = dvrr_stack + 1103710;
 target_ptr = Libderiv->deriv2_classes[6][7][20];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+1104718, dvrr_stack+308285, dvrr_stack+404545);
 tmp = dvrr_stack + 1104718;
 target_ptr = Libderiv->deriv2_classes[6][8][20];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+1105978, dvrr_stack+272947, dvrr_stack+405490);
 tmp = dvrr_stack + 1105978;
 target_ptr = Libderiv->deriv2_classes[6][9][20];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+1107518, dvrr_stack+302165, dvrr_stack+409515);
 tmp = dvrr_stack + 1107518;
 target_ptr = Libderiv->deriv2_classes[7][5][20];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+1108274, dvrr_stack+277303, dvrr_stack+408731);
 tmp = dvrr_stack + 1108274;
 target_ptr = Libderiv->deriv2_classes[7][6][20];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+1109282, dvrr_stack+246328, dvrr_stack+379185);
 tmp = dvrr_stack + 1109282;
 target_ptr = Libderiv->deriv2_classes[7][7][20];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+1110578, dvrr_stack+222808, dvrr_stack+380193);
 tmp = dvrr_stack + 1110578;
 target_ptr = Libderiv->deriv2_classes[7][8][20];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+1112198, dvrr_stack+189540, dvrr_stack+381453);
 tmp = dvrr_stack + 1112198;
 target_ptr = Libderiv->deriv2_classes[7][9][20];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+1114178, dvrr_stack+610144, dvrr_stack+328625);
 tmp = dvrr_stack + 1114178;
 target_ptr = Libderiv->deriv2_classes[8][5][20];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+1115123, dvrr_stack+611299, dvrr_stack+352623);
 tmp = dvrr_stack + 1115123;
 target_ptr = Libderiv->deriv2_classes[8][6][20];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+1116383, dvrr_stack+612839, dvrr_stack+329381);
 tmp = dvrr_stack + 1116383;
 target_ptr = Libderiv->deriv2_classes[8][7][20];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+1118003, dvrr_stack+597848, dvrr_stack+308285);
 tmp = dvrr_stack + 1118003;
 target_ptr = Libderiv->deriv2_classes[8][8][20];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+1120028, dvrr_stack+580358, dvrr_stack+272947);
 tmp = dvrr_stack + 1120028;
 target_ptr = Libderiv->deriv2_classes[8][9][20];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+1122503, dvrr_stack+248893, dvrr_stack+337940);
 tmp = dvrr_stack + 1122503;
 target_ptr = Libderiv->deriv2_classes[5][5][19];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+1122944, dvrr_stack+278563, dvrr_stack+608653);
 tmp = dvrr_stack + 1122944;
 target_ptr = Libderiv->deriv2_classes[5][6][19];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+1123532, dvrr_stack+205968, dvrr_stack+424662);
 tmp = dvrr_stack + 1123532;
 target_ptr = Libderiv->deriv2_classes[5][7][19];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+1124288, dvrr_stack+141200, dvrr_stack+600323);
 tmp = dvrr_stack + 1124288;
 target_ptr = Libderiv->deriv2_classes[5][8][19];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+1125233, dvrr_stack+123156, dvrr_stack+600998);
 tmp = dvrr_stack + 1125233;
 target_ptr = Libderiv->deriv2_classes[5][9][19];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+1126388, dvrr_stack+185508, dvrr_stack+309905);
 tmp = dvrr_stack + 1126388;
 target_ptr = Libderiv->deriv2_classes[6][5][19];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+1126976, dvrr_stack+142460, dvrr_stack+330677);
 tmp = dvrr_stack + 1126976;
 target_ptr = Libderiv->deriv2_classes[6][6][19];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+1127760, dvrr_stack+108726, dvrr_stack+310346);
 tmp = dvrr_stack + 1127760;
 target_ptr = Libderiv->deriv2_classes[6][7][19];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+1128768, dvrr_stack+97530, dvrr_stack+247948);
 tmp = dvrr_stack + 1128768;
 target_ptr = Libderiv->deriv2_classes[6][8][19];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+1130028, dvrr_stack+56086, dvrr_stack+204813);
 tmp = dvrr_stack + 1130028;
 target_ptr = Libderiv->deriv2_classes[6][9][19];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+1131568, dvrr_stack+38692, dvrr_stack+248893);
 tmp = dvrr_stack + 1131568;
 target_ptr = Libderiv->deriv2_classes[7][5][19];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+1132324, dvrr_stack+77128, dvrr_stack+278563);
 tmp = dvrr_stack + 1132324;
 target_ptr = Libderiv->deriv2_classes[7][6][19];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+1133332, dvrr_stack+513894, dvrr_stack+205968);
 tmp = dvrr_stack + 1133332;
 target_ptr = Libderiv->deriv2_classes[7][7][19];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+1134628, dvrr_stack+515514, dvrr_stack+141200);
 tmp = dvrr_stack + 1134628;
 target_ptr = Libderiv->deriv2_classes[7][8][19];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+1136248, dvrr_stack+517539, dvrr_stack+123156);
 tmp = dvrr_stack + 1136248;
 target_ptr = Libderiv->deriv2_classes[7][9][19];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+1138228, dvrr_stack+566243, dvrr_stack+185508);
 tmp = dvrr_stack + 1138228;
 target_ptr = Libderiv->deriv2_classes[8][5][19];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+1139173, dvrr_stack+555678, dvrr_stack+142460);
 tmp = dvrr_stack + 1139173;
 target_ptr = Libderiv->deriv2_classes[8][6][19];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+1140433, dvrr_stack+541921, dvrr_stack+108726);
 tmp = dvrr_stack + 1140433;
 target_ptr = Libderiv->deriv2_classes[8][7][19];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+1142053, dvrr_stack+617978, dvrr_stack+97530);
 tmp = dvrr_stack + 1142053;
 target_ptr = Libderiv->deriv2_classes[8][8][19];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+1144078, dvrr_stack+620453, dvrr_stack+56086);
 tmp = dvrr_stack + 1144078;
 target_ptr = Libderiv->deriv2_classes[8][9][19];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+1146553, dvrr_stack+78388, dvrr_stack+338255);
 tmp = dvrr_stack + 1146553;
 target_ptr = Libderiv->deriv2_classes[5][5][18];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+1146994, dvrr_stack+16402, dvrr_stack+425202);
 tmp = dvrr_stack + 1146994;
 target_ptr = Libderiv->deriv2_classes[5][6][18];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+1147582, dvrr_stack+50176, dvrr_stack+567398);
 tmp = dvrr_stack + 1147582;
 target_ptr = Libderiv->deriv2_classes[5][7][18];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+1148338, dvrr_stack+73082, dvrr_stack+567938);
 tmp = dvrr_stack + 1148338;
 target_ptr = Libderiv->deriv2_classes[5][8][18];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+1149283, dvrr_stack+522984, dvrr_stack+543901);
 tmp = dvrr_stack + 1149283;
 target_ptr = Libderiv->deriv2_classes[5][9][18];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+1150438, dvrr_stack+159830, dvrr_stack+192015);
 tmp = dvrr_stack + 1150438;
 target_ptr = Libderiv->deriv2_classes[6][5][18];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+1151026, dvrr_stack+158822, dvrr_stack+393921);
 tmp = dvrr_stack + 1151026;
 target_ptr = Libderiv->deriv2_classes[6][6][18];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+1151810, dvrr_stack+524524, dvrr_stack+24817);
 tmp = dvrr_stack + 1151810;
 target_ptr = Libderiv->deriv2_classes[6][7][18];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+1152818, dvrr_stack+525820, dvrr_stack+13315);
 tmp = dvrr_stack + 1152818;
 target_ptr = Libderiv->deriv2_classes[6][8][18];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+1154078, dvrr_stack+527440, dvrr_stack+101646);
 tmp = dvrr_stack + 1154078;
 target_ptr = Libderiv->deriv2_classes[6][9][18];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+1155618, dvrr_stack+410103, dvrr_stack+78388);
 tmp = dvrr_stack + 1155618;
 target_ptr = Libderiv->deriv2_classes[7][5][18];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+1156374, dvrr_stack+269323, dvrr_stack+16402);
 tmp = dvrr_stack + 1156374;
 target_ptr = Libderiv->deriv2_classes[7][6][18];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+1157382, dvrr_stack+270583, dvrr_stack+50176);
 tmp = dvrr_stack + 1157382;
 target_ptr = Libderiv->deriv2_classes[7][7][18];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+1158678, dvrr_stack+531796, dvrr_stack+73082);
 tmp = dvrr_stack + 1158678;
 target_ptr = Libderiv->deriv2_classes[7][8][18];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+1160298, dvrr_stack+533821, dvrr_stack+522984);
 tmp = dvrr_stack + 1160298;
 target_ptr = Libderiv->deriv2_classes[7][9][18];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+1162278, dvrr_stack+156272, dvrr_stack+159830);
 tmp = dvrr_stack + 1162278;
 target_ptr = Libderiv->deriv2_classes[8][5][18];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+1163223, dvrr_stack+241807, dvrr_stack+158822);
 tmp = dvrr_stack + 1163223;
 target_ptr = Libderiv->deriv2_classes[8][6][18];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+1164483, dvrr_stack+623478, dvrr_stack+524524);
 tmp = dvrr_stack + 1164483;
 target_ptr = Libderiv->deriv2_classes[8][7][18];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+1166103, dvrr_stack+625458, dvrr_stack+525820);
 tmp = dvrr_stack + 1166103;
 target_ptr = Libderiv->deriv2_classes[8][8][18];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+1168128, dvrr_stack+627933, dvrr_stack+527440);
 tmp = dvrr_stack + 1168128;
 target_ptr = Libderiv->deriv2_classes[8][9][18];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+335840, dvrr_stack+609388, dvrr_stack+609073);
 tmp = dvrr_stack + 335840;
 target_ptr = Libderiv->deriv2_classes[5][5][14];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+1170603, dvrr_stack+602243, dvrr_stack+601823);
 tmp = dvrr_stack + 1170603;
 target_ptr = Libderiv->deriv2_classes[5][6][14];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+1171191, dvrr_stack+603567, dvrr_stack+603027);
 tmp = dvrr_stack + 1171191;
 target_ptr = Libderiv->deriv2_classes[5][7][14];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+1171947, dvrr_stack+136008, dvrr_stack+604575);
 tmp = dvrr_stack + 1171947;
 target_ptr = Libderiv->deriv2_classes[5][8][14];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+1172892, dvrr_stack+630958, dvrr_stack+20857);
 tmp = dvrr_stack + 1172892;
 target_ptr = Libderiv->deriv2_classes[5][9][14];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+1174047, dvrr_stack+33852, dvrr_stack+605250);
 tmp = dvrr_stack + 1174047;
 target_ptr = Libderiv->deriv2_classes[6][5][14];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+1174635, dvrr_stack+52180, dvrr_stack+544726);
 tmp = dvrr_stack + 1174635;
 target_ptr = Libderiv->deriv2_classes[6][6][14];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+1175419, dvrr_stack+632498, dvrr_stack+10792);
 tmp = dvrr_stack + 1175419;
 target_ptr = Libderiv->deriv2_classes[6][7][14];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+1176427, dvrr_stack+634739, dvrr_stack+633794);
 tmp = dvrr_stack + 1176427;
 target_ptr = Libderiv->deriv2_classes[6][8][14];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+1177687, dvrr_stack+637514, dvrr_stack+636359);
 tmp = dvrr_stack + 1177687;
 target_ptr = Libderiv->deriv2_classes[6][9][14];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+1179227, dvrr_stack+639494, dvrr_stack+609388);
 tmp = dvrr_stack + 1179227;
 target_ptr = Libderiv->deriv2_classes[7][5][14];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+1179983, dvrr_stack+640439, dvrr_stack+602243);
 tmp = dvrr_stack + 1179983;
 target_ptr = Libderiv->deriv2_classes[7][6][14];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+1180991, dvrr_stack+641699, dvrr_stack+603567);
 tmp = dvrr_stack + 1180991;
 target_ptr = Libderiv->deriv2_classes[7][7][14];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+1182287, dvrr_stack+643319, dvrr_stack+136008);
 tmp = dvrr_stack + 1182287;
 target_ptr = Libderiv->deriv2_classes[7][8][14];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+1183907, dvrr_stack+645344, dvrr_stack+630958);
 tmp = dvrr_stack + 1183907;
 target_ptr = Libderiv->deriv2_classes[7][9][14];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+1185887, dvrr_stack+546799, dvrr_stack+33852);
 tmp = dvrr_stack + 1185887;
 target_ptr = Libderiv->deriv2_classes[8][5][14];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+1186832, dvrr_stack+549742, dvrr_stack+52180);
 tmp = dvrr_stack + 1186832;
 target_ptr = Libderiv->deriv2_classes[8][6][14];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+1188092, dvrr_stack+70742, dvrr_stack+632498);
 tmp = dvrr_stack + 1188092;
 target_ptr = Libderiv->deriv2_classes[8][7][14];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+1189712, dvrr_stack+557218, dvrr_stack+634739);
 tmp = dvrr_stack + 1189712;
 target_ptr = Libderiv->deriv2_classes[8][8][14];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+1191737, dvrr_stack+342800, dvrr_stack+637514);
 tmp = dvrr_stack + 1191737;
 target_ptr = Libderiv->deriv2_classes[8][9][14];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,21,dvrr_stack+1194212, dvrr_stack+546211, dvrr_stack+345825);
 tmp = dvrr_stack + 1194212;
 target_ptr = Libderiv->deriv2_classes[5][5][13];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+1194653, dvrr_stack+346140, dvrr_stack+574988);
 tmp = dvrr_stack + 1194653;
 target_ptr = Libderiv->deriv2_classes[5][6][13];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+1195241, dvrr_stack+66670, dvrr_stack+346924);
 tmp = dvrr_stack + 1195241;
 target_ptr = Libderiv->deriv2_classes[5][7][13];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+1195997, dvrr_stack+67678, dvrr_stack+347464);
 tmp = dvrr_stack + 1195997;
 target_ptr = Libderiv->deriv2_classes[5][8][13];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+1196942, dvrr_stack+647819, dvrr_stack+559693);
 tmp = dvrr_stack + 1196942;
 target_ptr = Libderiv->deriv2_classes[5][9][13];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,21,dvrr_stack+1198097, dvrr_stack+560518, dvrr_stack+89413);
 tmp = dvrr_stack + 1198097;
 target_ptr = Libderiv->deriv2_classes[6][5][13];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+1198685, dvrr_stack+561274, dvrr_stack+180488);
 tmp = dvrr_stack + 1198685;
 target_ptr = Libderiv->deriv2_classes[6][6][13];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+1199469, dvrr_stack+322595, dvrr_stack+8203);
 tmp = dvrr_stack + 1199469;
 target_ptr = Libderiv->deriv2_classes[6][7][13];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+1200477, dvrr_stack+104586, dvrr_stack+8959);
 tmp = dvrr_stack + 1200477;
 target_ptr = Libderiv->deriv2_classes[6][8][13];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+1201737, dvrr_stack+568613, dvrr_stack+18607);
 tmp = dvrr_stack + 1201737;
 target_ptr = Libderiv->deriv2_classes[6][9][13];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,21,dvrr_stack+1203277, dvrr_stack+551282, dvrr_stack+546211);
 tmp = dvrr_stack + 1203277;
 target_ptr = Libderiv->deriv2_classes[7][5][13];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+1204033, dvrr_stack+303110, dvrr_stack+346140);
 tmp = dvrr_stack + 1204033;
 target_ptr = Libderiv->deriv2_classes[7][6][13];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+1205041, dvrr_stack+304370, dvrr_stack+66670);
 tmp = dvrr_stack + 1205041;
 target_ptr = Libderiv->deriv2_classes[7][7][13];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+1206337, dvrr_stack+0, dvrr_stack+67678);
 tmp = dvrr_stack + 1206337;
 target_ptr = Libderiv->deriv2_classes[7][8][13];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+1207957, dvrr_stack+583383, dvrr_stack+647819);
 tmp = dvrr_stack + 1207957;
 target_ptr = Libderiv->deriv2_classes[7][9][13];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,21,dvrr_stack+1209937, dvrr_stack+305990, dvrr_stack+560518);
 tmp = dvrr_stack + 1209937;
 target_ptr = Libderiv->deriv2_classes[8][5][13];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+1210882, dvrr_stack+585858, dvrr_stack+561274);
 tmp = dvrr_stack + 1210882;
 target_ptr = Libderiv->deriv2_classes[8][6][13];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+1212142, dvrr_stack+587398, dvrr_stack+322595);
 tmp = dvrr_stack + 1212142;
 target_ptr = Libderiv->deriv2_classes[8][7][13];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+1213762, dvrr_stack+47176, dvrr_stack+104586);
 tmp = dvrr_stack + 1213762;
 target_ptr = Libderiv->deriv2_classes[8][8][13];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+1215787, dvrr_stack+651735, dvrr_stack+568613);
 tmp = dvrr_stack + 1215787;
 target_ptr = Libderiv->deriv2_classes[8][9][13];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,21,dvrr_stack+1218262, dvrr_stack+420266, dvrr_stack+411586);
 tmp = dvrr_stack + 1218262;
 target_ptr = Libderiv->deriv2_classes[5][5][11];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,28,dvrr_stack+1218703, dvrr_stack+419482, dvrr_stack+157517);
 tmp = dvrr_stack + 1218703;
 target_ptr = Libderiv->deriv2_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,36,dvrr_stack+1219291, dvrr_stack+420854, dvrr_stack+157937);
 tmp = dvrr_stack + 1219291;
 target_ptr = Libderiv->deriv2_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,45,dvrr_stack+157427, dvrr_stack+421862, dvrr_stack+31432);
 tmp = dvrr_stack + 157427;
 target_ptr = Libderiv->deriv2_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_h(Data,55,dvrr_stack+1220047, dvrr_stack+423122, dvrr_stack+545386);
 tmp = dvrr_stack + 1220047;
 target_ptr = Libderiv->deriv2_classes[5][9][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,21,dvrr_stack+31334, dvrr_stack+361458, dvrr_stack+413749);
 tmp = dvrr_stack + 31334;
 target_ptr = Libderiv->deriv2_classes[6][5][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,28,dvrr_stack+545314, dvrr_stack+360450, dvrr_stack+413161);
 tmp = dvrr_stack + 545314;
 target_ptr = Libderiv->deriv2_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,36,dvrr_stack+413077, dvrr_stack+362214, dvrr_stack+414190);
 tmp = dvrr_stack + 413077;
 target_ptr = Libderiv->deriv2_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,45,dvrr_stack+1221202, dvrr_stack+336320, dvrr_stack+414946);
 tmp = dvrr_stack + 1221202;
 target_ptr = Libderiv->deriv2_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_i(Data,55,dvrr_stack+414085, dvrr_stack+311120, dvrr_stack+415891);
 tmp = dvrr_stack + 414085;
 target_ptr = Libderiv->deriv2_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,21,dvrr_stack+415625, dvrr_stack+285520, dvrr_stack+420266);
 tmp = dvrr_stack + 415625;
 target_ptr = Libderiv->deriv2_classes[7][5][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,28,dvrr_stack+1222462, dvrr_stack+284260, dvrr_stack+419482);
 tmp = dvrr_stack + 1222462;
 target_ptr = Libderiv->deriv2_classes[7][6][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,36,dvrr_stack+284251, dvrr_stack+286465, dvrr_stack+420854);
 tmp = dvrr_stack + 284251;
 target_ptr = Libderiv->deriv2_classes[7][7][11];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,45,dvrr_stack+285547, dvrr_stack+288085, dvrr_stack+421862);
 tmp = dvrr_stack + 285547;
 target_ptr = Libderiv->deriv2_classes[7][8][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_k(Data,55,dvrr_stack+287167, dvrr_stack+230548, dvrr_stack+423122);
 tmp = dvrr_stack + 287167;
 target_ptr = Libderiv->deriv2_classes[7][9][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,21,dvrr_stack+289147, dvrr_stack+181832, dvrr_stack+361458);
 tmp = dvrr_stack + 289147;
 target_ptr = Libderiv->deriv2_classes[8][5][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,28,dvrr_stack+419426, dvrr_stack+186480, dvrr_stack+360450);
 tmp = dvrr_stack + 419426;
 target_ptr = Libderiv->deriv2_classes[8][6][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,36,dvrr_stack+420686, dvrr_stack+199368, dvrr_stack+362214);
 tmp = dvrr_stack + 420686;
 target_ptr = Libderiv->deriv2_classes[8][7][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,45,dvrr_stack+422306, dvrr_stack+216153, dvrr_stack+336320);
 tmp = dvrr_stack + 422306;
 target_ptr = Libderiv->deriv2_classes[8][8][11];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_l(Data,55,dvrr_stack+230314, dvrr_stack+368955, dvrr_stack+311120);
 tmp = dvrr_stack + 230314;
 target_ptr = Libderiv->deriv2_classes[8][9][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+181832, dvrr_stack+170382, dvrr_stack+49861);
 tmp = dvrr_stack + 181832;
 target_ptr = Libderiv->deriv2_classes[5][5][10];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+182273, dvrr_stack+169598, dvrr_stack+371980);
 tmp = dvrr_stack + 182273;
 target_ptr = Libderiv->deriv2_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+368820, dvrr_stack+170970, dvrr_stack+372400);
 tmp = dvrr_stack + 368820;
 target_ptr = Libderiv->deriv2_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+369576, dvrr_stack+171978, dvrr_stack+372940);
 tmp = dvrr_stack + 369576;
 target_ptr = Libderiv->deriv2_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+370521, dvrr_stack+173238, dvrr_stack+373615);
 tmp = dvrr_stack + 370521;
 target_ptr = Libderiv->deriv2_classes[5][9][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+371676, dvrr_stack+113514, dvrr_stack+233023);
 tmp = dvrr_stack + 371676;
 target_ptr = Libderiv->deriv2_classes[6][5][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+372264, dvrr_stack+150440, dvrr_stack+316151);
 tmp = dvrr_stack + 372264;
 target_ptr = Libderiv->deriv2_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+373048, dvrr_stack+80782, dvrr_stack+290110);
 tmp = dvrr_stack + 373048;
 target_ptr = Libderiv->deriv2_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+186264, dvrr_stack+82078, dvrr_stack+210969);
 tmp = dvrr_stack + 186264;
 target_ptr = Libderiv->deriv2_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+199270, dvrr_stack+83698, dvrr_stack+211914);
 tmp = dvrr_stack + 199270;
 target_ptr = Libderiv->deriv2_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+290092, dvrr_stack+62890, dvrr_stack+170382);
 tmp = dvrr_stack + 290092;
 target_ptr = Libderiv->deriv2_classes[7][5][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+215949, dvrr_stack+61630, dvrr_stack+169598);
 tmp = dvrr_stack + 215949;
 target_ptr = Libderiv->deriv2_classes[7][6][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+216957, dvrr_stack+43207, dvrr_stack+170970);
 tmp = dvrr_stack + 216957;
 target_ptr = Libderiv->deriv2_classes[7][7][10];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+43112, dvrr_stack+504048, dvrr_stack+171978);
 tmp = dvrr_stack + 43112;
 target_ptr = Libderiv->deriv2_classes[7][8][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+311102, dvrr_stack+506073, dvrr_stack+173238);
 tmp = dvrr_stack + 311102;
 target_ptr = Libderiv->deriv2_classes[7][9][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+315746, dvrr_stack+374440, dvrr_stack+113514);
 tmp = dvrr_stack + 315746;
 target_ptr = Libderiv->deriv2_classes[8][5][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+374056, dvrr_stack+134468, dvrr_stack+150440);
 tmp = dvrr_stack + 374056;
 target_ptr = Libderiv->deriv2_classes[8][6][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+134244, dvrr_stack+237352, dvrr_stack+80782);
 tmp = dvrr_stack + 134244;
 target_ptr = Libderiv->deriv2_classes[8][7][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+237145, dvrr_stack+239332, dvrr_stack+82078);
 tmp = dvrr_stack + 237145;
 target_ptr = Libderiv->deriv2_classes[8][8][10];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+239170, dvrr_stack+614953, dvrr_stack+83698);
 tmp = dvrr_stack + 239170;
 target_ptr = Libderiv->deriv2_classes[8][9][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+232789, dvrr_stack+96942, dvrr_stack+375595);
 tmp = dvrr_stack + 232789;
 target_ptr = Libderiv->deriv2_classes[5][5][9];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+375316, dvrr_stack+28408, dvrr_stack+155312);
 tmp = dvrr_stack + 375316;
 target_ptr = Libderiv->deriv2_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+113410, dvrr_stack+92514, dvrr_stack+155732);
 tmp = dvrr_stack + 113410;
 target_ptr = Libderiv->deriv2_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+155285, dvrr_stack+107466, dvrr_stack+539266);
 tmp = dvrr_stack + 155285;
 target_ptr = Libderiv->deriv2_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+503730, dvrr_stack+121616, dvrr_stack+539941);
 tmp = dvrr_stack + 503730;
 target_ptr = Libderiv->deriv2_classes[5][9][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+539026, dvrr_stack+93522, dvrr_stack+12874);
 tmp = dvrr_stack + 539026;
 target_ptr = Libderiv->deriv2_classes[6][5][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+539614, dvrr_stack+392913, dvrr_stack+411901);
 tmp = dvrr_stack + 539614;
 target_ptr = Libderiv->deriv2_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+150317, dvrr_stack+184212, dvrr_stack+7447);
 tmp = dvrr_stack + 150317;
 target_ptr = Libderiv->deriv2_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+504885, dvrr_stack+203193, dvrr_stack+23872);
 tmp = dvrr_stack + 504885;
 target_ptr = Libderiv->deriv2_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+506145, dvrr_stack+220828, dvrr_stack+37537);
 tmp = dvrr_stack + 506145;
 target_ptr = Libderiv->deriv2_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+37411, dvrr_stack+307340, dvrr_stack+96942);
 tmp = dvrr_stack + 37411;
 target_ptr = Libderiv->deriv2_classes[7][5][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+23752, dvrr_stack+282235, dvrr_stack+28408);
 tmp = dvrr_stack + 23752;
 target_ptr = Libderiv->deriv2_classes[7][6][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+614819, dvrr_stack+300545, dvrr_stack+92514);
 tmp = dvrr_stack + 614819;
 target_ptr = Libderiv->deriv2_classes[7][7][9];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+300451, dvrr_stack+326600, dvrr_stack+107466);
 tmp = dvrr_stack + 300451;
 target_ptr = Libderiv->deriv2_classes[7][8][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+326460, dvrr_stack+348300, dvrr_stack+121616);
 tmp = dvrr_stack + 326460;
 target_ptr = Libderiv->deriv2_classes[7][9][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+92422, dvrr_stack+540766, dvrr_stack+93522);
 tmp = dvrr_stack + 92422;
 target_ptr = Libderiv->deriv2_classes[8][5][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+540398, dvrr_stack+554138, dvrr_stack+392913);
 tmp = dvrr_stack + 540398;
 target_ptr = Libderiv->deriv2_classes[8][6][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+348139, dvrr_stack+564263, dvrr_stack+184212);
 tmp = dvrr_stack + 348139;
 target_ptr = Libderiv->deriv2_classes[8][7][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+360408, dvrr_stack+577883, dvrr_stack+203193);
 tmp = dvrr_stack + 360408;
 target_ptr = Libderiv->deriv2_classes[8][8][9];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+577883, dvrr_stack+594823, dvrr_stack+220828);
 tmp = dvrr_stack + 577883;
 target_ptr = Libderiv->deriv2_classes[8][9][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+93367, dvrr_stack+409515, dvrr_stack+605878);
 tmp = dvrr_stack + 93367;
 target_ptr = Libderiv->deriv2_classes[5][5][8];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+107361, dvrr_stack+408731, dvrr_stack+606193);
 tmp = dvrr_stack + 107361;
 target_ptr = Libderiv->deriv2_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+107949, dvrr_stack+379185, dvrr_stack+606613);
 tmp = dvrr_stack + 107949;
 target_ptr = Libderiv->deriv2_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+349759, dvrr_stack+380193, dvrr_stack+607153);
 tmp = dvrr_stack + 349759;
 target_ptr = Libderiv->deriv2_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+564221, dvrr_stack+381453, dvrr_stack+607828);
 tmp = dvrr_stack + 564221;
 target_ptr = Libderiv->deriv2_classes[5][9][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+7399, dvrr_stack+328625, dvrr_stack+403348);
 tmp = dvrr_stack + 7399;
 target_ptr = Libderiv->deriv2_classes[6][5][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+565376, dvrr_stack+352623, dvrr_stack+402760);
 tmp = dvrr_stack + 565376;
 target_ptr = Libderiv->deriv2_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+121554, dvrr_stack+329381, dvrr_stack+403789);
 tmp = dvrr_stack + 121554;
 target_ptr = Libderiv->deriv2_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+553847, dvrr_stack+308285, dvrr_stack+404545);
 tmp = dvrr_stack + 553847;
 target_ptr = Libderiv->deriv2_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+202888, dvrr_stack+272947, dvrr_stack+405490);
 tmp = dvrr_stack + 202888;
 target_ptr = Libderiv->deriv2_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+307145, dvrr_stack+302165, dvrr_stack+409515);
 tmp = dvrr_stack + 307145;
 target_ptr = Libderiv->deriv2_classes[7][5][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+302071, dvrr_stack+277303, dvrr_stack+408731);
 tmp = dvrr_stack + 302071;
 target_ptr = Libderiv->deriv2_classes[7][6][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+277132, dvrr_stack+246328, dvrr_stack+379185);
 tmp = dvrr_stack + 277132;
 target_ptr = Libderiv->deriv2_classes[7][7][8];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+246140, dvrr_stack+222808, dvrr_stack+380193);
 tmp = dvrr_stack + 246140;
 target_ptr = Libderiv->deriv2_classes[7][8][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+605691, dvrr_stack+189540, dvrr_stack+381453);
 tmp = dvrr_stack + 605691;
 target_ptr = Libderiv->deriv2_classes[7][9][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+408605, dvrr_stack+610144, dvrr_stack+328625);
 tmp = dvrr_stack + 408605;
 target_ptr = Libderiv->deriv2_classes[8][5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+189280, dvrr_stack+611299, dvrr_stack+352623);
 tmp = dvrr_stack + 189280;
 target_ptr = Libderiv->deriv2_classes[8][6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+609976, dvrr_stack+612839, dvrr_stack+329381);
 tmp = dvrr_stack + 609976;
 target_ptr = Libderiv->deriv2_classes[8][7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+328440, dvrr_stack+597848, dvrr_stack+308285);
 tmp = dvrr_stack + 328440;
 target_ptr = Libderiv->deriv2_classes[8][8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+611596, dvrr_stack+580358, dvrr_stack+272947);
 tmp = dvrr_stack + 611596;
 target_ptr = Libderiv->deriv2_classes[8][9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+580358, dvrr_stack+248893, dvrr_stack+337940);
 tmp = dvrr_stack + 580358;
 target_ptr = Libderiv->deriv2_classes[5][5][7];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+580799, dvrr_stack+278563, dvrr_stack+608653);
 tmp = dvrr_stack + 580799;
 target_ptr = Libderiv->deriv2_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+581387, dvrr_stack+205968, dvrr_stack+424662);
 tmp = dvrr_stack + 581387;
 target_ptr = Libderiv->deriv2_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+582143, dvrr_stack+141200, dvrr_stack+600323);
 tmp = dvrr_stack + 582143;
 target_ptr = Libderiv->deriv2_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+307901, dvrr_stack+123156, dvrr_stack+600998);
 tmp = dvrr_stack + 307901;
 target_ptr = Libderiv->deriv2_classes[5][9][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+352539, dvrr_stack+185508, dvrr_stack+309905);
 tmp = dvrr_stack + 352539;
 target_ptr = Libderiv->deriv2_classes[6][5][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+424331, dvrr_stack+142460, dvrr_stack+330677);
 tmp = dvrr_stack + 424331;
 target_ptr = Libderiv->deriv2_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+309056, dvrr_stack+108726, dvrr_stack+310346);
 tmp = dvrr_stack + 309056;
 target_ptr = Libderiv->deriv2_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+190540, dvrr_stack+97530, dvrr_stack+247948);
 tmp = dvrr_stack + 190540;
 target_ptr = Libderiv->deriv2_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+616115, dvrr_stack+56086, dvrr_stack+204813);
 tmp = dvrr_stack + 616115;
 target_ptr = Libderiv->deriv2_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+330465, dvrr_stack+38692, dvrr_stack+248893);
 tmp = dvrr_stack + 330465;
 target_ptr = Libderiv->deriv2_classes[7][5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+38167, dvrr_stack+77128, dvrr_stack+278563);
 tmp = dvrr_stack + 38167;
 target_ptr = Libderiv->deriv2_classes[7][6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+247760, dvrr_stack+513894, dvrr_stack+205968);
 tmp = dvrr_stack + 247760;
 target_ptr = Libderiv->deriv2_classes[7][7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+513483, dvrr_stack+515514, dvrr_stack+141200);
 tmp = dvrr_stack + 513483;
 target_ptr = Libderiv->deriv2_classes[7][8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+515103, dvrr_stack+517539, dvrr_stack+123156);
 tmp = dvrr_stack + 515103;
 target_ptr = Libderiv->deriv2_classes[7][9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+141116, dvrr_stack+566243, dvrr_stack+185508);
 tmp = dvrr_stack + 141116;
 target_ptr = Libderiv->deriv2_classes[8][5][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+517083, dvrr_stack+555678, dvrr_stack+142460);
 tmp = dvrr_stack + 517083;
 target_ptr = Libderiv->deriv2_classes[8][6][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+518343, dvrr_stack+541921, dvrr_stack+108726);
 tmp = dvrr_stack + 518343;
 target_ptr = Libderiv->deriv2_classes[8][7][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+541658, dvrr_stack+617978, dvrr_stack+97530);
 tmp = dvrr_stack + 541658;
 target_ptr = Libderiv->deriv2_classes[8][8][7];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+204428, dvrr_stack+620453, dvrr_stack+56086);
 tmp = dvrr_stack + 204428;
 target_ptr = Libderiv->deriv2_classes[8][9][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+278428, dvrr_stack+78388, dvrr_stack+338255);
 tmp = dvrr_stack + 278428;
 target_ptr = Libderiv->deriv2_classes[5][5][6];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+142061, dvrr_stack+16402, dvrr_stack+425202);
 tmp = dvrr_stack + 142061;
 target_ptr = Libderiv->deriv2_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+142649, dvrr_stack+50176, dvrr_stack+567398);
 tmp = dvrr_stack + 142649;
 target_ptr = Libderiv->deriv2_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+56072, dvrr_stack+73082, dvrr_stack+567938);
 tmp = dvrr_stack + 56072;
 target_ptr = Libderiv->deriv2_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+108705, dvrr_stack+522984, dvrr_stack+543901);
 tmp = dvrr_stack + 108705;
 target_ptr = Libderiv->deriv2_classes[5][9][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+543683, dvrr_stack+159830, dvrr_stack+192015);
 tmp = dvrr_stack + 543683;
 target_ptr = Libderiv->deriv2_classes[6][5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+57017, dvrr_stack+158822, dvrr_stack+393921);
 tmp = dvrr_stack + 57017;
 target_ptr = Libderiv->deriv2_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+566160, dvrr_stack+524524, dvrr_stack+24817);
 tmp = dvrr_stack + 566160;
 target_ptr = Libderiv->deriv2_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+567168, dvrr_stack+525820, dvrr_stack+13315);
 tmp = dvrr_stack + 567168;
 target_ptr = Libderiv->deriv2_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+122562, dvrr_stack+527440, dvrr_stack+101646);
 tmp = dvrr_stack + 122562;
 target_ptr = Libderiv->deriv2_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+24760, dvrr_stack+410103, dvrr_stack+78388);
 tmp = dvrr_stack + 24760;
 target_ptr = Libderiv->deriv2_classes[7][5][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+409550, dvrr_stack+269323, dvrr_stack+16402);
 tmp = dvrr_stack + 409550;
 target_ptr = Libderiv->deriv2_classes[7][6][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+268907, dvrr_stack+270583, dvrr_stack+50176);
 tmp = dvrr_stack + 268907;
 target_ptr = Libderiv->deriv2_classes[7][7][6];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+270203, dvrr_stack+531796, dvrr_stack+73082);
 tmp = dvrr_stack + 270203;
 target_ptr = Libderiv->deriv2_classes[7][8][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+531625, dvrr_stack+533821, dvrr_stack+522984);
 tmp = dvrr_stack + 531625;
 target_ptr = Libderiv->deriv2_classes[7][9][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+533605, dvrr_stack+156272, dvrr_stack+159830);
 tmp = dvrr_stack + 533605;
 target_ptr = Libderiv->deriv2_classes[8][5][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+534550, dvrr_stack+241807, dvrr_stack+158822);
 tmp = dvrr_stack + 534550;
 target_ptr = Libderiv->deriv2_classes[8][6][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+72722, dvrr_stack+623478, dvrr_stack+524524);
 tmp = dvrr_stack + 72722;
 target_ptr = Libderiv->deriv2_classes[8][7][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+522744, dvrr_stack+625458, dvrr_stack+525820);
 tmp = dvrr_stack + 522744;
 target_ptr = Libderiv->deriv2_classes[8][8][6];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+524769, dvrr_stack+627933, dvrr_stack+527440);
 tmp = dvrr_stack + 524769;
 target_ptr = Libderiv->deriv2_classes[8][9][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+544271, dvrr_stack+609388, dvrr_stack+609073);
 tmp = dvrr_stack + 544271;
 target_ptr = Libderiv->deriv2_classes[5][5][2];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+527244, dvrr_stack+602243, dvrr_stack+601823);
 tmp = dvrr_stack + 527244;
 target_ptr = Libderiv->deriv2_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+527832, dvrr_stack+603567, dvrr_stack+603027);
 tmp = dvrr_stack + 527832;
 target_ptr = Libderiv->deriv2_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+241645, dvrr_stack+136008, dvrr_stack+604575);
 tmp = dvrr_stack + 241645;
 target_ptr = Libderiv->deriv2_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+12793, dvrr_stack+630958, dvrr_stack+20857);
 tmp = dvrr_stack + 12793;
 target_ptr = Libderiv->deriv2_classes[5][9][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+604575, dvrr_stack+33852, dvrr_stack+605250);
 tmp = dvrr_stack + 604575;
 target_ptr = Libderiv->deriv2_classes[6][5][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+528588, dvrr_stack+52180, dvrr_stack+544726);
 tmp = dvrr_stack + 528588;
 target_ptr = Libderiv->deriv2_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+555107, dvrr_stack+632498, dvrr_stack+10792);
 tmp = dvrr_stack + 555107;
 target_ptr = Libderiv->deriv2_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+158372, dvrr_stack+634739, dvrr_stack+633794);
 tmp = dvrr_stack + 158372;
 target_ptr = Libderiv->deriv2_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+96843, dvrr_stack+637514, dvrr_stack+636359);
 tmp = dvrr_stack + 96843;
 target_ptr = Libderiv->deriv2_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+636359, dvrr_stack+639494, dvrr_stack+609388);
 tmp = dvrr_stack + 636359;
 target_ptr = Libderiv->deriv2_classes[7][5][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+556115, dvrr_stack+640439, dvrr_stack+602243);
 tmp = dvrr_stack + 556115;
 target_ptr = Libderiv->deriv2_classes[7][6][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+639494, dvrr_stack+641699, dvrr_stack+603567);
 tmp = dvrr_stack + 639494;
 target_ptr = Libderiv->deriv2_classes[7][7][2];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+640790, dvrr_stack+643319, dvrr_stack+136008);
 tmp = dvrr_stack + 640790;
 target_ptr = Libderiv->deriv2_classes[7][8][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+642410, dvrr_stack+645344, dvrr_stack+630958);
 tmp = dvrr_stack + 642410;
 target_ptr = Libderiv->deriv2_classes[7][9][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+633794, dvrr_stack+546799, dvrr_stack+33852);
 tmp = dvrr_stack + 633794;
 target_ptr = Libderiv->deriv2_classes[8][5][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+644390, dvrr_stack+549742, dvrr_stack+52180);
 tmp = dvrr_stack + 644390;
 target_ptr = Libderiv->deriv2_classes[8][6][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+645650, dvrr_stack+70742, dvrr_stack+632498);
 tmp = dvrr_stack + 645650;
 target_ptr = Libderiv->deriv2_classes[8][7][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+617655, dvrr_stack+557218, dvrr_stack+634739);
 tmp = dvrr_stack + 617655;
 target_ptr = Libderiv->deriv2_classes[8][8][2];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+557123, dvrr_stack+342800, dvrr_stack+637514);
 tmp = dvrr_stack + 557123;
 target_ptr = Libderiv->deriv2_classes[8][9][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+634739, dvrr_stack+546211, dvrr_stack+345825);
 tmp = dvrr_stack + 634739;
 target_ptr = Libderiv->deriv2_classes[5][5][1];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+635180, dvrr_stack+346140, dvrr_stack+574988);
 tmp = dvrr_stack + 635180;
 target_ptr = Libderiv->deriv2_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+546799, dvrr_stack+66670, dvrr_stack+346924);
 tmp = dvrr_stack + 546799;
 target_ptr = Libderiv->deriv2_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+637115, dvrr_stack+67678, dvrr_stack+347464);
 tmp = dvrr_stack + 637115;
 target_ptr = Libderiv->deriv2_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+346924, dvrr_stack+647819, dvrr_stack+559693);
 tmp = dvrr_stack + 346924;
 target_ptr = Libderiv->deriv2_classes[5][9][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+635768, dvrr_stack+560518, dvrr_stack+89413);
 tmp = dvrr_stack + 635768;
 target_ptr = Libderiv->deriv2_classes[6][5][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+638060, dvrr_stack+561274, dvrr_stack+180488);
 tmp = dvrr_stack + 638060;
 target_ptr = Libderiv->deriv2_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+135864, dvrr_stack+322595, dvrr_stack+8203);
 tmp = dvrr_stack + 135864;
 target_ptr = Libderiv->deriv2_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+70702, dvrr_stack+104586, dvrr_stack+8959);
 tmp = dvrr_stack + 70702;
 target_ptr = Libderiv->deriv2_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+7987, dvrr_stack+568613, dvrr_stack+18607);
 tmp = dvrr_stack + 7987;
 target_ptr = Libderiv->deriv2_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+242590, dvrr_stack+551282, dvrr_stack+546211);
 tmp = dvrr_stack + 242590;
 target_ptr = Libderiv->deriv2_classes[7][5][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+310064, dvrr_stack+303110, dvrr_stack+346140);
 tmp = dvrr_stack + 310064;
 target_ptr = Libderiv->deriv2_classes[7][6][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+549655, dvrr_stack+304370, dvrr_stack+66670);
 tmp = dvrr_stack + 549655;
 target_ptr = Libderiv->deriv2_classes[7][7][1];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+303079, dvrr_stack+0, dvrr_stack+67678);
 tmp = dvrr_stack + 303079;
 target_ptr = Libderiv->deriv2_classes[7][8][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+0, dvrr_stack+583383, dvrr_stack+647819);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv2_classes[7][9][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+647270, dvrr_stack+305990, dvrr_stack+560518);
 tmp = dvrr_stack + 647270;
 target_ptr = Libderiv->deriv2_classes[8][5][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+583088, dvrr_stack+585858, dvrr_stack+561274);
 tmp = dvrr_stack + 583088;
 target_ptr = Libderiv->deriv2_classes[8][6][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+584348, dvrr_stack+587398, dvrr_stack+322595);
 tmp = dvrr_stack + 584348;
 target_ptr = Libderiv->deriv2_classes[8][7][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+585968, dvrr_stack+47176, dvrr_stack+104586);
 tmp = dvrr_stack + 585968;
 target_ptr = Libderiv->deriv2_classes[8][8][1];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+66362, dvrr_stack+651735, dvrr_stack+568613);
 tmp = dvrr_stack + 66362;
 target_ptr = Libderiv->deriv2_classes[8][9][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,21,dvrr_stack+648215, dvrr_stack+323891, dvrr_stack+68938);
 tmp = dvrr_stack + 648215;
 target_ptr = Libderiv->deriv2_classes[5][5][0];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+648656, dvrr_stack+4150, dvrr_stack+3730);
 tmp = dvrr_stack + 648656;
 target_ptr = Libderiv->deriv2_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+587993, dvrr_stack+4934, dvrr_stack+6859);
 tmp = dvrr_stack + 587993;
 target_ptr = Libderiv->deriv2_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+322593, dvrr_stack+2025, dvrr_stack+12118);
 tmp = dvrr_stack + 322593;
 target_ptr = Libderiv->deriv2_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+651375, dvrr_stack+589378, dvrr_stack+22927);
 tmp = dvrr_stack + 651375;
 target_ptr = Libderiv->deriv2_classes[5][9][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,21,dvrr_stack+638844, dvrr_stack+9904, dvrr_stack+36382);
 tmp = dvrr_stack + 638844;
 target_ptr = Libderiv->deriv2_classes[6][5][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+652530, dvrr_stack+19762, dvrr_stack+89854);
 tmp = dvrr_stack + 652530;
 target_ptr = Libderiv->deriv2_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+653314, dvrr_stack+32107, dvrr_stack+5942);
 tmp = dvrr_stack + 653314;
 target_ptr = Libderiv->deriv2_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+5942, dvrr_stack+654760, dvrr_stack+95898);
 tmp = dvrr_stack + 5942;
 target_ptr = Libderiv->deriv2_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+304699, dvrr_stack+656380, dvrr_stack+106206);
 tmp = dvrr_stack + 304699;
 target_ptr = Libderiv->deriv2_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,21,dvrr_stack+95874, dvrr_stack+120021, dvrr_stack+323891);
 tmp = dvrr_stack + 95874;
 target_ptr = Libderiv->deriv2_classes[7][5][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+568428, dvrr_stack+547954, dvrr_stack+4150);
 tmp = dvrr_stack + 568428;
 target_ptr = Libderiv->deriv2_classes[7][6][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+547555, dvrr_stack+552227, dvrr_stack+4934);
 tmp = dvrr_stack + 547555;
 target_ptr = Libderiv->deriv2_classes[7][7][0];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+559598, dvrr_stack+658360, dvrr_stack+2025);
 tmp = dvrr_stack + 559598;
 target_ptr = Libderiv->deriv2_classes[7][8][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+658360, dvrr_stack+575408, dvrr_stack+589378);
 tmp = dvrr_stack + 658360;
 target_ptr = Libderiv->deriv2_classes[7][9][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,21,dvrr_stack+1980, dvrr_stack+562282, dvrr_stack+9904);
 tmp = dvrr_stack + 1980;
 target_ptr = Libderiv->deriv2_classes[8][5][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+588749, dvrr_stack+201348, dvrr_stack+19762);
 tmp = dvrr_stack + 588749;
 target_ptr = Libderiv->deriv2_classes[8][6][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+9527, dvrr_stack+90442, dvrr_stack+32107);
 tmp = dvrr_stack + 9527;
 target_ptr = Libderiv->deriv2_classes[8][7][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+574895, dvrr_stack+297220, dvrr_stack+654760);
 tmp = dvrr_stack + 574895;
 target_ptr = Libderiv->deriv2_classes[8][8][0];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+31922, dvrr_stack+590918, dvrr_stack+656380);
 tmp = dvrr_stack + 31922;
 target_ptr = Libderiv->deriv2_classes[8][9][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];


}

