/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_ggih(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gg|ih) integrals */

void d1hrr_order_ggih(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][6][11] = int_stack + 0;
 Libderiv->deriv_classes[4][7][11] = int_stack + 420;
 Libderiv->deriv_classes[4][8][11] = int_stack + 960;
 Libderiv->deriv_classes[4][9][11] = int_stack + 1635;
 Libderiv->deriv_classes[4][10][11] = int_stack + 2460;
 Libderiv->deriv_classes[4][11][11] = int_stack + 3450;
 Libderiv->deriv_classes[5][6][11] = int_stack + 4620;
 Libderiv->deriv_classes[5][7][11] = int_stack + 5208;
 Libderiv->deriv_classes[5][8][11] = int_stack + 5964;
 Libderiv->deriv_classes[5][9][11] = int_stack + 6909;
 Libderiv->deriv_classes[5][10][11] = int_stack + 8064;
 Libderiv->deriv_classes[5][11][11] = int_stack + 9450;
 Libderiv->deriv_classes[6][6][11] = int_stack + 11088;
 Libderiv->deriv_classes[6][7][11] = int_stack + 11872;
 Libderiv->deriv_classes[6][8][11] = int_stack + 12880;
 Libderiv->deriv_classes[6][9][11] = int_stack + 14140;
 Libderiv->deriv_classes[6][10][11] = int_stack + 15680;
 Libderiv->deriv_classes[6][11][11] = int_stack + 17528;
 Libderiv->deriv_classes[7][6][11] = int_stack + 19712;
 Libderiv->deriv_classes[7][7][11] = int_stack + 20720;
 Libderiv->deriv_classes[7][8][11] = int_stack + 22016;
 Libderiv->deriv_classes[7][9][11] = int_stack + 23636;
 Libderiv->deriv_classes[7][10][11] = int_stack + 25616;
 Libderiv->deriv_classes[7][11][11] = int_stack + 27992;
 Libderiv->deriv_classes[8][6][11] = int_stack + 30800;
 Libderiv->deriv_classes[8][7][11] = int_stack + 32060;
 Libderiv->deriv_classes[8][8][11] = int_stack + 33680;
 Libderiv->deriv_classes[8][9][11] = int_stack + 35705;
 Libderiv->deriv_classes[8][10][11] = int_stack + 38180;
 Libderiv->deriv_classes[8][11][11] = int_stack + 41150;
 Libderiv->deriv_classes[4][6][10] = int_stack + 44660;
 Libderiv->deriv_classes[4][7][10] = int_stack + 45080;
 Libderiv->deriv_classes[4][8][10] = int_stack + 45620;
 Libderiv->deriv_classes[4][9][10] = int_stack + 46295;
 Libderiv->deriv_classes[4][10][10] = int_stack + 47120;
 Libderiv->deriv_classes[4][11][10] = int_stack + 48110;
 Libderiv->deriv_classes[5][6][10] = int_stack + 49280;
 Libderiv->deriv_classes[5][7][10] = int_stack + 49868;
 Libderiv->deriv_classes[5][8][10] = int_stack + 50624;
 Libderiv->deriv_classes[5][9][10] = int_stack + 51569;
 Libderiv->deriv_classes[5][10][10] = int_stack + 52724;
 Libderiv->deriv_classes[5][11][10] = int_stack + 54110;
 Libderiv->deriv_classes[6][6][10] = int_stack + 55748;
 Libderiv->deriv_classes[6][7][10] = int_stack + 56532;
 Libderiv->deriv_classes[6][8][10] = int_stack + 57540;
 Libderiv->deriv_classes[6][9][10] = int_stack + 58800;
 Libderiv->deriv_classes[6][10][10] = int_stack + 60340;
 Libderiv->deriv_classes[6][11][10] = int_stack + 62188;
 Libderiv->deriv_classes[7][6][10] = int_stack + 64372;
 Libderiv->deriv_classes[7][7][10] = int_stack + 65380;
 Libderiv->deriv_classes[7][8][10] = int_stack + 66676;
 Libderiv->deriv_classes[7][9][10] = int_stack + 68296;
 Libderiv->deriv_classes[7][10][10] = int_stack + 70276;
 Libderiv->deriv_classes[7][11][10] = int_stack + 72652;
 Libderiv->deriv_classes[8][6][10] = int_stack + 75460;
 Libderiv->deriv_classes[8][7][10] = int_stack + 76720;
 Libderiv->deriv_classes[8][8][10] = int_stack + 78340;
 Libderiv->deriv_classes[8][9][10] = int_stack + 80365;
 Libderiv->deriv_classes[8][10][10] = int_stack + 82840;
 Libderiv->deriv_classes[8][11][10] = int_stack + 85810;
 Libderiv->deriv_classes[4][6][9] = int_stack + 89320;
 Libderiv->deriv_classes[4][7][9] = int_stack + 89740;
 Libderiv->deriv_classes[4][8][9] = int_stack + 90280;
 Libderiv->deriv_classes[4][9][9] = int_stack + 90955;
 Libderiv->deriv_classes[4][10][9] = int_stack + 91780;
 Libderiv->deriv_classes[4][11][9] = int_stack + 92770;
 Libderiv->deriv_classes[5][6][9] = int_stack + 93940;
 Libderiv->deriv_classes[5][7][9] = int_stack + 94528;
 Libderiv->deriv_classes[5][8][9] = int_stack + 95284;
 Libderiv->deriv_classes[5][9][9] = int_stack + 96229;
 Libderiv->deriv_classes[5][10][9] = int_stack + 97384;
 Libderiv->deriv_classes[5][11][9] = int_stack + 98770;
 Libderiv->deriv_classes[6][6][9] = int_stack + 100408;
 Libderiv->deriv_classes[6][7][9] = int_stack + 101192;
 Libderiv->deriv_classes[6][8][9] = int_stack + 102200;
 Libderiv->deriv_classes[6][9][9] = int_stack + 103460;
 Libderiv->deriv_classes[6][10][9] = int_stack + 105000;
 Libderiv->deriv_classes[6][11][9] = int_stack + 106848;
 Libderiv->deriv_classes[7][6][9] = int_stack + 109032;
 Libderiv->deriv_classes[7][7][9] = int_stack + 110040;
 Libderiv->deriv_classes[7][8][9] = int_stack + 111336;
 Libderiv->deriv_classes[7][9][9] = int_stack + 112956;
 Libderiv->deriv_classes[7][10][9] = int_stack + 114936;
 Libderiv->deriv_classes[7][11][9] = int_stack + 117312;
 Libderiv->deriv_classes[8][6][9] = int_stack + 120120;
 Libderiv->deriv_classes[8][7][9] = int_stack + 121380;
 Libderiv->deriv_classes[8][8][9] = int_stack + 123000;
 Libderiv->deriv_classes[8][9][9] = int_stack + 125025;
 Libderiv->deriv_classes[8][10][9] = int_stack + 127500;
 Libderiv->deriv_classes[8][11][9] = int_stack + 130470;
 Libderiv->deriv_classes[4][6][8] = int_stack + 133980;
 Libderiv->deriv_classes[4][7][8] = int_stack + 134400;
 Libderiv->deriv_classes[4][8][8] = int_stack + 134940;
 Libderiv->deriv_classes[4][9][8] = int_stack + 135615;
 Libderiv->deriv_classes[4][10][8] = int_stack + 136440;
 Libderiv->deriv_classes[4][11][8] = int_stack + 137430;
 Libderiv->deriv_classes[5][6][8] = int_stack + 138600;
 Libderiv->deriv_classes[5][7][8] = int_stack + 139188;
 Libderiv->deriv_classes[5][8][8] = int_stack + 139944;
 Libderiv->deriv_classes[5][9][8] = int_stack + 140889;
 Libderiv->deriv_classes[5][10][8] = int_stack + 142044;
 Libderiv->deriv_classes[5][11][8] = int_stack + 143430;
 Libderiv->deriv_classes[6][6][8] = int_stack + 145068;
 Libderiv->deriv_classes[6][7][8] = int_stack + 145852;
 Libderiv->deriv_classes[6][8][8] = int_stack + 146860;
 Libderiv->deriv_classes[6][9][8] = int_stack + 148120;
 Libderiv->deriv_classes[6][10][8] = int_stack + 149660;
 Libderiv->deriv_classes[6][11][8] = int_stack + 151508;
 Libderiv->deriv_classes[7][6][8] = int_stack + 153692;
 Libderiv->deriv_classes[7][7][8] = int_stack + 154700;
 Libderiv->deriv_classes[7][8][8] = int_stack + 155996;
 Libderiv->deriv_classes[7][9][8] = int_stack + 157616;
 Libderiv->deriv_classes[7][10][8] = int_stack + 159596;
 Libderiv->deriv_classes[7][11][8] = int_stack + 161972;
 Libderiv->deriv_classes[8][6][8] = int_stack + 164780;
 Libderiv->deriv_classes[8][7][8] = int_stack + 166040;
 Libderiv->deriv_classes[8][8][8] = int_stack + 167660;
 Libderiv->deriv_classes[8][9][8] = int_stack + 169685;
 Libderiv->deriv_classes[8][10][8] = int_stack + 172160;
 Libderiv->deriv_classes[8][11][8] = int_stack + 175130;
 Libderiv->deriv_classes[4][6][7] = int_stack + 178640;
 Libderiv->deriv_classes[4][7][7] = int_stack + 179060;
 Libderiv->deriv_classes[4][8][7] = int_stack + 179600;
 Libderiv->deriv_classes[4][9][7] = int_stack + 180275;
 Libderiv->deriv_classes[4][10][7] = int_stack + 181100;
 Libderiv->deriv_classes[4][11][7] = int_stack + 182090;
 Libderiv->deriv_classes[5][6][7] = int_stack + 183260;
 Libderiv->deriv_classes[5][7][7] = int_stack + 183848;
 Libderiv->deriv_classes[5][8][7] = int_stack + 184604;
 Libderiv->deriv_classes[5][9][7] = int_stack + 185549;
 Libderiv->deriv_classes[5][10][7] = int_stack + 186704;
 Libderiv->deriv_classes[5][11][7] = int_stack + 188090;
 Libderiv->deriv_classes[6][6][7] = int_stack + 189728;
 Libderiv->deriv_classes[6][7][7] = int_stack + 190512;
 Libderiv->deriv_classes[6][8][7] = int_stack + 191520;
 Libderiv->deriv_classes[6][9][7] = int_stack + 192780;
 Libderiv->deriv_classes[6][10][7] = int_stack + 194320;
 Libderiv->deriv_classes[6][11][7] = int_stack + 196168;
 Libderiv->deriv_classes[7][6][7] = int_stack + 198352;
 Libderiv->deriv_classes[7][7][7] = int_stack + 199360;
 Libderiv->deriv_classes[7][8][7] = int_stack + 200656;
 Libderiv->deriv_classes[7][9][7] = int_stack + 202276;
 Libderiv->deriv_classes[7][10][7] = int_stack + 204256;
 Libderiv->deriv_classes[7][11][7] = int_stack + 206632;
 Libderiv->deriv_classes[8][6][7] = int_stack + 209440;
 Libderiv->deriv_classes[8][7][7] = int_stack + 210700;
 Libderiv->deriv_classes[8][8][7] = int_stack + 212320;
 Libderiv->deriv_classes[8][9][7] = int_stack + 214345;
 Libderiv->deriv_classes[8][10][7] = int_stack + 216820;
 Libderiv->deriv_classes[8][11][7] = int_stack + 219790;
 Libderiv->deriv_classes[4][6][6] = int_stack + 223300;
 Libderiv->deriv_classes[4][7][6] = int_stack + 223720;
 Libderiv->deriv_classes[4][8][6] = int_stack + 224260;
 Libderiv->deriv_classes[4][9][6] = int_stack + 224935;
 Libderiv->deriv_classes[4][10][6] = int_stack + 225760;
 Libderiv->deriv_classes[4][11][6] = int_stack + 226750;
 Libderiv->deriv_classes[5][6][6] = int_stack + 227920;
 Libderiv->deriv_classes[5][7][6] = int_stack + 228508;
 Libderiv->deriv_classes[5][8][6] = int_stack + 229264;
 Libderiv->deriv_classes[5][9][6] = int_stack + 230209;
 Libderiv->deriv_classes[5][10][6] = int_stack + 231364;
 Libderiv->deriv_classes[5][11][6] = int_stack + 232750;
 Libderiv->deriv_classes[6][6][6] = int_stack + 234388;
 Libderiv->deriv_classes[6][7][6] = int_stack + 235172;
 Libderiv->deriv_classes[6][8][6] = int_stack + 236180;
 Libderiv->deriv_classes[6][9][6] = int_stack + 237440;
 Libderiv->deriv_classes[6][10][6] = int_stack + 238980;
 Libderiv->deriv_classes[6][11][6] = int_stack + 240828;
 Libderiv->deriv_classes[7][6][6] = int_stack + 243012;
 Libderiv->deriv_classes[7][7][6] = int_stack + 244020;
 Libderiv->deriv_classes[7][8][6] = int_stack + 245316;
 Libderiv->deriv_classes[7][9][6] = int_stack + 246936;
 Libderiv->deriv_classes[7][10][6] = int_stack + 248916;
 Libderiv->deriv_classes[7][11][6] = int_stack + 251292;
 Libderiv->dvrr_classes[8][6] = int_stack + 254100;
 Libderiv->deriv_classes[8][6][6] = int_stack + 255360;
 Libderiv->dvrr_classes[8][7] = int_stack + 256620;
 Libderiv->deriv_classes[8][7][6] = int_stack + 258240;
 Libderiv->dvrr_classes[8][8] = int_stack + 259860;
 Libderiv->deriv_classes[8][8][6] = int_stack + 261885;
 Libderiv->dvrr_classes[8][9] = int_stack + 263910;
 Libderiv->deriv_classes[8][9][6] = int_stack + 266385;
 Libderiv->dvrr_classes[8][10] = int_stack + 268860;
 Libderiv->deriv_classes[8][10][6] = int_stack + 271830;
 Libderiv->deriv_classes[8][11][6] = int_stack + 274800;
 Libderiv->deriv_classes[4][6][2] = int_stack + 278310;
 Libderiv->deriv_classes[4][7][2] = int_stack + 278730;
 Libderiv->deriv_classes[4][8][2] = int_stack + 279270;
 Libderiv->deriv_classes[4][9][2] = int_stack + 279945;
 Libderiv->deriv_classes[4][10][2] = int_stack + 280770;
 Libderiv->deriv_classes[4][11][2] = int_stack + 281760;
 Libderiv->deriv_classes[5][6][2] = int_stack + 282930;
 Libderiv->deriv_classes[5][7][2] = int_stack + 283518;
 Libderiv->deriv_classes[5][8][2] = int_stack + 284274;
 Libderiv->deriv_classes[5][9][2] = int_stack + 285219;
 Libderiv->deriv_classes[5][10][2] = int_stack + 286374;
 Libderiv->deriv_classes[5][11][2] = int_stack + 287760;
 Libderiv->deriv_classes[6][6][2] = int_stack + 289398;
 Libderiv->deriv_classes[6][7][2] = int_stack + 290182;
 Libderiv->deriv_classes[6][8][2] = int_stack + 291190;
 Libderiv->deriv_classes[6][9][2] = int_stack + 292450;
 Libderiv->deriv_classes[6][10][2] = int_stack + 293990;
 Libderiv->deriv_classes[6][11][2] = int_stack + 295838;
 Libderiv->deriv_classes[7][6][2] = int_stack + 298022;
 Libderiv->deriv_classes[7][7][2] = int_stack + 299030;
 Libderiv->deriv_classes[7][8][2] = int_stack + 300326;
 Libderiv->deriv_classes[7][9][2] = int_stack + 301946;
 Libderiv->deriv_classes[7][10][2] = int_stack + 303926;
 Libderiv->deriv_classes[7][11][2] = int_stack + 306302;
 Libderiv->deriv_classes[8][6][2] = int_stack + 309110;
 Libderiv->deriv_classes[8][7][2] = int_stack + 310370;
 Libderiv->deriv_classes[8][8][2] = int_stack + 311990;
 Libderiv->deriv_classes[8][9][2] = int_stack + 314015;
 Libderiv->deriv_classes[8][10][2] = int_stack + 316490;
 Libderiv->deriv_classes[8][11][2] = int_stack + 319460;
 Libderiv->deriv_classes[4][6][1] = int_stack + 322970;
 Libderiv->deriv_classes[4][7][1] = int_stack + 323390;
 Libderiv->deriv_classes[4][8][1] = int_stack + 323930;
 Libderiv->deriv_classes[4][9][1] = int_stack + 324605;
 Libderiv->deriv_classes[4][10][1] = int_stack + 325430;
 Libderiv->deriv_classes[4][11][1] = int_stack + 326420;
 Libderiv->deriv_classes[5][6][1] = int_stack + 327590;
 Libderiv->deriv_classes[5][7][1] = int_stack + 328178;
 Libderiv->deriv_classes[5][8][1] = int_stack + 328934;
 Libderiv->deriv_classes[5][9][1] = int_stack + 329879;
 Libderiv->deriv_classes[5][10][1] = int_stack + 331034;
 Libderiv->deriv_classes[5][11][1] = int_stack + 332420;
 Libderiv->deriv_classes[6][6][1] = int_stack + 334058;
 Libderiv->deriv_classes[6][7][1] = int_stack + 334842;
 Libderiv->deriv_classes[6][8][1] = int_stack + 335850;
 Libderiv->deriv_classes[6][9][1] = int_stack + 337110;
 Libderiv->deriv_classes[6][10][1] = int_stack + 338650;
 Libderiv->deriv_classes[6][11][1] = int_stack + 340498;
 Libderiv->deriv_classes[7][6][1] = int_stack + 342682;
 Libderiv->deriv_classes[7][7][1] = int_stack + 343690;
 Libderiv->deriv_classes[7][8][1] = int_stack + 344986;
 Libderiv->deriv_classes[7][9][1] = int_stack + 346606;
 Libderiv->deriv_classes[7][10][1] = int_stack + 348586;
 Libderiv->deriv_classes[7][11][1] = int_stack + 350962;
 Libderiv->deriv_classes[8][6][1] = int_stack + 353770;
 Libderiv->deriv_classes[8][7][1] = int_stack + 355030;
 Libderiv->deriv_classes[8][8][1] = int_stack + 356650;
 Libderiv->deriv_classes[8][9][1] = int_stack + 358675;
 Libderiv->deriv_classes[8][10][1] = int_stack + 361150;
 Libderiv->deriv_classes[8][11][1] = int_stack + 364120;
 Libderiv->dvrr_classes[4][6] = int_stack + 367630;
 Libderiv->dvrr_classes[4][7] = int_stack + 368050;
 Libderiv->dvrr_classes[4][8] = int_stack + 368590;
 Libderiv->dvrr_classes[4][9] = int_stack + 369265;
 Libderiv->dvrr_classes[4][10] = int_stack + 370090;
 Libderiv->dvrr_classes[4][11] = int_stack + 371080;
 Libderiv->deriv_classes[4][6][0] = int_stack + 372250;
 Libderiv->deriv_classes[4][7][0] = int_stack + 372670;
 Libderiv->deriv_classes[4][8][0] = int_stack + 373210;
 Libderiv->deriv_classes[4][9][0] = int_stack + 373885;
 Libderiv->deriv_classes[4][10][0] = int_stack + 374710;
 Libderiv->deriv_classes[4][11][0] = int_stack + 375700;
 Libderiv->dvrr_classes[5][6] = int_stack + 376870;
 Libderiv->dvrr_classes[5][7] = int_stack + 377458;
 Libderiv->dvrr_classes[5][8] = int_stack + 378214;
 Libderiv->dvrr_classes[5][9] = int_stack + 379159;
 Libderiv->dvrr_classes[5][10] = int_stack + 380314;
 Libderiv->dvrr_classes[5][11] = int_stack + 381700;
 Libderiv->deriv_classes[5][6][0] = int_stack + 383338;
 Libderiv->deriv_classes[5][7][0] = int_stack + 383926;
 Libderiv->deriv_classes[5][8][0] = int_stack + 384682;
 Libderiv->deriv_classes[5][9][0] = int_stack + 385627;
 Libderiv->deriv_classes[5][10][0] = int_stack + 386782;
 Libderiv->deriv_classes[5][11][0] = int_stack + 388168;
 Libderiv->dvrr_classes[6][6] = int_stack + 389806;
 Libderiv->dvrr_classes[6][7] = int_stack + 390590;
 Libderiv->dvrr_classes[6][8] = int_stack + 391598;
 Libderiv->dvrr_classes[6][9] = int_stack + 392858;
 Libderiv->dvrr_classes[6][10] = int_stack + 394398;
 Libderiv->dvrr_classes[6][11] = int_stack + 396246;
 Libderiv->deriv_classes[6][6][0] = int_stack + 398430;
 Libderiv->deriv_classes[6][7][0] = int_stack + 399214;
 Libderiv->deriv_classes[6][8][0] = int_stack + 400222;
 Libderiv->deriv_classes[6][9][0] = int_stack + 401482;
 Libderiv->deriv_classes[6][10][0] = int_stack + 403022;
 Libderiv->deriv_classes[6][11][0] = int_stack + 404870;
 Libderiv->dvrr_classes[7][6] = int_stack + 407054;
 Libderiv->dvrr_classes[7][7] = int_stack + 408062;
 Libderiv->dvrr_classes[7][8] = int_stack + 409358;
 Libderiv->dvrr_classes[7][9] = int_stack + 410978;
 Libderiv->dvrr_classes[7][10] = int_stack + 412958;
 Libderiv->dvrr_classes[7][11] = int_stack + 415334;
 Libderiv->deriv_classes[7][6][0] = int_stack + 418142;
 Libderiv->deriv_classes[7][7][0] = int_stack + 419150;
 Libderiv->deriv_classes[7][8][0] = int_stack + 420446;
 Libderiv->deriv_classes[7][9][0] = int_stack + 422066;
 Libderiv->deriv_classes[7][10][0] = int_stack + 424046;
 Libderiv->deriv_classes[7][11][0] = int_stack + 426422;
 Libderiv->deriv_classes[8][6][0] = int_stack + 429230;
 Libderiv->deriv_classes[8][7][0] = int_stack + 430490;
 Libderiv->deriv_classes[8][8][0] = int_stack + 432110;
 Libderiv->deriv_classes[8][9][0] = int_stack + 434135;
 Libderiv->deriv_classes[8][10][0] = int_stack + 436610;
 Libderiv->deriv_classes[8][11][0] = int_stack + 439580;
 memset(int_stack,0,3544720);

 Libderiv->dvrr_stack = int_stack + 2897738;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_ggih(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+443090,int_stack+368050,int_stack+367630,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+444350,int_stack+368590,int_stack+368050,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+445970,int_stack+444350,int_stack+443090,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+448490,int_stack+369265,int_stack+368590,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+450515,int_stack+448490,int_stack+444350,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+453755,int_stack+450515,int_stack+445970,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+457955,int_stack+370090,int_stack+369265,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+460430,int_stack+457955,int_stack+448490,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+464480,int_stack+460430,int_stack+450515,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+469880,int_stack+464480,int_stack+453755,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+476180,int_stack+420,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367630,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+477440,int_stack+960,int_stack+420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368050,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+479060,int_stack+477440,int_stack+476180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443090,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+481580,int_stack+1635,int_stack+960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368590,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+483605,int_stack+481580,int_stack+477440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+444350,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+486845,int_stack+483605,int_stack+479060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+445970,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+476180,int_stack+2460,int_stack+1635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369265,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+491045,int_stack+476180,int_stack+481580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+448490,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+495095,int_stack+491045,int_stack+483605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450515,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+478655,int_stack+495095,int_stack+486845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+453755,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+484955,int_stack+3450,int_stack+2460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370090,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+500495,int_stack+484955,int_stack+476180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457955,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+505445,int_stack+500495,int_stack+491045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460430,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+484955,int_stack+505445,int_stack+495095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464480,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+493055,int_stack+484955,int_stack+478655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+469880,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+476180,int_stack+377458,int_stack+376870,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+477944,int_stack+378214,int_stack+377458,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+480212,int_stack+477944,int_stack+476180,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+483740,int_stack+379159,int_stack+378214,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+486575,int_stack+483740,int_stack+477944,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+501875,int_stack+486575,int_stack+480212,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+507755,int_stack+380314,int_stack+379159,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+511220,int_stack+507755,int_stack+483740,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+516890,int_stack+511220,int_stack+486575,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+524450,int_stack+516890,int_stack+501875,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+491111,int_stack+5208,int_stack+4620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376870,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+5964,int_stack+5208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+377458,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2268,int_stack+0,int_stack+491111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476180,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+533270,int_stack+6909,int_stack+5964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+378214,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+536105,int_stack+533270,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477944,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+540641,int_stack+536105,int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480212,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+8064,int_stack+6909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+379159,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+546521,int_stack+0,int_stack+533270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483740,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+552191,int_stack+546521,int_stack+536105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486575,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+559751,int_stack+552191,int_stack+540641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+501875,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+533270,int_stack+9450,int_stack+8064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+380314,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+537428,int_stack+533270,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507755,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+0,int_stack+537428,int_stack+546521, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511220,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+533270,int_stack+0,int_stack+552191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+516890,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+544610,int_stack+533270,int_stack+559751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524450,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+556958,int_stack+544610,int_stack+493055,588);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+533270,int_stack+390590,int_stack+389806,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+535622,int_stack+391598,int_stack+390590,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+538646,int_stack+535622,int_stack+533270,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+392858,int_stack+391598,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3780,int_stack+0,int_stack+535622,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+491111,int_stack+3780,int_stack+538646,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+583418,int_stack+394398,int_stack+392858,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+588038,int_stack+583418,int_stack+0,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+595598,int_stack+588038,int_stack+3780,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+605678,int_stack+595598,int_stack+491111,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+498951,int_stack+11872,int_stack+11088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+389806,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+617438,int_stack+12880,int_stack+11872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390590,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+620462,int_stack+617438,int_stack+498951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533270,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+625166,int_stack+14140,int_stack+12880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+391598,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+628946,int_stack+625166,int_stack+617438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535622,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+634994,int_stack+628946,int_stack+620462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+538646,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+617438,int_stack+15680,int_stack+14140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392858,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+642834,int_stack+617438,int_stack+625166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+650394,int_stack+642834,int_stack+628946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+622058,int_stack+650394,int_stack+634994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+491111,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+633818,int_stack+17528,int_stack+15680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+394398,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+9828,int_stack+633818,int_stack+617438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+583418,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+660474,int_stack+9828,int_stack+642834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588038,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+633818,int_stack+660474,int_stack+650394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595598,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+648938,int_stack+633818,int_stack+622058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+605678,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+665402,int_stack+648938,int_stack+544610,588);
 /*--- compute (gd|ih) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+702446,int_stack+665402,int_stack+556958,588);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+9828,int_stack+408062,int_stack+407054,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+12852,int_stack+409358,int_stack+408062,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+617438,int_stack+12852,int_stack+9828,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+623486,int_stack+410978,int_stack+409358,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+628346,int_stack+623486,int_stack+12852,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+636122,int_stack+628346,int_stack+617438,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+543350,int_stack+412958,int_stack+410978,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+549290,int_stack+543350,int_stack+623486,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+559010,int_stack+549290,int_stack+628346,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+755366,int_stack+559010,int_stack+636122,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+571970,int_stack+20720,int_stack+19712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+407054,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+16740,int_stack+22016,int_stack+20720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+408062,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+574994,int_stack+16740,int_stack+571970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9828,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+770486,int_stack+23636,int_stack+22016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409358,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+775346,int_stack+770486,int_stack+16740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12852,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+783122,int_stack+775346,int_stack+574994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617438,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+16740,int_stack+25616,int_stack+23636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410978,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+571970,int_stack+16740,int_stack+770486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+623486,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+793202,int_stack+571970,int_stack+775346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+628346,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+806162,int_stack+793202,int_stack+783122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+636122,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+770486,int_stack+27992,int_stack+25616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412958,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+777614,int_stack+770486,int_stack+16740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+543350,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+821282,int_stack+777614,int_stack+571970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+549290,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+770486,int_stack+821282,int_stack+793202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+559010,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+821282,int_stack+770486,int_stack+806162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+755366,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+770486,int_stack+821282,int_stack+648938,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+842450,int_stack+770486,int_stack+665402,588);
 /*--- compute (gf|ih) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+916538,int_stack+842450,int_stack+702446,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+571970,int_stack+256620,int_stack+254100,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+575750,int_stack+259860,int_stack+256620,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+16740,int_stack+575750,int_stack+571970,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+24300,int_stack+263910,int_stack+259860,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+646202,int_stack+24300,int_stack+575750,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+655922,int_stack+646202,int_stack+16740,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+668522,int_stack+268860,int_stack+263910,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+675947,int_stack+668522,int_stack+24300,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+688097,int_stack+675947,int_stack+646202,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+704297,int_stack+688097,int_stack+655922,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+723197,int_stack+32060,int_stack+30800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254100,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+726977,int_stack+33680,int_stack+32060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256620,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+731837,int_stack+726977,int_stack+723197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+571970,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+739397,int_stack+35705,int_stack+33680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259860,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+745472,int_stack+739397,int_stack+726977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+575750,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1004738,int_stack+745472,int_stack+731837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16740,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+723197,int_stack+38180,int_stack+35705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263910,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1017338,int_stack+723197,int_stack+739397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24300,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1029488,int_stack+1017338,int_stack+745472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646202,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+730622,int_stack+1029488,int_stack+1004738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+655922,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1004738,int_stack+41150,int_stack+38180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268860,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1045688,int_stack+1004738,int_stack+723197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+668522,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1060538,int_stack+1045688,int_stack+1017338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+675947,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1004738,int_stack+1060538,int_stack+1029488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+688097,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1029038,int_stack+1004738,int_stack+730622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704297,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1055498,int_stack+1029038,int_stack+821282,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1119002,int_stack+1055498,int_stack+770486,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1217786,int_stack+1119002,int_stack+842450,588);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+770486,int_stack+45080,int_stack+44660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367630, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+771746,int_stack+45620,int_stack+45080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368050, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+773366,int_stack+771746,int_stack+770486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443090, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+775886,int_stack+46295,int_stack+45620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368590, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+777911,int_stack+775886,int_stack+771746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+444350, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+781151,int_stack+777911,int_stack+773366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+445970, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+770486,int_stack+47120,int_stack+46295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369265, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+785351,int_stack+770486,int_stack+775886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+448490, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+789401,int_stack+785351,int_stack+777911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450515, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+772961,int_stack+789401,int_stack+781151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+453755, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+779261,int_stack+48110,int_stack+47120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370090, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+794801,int_stack+779261,int_stack+770486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457955, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+799751,int_stack+794801,int_stack+785351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460430, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+779261,int_stack+799751,int_stack+789401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464480, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+787361,int_stack+779261,int_stack+772961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+469880, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+770486,int_stack+49868,int_stack+49280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376870, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+772250,int_stack+50624,int_stack+49868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+377458, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+774518,int_stack+772250,int_stack+770486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476180, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+778046,int_stack+51569,int_stack+50624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+378214, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+780881,int_stack+778046,int_stack+772250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477944, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+796181,int_stack+780881,int_stack+774518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480212, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+770486,int_stack+52724,int_stack+51569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+379159, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+802061,int_stack+770486,int_stack+778046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483740, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+807731,int_stack+802061,int_stack+780881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486575, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+773951,int_stack+807731,int_stack+796181, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+501875, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+796181,int_stack+54110,int_stack+52724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+380314, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+815291,int_stack+796181,int_stack+770486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507755, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+822221,int_stack+815291,int_stack+802061, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511220, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+796181,int_stack+822221,int_stack+807731, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+516890, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+807521,int_stack+796181,int_stack+773951, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524450, 0.0, zero_stack,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+819869,int_stack+807521,int_stack+787361,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+770486,int_stack+56532,int_stack+55748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+389806, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+772838,int_stack+57540,int_stack+56532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390590, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+775862,int_stack+772838,int_stack+770486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533270, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+780566,int_stack+58800,int_stack+57540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+391598, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+784346,int_stack+780566,int_stack+772838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535622, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+790394,int_stack+784346,int_stack+775862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+538646, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+770486,int_stack+60340,int_stack+58800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392858, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+798234,int_stack+770486,int_stack+780566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+846329,int_stack+798234,int_stack+784346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+775106,int_stack+846329,int_stack+790394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+491111, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+786866,int_stack+62188,int_stack+60340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+394398, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+856409,int_stack+786866,int_stack+770486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+583418, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+865649,int_stack+856409,int_stack+798234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588038, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+786866,int_stack+865649,int_stack+846329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595598, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+846329,int_stack+786866,int_stack+775106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+605678, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+862793,int_stack+846329,int_stack+807521,588);
 /*--- compute (gd|ih) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1004738,int_stack+862793,int_stack+819869,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+899837,int_stack+65380,int_stack+64372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+407054, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+902861,int_stack+66676,int_stack+65380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+408062, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+906749,int_stack+902861,int_stack+899837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9828, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+770486,int_stack+68296,int_stack+66676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409358, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+775346,int_stack+770486,int_stack+902861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12852, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+783122,int_stack+775346,int_stack+906749, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617438, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+899837,int_stack+70276,int_stack+68296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410978, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+905777,int_stack+899837,int_stack+770486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+623486, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+793202,int_stack+905777,int_stack+775346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+628346, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+806162,int_stack+793202,int_stack+783122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+636122, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+770486,int_stack+72652,int_stack+70276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412958, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+777614,int_stack+770486,int_stack+899837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+543350, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+821282,int_stack+777614,int_stack+905777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+549290, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+770486,int_stack+821282,int_stack+793202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+559010, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+821282,int_stack+770486,int_stack+806162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+755366, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+770486,int_stack+821282,int_stack+846329,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1057658,int_stack+770486,int_stack+862793,588);
 /*--- compute (gf|ih) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1341266,int_stack+1057658,int_stack+1004738,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1004738,int_stack+76720,int_stack+75460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254100, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1008518,int_stack+78340,int_stack+76720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256620, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1013378,int_stack+1008518,int_stack+1004738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+571970, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1020938,int_stack+80365,int_stack+78340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259860, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1027013,int_stack+1020938,int_stack+1008518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+575750, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1036733,int_stack+1027013,int_stack+1013378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16740, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1004738,int_stack+82840,int_stack+80365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263910, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+842450,int_stack+1004738,int_stack+1020938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24300, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+854600,int_stack+842450,int_stack+1027013, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646202, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1012163,int_stack+854600,int_stack+1036733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+655922, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1031063,int_stack+85810,int_stack+82840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268860, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1039973,int_stack+1031063,int_stack+1004738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+668522, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+870800,int_stack+1039973,int_stack+842450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+675947, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1031063,int_stack+870800,int_stack+854600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+688097, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+842450,int_stack+1031063,int_stack+1012163, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704297, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1131746,int_stack+842450,int_stack+821282,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1429466,int_stack+1131746,int_stack+770486,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+770486,int_stack+1429466,int_stack+1057658,588);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1429466,int_stack+89740,int_stack+89320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367630, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1430726,int_stack+90280,int_stack+89740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368050, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1432346,int_stack+1430726,int_stack+1429466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443090, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1434866,int_stack+90955,int_stack+90280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368590, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1436891,int_stack+1434866,int_stack+1430726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+444350, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1440131,int_stack+1436891,int_stack+1432346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+445970, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1429466,int_stack+91780,int_stack+90955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369265, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1444331,int_stack+1429466,int_stack+1434866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+448490, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1448381,int_stack+1444331,int_stack+1436891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450515, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1431941,int_stack+1448381,int_stack+1440131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+453755, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1438241,int_stack+92770,int_stack+91780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370090, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1453781,int_stack+1438241,int_stack+1429466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457955, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1458731,int_stack+1453781,int_stack+1444331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460430, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1438241,int_stack+1458731,int_stack+1448381, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464480, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1446341,int_stack+1438241,int_stack+1431941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+469880, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1429466,int_stack+94528,int_stack+93940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376870, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1431230,int_stack+95284,int_stack+94528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+377458, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1433498,int_stack+1431230,int_stack+1429466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476180, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1437026,int_stack+96229,int_stack+95284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+378214, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1439861,int_stack+1437026,int_stack+1431230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477944, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1455161,int_stack+1439861,int_stack+1433498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480212, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1429466,int_stack+97384,int_stack+96229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+379159, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1461041,int_stack+1429466,int_stack+1437026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483740, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1466711,int_stack+1461041,int_stack+1439861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486575, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1432931,int_stack+1466711,int_stack+1455161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+501875, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1455161,int_stack+98770,int_stack+97384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+380314, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1474271,int_stack+1455161,int_stack+1429466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507755, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1481201,int_stack+1474271,int_stack+1461041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511220, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1455161,int_stack+1481201,int_stack+1466711, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+516890, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1466501,int_stack+1455161,int_stack+1432931, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524450, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+1478849,int_stack+1466501,int_stack+1446341,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1429466,int_stack+101192,int_stack+100408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+389806, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1431818,int_stack+102200,int_stack+101192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390590, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1434842,int_stack+1431818,int_stack+1429466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533270, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1439546,int_stack+103460,int_stack+102200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+391598, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1443326,int_stack+1439546,int_stack+1431818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535622, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1449374,int_stack+1443326,int_stack+1434842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+538646, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1429466,int_stack+105000,int_stack+103460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392858, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1457214,int_stack+1429466,int_stack+1439546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1505309,int_stack+1457214,int_stack+1443326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1434086,int_stack+1505309,int_stack+1449374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+491111, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1445846,int_stack+106848,int_stack+105000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+394398, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1515389,int_stack+1445846,int_stack+1429466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+583418, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+893966,int_stack+1515389,int_stack+1457214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588038, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1445846,int_stack+893966,int_stack+1505309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595598, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1505309,int_stack+1445846,int_stack+1434086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+605678, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1004738,int_stack+1505309,int_stack+1466501,588);
 /*--- compute (gd|ih) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1041782,int_stack+1004738,int_stack+1478849,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1521773,int_stack+110040,int_stack+109032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+407054, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1524797,int_stack+111336,int_stack+110040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+408062, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+893966,int_stack+1524797,int_stack+1521773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9828, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+900014,int_stack+112956,int_stack+111336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409358, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+904874,int_stack+900014,int_stack+1524797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12852, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1429466,int_stack+904874,int_stack+893966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617438, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+893966,int_stack+114936,int_stack+112956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410978, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1439546,int_stack+893966,int_stack+900014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+623486, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1449266,int_stack+1439546,int_stack+904874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+628346, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+899906,int_stack+1449266,int_stack+1429466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+636122, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1429466,int_stack+117312,int_stack+114936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412958, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1462226,int_stack+1429466,int_stack+893966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+543350, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1474106,int_stack+1462226,int_stack+1439546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+549290, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1429466,int_stack+1474106,int_stack+1449266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+559010, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1448906,int_stack+1429466,int_stack+899906, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+755366, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1094702,int_stack+1448906,int_stack+1505309,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+30375,int_stack+1094702,int_stack+1004738,588);
 /*--- compute (gf|ih) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1470074,int_stack+30375,int_stack+1041782,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1004738,int_stack+121380,int_stack+120120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254100, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1008518,int_stack+123000,int_stack+121380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256620, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1013378,int_stack+1008518,int_stack+1004738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+571970, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1020938,int_stack+125025,int_stack+123000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259860, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1027013,int_stack+1020938,int_stack+1008518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+575750, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1036733,int_stack+1027013,int_stack+1013378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16740, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1004738,int_stack+127500,int_stack+125025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263910, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1049333,int_stack+1004738,int_stack+1020938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24300, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1061483,int_stack+1049333,int_stack+1027013, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646202, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1012163,int_stack+1061483,int_stack+1036733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+655922, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1031063,int_stack+130470,int_stack+127500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268860, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1077683,int_stack+1031063,int_stack+1004738, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+668522, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+893966,int_stack+1077683,int_stack+1049333, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+675947, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1031063,int_stack+893966,int_stack+1061483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+688097, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1055363,int_stack+1031063,int_stack+1012163, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704297, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1144094,int_stack+1055363,int_stack+1448906,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1558274,int_stack+1144094,int_stack+1094702,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1004738,int_stack+1558274,int_stack+30375,588);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30375,int_stack+134400,int_stack+133980, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+31635,int_stack+134940,int_stack+134400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+33255,int_stack+31635,int_stack+30375, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+35775,int_stack+135615,int_stack+134940, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+37800,int_stack+35775,int_stack+31635, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+444350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+41040,int_stack+37800,int_stack+33255, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+445970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+30375,int_stack+136440,int_stack+135615, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+45240,int_stack+30375,int_stack+35775, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+448490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+49290,int_stack+45240,int_stack+37800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+32850,int_stack+49290,int_stack+41040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+453755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+39150,int_stack+137430,int_stack+136440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+370090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+54690,int_stack+39150,int_stack+30375, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+59640,int_stack+54690,int_stack+45240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+39150,int_stack+59640,int_stack+49290, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+47250,int_stack+39150,int_stack+32850, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+469880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30375,int_stack+139188,int_stack+138600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+376870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+32139,int_stack+139944,int_stack+139188, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+377458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+34407,int_stack+32139,int_stack+30375, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+37935,int_stack+140889,int_stack+139944, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+378214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+40770,int_stack+37935,int_stack+32139, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+56070,int_stack+40770,int_stack+34407, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+30375,int_stack+142044,int_stack+140889, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+379159, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+61950,int_stack+30375,int_stack+37935, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+67620,int_stack+61950,int_stack+40770, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+33840,int_stack+67620,int_stack+56070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+501875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+56070,int_stack+143430,int_stack+142044, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+380314, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+75180,int_stack+56070,int_stack+30375, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+507755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+82110,int_stack+75180,int_stack+61950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+56070,int_stack+82110,int_stack+67620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+516890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+67410,int_stack+56070,int_stack+33840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+79758,int_stack+67410,int_stack+47250,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30375,int_stack+145852,int_stack+145068, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+389806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+32727,int_stack+146860,int_stack+145852, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+35751,int_stack+32727,int_stack+30375, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+40455,int_stack+148120,int_stack+146860, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+391598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+44235,int_stack+40455,int_stack+32727, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+50283,int_stack+44235,int_stack+35751, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+538646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+30375,int_stack+149660,int_stack+148120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+58123,int_stack+30375,int_stack+40455, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+106218,int_stack+58123,int_stack+44235, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+34995,int_stack+106218,int_stack+50283, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+491111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+46755,int_stack+151508,int_stack+149660, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+394398, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+116298,int_stack+46755,int_stack+30375, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+583418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+125538,int_stack+116298,int_stack+58123, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+46755,int_stack+125538,int_stack+106218, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+106218,int_stack+46755,int_stack+34995, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+605678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1558274,int_stack+106218,int_stack+67410,588);
 /*--- compute (gd|ih) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1595318,int_stack+1558274,int_stack+79758,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+122682,int_stack+154700,int_stack+153692, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+407054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+125706,int_stack+155996,int_stack+154700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+408062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+129594,int_stack+125706,int_stack+122682, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+135642,int_stack+157616,int_stack+155996, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+140502,int_stack+135642,int_stack+125706, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+30375,int_stack+140502,int_stack+129594, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+122682,int_stack+159596,int_stack+157616, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+148278,int_stack+122682,int_stack+135642, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+623486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+40455,int_stack+148278,int_stack+140502, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+628346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+128622,int_stack+40455,int_stack+30375, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+636122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+30375,int_stack+161972,int_stack+159596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+53415,int_stack+30375,int_stack+122682, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+543350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+65295,int_stack+53415,int_stack+148278, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+549290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+143742,int_stack+65295,int_stack+40455, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+559010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+30375,int_stack+143742,int_stack+128622, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+755366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+51543,int_stack+30375,int_stack+106218,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1128218,int_stack+51543,int_stack+1558274,588);
 /*--- compute (gf|ih) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1648238,int_stack+1128218,int_stack+1595318,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1558274,int_stack+166040,int_stack+164780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1562054,int_stack+167660,int_stack+166040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1566914,int_stack+1562054,int_stack+1558274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+571970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1574474,int_stack+169685,int_stack+167660, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1580549,int_stack+1574474,int_stack+1562054, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+575750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1590269,int_stack+1580549,int_stack+1566914, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1558274,int_stack+172160,int_stack+169685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1602869,int_stack+1558274,int_stack+1574474, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1615019,int_stack+1602869,int_stack+1580549, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1565699,int_stack+1615019,int_stack+1590269, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+655922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1584599,int_stack+175130,int_stack+172160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1631219,int_stack+1584599,int_stack+1558274, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+668522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+100935,int_stack+1631219,int_stack+1602869, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+675947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1584599,int_stack+100935,int_stack+1615019, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+688097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+100935,int_stack+1584599,int_stack+1565699, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1558274,int_stack+100935,int_stack+30375,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1736438,int_stack+1558274,int_stack+51543,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+30375,int_stack+1736438,int_stack+1128218,588);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1128218,int_stack+179060,int_stack+178640, 0.0, zero_stack, 1.0, int_stack+367630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1129478,int_stack+179600,int_stack+179060, 0.0, zero_stack, 1.0, int_stack+368050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1131098,int_stack+1129478,int_stack+1128218, 0.0, zero_stack, 1.0, int_stack+443090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1133618,int_stack+180275,int_stack+179600, 0.0, zero_stack, 1.0, int_stack+368590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1135643,int_stack+1133618,int_stack+1129478, 0.0, zero_stack, 1.0, int_stack+444350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1138883,int_stack+1135643,int_stack+1131098, 0.0, zero_stack, 1.0, int_stack+445970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1128218,int_stack+181100,int_stack+180275, 0.0, zero_stack, 1.0, int_stack+369265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1143083,int_stack+1128218,int_stack+1133618, 0.0, zero_stack, 1.0, int_stack+448490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1147133,int_stack+1143083,int_stack+1135643, 0.0, zero_stack, 1.0, int_stack+450515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1130693,int_stack+1147133,int_stack+1138883, 0.0, zero_stack, 1.0, int_stack+453755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1136993,int_stack+182090,int_stack+181100, 0.0, zero_stack, 1.0, int_stack+370090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1152533,int_stack+1136993,int_stack+1128218, 0.0, zero_stack, 1.0, int_stack+457955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1157483,int_stack+1152533,int_stack+1143083, 0.0, zero_stack, 1.0, int_stack+460430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1136993,int_stack+1157483,int_stack+1147133, 0.0, zero_stack, 1.0, int_stack+464480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1145093,int_stack+1136993,int_stack+1130693, 0.0, zero_stack, 1.0, int_stack+469880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1128218,int_stack+183848,int_stack+183260, 0.0, zero_stack, 1.0, int_stack+376870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1129982,int_stack+184604,int_stack+183848, 0.0, zero_stack, 1.0, int_stack+377458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1132250,int_stack+1129982,int_stack+1128218, 0.0, zero_stack, 1.0, int_stack+476180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1135778,int_stack+185549,int_stack+184604, 0.0, zero_stack, 1.0, int_stack+378214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1138613,int_stack+1135778,int_stack+1129982, 0.0, zero_stack, 1.0, int_stack+477944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1153913,int_stack+1138613,int_stack+1132250, 0.0, zero_stack, 1.0, int_stack+480212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1128218,int_stack+186704,int_stack+185549, 0.0, zero_stack, 1.0, int_stack+379159, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1159793,int_stack+1128218,int_stack+1135778, 0.0, zero_stack, 1.0, int_stack+483740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1165463,int_stack+1159793,int_stack+1138613, 0.0, zero_stack, 1.0, int_stack+486575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1131683,int_stack+1165463,int_stack+1153913, 0.0, zero_stack, 1.0, int_stack+501875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1153913,int_stack+188090,int_stack+186704, 0.0, zero_stack, 1.0, int_stack+380314, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1173023,int_stack+1153913,int_stack+1128218, 0.0, zero_stack, 1.0, int_stack+507755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1179953,int_stack+1173023,int_stack+1159793, 0.0, zero_stack, 1.0, int_stack+511220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1153913,int_stack+1179953,int_stack+1165463, 0.0, zero_stack, 1.0, int_stack+516890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1165253,int_stack+1153913,int_stack+1131683, 0.0, zero_stack, 1.0, int_stack+524450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+1177601,int_stack+1165253,int_stack+1145093,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1128218,int_stack+190512,int_stack+189728, 0.0, zero_stack, 1.0, int_stack+389806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1130570,int_stack+191520,int_stack+190512, 0.0, zero_stack, 1.0, int_stack+390590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1133594,int_stack+1130570,int_stack+1128218, 0.0, zero_stack, 1.0, int_stack+533270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1138298,int_stack+192780,int_stack+191520, 0.0, zero_stack, 1.0, int_stack+391598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1142078,int_stack+1138298,int_stack+1130570, 0.0, zero_stack, 1.0, int_stack+535622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1148126,int_stack+1142078,int_stack+1133594, 0.0, zero_stack, 1.0, int_stack+538646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1128218,int_stack+194320,int_stack+192780, 0.0, zero_stack, 1.0, int_stack+392858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1155966,int_stack+1128218,int_stack+1138298, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1204061,int_stack+1155966,int_stack+1142078, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1132838,int_stack+1204061,int_stack+1148126, 0.0, zero_stack, 1.0, int_stack+491111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1144598,int_stack+196168,int_stack+194320, 0.0, zero_stack, 1.0, int_stack+394398, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1736438,int_stack+1144598,int_stack+1128218, 0.0, zero_stack, 1.0, int_stack+583418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1745678,int_stack+1736438,int_stack+1155966, 0.0, zero_stack, 1.0, int_stack+588038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1144598,int_stack+1745678,int_stack+1204061, 0.0, zero_stack, 1.0, int_stack+595598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1736438,int_stack+1144598,int_stack+1132838, 0.0, zero_stack, 1.0, int_stack+605678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1752902,int_stack+1736438,int_stack+1165253,588);
 /*--- compute (gd|ih) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1558274,int_stack+1752902,int_stack+1177601,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1789946,int_stack+199360,int_stack+198352, 0.0, zero_stack, 1.0, int_stack+407054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1792970,int_stack+200656,int_stack+199360, 0.0, zero_stack, 1.0, int_stack+408062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1796858,int_stack+1792970,int_stack+1789946, 0.0, zero_stack, 1.0, int_stack+9828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1802906,int_stack+202276,int_stack+200656, 0.0, zero_stack, 1.0, int_stack+409358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1807766,int_stack+1802906,int_stack+1792970, 0.0, zero_stack, 1.0, int_stack+12852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1815542,int_stack+1807766,int_stack+1796858, 0.0, zero_stack, 1.0, int_stack+617438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1789946,int_stack+204256,int_stack+202276, 0.0, zero_stack, 1.0, int_stack+410978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1825622,int_stack+1789946,int_stack+1802906, 0.0, zero_stack, 1.0, int_stack+623486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1128218,int_stack+1825622,int_stack+1807766, 0.0, zero_stack, 1.0, int_stack+628346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1795886,int_stack+1128218,int_stack+1815542, 0.0, zero_stack, 1.0, int_stack+636122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1811006,int_stack+206632,int_stack+204256, 0.0, zero_stack, 1.0, int_stack+412958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1141178,int_stack+1811006,int_stack+1789946, 0.0, zero_stack, 1.0, int_stack+543350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1153058,int_stack+1141178,int_stack+1825622, 0.0, zero_stack, 1.0, int_stack+549290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1811006,int_stack+1153058,int_stack+1128218, 0.0, zero_stack, 1.0, int_stack+559010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1128218,int_stack+1811006,int_stack+1795886, 0.0, zero_stack, 1.0, int_stack+755366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1149386,int_stack+1128218,int_stack+1736438,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1789946,int_stack+1149386,int_stack+1752902,588);
 /*--- compute (gf|ih) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1864034,int_stack+1789946,int_stack+1558274,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1558274,int_stack+210700,int_stack+209440, 0.0, zero_stack, 1.0, int_stack+254100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1562054,int_stack+212320,int_stack+210700, 0.0, zero_stack, 1.0, int_stack+256620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1566914,int_stack+1562054,int_stack+1558274, 0.0, zero_stack, 1.0, int_stack+571970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1574474,int_stack+214345,int_stack+212320, 0.0, zero_stack, 1.0, int_stack+259860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1580549,int_stack+1574474,int_stack+1562054, 0.0, zero_stack, 1.0, int_stack+575750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1590269,int_stack+1580549,int_stack+1566914, 0.0, zero_stack, 1.0, int_stack+16740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1558274,int_stack+216820,int_stack+214345, 0.0, zero_stack, 1.0, int_stack+263910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1602869,int_stack+1558274,int_stack+1574474, 0.0, zero_stack, 1.0, int_stack+24300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1615019,int_stack+1602869,int_stack+1580549, 0.0, zero_stack, 1.0, int_stack+646202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1565699,int_stack+1615019,int_stack+1590269, 0.0, zero_stack, 1.0, int_stack+655922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1584599,int_stack+219790,int_stack+216820, 0.0, zero_stack, 1.0, int_stack+268860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1631219,int_stack+1584599,int_stack+1558274, 0.0, zero_stack, 1.0, int_stack+668522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1736438,int_stack+1631219,int_stack+1602869, 0.0, zero_stack, 1.0, int_stack+675947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1584599,int_stack+1736438,int_stack+1615019, 0.0, zero_stack, 1.0, int_stack+688097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1736438,int_stack+1584599,int_stack+1565699, 0.0, zero_stack, 1.0, int_stack+704297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1558274,int_stack+1736438,int_stack+1128218,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1952234,int_stack+1558274,int_stack+1149386,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2051018,int_stack+1952234,int_stack+1789946,588);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1952234,int_stack+223720,int_stack+223300, 1.0, int_stack+367630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1953494,int_stack+224260,int_stack+223720, 1.0, int_stack+368050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1955114,int_stack+1953494,int_stack+1952234, 1.0, int_stack+443090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1957634,int_stack+224935,int_stack+224260, 1.0, int_stack+368590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1959659,int_stack+1957634,int_stack+1953494, 1.0, int_stack+444350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1962899,int_stack+1959659,int_stack+1955114, 1.0, int_stack+445970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+443090,int_stack+225760,int_stack+224935, 1.0, int_stack+369265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1952234,int_stack+443090,int_stack+1957634, 1.0, int_stack+448490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1967099,int_stack+1952234,int_stack+1959659, 1.0, int_stack+450515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+445565,int_stack+1967099,int_stack+1962899, 1.0, int_stack+453755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+451865,int_stack+226750,int_stack+225760, 1.0, int_stack+370090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1956284,int_stack+451865,int_stack+443090, 1.0, int_stack+457955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1972499,int_stack+1956284,int_stack+1952234, 1.0, int_stack+460430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1952234,int_stack+1972499,int_stack+1967099, 1.0, int_stack+464480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1960334,int_stack+1952234,int_stack+445565, 1.0, int_stack+469880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1952234,int_stack+228508,int_stack+227920, 1.0, int_stack+376870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1953998,int_stack+229264,int_stack+228508, 1.0, int_stack+377458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1956266,int_stack+1953998,int_stack+1952234, 1.0, int_stack+476180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1969154,int_stack+230209,int_stack+229264, 1.0, int_stack+378214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1971989,int_stack+1969154,int_stack+1953998, 1.0, int_stack+477944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1976525,int_stack+1971989,int_stack+1956266, 1.0, int_stack+480212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+476180,int_stack+231364,int_stack+230209, 1.0, int_stack+379159, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1952234,int_stack+476180,int_stack+1969154, 1.0, int_stack+483740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1982405,int_stack+1952234,int_stack+1971989, 1.0, int_stack+486575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+479645,int_stack+1982405,int_stack+1976525, 1.0, int_stack+501875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1969154,int_stack+232750,int_stack+231364, 1.0, int_stack+380314, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1973312,int_stack+1969154,int_stack+476180, 1.0, int_stack+507755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1989965,int_stack+1973312,int_stack+1952234, 1.0, int_stack+511220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1969154,int_stack+1989965,int_stack+1982405, 1.0, int_stack+516890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1980494,int_stack+1969154,int_stack+479645, 1.0, int_stack+524450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+1992842,int_stack+1980494,int_stack+1960334,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1952234,int_stack+235172,int_stack+234388, 1.0, int_stack+389806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1954586,int_stack+236180,int_stack+235172, 1.0, int_stack+390590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1957610,int_stack+1954586,int_stack+1952234, 1.0, int_stack+533270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1962314,int_stack+237440,int_stack+236180, 1.0, int_stack+391598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1966094,int_stack+1962314,int_stack+1954586, 1.0, int_stack+535622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1972142,int_stack+1966094,int_stack+1957610, 1.0, int_stack+538646, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+533270,int_stack+238980,int_stack+237440, 1.0, int_stack+392858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1952234,int_stack+533270,int_stack+1962314, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+476180,int_stack+1952234,int_stack+1966094, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1959794,int_stack+476180,int_stack+1972142, 1.0, int_stack+491111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+0,int_stack+240828,int_stack+238980, 1.0, int_stack+394398, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+486260,int_stack+0,int_stack+533270, 1.0, int_stack+583418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+2019302,int_stack+486260,int_stack+1952234, 1.0, int_stack+588038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+486260,int_stack+2019302,int_stack+476180, 1.0, int_stack+595598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+2019302,int_stack+486260,int_stack+1959794, 1.0, int_stack+605678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1558274,int_stack+2019302,int_stack+1980494,588);
 /*--- compute (gd|ih) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1595318,int_stack+1558274,int_stack+1992842,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+476180,int_stack+244020,int_stack+243012, 1.0, int_stack+407054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+479204,int_stack+245316,int_stack+244020, 1.0, int_stack+408062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+483092,int_stack+479204,int_stack+476180, 1.0, int_stack+9828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+489140,int_stack+246936,int_stack+245316, 1.0, int_stack+409358, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+494000,int_stack+489140,int_stack+479204, 1.0, int_stack+12852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+533270,int_stack+494000,int_stack+483092, 1.0, int_stack+617438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+617438,int_stack+248916,int_stack+246936, 1.0, int_stack+410978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+476180,int_stack+617438,int_stack+489140, 1.0, int_stack+623486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+2035766,int_stack+476180,int_stack+494000, 1.0, int_stack+628346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+485900,int_stack+2035766,int_stack+533270, 1.0, int_stack+636122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+533270,int_stack+251292,int_stack+248916, 1.0, int_stack+412958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+623378,int_stack+533270,int_stack+617438, 1.0, int_stack+543350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1952234,int_stack+623378,int_stack+476180, 1.0, int_stack+549290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+617438,int_stack+1952234,int_stack+2035766, 1.0, int_stack+559010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+1952234,int_stack+617438,int_stack+485900, 1.0, int_stack+755366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1128218,int_stack+1952234,int_stack+2019302,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1973402,int_stack+1128218,int_stack+1558274,588);
 /*--- compute (gf|ih) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1736438,int_stack+1973402,int_stack+1595318,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1558274,int_stack+258240,int_stack+255360, 1.0, int_stack+254100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1562054,int_stack+261885,int_stack+258240, 1.0, int_stack+256620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1566914,int_stack+1562054,int_stack+1558274, 1.0, int_stack+571970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1574474,int_stack+266385,int_stack+261885, 1.0, int_stack+259860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1580549,int_stack+1574474,int_stack+1562054, 1.0, int_stack+575750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1590269,int_stack+1580549,int_stack+1566914, 1.0, int_stack+16740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+571970,int_stack+271830,int_stack+266385, 1.0, int_stack+263910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1558274,int_stack+571970,int_stack+1574474, 1.0, int_stack+24300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1602869,int_stack+1558274,int_stack+1580549, 1.0, int_stack+646202, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1570424,int_stack+1602869,int_stack+1590269, 1.0, int_stack+655922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+1589324,int_stack+274800,int_stack+271830, 1.0, int_stack+268860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+1619069,int_stack+1589324,int_stack+571970, 1.0, int_stack+668522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+617438,int_stack+1619069,int_stack+1558274, 1.0, int_stack+675947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+1619069,int_stack+617438,int_stack+1602869, 1.0, int_stack+688097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+617438,int_stack+1619069,int_stack+1570424, 1.0, int_stack+704297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+643898,int_stack+617438,int_stack+1952234,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+153855,int_stack+643898,int_stack+1128218,588);
 /*--- compute (hf|ih) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+617438,int_stack+153855,int_stack+1973402,588);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+153855,int_stack+371080,int_stack+370090,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+156825,int_stack+153855,int_stack+457955,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+161775,int_stack+156825,int_stack+460430,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+168525,int_stack+161775,int_stack+464480,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+153855,int_stack+168525,int_stack+469880,15);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+162675,int_stack+381700,int_stack+380314,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+166833,int_stack+162675,int_stack+507755,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+173763,int_stack+166833,int_stack+511220,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+183213,int_stack+173763,int_stack+516890,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+162675,int_stack+183213,int_stack+524450,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+175023,int_stack+162675,int_stack+153855,588);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+201483,int_stack+396246,int_stack+394398,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+207027,int_stack+201483,int_stack+583418,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+216267,int_stack+207027,int_stack+588038,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+228867,int_stack+216267,int_stack+595598,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+201483,int_stack+228867,int_stack+605678,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+217947,int_stack+201483,int_stack+162675,588);
 /*--- compute (gd|ih) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1128218,int_stack+217947,int_stack+175023,588);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+254991,int_stack+415334,int_stack+412958,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+262119,int_stack+254991,int_stack+543350,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1181138,int_stack+262119,int_stack+549290,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+254991,int_stack+1181138,int_stack+559010,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1181138,int_stack+254991,int_stack+755366,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1952234,int_stack+1181138,int_stack+201483,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1558274,int_stack+1952234,int_stack+217947,588);
 /*--- compute (gf|ih) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+443090,int_stack+1558274,int_stack+1128218,588);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+254991,int_stack+278730,int_stack+278310,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+256251,int_stack+279270,int_stack+278730,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+257871,int_stack+256251,int_stack+254991,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+260391,int_stack+279945,int_stack+279270,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+262416,int_stack+260391,int_stack+256251,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+265656,int_stack+262416,int_stack+257871,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+254991,int_stack+280770,int_stack+279945,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+269856,int_stack+254991,int_stack+260391,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+273906,int_stack+269856,int_stack+262416,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+257466,int_stack+273906,int_stack+265656,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+263766,int_stack+281760,int_stack+280770,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1202306,int_stack+263766,int_stack+254991,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1207256,int_stack+1202306,int_stack+269856,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+263766,int_stack+1207256,int_stack+273906,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1202306,int_stack+263766,int_stack+257466,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1211126,int_stack+283518,int_stack+282930,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1212890,int_stack+284274,int_stack+283518,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+254991,int_stack+1212890,int_stack+1211126,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+258519,int_stack+285219,int_stack+284274,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+261354,int_stack+258519,int_stack+1212890,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1211126,int_stack+261354,int_stack+254991,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+254991,int_stack+286374,int_stack+285219,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+265890,int_stack+254991,int_stack+258519,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+271560,int_stack+265890,int_stack+261354,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2001626,int_stack+271560,int_stack+1211126,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1211126,int_stack+287760,int_stack+286374,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+258456,int_stack+1211126,int_stack+254991,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+279120,int_stack+258456,int_stack+265890,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+254991,int_stack+279120,int_stack+271560,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+266331,int_stack+254991,int_stack+2001626,21);
 /*--- compute (gp|ih) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+2001626,int_stack+266331,int_stack+1202306, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1202306,int_stack+290182,int_stack+289398,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1204658,int_stack+291190,int_stack+290182,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1207682,int_stack+1204658,int_stack+1202306,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1212386,int_stack+292450,int_stack+291190,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2028086,int_stack+1212386,int_stack+1204658,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2034134,int_stack+2028086,int_stack+1207682,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+367630,int_stack+293990,int_stack+292450,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1202306,int_stack+367630,int_stack+1212386,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+254991,int_stack+1202306,int_stack+2028086,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+278679,int_stack+254991,int_stack+2034134,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2028086,int_stack+295838,int_stack+293990,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2033630,int_stack+2028086,int_stack+367630,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+740918,int_stack+2033630,int_stack+1202306,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1202306,int_stack+740918,int_stack+254991,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+740918,int_stack+1202306,int_stack+278679,28);
 /*--- compute (hp|ih) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+531290,int_stack+740918,int_stack+266331, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (gd|ih) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+2174498,int_stack+531290,int_stack+2001626, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175023, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2001626,int_stack+299030,int_stack+298022,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2004650,int_stack+300326,int_stack+299030,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2008538,int_stack+2004650,int_stack+2001626,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2014586,int_stack+301946,int_stack+300326,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2019446,int_stack+2014586,int_stack+2004650,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2027222,int_stack+2019446,int_stack+2008538,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2001626,int_stack+303926,int_stack+301946,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2037302,int_stack+2001626,int_stack+2014586,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1202306,int_stack+2037302,int_stack+2019446,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2007566,int_stack+1202306,int_stack+2027222,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2022686,int_stack+306302,int_stack+303926,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+254991,int_stack+2022686,int_stack+2001626,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+266871,int_stack+254991,int_stack+2037302,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2022686,int_stack+266871,int_stack+1202306,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+254991,int_stack+2022686,int_stack+2007566,36);
 /*--- compute (ip|ih) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+2001626,int_stack+254991,int_stack+740918, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hd|ih) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2227418,int_stack+2001626,int_stack+531290, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (gf|ih) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+2301506,int_stack+2227418,int_stack+2174498, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1128218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2174498,int_stack+310370,int_stack+309110,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2178278,int_stack+311990,int_stack+310370,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2183138,int_stack+2178278,int_stack+2174498,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2190698,int_stack+314015,int_stack+311990,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2196773,int_stack+2190698,int_stack+2178278,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2206493,int_stack+2196773,int_stack+2183138,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2174498,int_stack+316490,int_stack+314015,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+531290,int_stack+2174498,int_stack+2190698,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+543440,int_stack+531290,int_stack+2196773,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2181923,int_stack+543440,int_stack+2206493,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2200823,int_stack+319460,int_stack+316490,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2209733,int_stack+2200823,int_stack+2174498,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+559640,int_stack+2209733,int_stack+531290,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2200823,int_stack+559640,int_stack+543440,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+531290,int_stack+2200823,int_stack+2181923,45);
 /*--- compute (kp|ih) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+2389706,int_stack+531290,int_stack+254991, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1181138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (id|ih) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2453210,int_stack+2389706,int_stack+2001626, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1952234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hf|ih) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+2551994,int_stack+2453210,int_stack+2227418, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1558274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2001626,int_stack+323390,int_stack+322970,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2002886,int_stack+323930,int_stack+323390,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2004506,int_stack+2002886,int_stack+2001626,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2007026,int_stack+324605,int_stack+323930,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2009051,int_stack+2007026,int_stack+2002886,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2012291,int_stack+2009051,int_stack+2004506,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2001626,int_stack+325430,int_stack+324605,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2016491,int_stack+2001626,int_stack+2007026,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2020541,int_stack+2016491,int_stack+2009051,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2004101,int_stack+2020541,int_stack+2012291,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2010401,int_stack+326420,int_stack+325430,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2025941,int_stack+2010401,int_stack+2001626,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+2030891,int_stack+2025941,int_stack+2016491,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2010401,int_stack+2030891,int_stack+2020541,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2018501,int_stack+2010401,int_stack+2004101,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2001626,int_stack+328178,int_stack+327590,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2003390,int_stack+328934,int_stack+328178,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2005658,int_stack+2003390,int_stack+2001626,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2009186,int_stack+329879,int_stack+328934,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2012021,int_stack+2009186,int_stack+2003390,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2027321,int_stack+2012021,int_stack+2005658,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2001626,int_stack+331034,int_stack+329879,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2033201,int_stack+2001626,int_stack+2009186,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2038871,int_stack+2033201,int_stack+2012021,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2005091,int_stack+2038871,int_stack+2027321,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2027321,int_stack+332420,int_stack+331034,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2389706,int_stack+2027321,int_stack+2001626,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+2396636,int_stack+2389706,int_stack+2033201,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2027321,int_stack+2396636,int_stack+2038871,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2389706,int_stack+2027321,int_stack+2005091,21);
 /*--- compute (gp|ih) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+2402054,int_stack+2389706,int_stack+2018501, 0.0, zero_stack, 1.0, int_stack+153855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2428514,int_stack+334842,int_stack+334058,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2430866,int_stack+335850,int_stack+334842,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2433890,int_stack+2430866,int_stack+2428514,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2438594,int_stack+337110,int_stack+335850,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2442374,int_stack+2438594,int_stack+2430866,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2448422,int_stack+2442374,int_stack+2433890,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+367630,int_stack+338650,int_stack+337110,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2428514,int_stack+367630,int_stack+2438594,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2456262,int_stack+2428514,int_stack+2442374,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2436074,int_stack+2456262,int_stack+2448422,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2447834,int_stack+340498,int_stack+338650,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2466342,int_stack+2447834,int_stack+367630,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+2475582,int_stack+2466342,int_stack+2428514,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2488182,int_stack+2475582,int_stack+2456262,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2447834,int_stack+2488182,int_stack+2436074,28);
 /*--- compute (hp|ih) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2464298,int_stack+2447834,int_stack+2389706, 0.0, zero_stack, 1.0, int_stack+162675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (gd|ih) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+254991,int_stack+2464298,int_stack+2402054, 0.0, zero_stack, 1.0, int_stack+175023, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2389706,int_stack+343690,int_stack+342682,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2392730,int_stack+344986,int_stack+343690,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2396618,int_stack+2392730,int_stack+2389706,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2402666,int_stack+346606,int_stack+344986,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2407526,int_stack+2402666,int_stack+2392730,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2415302,int_stack+2407526,int_stack+2396618,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2389706,int_stack+348586,int_stack+346606,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2425382,int_stack+2389706,int_stack+2402666,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2501342,int_stack+2425382,int_stack+2407526,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2395646,int_stack+2501342,int_stack+2415302,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2410766,int_stack+350962,int_stack+348586,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2435102,int_stack+2410766,int_stack+2389706,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+2514302,int_stack+2435102,int_stack+2425382,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2410766,int_stack+2514302,int_stack+2501342,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2501342,int_stack+2410766,int_stack+2395646,36);
 /*--- compute (ip|ih) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+2001626,int_stack+2501342,int_stack+2447834, 0.0, zero_stack, 1.0, int_stack+201483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hd|ih) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2389706,int_stack+2001626,int_stack+2464298, 0.0, zero_stack, 1.0, int_stack+217947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (gf|ih) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+2174498,int_stack+2389706,int_stack+254991, 0.0, zero_stack, 1.0, int_stack+1128218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+254991,int_stack+355030,int_stack+353770,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+258771,int_stack+356650,int_stack+355030,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+263631,int_stack+258771,int_stack+254991,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+271191,int_stack+358675,int_stack+356650,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+277266,int_stack+271191,int_stack+258771,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+286986,int_stack+277266,int_stack+263631,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+254991,int_stack+361150,int_stack+358675,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+299586,int_stack+254991,int_stack+271191,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+311736,int_stack+299586,int_stack+277266,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+262416,int_stack+311736,int_stack+286986,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+281316,int_stack+364120,int_stack+361150,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+327936,int_stack+281316,int_stack+254991,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+342786,int_stack+327936,int_stack+299586,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+281316,int_stack+342786,int_stack+311736,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+305616,int_stack+281316,int_stack+262416,45);
 /*--- compute (kp|ih) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+531290,int_stack+305616,int_stack+2501342, 0.0, zero_stack, 1.0, int_stack+1181138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (id|ih) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+254991,int_stack+531290,int_stack+2001626, 0.0, zero_stack, 1.0, int_stack+1952234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hf|ih) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+2675474,int_stack+254991,int_stack+2389706, 0.0, zero_stack, 1.0, int_stack+1558274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2389706,int_stack+372670,int_stack+372250,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2390966,int_stack+373210,int_stack+372670,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2392586,int_stack+2390966,int_stack+2389706,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2395106,int_stack+373885,int_stack+373210,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2397131,int_stack+2395106,int_stack+2390966,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2400371,int_stack+2397131,int_stack+2392586,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2389706,int_stack+374710,int_stack+373885,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2404571,int_stack+2389706,int_stack+2395106,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2408621,int_stack+2404571,int_stack+2397131,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2392181,int_stack+2408621,int_stack+2400371,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2398481,int_stack+375700,int_stack+374710,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2414021,int_stack+2398481,int_stack+2389706,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+2418971,int_stack+2414021,int_stack+2404571,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2398481,int_stack+2418971,int_stack+2408621,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2406581,int_stack+2398481,int_stack+2392181,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2389706,int_stack+383926,int_stack+383338,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2391470,int_stack+384682,int_stack+383926,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2393738,int_stack+2391470,int_stack+2389706,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2397266,int_stack+385627,int_stack+384682,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2400101,int_stack+2397266,int_stack+2391470,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2415401,int_stack+2400101,int_stack+2393738,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2389706,int_stack+386782,int_stack+385627,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2421281,int_stack+2389706,int_stack+2397266,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2426951,int_stack+2421281,int_stack+2400101,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2393171,int_stack+2426951,int_stack+2415401,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2415401,int_stack+388168,int_stack+386782,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2434511,int_stack+2415401,int_stack+2389706,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+2441441,int_stack+2434511,int_stack+2421281,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2415401,int_stack+2441441,int_stack+2426951,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2426741,int_stack+2415401,int_stack+2393171,21);
 /*--- compute (gp|ih) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+2439089,int_stack+2426741,int_stack+2406581, 1.0, int_stack+153855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+153855,int_stack+399214,int_stack+398430,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+156207,int_stack+400222,int_stack+399214,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2389706,int_stack+156207,int_stack+153855,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2394410,int_stack+401482,int_stack+400222,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2398190,int_stack+2394410,int_stack+156207,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+153855,int_stack+2398190,int_stack+2389706,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2389706,int_stack+403022,int_stack+401482,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2404238,int_stack+2389706,int_stack+2394410,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2411798,int_stack+2404238,int_stack+2398190,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2465549,int_stack+2411798,int_stack+153855,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+153855,int_stack+404870,int_stack+403022,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2394326,int_stack+153855,int_stack+2389706,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+2477309,int_stack+2394326,int_stack+2404238,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2389706,int_stack+2477309,int_stack+2411798,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2477309,int_stack+2389706,int_stack+2465549,28);
 /*--- compute (hp|ih) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2493773,int_stack+2477309,int_stack+2426741, 1.0, int_stack+162675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (gd|ih) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+254991,int_stack+2493773,int_stack+2439089, 1.0, int_stack+175023, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2389706,int_stack+419150,int_stack+418142,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2392730,int_stack+420446,int_stack+419150,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2396618,int_stack+2392730,int_stack+2389706,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2402666,int_stack+422066,int_stack+420446,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+2407526,int_stack+2402666,int_stack+2392730,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2415302,int_stack+2407526,int_stack+2396618,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+2389706,int_stack+424046,int_stack+422066,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2425382,int_stack+2389706,int_stack+2402666,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2435102,int_stack+2425382,int_stack+2407526,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+2395646,int_stack+2435102,int_stack+2415302,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+2410766,int_stack+426422,int_stack+424046,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+2448062,int_stack+2410766,int_stack+2389706,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+2459942,int_stack+2448062,int_stack+2425382,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+2410766,int_stack+2459942,int_stack+2435102,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+2430206,int_stack+2410766,int_stack+2395646,36);
 /*--- compute (ip|ih) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+2001626,int_stack+2430206,int_stack+2477309, 1.0, int_stack+201483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hd|ih) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+307911,int_stack+2001626,int_stack+2493773, 1.0, int_stack+217947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (gf|ih) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+2451374,int_stack+307911,int_stack+254991, 1.0, int_stack+1128218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1128218,int_stack+430490,int_stack+429230,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1131998,int_stack+432110,int_stack+430490,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1136858,int_stack+1131998,int_stack+1128218,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1144418,int_stack+434135,int_stack+432110,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1150493,int_stack+1144418,int_stack+1131998,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1160213,int_stack+1150493,int_stack+1136858,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+1128218,int_stack+436610,int_stack+434135,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+2389706,int_stack+1128218,int_stack+1144418,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+2401856,int_stack+2389706,int_stack+1150493,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1135643,int_stack+2401856,int_stack+1160213,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1154543,int_stack+439580,int_stack+436610,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1163453,int_stack+1154543,int_stack+1128218,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+153855,int_stack+1163453,int_stack+2389706,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1154543,int_stack+153855,int_stack+2401856,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+153855,int_stack+1154543,int_stack+1135643,45);
 /*--- compute (kp|ih) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+180315,int_stack+153855,int_stack+2430206, 1.0, int_stack+1181138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (id|ih) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2798954,int_stack+180315,int_stack+2001626, 1.0, int_stack+1952234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hf|ih) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+153855,int_stack+2798954,int_stack+307911, 1.0, int_stack+1558274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (gg|ih) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+277335,int_stack+1217786,int_stack+916538,588);
     Libderiv->ABCD[11] = int_stack + 277335;
 /*--- compute (gg|ih) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+1128218,int_stack+770486,int_stack+1341266,588);
     Libderiv->ABCD[10] = int_stack + 1128218;
 /*--- compute (gg|ih) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+1260518,int_stack+1004738,int_stack+1470074,588);
     Libderiv->ABCD[9] = int_stack + 1260518;
 /*--- compute (gg|ih) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+1392818,int_stack+30375,int_stack+1648238,588);
     Libderiv->ABCD[8] = int_stack + 1392818;
 /*--- compute (gg|ih) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+1525118,int_stack+2051018,int_stack+1864034,588);
     Libderiv->ABCD[7] = int_stack + 1525118;
 /*--- compute (gg|ih) ---*/
   hrr1_build_gg(Libderiv->AB,int_stack+740918,int_stack+617438,int_stack+1736438,588);
     Libderiv->ABCD[6] = int_stack + 740918;
 /*--- compute (gg|ih) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+1657418,int_stack+2551994,int_stack+2301506, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[2] = int_stack + 1657418;
 /*--- compute (gg|ih) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+1789718,int_stack+2675474,int_stack+2174498, 0.0, zero_stack, 1.0, int_stack+443090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[1] = int_stack + 1789718;
 /*--- compute (gg|ih) ---*/
   d1hrr1_build_gg(Libderiv->AB,int_stack+1922018,int_stack+153855,int_stack+2451374, 1.0, int_stack+443090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[0] = int_stack + 1922018;

}
