/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (hh|ig) integrals */

void d1vrr_order_hhig(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+0, dvrr_stack+3, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+12, dvrr_stack+0, Data->F+4, Data->F+5, NULL);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+21, dvrr_stack+15, dvrr_stack+6, NULL, NULL, dvrr_stack+0);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+39, dvrr_stack+15, dvrr_stack+6, dvrr_stack+12, dvrr_stack+0, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+49, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+52, dvrr_stack+49, dvrr_stack+12, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+58, dvrr_stack+52, dvrr_stack+15, dvrr_stack+49, dvrr_stack+12, NULL);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+68, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+71, dvrr_stack+3, dvrr_stack+68, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+77, dvrr_stack+6, dvrr_stack+71, dvrr_stack+0, dvrr_stack+3, NULL);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+87, dvrr_stack+39, dvrr_stack+77, NULL, NULL, dvrr_stack+6);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+117, dvrr_stack+58, dvrr_stack+39, NULL, NULL, dvrr_stack+15);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+147, dvrr_stack+117, dvrr_stack+87, dvrr_stack+58, dvrr_stack+39, dvrr_stack+21);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+207, dvrr_stack+39, dvrr_stack+77, dvrr_stack+15, dvrr_stack+6, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+222, dvrr_stack+58, dvrr_stack+39, dvrr_stack+52, dvrr_stack+15, NULL);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+237, dvrr_stack+222, dvrr_stack+207, NULL, NULL, dvrr_stack+39);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+282, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+285, dvrr_stack+282, dvrr_stack+49, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+291, dvrr_stack+285, dvrr_stack+52, dvrr_stack+282, dvrr_stack+49, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+301, dvrr_stack+291, dvrr_stack+58, dvrr_stack+285, dvrr_stack+52, NULL);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+316, dvrr_stack+301, dvrr_stack+222, NULL, NULL, dvrr_stack+58);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+49, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+361, dvrr_stack+68, dvrr_stack+49, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+367, dvrr_stack+71, dvrr_stack+361, dvrr_stack+3, dvrr_stack+68, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+377, dvrr_stack+77, dvrr_stack+367, dvrr_stack+6, dvrr_stack+71, NULL);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+392, dvrr_stack+207, dvrr_stack+377, NULL, NULL, dvrr_stack+77);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+437, dvrr_stack+237, dvrr_stack+392, dvrr_stack+222, dvrr_stack+207, dvrr_stack+87);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+527, dvrr_stack+316, dvrr_stack+237, dvrr_stack+301, dvrr_stack+222, dvrr_stack+117);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+617, dvrr_stack+527, dvrr_stack+437, dvrr_stack+316, dvrr_stack+237, dvrr_stack+147);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+767, dvrr_stack+222, dvrr_stack+207, dvrr_stack+58, dvrr_stack+39, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+788, dvrr_stack+301, dvrr_stack+222, dvrr_stack+291, dvrr_stack+58, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+809, dvrr_stack+207, dvrr_stack+377, dvrr_stack+39, dvrr_stack+77, NULL);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+830, dvrr_stack+767, dvrr_stack+809, NULL, NULL, dvrr_stack+207);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+893, dvrr_stack+788, dvrr_stack+767, NULL, NULL, dvrr_stack+222);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+956, dvrr_stack+893, dvrr_stack+830, dvrr_stack+788, dvrr_stack+767, dvrr_stack+237);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1082, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1085, dvrr_stack+1082, dvrr_stack+282, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1091, dvrr_stack+1085, dvrr_stack+285, dvrr_stack+1082, dvrr_stack+282, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1101, dvrr_stack+1091, dvrr_stack+291, dvrr_stack+1085, dvrr_stack+285, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1116, dvrr_stack+1101, dvrr_stack+301, dvrr_stack+1091, dvrr_stack+291, NULL);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1137, dvrr_stack+1116, dvrr_stack+788, NULL, NULL, dvrr_stack+301);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1200, dvrr_stack+1137, dvrr_stack+893, dvrr_stack+1116, dvrr_stack+788, dvrr_stack+316);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+282, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+285, dvrr_stack+49, dvrr_stack+282, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1326, dvrr_stack+361, dvrr_stack+285, dvrr_stack+68, dvrr_stack+49, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1336, dvrr_stack+367, dvrr_stack+1326, dvrr_stack+71, dvrr_stack+361, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1351, dvrr_stack+377, dvrr_stack+1336, dvrr_stack+77, dvrr_stack+367, NULL);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1372, dvrr_stack+809, dvrr_stack+1351, NULL, NULL, dvrr_stack+377);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1435, dvrr_stack+830, dvrr_stack+1372, dvrr_stack+767, dvrr_stack+809, dvrr_stack+392);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+1561, dvrr_stack+956, dvrr_stack+1435, dvrr_stack+893, dvrr_stack+830, dvrr_stack+437);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+1771, dvrr_stack+1200, dvrr_stack+956, dvrr_stack+1137, dvrr_stack+893, dvrr_stack+527);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+1981, dvrr_stack+1771, dvrr_stack+1561, dvrr_stack+1200, dvrr_stack+956, dvrr_stack+617);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2296, dvrr_stack+767, dvrr_stack+809, dvrr_stack+222, dvrr_stack+207, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2324, dvrr_stack+788, dvrr_stack+767, dvrr_stack+301, dvrr_stack+222, NULL);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2352, dvrr_stack+2324, dvrr_stack+2296, NULL, NULL, dvrr_stack+767);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2436, dvrr_stack+1116, dvrr_stack+788, dvrr_stack+1101, dvrr_stack+301, NULL);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2464, dvrr_stack+2436, dvrr_stack+2324, NULL, NULL, dvrr_stack+788);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2548, dvrr_stack+809, dvrr_stack+1351, dvrr_stack+207, dvrr_stack+377, NULL);

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2576, dvrr_stack+2296, dvrr_stack+2548, NULL, NULL, dvrr_stack+809);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+2660, dvrr_stack+2352, dvrr_stack+2576, dvrr_stack+2324, dvrr_stack+2296, dvrr_stack+830);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+2828, dvrr_stack+2464, dvrr_stack+2352, dvrr_stack+2436, dvrr_stack+2324, dvrr_stack+893);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+2996, dvrr_stack+2828, dvrr_stack+2660, dvrr_stack+2464, dvrr_stack+2352, dvrr_stack+956);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+893, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+896, dvrr_stack+893, dvrr_stack+1082, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+902, dvrr_stack+896, dvrr_stack+1085, dvrr_stack+893, dvrr_stack+1082, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+222, dvrr_stack+902, dvrr_stack+1091, dvrr_stack+896, dvrr_stack+1085, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+912, dvrr_stack+222, dvrr_stack+1101, dvrr_stack+902, dvrr_stack+1091, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3276, dvrr_stack+912, dvrr_stack+1116, dvrr_stack+222, dvrr_stack+1101, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+3304, dvrr_stack+3276, dvrr_stack+2436, NULL, NULL, dvrr_stack+1116);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+3388, dvrr_stack+3304, dvrr_stack+2464, dvrr_stack+3276, dvrr_stack+2436, dvrr_stack+1137);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+3556, dvrr_stack+3388, dvrr_stack+2828, dvrr_stack+3304, dvrr_stack+2464, dvrr_stack+1200);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3304, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+3307, dvrr_stack+282, dvrr_stack+3304, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+3313, dvrr_stack+285, dvrr_stack+3307, dvrr_stack+49, dvrr_stack+282, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+222, dvrr_stack+1326, dvrr_stack+3313, dvrr_stack+361, dvrr_stack+285, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+3323, dvrr_stack+1336, dvrr_stack+222, dvrr_stack+367, dvrr_stack+1326, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3344, dvrr_stack+1351, dvrr_stack+3323, dvrr_stack+377, dvrr_stack+1336, NULL);

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+3836, dvrr_stack+2548, dvrr_stack+3344, NULL, NULL, dvrr_stack+1351);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+3920, dvrr_stack+2576, dvrr_stack+3836, dvrr_stack+2296, dvrr_stack+2548, dvrr_stack+1372);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+4088, dvrr_stack+2660, dvrr_stack+3920, dvrr_stack+2352, dvrr_stack+2576, dvrr_stack+1435);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+4368, dvrr_stack+2996, dvrr_stack+4088, dvrr_stack+2828, dvrr_stack+2660, dvrr_stack+1561);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+4788, dvrr_stack+3556, dvrr_stack+2996, dvrr_stack+3388, dvrr_stack+2828, dvrr_stack+1771);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+5208, dvrr_stack+4788, dvrr_stack+4368, dvrr_stack+3556, dvrr_stack+2996, dvrr_stack+1981);
 tmp = dvrr_stack + 5208;
 target_ptr = Libderiv->dvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3372, dvrr_stack+2296, dvrr_stack+2548, dvrr_stack+767, dvrr_stack+809, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3408, dvrr_stack+2324, dvrr_stack+2296, dvrr_stack+788, dvrr_stack+767, NULL);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3444, dvrr_stack+3408, dvrr_stack+3372, NULL, NULL, dvrr_stack+2296);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3552, dvrr_stack+2436, dvrr_stack+2324, dvrr_stack+1116, dvrr_stack+788, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3588, dvrr_stack+3552, dvrr_stack+3408, NULL, NULL, dvrr_stack+2324);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+767, dvrr_stack+2548, dvrr_stack+3344, dvrr_stack+809, dvrr_stack+1351, NULL);

 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3696, dvrr_stack+3372, dvrr_stack+767, NULL, NULL, dvrr_stack+2548);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5796, dvrr_stack+3444, dvrr_stack+3696, dvrr_stack+3408, dvrr_stack+3372, dvrr_stack+2576);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6012, dvrr_stack+3588, dvrr_stack+3444, dvrr_stack+3552, dvrr_stack+3408, dvrr_stack+2352);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6228, dvrr_stack+6012, dvrr_stack+5796, dvrr_stack+3588, dvrr_stack+3444, dvrr_stack+2660);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2352, dvrr_stack+3276, dvrr_stack+2436, dvrr_stack+912, dvrr_stack+1116, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6588, dvrr_stack+2352, dvrr_stack+3552, NULL, NULL, dvrr_stack+2436);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6696, dvrr_stack+6588, dvrr_stack+3588, dvrr_stack+2352, dvrr_stack+3552, dvrr_stack+2464);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6912, dvrr_stack+6696, dvrr_stack+6012, dvrr_stack+6588, dvrr_stack+3588, dvrr_stack+2828);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+2828, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+803, dvrr_stack+3304, dvrr_stack+2828, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2831, dvrr_stack+3307, dvrr_stack+803, dvrr_stack+282, dvrr_stack+3304, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2841, dvrr_stack+3313, dvrr_stack+2831, dvrr_stack+285, dvrr_stack+3307, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2856, dvrr_stack+222, dvrr_stack+2841, dvrr_stack+1326, dvrr_stack+3313, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2877, dvrr_stack+3323, dvrr_stack+2856, dvrr_stack+1336, dvrr_stack+222, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2905, dvrr_stack+3344, dvrr_stack+2877, dvrr_stack+1351, dvrr_stack+3323, NULL);

 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6588, dvrr_stack+767, dvrr_stack+2905, NULL, NULL, dvrr_stack+3344);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7272, dvrr_stack+3696, dvrr_stack+6588, dvrr_stack+3372, dvrr_stack+767, dvrr_stack+3836);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7488, dvrr_stack+5796, dvrr_stack+7272, dvrr_stack+3444, dvrr_stack+3696, dvrr_stack+3920);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7848, dvrr_stack+6228, dvrr_stack+7488, dvrr_stack+6012, dvrr_stack+5796, dvrr_stack+4088);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8388, dvrr_stack+6912, dvrr_stack+6228, dvrr_stack+6696, dvrr_stack+6012, dvrr_stack+2996);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8928, dvrr_stack+8388, dvrr_stack+7848, dvrr_stack+6912, dvrr_stack+6228, dvrr_stack+4368);
 tmp = dvrr_stack + 8928;
 target_ptr = Libderiv->dvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+9684,dvrr_stack+8928,dvrr_stack+5208,21);


 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6696, dvrr_stack+3372, dvrr_stack+767, dvrr_stack+2296, dvrr_stack+2548, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6741, dvrr_stack+3408, dvrr_stack+3372, dvrr_stack+2324, dvrr_stack+2296, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6786, dvrr_stack+6741, dvrr_stack+6696, NULL, NULL, dvrr_stack+3372);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6921, dvrr_stack+3552, dvrr_stack+3408, dvrr_stack+2436, dvrr_stack+2324, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6966, dvrr_stack+6921, dvrr_stack+6741, NULL, NULL, dvrr_stack+3408);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2296, dvrr_stack+767, dvrr_stack+2905, dvrr_stack+2548, dvrr_stack+3344, NULL);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7101, dvrr_stack+6696, dvrr_stack+2296, NULL, NULL, dvrr_stack+767);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11448, dvrr_stack+6786, dvrr_stack+7101, dvrr_stack+6741, dvrr_stack+6696, dvrr_stack+3696);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11718, dvrr_stack+6966, dvrr_stack+6786, dvrr_stack+6921, dvrr_stack+6741, dvrr_stack+3444);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11988, dvrr_stack+11718, dvrr_stack+11448, dvrr_stack+6966, dvrr_stack+6786, dvrr_stack+5796);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3444, dvrr_stack+2352, dvrr_stack+3552, dvrr_stack+3276, dvrr_stack+2436, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2388, dvrr_stack+3444, dvrr_stack+6921, NULL, NULL, dvrr_stack+3552);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12438, dvrr_stack+2388, dvrr_stack+6966, dvrr_stack+3444, dvrr_stack+6921, dvrr_stack+3588);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12708, dvrr_stack+12438, dvrr_stack+11718, dvrr_stack+2388, dvrr_stack+6966, dvrr_stack+6012);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6012, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6015, dvrr_stack+2828, dvrr_stack+6012, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+6021, dvrr_stack+803, dvrr_stack+6015, dvrr_stack+3304, dvrr_stack+2828, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+6031, dvrr_stack+2831, dvrr_stack+6021, dvrr_stack+3307, dvrr_stack+803, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+6046, dvrr_stack+2841, dvrr_stack+6031, dvrr_stack+3313, dvrr_stack+2831, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3276, dvrr_stack+2856, dvrr_stack+6046, dvrr_stack+222, dvrr_stack+2841, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7236, dvrr_stack+2877, dvrr_stack+3276, dvrr_stack+3323, dvrr_stack+2856, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6067, dvrr_stack+2905, dvrr_stack+7236, dvrr_stack+3344, dvrr_stack+2877, NULL);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2388, dvrr_stack+2296, dvrr_stack+6067, NULL, NULL, dvrr_stack+2905);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13158, dvrr_stack+7101, dvrr_stack+2388, dvrr_stack+6696, dvrr_stack+2296, dvrr_stack+6588);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13428, dvrr_stack+11448, dvrr_stack+13158, dvrr_stack+6786, dvrr_stack+7101, dvrr_stack+7272);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13878, dvrr_stack+11988, dvrr_stack+13428, dvrr_stack+11718, dvrr_stack+11448, dvrr_stack+7488);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+14553, dvrr_stack+12708, dvrr_stack+11988, dvrr_stack+12438, dvrr_stack+11718, dvrr_stack+6228);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+15228, dvrr_stack+14553, dvrr_stack+13878, dvrr_stack+12708, dvrr_stack+11988, dvrr_stack+7848);
 tmp = dvrr_stack + 15228;
 target_ptr = Libderiv->dvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+16173,dvrr_stack+15228,dvrr_stack+8928,21);


 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2941, dvrr_stack+6696, dvrr_stack+2296, dvrr_stack+3372, dvrr_stack+767, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12438, dvrr_stack+6741, dvrr_stack+6696, dvrr_stack+3408, dvrr_stack+3372, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12493, dvrr_stack+12438, dvrr_stack+2941, NULL, NULL, dvrr_stack+6696);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12658, dvrr_stack+6921, dvrr_stack+6741, dvrr_stack+3552, dvrr_stack+3408, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12713, dvrr_stack+12658, dvrr_stack+12438, NULL, NULL, dvrr_stack+6741);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3372, dvrr_stack+2296, dvrr_stack+6067, dvrr_stack+767, dvrr_stack+2905, NULL);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12878, dvrr_stack+2941, dvrr_stack+3372, NULL, NULL, dvrr_stack+2296);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18441, dvrr_stack+12493, dvrr_stack+12878, dvrr_stack+12438, dvrr_stack+2941, dvrr_stack+7101);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18771, dvrr_stack+12713, dvrr_stack+12493, dvrr_stack+12658, dvrr_stack+12438, dvrr_stack+6786);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19101, dvrr_stack+18771, dvrr_stack+18441, dvrr_stack+12713, dvrr_stack+12493, dvrr_stack+11448);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6786, dvrr_stack+3444, dvrr_stack+6921, dvrr_stack+2352, dvrr_stack+3552, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3489, dvrr_stack+6786, dvrr_stack+12658, NULL, NULL, dvrr_stack+6921);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19651, dvrr_stack+3489, dvrr_stack+12713, dvrr_stack+6786, dvrr_stack+12658, dvrr_stack+6966);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19981, dvrr_stack+19651, dvrr_stack+18771, dvrr_stack+3489, dvrr_stack+12713, dvrr_stack+11718);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+11718, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+11721, dvrr_stack+6012, dvrr_stack+11718, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+11727, dvrr_stack+6015, dvrr_stack+11721, dvrr_stack+2828, dvrr_stack+6012, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+11737, dvrr_stack+6021, dvrr_stack+11727, dvrr_stack+803, dvrr_stack+6015, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+11752, dvrr_stack+6031, dvrr_stack+11737, dvrr_stack+2831, dvrr_stack+6021, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+11773, dvrr_stack+6046, dvrr_stack+11752, dvrr_stack+2841, dvrr_stack+6031, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11801, dvrr_stack+3276, dvrr_stack+11773, dvrr_stack+2856, dvrr_stack+6046, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11837, dvrr_stack+7236, dvrr_stack+11801, dvrr_stack+2877, dvrr_stack+3276, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11882, dvrr_stack+6067, dvrr_stack+11837, dvrr_stack+2905, dvrr_stack+7236, NULL);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3489, dvrr_stack+3372, dvrr_stack+11882, NULL, NULL, dvrr_stack+6067);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20531, dvrr_stack+12878, dvrr_stack+3489, dvrr_stack+2941, dvrr_stack+3372, dvrr_stack+2388);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20861, dvrr_stack+18441, dvrr_stack+20531, dvrr_stack+12493, dvrr_stack+12878, dvrr_stack+13158);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21411, dvrr_stack+19101, dvrr_stack+20861, dvrr_stack+18771, dvrr_stack+18441, dvrr_stack+13428);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+22236, dvrr_stack+19981, dvrr_stack+19101, dvrr_stack+19651, dvrr_stack+18771, dvrr_stack+11988);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+23061, dvrr_stack+22236, dvrr_stack+21411, dvrr_stack+19981, dvrr_stack+19101, dvrr_stack+13878);
 tmp = dvrr_stack + 23061;
 target_ptr = Libderiv->dvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+24216,dvrr_stack+23061,dvrr_stack+15228,21);


 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19651, dvrr_stack+2941, dvrr_stack+3372, dvrr_stack+6696, dvrr_stack+2296, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19717, dvrr_stack+12438, dvrr_stack+2941, dvrr_stack+6741, dvrr_stack+6696, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19783, dvrr_stack+19717, dvrr_stack+19651, NULL, NULL, dvrr_stack+2941);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19981, dvrr_stack+12658, dvrr_stack+12438, dvrr_stack+6921, dvrr_stack+6741, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20047, dvrr_stack+19981, dvrr_stack+19717, NULL, NULL, dvrr_stack+12438);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6696, dvrr_stack+3372, dvrr_stack+11882, dvrr_stack+2296, dvrr_stack+6067, NULL);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20245, dvrr_stack+19651, dvrr_stack+6696, NULL, NULL, dvrr_stack+3372);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27051, dvrr_stack+19783, dvrr_stack+20245, dvrr_stack+19717, dvrr_stack+19651, dvrr_stack+12878);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27447, dvrr_stack+20047, dvrr_stack+19783, dvrr_stack+19981, dvrr_stack+19717, dvrr_stack+12493);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27843, dvrr_stack+27447, dvrr_stack+27051, dvrr_stack+20047, dvrr_stack+19783, dvrr_stack+18441);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12493, dvrr_stack+6786, dvrr_stack+12658, dvrr_stack+3444, dvrr_stack+6921, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6841, dvrr_stack+12493, dvrr_stack+19981, NULL, NULL, dvrr_stack+12658);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+28503, dvrr_stack+6841, dvrr_stack+20047, dvrr_stack+12493, dvrr_stack+19981, dvrr_stack+12713);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+28899, dvrr_stack+28503, dvrr_stack+27447, dvrr_stack+6841, dvrr_stack+20047, dvrr_stack+18771);

 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+18771, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+18774, dvrr_stack+11718, dvrr_stack+18771, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+18780, dvrr_stack+11721, dvrr_stack+18774, dvrr_stack+6012, dvrr_stack+11718, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+18790, dvrr_stack+11727, dvrr_stack+18780, dvrr_stack+6015, dvrr_stack+11721, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+18805, dvrr_stack+11737, dvrr_stack+18790, dvrr_stack+6021, dvrr_stack+11727, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+18826, dvrr_stack+11752, dvrr_stack+18805, dvrr_stack+6031, dvrr_stack+11737, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+18854, dvrr_stack+11773, dvrr_stack+18826, dvrr_stack+6046, dvrr_stack+11752, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18890, dvrr_stack+11801, dvrr_stack+18854, dvrr_stack+3276, dvrr_stack+11773, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18935, dvrr_stack+11837, dvrr_stack+18890, dvrr_stack+7236, dvrr_stack+11801, NULL);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18990, dvrr_stack+11882, dvrr_stack+18935, dvrr_stack+6067, dvrr_stack+11837, NULL);

 /* compute (1 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6841, dvrr_stack+6696, dvrr_stack+18990, NULL, NULL, dvrr_stack+11882);

 /* compute (2 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+29559, dvrr_stack+20245, dvrr_stack+6841, dvrr_stack+19651, dvrr_stack+6696, dvrr_stack+3489);

 /* compute (3 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+29955, dvrr_stack+27051, dvrr_stack+29559, dvrr_stack+19783, dvrr_stack+20245, dvrr_stack+20531);

 /* compute (4 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30615, dvrr_stack+27843, dvrr_stack+29955, dvrr_stack+27447, dvrr_stack+27051, dvrr_stack+20861);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31605, dvrr_stack+28899, dvrr_stack+27843, dvrr_stack+28503, dvrr_stack+27447, dvrr_stack+19101);

 /* compute (5 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32595, dvrr_stack+31605, dvrr_stack+30615, dvrr_stack+28899, dvrr_stack+27843, dvrr_stack+21411);
 tmp = dvrr_stack + 32595;
 target_ptr = Libderiv->dvrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+33981,dvrr_stack+32595,dvrr_stack+23061,21);


 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28503, dvrr_stack+19651, dvrr_stack+6696, dvrr_stack+2941, dvrr_stack+3372, NULL);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28581, dvrr_stack+19717, dvrr_stack+19651, dvrr_stack+12438, dvrr_stack+2941, NULL);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28659, dvrr_stack+28581, dvrr_stack+28503, NULL, NULL, dvrr_stack+19651);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28893, dvrr_stack+19981, dvrr_stack+19717, dvrr_stack+12658, dvrr_stack+12438, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28971, dvrr_stack+28893, dvrr_stack+28581, NULL, NULL, dvrr_stack+19717);

 /* compute (0 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+19651, dvrr_stack+6696, dvrr_stack+18990, dvrr_stack+3372, dvrr_stack+11882, NULL);

 /* compute (1 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+29205, dvrr_stack+28503, dvrr_stack+19651, NULL, NULL, dvrr_stack+6696);

 /* compute (2 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+37446, dvrr_stack+28659, dvrr_stack+29205, dvrr_stack+28581, dvrr_stack+28503, dvrr_stack+20245);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+37914, dvrr_stack+28971, dvrr_stack+28659, dvrr_stack+28893, dvrr_stack+28581, dvrr_stack+19783);

 /* compute (3 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+38382, dvrr_stack+37914, dvrr_stack+37446, dvrr_stack+28971, dvrr_stack+28659, dvrr_stack+27051);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28581, dvrr_stack+12493, dvrr_stack+19981, dvrr_stack+6786, dvrr_stack+12658, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+12438, dvrr_stack+28581, dvrr_stack+28893, NULL, NULL, dvrr_stack+19981);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+39162, dvrr_stack+12438, dvrr_stack+28971, dvrr_stack+28581, dvrr_stack+28893, dvrr_stack+20047);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+39630, dvrr_stack+39162, dvrr_stack+37914, dvrr_stack+12438, dvrr_stack+28971, dvrr_stack+27447);

 /* compute (0 0 | 1 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6012, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+27447, dvrr_stack+18771, dvrr_stack+6012, Data->F+14, Data->F+15, NULL);

 /* compute (0 0 | 3 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+27453, dvrr_stack+18774, dvrr_stack+27447, dvrr_stack+11718, dvrr_stack+18771, NULL);

 /* compute (0 0 | 4 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+27463, dvrr_stack+18780, dvrr_stack+27453, dvrr_stack+11721, dvrr_stack+18774, NULL);

 /* compute (0 0 | 5 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+27478, dvrr_stack+18790, dvrr_stack+27463, dvrr_stack+11727, dvrr_stack+18780, NULL);

 /* compute (0 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+27499, dvrr_stack+18805, dvrr_stack+27478, dvrr_stack+11737, dvrr_stack+18790, NULL);

 /* compute (0 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+27527, dvrr_stack+18826, dvrr_stack+27499, dvrr_stack+11752, dvrr_stack+18805, NULL);

 /* compute (0 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19056, dvrr_stack+18854, dvrr_stack+27527, dvrr_stack+11773, dvrr_stack+18826, NULL);

 /* compute (0 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2941, dvrr_stack+18890, dvrr_stack+19056, dvrr_stack+11801, dvrr_stack+18854, NULL);

 /* compute (0 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27563, dvrr_stack+18935, dvrr_stack+2941, dvrr_stack+11837, dvrr_stack+18890, NULL);

 /* compute (0 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28581, dvrr_stack+18990, dvrr_stack+27563, dvrr_stack+11882, dvrr_stack+18935, NULL);

 /* compute (1 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+12438, dvrr_stack+19651, dvrr_stack+28581, NULL, NULL, dvrr_stack+18990);

 /* compute (2 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+19729, dvrr_stack+29205, dvrr_stack+12438, dvrr_stack+28503, dvrr_stack+19651, dvrr_stack+6841);

 /* compute (3 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+40410, dvrr_stack+37446, dvrr_stack+19729, dvrr_stack+28659, dvrr_stack+29205, dvrr_stack+29559);

 /* compute (4 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+41190, dvrr_stack+38382, dvrr_stack+40410, dvrr_stack+37914, dvrr_stack+37446, dvrr_stack+29955);

 /* compute (4 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+42360, dvrr_stack+39630, dvrr_stack+38382, dvrr_stack+39162, dvrr_stack+37914, dvrr_stack+27843);

 /* compute (5 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+43530, dvrr_stack+42360, dvrr_stack+41190, dvrr_stack+39630, dvrr_stack+38382, dvrr_stack+30615);

 /* compute (5 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+45168,dvrr_stack+43530,dvrr_stack+32595,21);


 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+11718, dvrr_stack+0, dvrr_stack+3, NULL, NULL, Data->F+6);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+37914, dvrr_stack+6, dvrr_stack+71, NULL, NULL, dvrr_stack+3);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+37932, dvrr_stack+21, dvrr_stack+37914, dvrr_stack+15, dvrr_stack+6, dvrr_stack+11718);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+37968, dvrr_stack+77, dvrr_stack+367, NULL, NULL, dvrr_stack+71);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+37998, dvrr_stack+87, dvrr_stack+37968, dvrr_stack+39, dvrr_stack+77, dvrr_stack+37914);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+38058, dvrr_stack+147, dvrr_stack+37998, dvrr_stack+117, dvrr_stack+87, dvrr_stack+37932);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+38158, dvrr_stack+377, dvrr_stack+1336, NULL, NULL, dvrr_stack+367);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+38203, dvrr_stack+392, dvrr_stack+38158, dvrr_stack+207, dvrr_stack+377, dvrr_stack+37968);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+39162, dvrr_stack+437, dvrr_stack+38203, dvrr_stack+237, dvrr_stack+392, dvrr_stack+37998);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+39312, dvrr_stack+617, dvrr_stack+39162, dvrr_stack+527, dvrr_stack+437, dvrr_stack+38058);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+38293, dvrr_stack+1351, dvrr_stack+3323, NULL, NULL, dvrr_stack+1336);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+39537, dvrr_stack+1372, dvrr_stack+38293, dvrr_stack+809, dvrr_stack+1351, dvrr_stack+38158);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+39663, dvrr_stack+1435, dvrr_stack+39537, dvrr_stack+830, dvrr_stack+1372, dvrr_stack+38203);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+39873, dvrr_stack+1561, dvrr_stack+39663, dvrr_stack+956, dvrr_stack+1435, dvrr_stack+39162);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+28659, dvrr_stack+1981, dvrr_stack+39873, dvrr_stack+1771, dvrr_stack+1561, dvrr_stack+39312);

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+809, dvrr_stack+3344, dvrr_stack+2877, NULL, NULL, dvrr_stack+3323);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+933, dvrr_stack+3836, dvrr_stack+809, dvrr_stack+2548, dvrr_stack+3344, dvrr_stack+38293);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+49326, dvrr_stack+3920, dvrr_stack+933, dvrr_stack+2576, dvrr_stack+3836, dvrr_stack+39537);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+49606, dvrr_stack+4088, dvrr_stack+49326, dvrr_stack+2660, dvrr_stack+3920, dvrr_stack+39663);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+50026, dvrr_stack+4368, dvrr_stack+49606, dvrr_stack+2996, dvrr_stack+4088, dvrr_stack+39873);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+50614, dvrr_stack+5208, dvrr_stack+50026, dvrr_stack+4788, dvrr_stack+4368, dvrr_stack+28659);
 tmp = dvrr_stack + 50614;
 target_ptr = Libderiv->dvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2996, dvrr_stack+2905, dvrr_stack+7236, NULL, NULL, dvrr_stack+2877);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+40188, dvrr_stack+6588, dvrr_stack+2996, dvrr_stack+767, dvrr_stack+2905, dvrr_stack+809);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+51398, dvrr_stack+7272, dvrr_stack+40188, dvrr_stack+3696, dvrr_stack+6588, dvrr_stack+933);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+51758, dvrr_stack+7488, dvrr_stack+51398, dvrr_stack+5796, dvrr_stack+7272, dvrr_stack+49326);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+52298, dvrr_stack+7848, dvrr_stack+51758, dvrr_stack+6228, dvrr_stack+7488, dvrr_stack+49606);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+53054, dvrr_stack+8928, dvrr_stack+52298, dvrr_stack+8388, dvrr_stack+7848, dvrr_stack+50026);
 tmp = dvrr_stack + 53054;
 target_ptr = Libderiv->dvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+54062,dvrr_stack+53054,dvrr_stack+50614,28);


 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+5796, dvrr_stack+6067, dvrr_stack+11837, NULL, NULL, dvrr_stack+7236);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6112, dvrr_stack+2388, dvrr_stack+5796, dvrr_stack+2296, dvrr_stack+6067, dvrr_stack+2996);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+56414, dvrr_stack+13158, dvrr_stack+6112, dvrr_stack+7101, dvrr_stack+2388, dvrr_stack+40188);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+56864, dvrr_stack+13428, dvrr_stack+56414, dvrr_stack+11448, dvrr_stack+13158, dvrr_stack+51398);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+57539, dvrr_stack+13878, dvrr_stack+56864, dvrr_stack+11988, dvrr_stack+13428, dvrr_stack+51758);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+58484, dvrr_stack+15228, dvrr_stack+57539, dvrr_stack+14553, dvrr_stack+13878, dvrr_stack+52298);
 tmp = dvrr_stack + 58484;
 target_ptr = Libderiv->dvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+59744,dvrr_stack+58484,dvrr_stack+53054,28);


 /* compute (1 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11448, dvrr_stack+11882, dvrr_stack+18935, NULL, NULL, dvrr_stack+11837);

 /* compute (2 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11937, dvrr_stack+3489, dvrr_stack+11448, dvrr_stack+3372, dvrr_stack+11882, dvrr_stack+5796);

 /* compute (3 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+62768, dvrr_stack+20531, dvrr_stack+11937, dvrr_stack+12878, dvrr_stack+3489, dvrr_stack+6112);

 /* compute (4 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+63318, dvrr_stack+20861, dvrr_stack+62768, dvrr_stack+18441, dvrr_stack+20531, dvrr_stack+56414);

 /* compute (5 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+64143, dvrr_stack+21411, dvrr_stack+63318, dvrr_stack+19101, dvrr_stack+20861, dvrr_stack+56864);

 /* compute (6 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+65298, dvrr_stack+23061, dvrr_stack+64143, dvrr_stack+22236, dvrr_stack+21411, dvrr_stack+57539);
 tmp = dvrr_stack + 65298;
 target_ptr = Libderiv->dvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+66838,dvrr_stack+65298,dvrr_stack+58484,28);


 /* compute (1 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19101, dvrr_stack+18990, dvrr_stack+27563, NULL, NULL, dvrr_stack+18935);

 /* compute (2 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12672, dvrr_stack+6841, dvrr_stack+19101, dvrr_stack+6696, dvrr_stack+18990, dvrr_stack+11448);

 /* compute (3 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+70618, dvrr_stack+29559, dvrr_stack+12672, dvrr_stack+20245, dvrr_stack+6841, dvrr_stack+11937);

 /* compute (4 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+71278, dvrr_stack+29955, dvrr_stack+70618, dvrr_stack+27051, dvrr_stack+29559, dvrr_stack+62768);

 /* compute (5 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+72268, dvrr_stack+30615, dvrr_stack+71278, dvrr_stack+27843, dvrr_stack+29955, dvrr_stack+63318);

 /* compute (6 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+73654, dvrr_stack+32595, dvrr_stack+72268, dvrr_stack+31605, dvrr_stack+30615, dvrr_stack+64143);
 tmp = dvrr_stack + 73654;
 target_ptr = Libderiv->dvrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+75502,dvrr_stack+73654,dvrr_stack+65298,28);


 /* compute (0 0 | 1 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+27051, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+40404, dvrr_stack+6012, dvrr_stack+27051, Data->F+15, Data->F+16, NULL);

 /* compute (0 0 | 3 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+39, dvrr_stack+27447, dvrr_stack+40404, dvrr_stack+18771, dvrr_stack+6012, NULL);

 /* compute (0 0 | 4 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+207, dvrr_stack+27453, dvrr_stack+39, dvrr_stack+18774, dvrr_stack+27447, NULL);

 /* compute (0 0 | 5 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+27054, dvrr_stack+27463, dvrr_stack+207, dvrr_stack+18780, dvrr_stack+27453, NULL);

 /* compute (0 0 | 6 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+27075, dvrr_stack+27478, dvrr_stack+27054, dvrr_stack+18790, dvrr_stack+27463, NULL);

 /* compute (0 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+767, dvrr_stack+27499, dvrr_stack+27075, dvrr_stack+18805, dvrr_stack+27478, NULL);

 /* compute (0 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+237, dvrr_stack+27527, dvrr_stack+767, dvrr_stack+18826, dvrr_stack+27499, NULL);

 /* compute (0 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+27103, dvrr_stack+19056, dvrr_stack+237, dvrr_stack+18854, dvrr_stack+27527, NULL);

 /* compute (0 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27158, dvrr_stack+2941, dvrr_stack+27103, dvrr_stack+18890, dvrr_stack+19056, NULL);

 /* compute (0 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27224, dvrr_stack+27563, dvrr_stack+27158, dvrr_stack+18935, dvrr_stack+2941, NULL);

 /* compute (1 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+19299, dvrr_stack+28581, dvrr_stack+27224, NULL, NULL, dvrr_stack+27563);

 /* compute (2 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27629, dvrr_stack+12438, dvrr_stack+19299, dvrr_stack+19651, dvrr_stack+28581, dvrr_stack+19101);

 /* compute (3 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+80122, dvrr_stack+19729, dvrr_stack+27629, dvrr_stack+29205, dvrr_stack+12438, dvrr_stack+12672);

 /* compute (4 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+80902, dvrr_stack+40410, dvrr_stack+80122, dvrr_stack+37446, dvrr_stack+19729, dvrr_stack+70618);

 /* compute (5 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+82072, dvrr_stack+41190, dvrr_stack+80902, dvrr_stack+38382, dvrr_stack+40410, dvrr_stack+71278);

 /* compute (6 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+83710, dvrr_stack+43530, dvrr_stack+82072, dvrr_stack+42360, dvrr_stack+41190, dvrr_stack+72268);

 /* compute (6 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+85894,dvrr_stack+83710,dvrr_stack+73654,28);


 /* compute (1 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+42360, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+42363, dvrr_stack+3, dvrr_stack+68, NULL, NULL, Data->F+7);

 /* compute (2 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+42372, dvrr_stack+11718, dvrr_stack+42363, dvrr_stack+0, dvrr_stack+3, dvrr_stack+42360);

 /* compute (1 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+42390, dvrr_stack+71, dvrr_stack+361, NULL, NULL, dvrr_stack+68);

 /* compute (2 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+42408, dvrr_stack+37914, dvrr_stack+42390, dvrr_stack+6, dvrr_stack+71, dvrr_stack+42363);

 /* compute (3 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+42444, dvrr_stack+37932, dvrr_stack+42408, dvrr_stack+21, dvrr_stack+37914, dvrr_stack+42372);

 /* compute (1 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+42504, dvrr_stack+367, dvrr_stack+1326, NULL, NULL, dvrr_stack+361);

 /* compute (2 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+42534, dvrr_stack+37968, dvrr_stack+42504, dvrr_stack+77, dvrr_stack+367, dvrr_stack+42390);

 /* compute (3 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+42594, dvrr_stack+37998, dvrr_stack+42534, dvrr_stack+87, dvrr_stack+37968, dvrr_stack+42408);

 /* compute (4 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+42694, dvrr_stack+38058, dvrr_stack+42594, dvrr_stack+147, dvrr_stack+37998, dvrr_stack+42444);

 /* compute (1 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+42844, dvrr_stack+1336, dvrr_stack+222, NULL, NULL, dvrr_stack+1326);

 /* compute (2 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+13068, dvrr_stack+38158, dvrr_stack+42844, dvrr_stack+377, dvrr_stack+1336, dvrr_stack+42504);

 /* compute (3 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+42889, dvrr_stack+38203, dvrr_stack+13068, dvrr_stack+392, dvrr_stack+38158, dvrr_stack+42534);

 /* compute (4 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+43039, dvrr_stack+39162, dvrr_stack+42889, dvrr_stack+437, dvrr_stack+38203, dvrr_stack+42594);

 /* compute (5 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+37446, dvrr_stack+39312, dvrr_stack+43039, dvrr_stack+617, dvrr_stack+39162, dvrr_stack+42694);

 /* compute (1 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+377, dvrr_stack+3323, dvrr_stack+2856, NULL, NULL, dvrr_stack+222);

 /* compute (2 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+43264, dvrr_stack+38293, dvrr_stack+377, dvrr_stack+1351, dvrr_stack+3323, dvrr_stack+42844);

 /* compute (3 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+18441, dvrr_stack+39537, dvrr_stack+43264, dvrr_stack+1372, dvrr_stack+38293, dvrr_stack+13068);

 /* compute (4 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+38356, dvrr_stack+39663, dvrr_stack+18441, dvrr_stack+1435, dvrr_stack+39537, dvrr_stack+42889);

 /* compute (5 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+38671, dvrr_stack+39873, dvrr_stack+38356, dvrr_stack+1561, dvrr_stack+39663, dvrr_stack+43039);

 /* compute (6 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+91438, dvrr_stack+28659, dvrr_stack+38671, dvrr_stack+1981, dvrr_stack+39873, dvrr_stack+37446);

 /* compute (1 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1351, dvrr_stack+2877, dvrr_stack+3276, NULL, NULL, dvrr_stack+2856);

 /* compute (2 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+1435, dvrr_stack+809, dvrr_stack+1351, dvrr_stack+3344, dvrr_stack+2877, dvrr_stack+377);

 /* compute (3 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+29100, dvrr_stack+933, dvrr_stack+1435, dvrr_stack+3836, dvrr_stack+809, dvrr_stack+43264);

 /* compute (4 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+28097, dvrr_stack+49326, dvrr_stack+29100, dvrr_stack+3920, dvrr_stack+933, dvrr_stack+18441);

 /* compute (5 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+92026, dvrr_stack+49606, dvrr_stack+28097, dvrr_stack+4088, dvrr_stack+49326, dvrr_stack+38356);

 /* compute (6 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+92614, dvrr_stack+50026, dvrr_stack+92026, dvrr_stack+4368, dvrr_stack+49606, dvrr_stack+38671);

 /* compute (7 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+3654, dvrr_stack+50614, dvrr_stack+92614, dvrr_stack+5208, dvrr_stack+50026, dvrr_stack+91438);
 tmp = dvrr_stack + 3654;
 target_ptr = Libderiv->dvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3344, dvrr_stack+7236, dvrr_stack+11801, NULL, NULL, dvrr_stack+3276);

 /* compute (2 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+20197, dvrr_stack+2996, dvrr_stack+3344, dvrr_stack+2905, dvrr_stack+7236, dvrr_stack+1351);

 /* compute (3 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+93398, dvrr_stack+40188, dvrr_stack+20197, dvrr_stack+6588, dvrr_stack+2996, dvrr_stack+1435);

 /* compute (4 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+93758, dvrr_stack+51398, dvrr_stack+93398, dvrr_stack+7272, dvrr_stack+40188, dvrr_stack+29100);

 /* compute (5 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+94298, dvrr_stack+51758, dvrr_stack+93758, dvrr_stack+7488, dvrr_stack+51398, dvrr_stack+28097);

 /* compute (6 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+95054, dvrr_stack+52298, dvrr_stack+94298, dvrr_stack+7848, dvrr_stack+51758, dvrr_stack+92026);

 /* compute (7 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+96062, dvrr_stack+53054, dvrr_stack+95054, dvrr_stack+8928, dvrr_stack+52298, dvrr_stack+92614);
 tmp = dvrr_stack + 96062;
 target_ptr = Libderiv->dvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+97358,dvrr_stack+96062,dvrr_stack+3654,36);


 /* compute (1 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7272, dvrr_stack+11837, dvrr_stack+18890, NULL, NULL, dvrr_stack+11801);

 /* compute (2 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7407, dvrr_stack+5796, dvrr_stack+7272, dvrr_stack+6067, dvrr_stack+11837, dvrr_stack+3344);

 /* compute (3 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7677, dvrr_stack+6112, dvrr_stack+7407, dvrr_stack+2388, dvrr_stack+5796, dvrr_stack+20197);

 /* compute (4 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+100382, dvrr_stack+56414, dvrr_stack+7677, dvrr_stack+13158, dvrr_stack+6112, dvrr_stack+93398);

 /* compute (5 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+101057, dvrr_stack+56864, dvrr_stack+100382, dvrr_stack+13428, dvrr_stack+56414, dvrr_stack+93758);

 /* compute (6 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+102002, dvrr_stack+57539, dvrr_stack+101057, dvrr_stack+13878, dvrr_stack+56864, dvrr_stack+94298);

 /* compute (7 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+103262, dvrr_stack+58484, dvrr_stack+102002, dvrr_stack+15228, dvrr_stack+57539, dvrr_stack+95054);
 tmp = dvrr_stack + 103262;
 target_ptr = Libderiv->dvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+104882,dvrr_stack+103262,dvrr_stack+96062,36);


 /* compute (1 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+13158, dvrr_stack+18935, dvrr_stack+2941, NULL, NULL, dvrr_stack+18890);

 /* compute (2 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+13323, dvrr_stack+11448, dvrr_stack+13158, dvrr_stack+11882, dvrr_stack+18935, dvrr_stack+7272);

 /* compute (3 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+13653, dvrr_stack+11937, dvrr_stack+13323, dvrr_stack+3489, dvrr_stack+11448, dvrr_stack+7407);

 /* compute (4 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+108770, dvrr_stack+62768, dvrr_stack+13653, dvrr_stack+20531, dvrr_stack+11937, dvrr_stack+7677);

 /* compute (5 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+109595, dvrr_stack+63318, dvrr_stack+108770, dvrr_stack+20861, dvrr_stack+62768, dvrr_stack+100382);

 /* compute (6 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+110750, dvrr_stack+64143, dvrr_stack+109595, dvrr_stack+21411, dvrr_stack+63318, dvrr_stack+101057);

 /* compute (7 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+112290, dvrr_stack+65298, dvrr_stack+110750, dvrr_stack+23061, dvrr_stack+64143, dvrr_stack+102002);
 tmp = dvrr_stack + 112290;
 target_ptr = Libderiv->dvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+114270,dvrr_stack+112290,dvrr_stack+103262,36);


 /* compute (1 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+14203, dvrr_stack+27563, dvrr_stack+27158, NULL, NULL, dvrr_stack+2941);

 /* compute (2 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+2296, dvrr_stack+19101, dvrr_stack+14203, dvrr_stack+18990, dvrr_stack+27563, dvrr_stack+13158);

 /* compute (3 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20413, dvrr_stack+12672, dvrr_stack+2296, dvrr_stack+6841, dvrr_stack+19101, dvrr_stack+13323);

 /* compute (4 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+21073, dvrr_stack+70618, dvrr_stack+20413, dvrr_stack+29559, dvrr_stack+12672, dvrr_stack+13653);

 /* compute (5 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+119130, dvrr_stack+71278, dvrr_stack+21073, dvrr_stack+29955, dvrr_stack+70618, dvrr_stack+108770);

 /* compute (6 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+120516, dvrr_stack+72268, dvrr_stack+119130, dvrr_stack+30615, dvrr_stack+71278, dvrr_stack+109595);

 /* compute (7 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+122364, dvrr_stack+73654, dvrr_stack+120516, dvrr_stack+32595, dvrr_stack+72268, dvrr_stack+110750);
 tmp = dvrr_stack + 122364;
 target_ptr = Libderiv->dvrr_classes[7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+124740,dvrr_stack+122364,dvrr_stack+112290,36);


 /* compute (0 0 | 1 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+18990, Data->F+17, Data->F+18, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+27051, dvrr_stack+18990, Data->F+16, Data->F+17, NULL);

 /* compute (0 0 | 3 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+18993, dvrr_stack+40404, dvrr_stack+6, dvrr_stack+6012, dvrr_stack+27051, NULL);

 /* compute (0 0 | 4 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+19003, dvrr_stack+39, dvrr_stack+18993, dvrr_stack+27447, dvrr_stack+40404, NULL);

 /* compute (0 0 | 5 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+19018, dvrr_stack+207, dvrr_stack+19003, dvrr_stack+27453, dvrr_stack+39, NULL);

 /* compute (0 0 | 6 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+11882, dvrr_stack+27054, dvrr_stack+19018, dvrr_stack+27463, dvrr_stack+207, NULL);

 /* compute (0 0 | 7 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2905, dvrr_stack+27075, dvrr_stack+11882, dvrr_stack+27478, dvrr_stack+27054, NULL);

 /* compute (0 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6067, dvrr_stack+767, dvrr_stack+2905, dvrr_stack+27499, dvrr_stack+27075, NULL);

 /* compute (0 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+14401, dvrr_stack+237, dvrr_stack+6067, dvrr_stack+27527, dvrr_stack+767, NULL);

 /* compute (0 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+14456, dvrr_stack+27103, dvrr_stack+14401, dvrr_stack+19056, dvrr_stack+237, NULL);

 /* compute (0 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+8127, dvrr_stack+27158, dvrr_stack+14456, dvrr_stack+2941, dvrr_stack+27103, NULL);

 /* compute (1 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+29380, dvrr_stack+27224, dvrr_stack+8127, NULL, NULL, dvrr_stack+27158);

 /* compute (2 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+29614, dvrr_stack+19299, dvrr_stack+29380, dvrr_stack+28581, dvrr_stack+27224, dvrr_stack+14203);

 /* compute (3 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+30082, dvrr_stack+27629, dvrr_stack+29614, dvrr_stack+12438, dvrr_stack+19299, dvrr_stack+2296);

 /* compute (4 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+130680, dvrr_stack+80122, dvrr_stack+30082, dvrr_stack+19729, dvrr_stack+27629, dvrr_stack+20413);

 /* compute (5 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+131850, dvrr_stack+80902, dvrr_stack+130680, dvrr_stack+40410, dvrr_stack+80122, dvrr_stack+21073);

 /* compute (6 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+133488, dvrr_stack+82072, dvrr_stack+131850, dvrr_stack+41190, dvrr_stack+80902, dvrr_stack+119130);

 /* compute (7 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+135672, dvrr_stack+83710, dvrr_stack+133488, dvrr_stack+43530, dvrr_stack+82072, dvrr_stack+120516);

 /* compute (7 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+138480,dvrr_stack+135672,dvrr_stack+122364,36);


 /* compute (1 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+40410, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+40413, dvrr_stack+42360, dvrr_stack+40410, Data->F+6, Data->F+7, NULL);

 /* compute (1 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+40419, dvrr_stack+68, dvrr_stack+49, NULL, NULL, Data->F+8);

 /* compute (2 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+40428, dvrr_stack+42363, dvrr_stack+40419, dvrr_stack+3, dvrr_stack+68, dvrr_stack+40410);

 /* compute (3 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+40446, dvrr_stack+42372, dvrr_stack+40428, dvrr_stack+11718, dvrr_stack+42363, dvrr_stack+40413);

 /* compute (1 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+40476, dvrr_stack+361, dvrr_stack+285, NULL, NULL, dvrr_stack+49);

 /* compute (2 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+40494, dvrr_stack+42390, dvrr_stack+40476, dvrr_stack+71, dvrr_stack+361, dvrr_stack+40419);

 /* compute (3 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+40530, dvrr_stack+42408, dvrr_stack+40494, dvrr_stack+37914, dvrr_stack+42390, dvrr_stack+40428);

 /* compute (4 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+40590, dvrr_stack+42444, dvrr_stack+40530, dvrr_stack+37932, dvrr_stack+42408, dvrr_stack+40446);

 /* compute (1 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+71, dvrr_stack+1326, dvrr_stack+3313, NULL, NULL, dvrr_stack+285);

 /* compute (2 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+40680, dvrr_stack+42504, dvrr_stack+71, dvrr_stack+367, dvrr_stack+1326, dvrr_stack+40476);

 /* compute (3 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+40740, dvrr_stack+42534, dvrr_stack+40680, dvrr_stack+37968, dvrr_stack+42504, dvrr_stack+40494);

 /* compute (4 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+40840, dvrr_stack+42594, dvrr_stack+40740, dvrr_stack+37998, dvrr_stack+42534, dvrr_stack+40530);

 /* compute (5 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+40990, dvrr_stack+42694, dvrr_stack+40840, dvrr_stack+38058, dvrr_stack+42594, dvrr_stack+40590);

 /* compute (1 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+37968, dvrr_stack+222, dvrr_stack+2841, NULL, NULL, dvrr_stack+3313);

 /* compute (2 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+41200, dvrr_stack+42844, dvrr_stack+37968, dvrr_stack+1336, dvrr_stack+222, dvrr_stack+71);

 /* compute (3 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+41290, dvrr_stack+13068, dvrr_stack+41200, dvrr_stack+38158, dvrr_stack+42844, dvrr_stack+40680);

 /* compute (4 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+41440, dvrr_stack+42889, dvrr_stack+41290, dvrr_stack+38203, dvrr_stack+13068, dvrr_stack+40740);

 /* compute (5 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+41665, dvrr_stack+43039, dvrr_stack+41440, dvrr_stack+39162, dvrr_stack+42889, dvrr_stack+40840);

 /* compute (6 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+19533, dvrr_stack+37446, dvrr_stack+41665, dvrr_stack+39312, dvrr_stack+43039, dvrr_stack+40990);

 /* compute (1 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+38158, dvrr_stack+2856, dvrr_stack+6046, NULL, NULL, dvrr_stack+2841);

 /* compute (2 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+4662, dvrr_stack+377, dvrr_stack+38158, dvrr_stack+3323, dvrr_stack+2856, dvrr_stack+37968);

 /* compute (3 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+41980, dvrr_stack+43264, dvrr_stack+4662, dvrr_stack+38293, dvrr_stack+377, dvrr_stack+41200);

 /* compute (4 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+30862, dvrr_stack+18441, dvrr_stack+41980, dvrr_stack+39537, dvrr_stack+43264, dvrr_stack+41290);

 /* compute (5 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+6382, dvrr_stack+38356, dvrr_stack+30862, dvrr_stack+39663, dvrr_stack+18441, dvrr_stack+41440);

 /* compute (6 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+145608, dvrr_stack+38671, dvrr_stack+6382, dvrr_stack+39873, dvrr_stack+38356, dvrr_stack+41665);

 /* compute (7 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+146196, dvrr_stack+91438, dvrr_stack+145608, dvrr_stack+28659, dvrr_stack+38671, dvrr_stack+19533);

 /* compute (1 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+5931, dvrr_stack+3276, dvrr_stack+11773, NULL, NULL, dvrr_stack+6046);

 /* compute (2 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+1603, dvrr_stack+1351, dvrr_stack+5931, dvrr_stack+2877, dvrr_stack+3276, dvrr_stack+38158);

 /* compute (3 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+39537, dvrr_stack+1435, dvrr_stack+1603, dvrr_stack+809, dvrr_stack+1351, dvrr_stack+4662);

 /* compute (4 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+31177, dvrr_stack+29100, dvrr_stack+39537, dvrr_stack+933, dvrr_stack+1435, dvrr_stack+41980);

 /* compute (5 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+146952, dvrr_stack+28097, dvrr_stack+31177, dvrr_stack+49326, dvrr_stack+29100, dvrr_stack+30862);

 /* compute (6 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+147540, dvrr_stack+92026, dvrr_stack+146952, dvrr_stack+49606, dvrr_stack+28097, dvrr_stack+6382);

 /* compute (7 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+148324, dvrr_stack+92614, dvrr_stack+147540, dvrr_stack+50026, dvrr_stack+92026, dvrr_stack+145608);

 /* compute (8 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+49326, dvrr_stack+3654, dvrr_stack+148324, dvrr_stack+50614, dvrr_stack+92614, dvrr_stack+146196);
 tmp = dvrr_stack + 49326;
 target_ptr = Libderiv->dvrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+933, dvrr_stack+11801, dvrr_stack+18854, NULL, NULL, dvrr_stack+11773);

 /* compute (2 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+39817, dvrr_stack+3344, dvrr_stack+933, dvrr_stack+7236, dvrr_stack+11801, dvrr_stack+5931);

 /* compute (3 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+12267, dvrr_stack+20197, dvrr_stack+39817, dvrr_stack+2996, dvrr_stack+3344, dvrr_stack+1603);

 /* compute (4 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+149332, dvrr_stack+93398, dvrr_stack+12267, dvrr_stack+40188, dvrr_stack+20197, dvrr_stack+39537);

 /* compute (5 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+149872, dvrr_stack+93758, dvrr_stack+149332, dvrr_stack+51398, dvrr_stack+93398, dvrr_stack+31177);

 /* compute (6 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+150628, dvrr_stack+94298, dvrr_stack+149872, dvrr_stack+51758, dvrr_stack+93758, dvrr_stack+146952);

 /* compute (7 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+151636, dvrr_stack+95054, dvrr_stack+150628, dvrr_stack+52298, dvrr_stack+94298, dvrr_stack+147540);

 /* compute (8 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+51398, dvrr_stack+96062, dvrr_stack+151636, dvrr_stack+53054, dvrr_stack+95054, dvrr_stack+148324);
 tmp = dvrr_stack + 51398;
 target_ptr = Libderiv->dvrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+152932,dvrr_stack+51398,dvrr_stack+49326,45);


 /* compute (1 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+38221, dvrr_stack+18890, dvrr_stack+19056, NULL, NULL, dvrr_stack+18854);

 /* compute (2 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2996, dvrr_stack+7272, dvrr_stack+38221, dvrr_stack+11837, dvrr_stack+18890, dvrr_stack+933);

 /* compute (3 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+156712, dvrr_stack+7407, dvrr_stack+2996, dvrr_stack+5796, dvrr_stack+7272, dvrr_stack+39817);

 /* compute (4 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+157162, dvrr_stack+7677, dvrr_stack+156712, dvrr_stack+6112, dvrr_stack+7407, dvrr_stack+12267);

 /* compute (5 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+157837, dvrr_stack+100382, dvrr_stack+157162, dvrr_stack+56414, dvrr_stack+7677, dvrr_stack+149332);

 /* compute (6 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+158782, dvrr_stack+101057, dvrr_stack+157837, dvrr_stack+56864, dvrr_stack+100382, dvrr_stack+149872);

 /* compute (7 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+160042, dvrr_stack+102002, dvrr_stack+158782, dvrr_stack+57539, dvrr_stack+101057, dvrr_stack+150628);

 /* compute (8 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+56414, dvrr_stack+103262, dvrr_stack+160042, dvrr_stack+58484, dvrr_stack+102002, dvrr_stack+151636);
 tmp = dvrr_stack + 56414;
 target_ptr = Libderiv->dvrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+161662,dvrr_stack+56414,dvrr_stack+51398,45);


 /* compute (1 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6112, dvrr_stack+2941, dvrr_stack+27103, NULL, NULL, dvrr_stack+19056);

 /* compute (2 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+40033, dvrr_stack+13158, dvrr_stack+6112, dvrr_stack+18935, dvrr_stack+2941, dvrr_stack+38221);

 /* compute (3 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+166522, dvrr_stack+13323, dvrr_stack+40033, dvrr_stack+11448, dvrr_stack+13158, dvrr_stack+2996);

 /* compute (4 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+167072, dvrr_stack+13653, dvrr_stack+166522, dvrr_stack+11937, dvrr_stack+13323, dvrr_stack+156712);

 /* compute (5 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+167897, dvrr_stack+108770, dvrr_stack+167072, dvrr_stack+62768, dvrr_stack+13653, dvrr_stack+157162);

 /* compute (6 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+169052, dvrr_stack+109595, dvrr_stack+167897, dvrr_stack+63318, dvrr_stack+108770, dvrr_stack+157837);

 /* compute (7 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+170592, dvrr_stack+110750, dvrr_stack+169052, dvrr_stack+64143, dvrr_stack+109595, dvrr_stack+158782);

 /* compute (8 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+62768, dvrr_stack+112290, dvrr_stack+170592, dvrr_stack+65298, dvrr_stack+110750, dvrr_stack+160042);
 tmp = dvrr_stack + 62768;
 target_ptr = Libderiv->dvrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+172572,dvrr_stack+62768,dvrr_stack+56414,45);


 /* compute (1 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+11448, dvrr_stack+27158, dvrr_stack+14456, NULL, NULL, dvrr_stack+27103);

 /* compute (2 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6823, dvrr_stack+14203, dvrr_stack+11448, dvrr_stack+27563, dvrr_stack+27158, dvrr_stack+6112);

 /* compute (3 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+178647, dvrr_stack+2296, dvrr_stack+6823, dvrr_stack+19101, dvrr_stack+14203, dvrr_stack+40033);

 /* compute (4 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+179307, dvrr_stack+20413, dvrr_stack+178647, dvrr_stack+12672, dvrr_stack+2296, dvrr_stack+166522);

 /* compute (5 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+180297, dvrr_stack+21073, dvrr_stack+179307, dvrr_stack+70618, dvrr_stack+20413, dvrr_stack+167072);

 /* compute (6 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+181683, dvrr_stack+119130, dvrr_stack+180297, dvrr_stack+71278, dvrr_stack+21073, dvrr_stack+167897);

 /* compute (7 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+183531, dvrr_stack+120516, dvrr_stack+181683, dvrr_stack+72268, dvrr_stack+119130, dvrr_stack+169052);

 /* compute (8 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+70618, dvrr_stack+122364, dvrr_stack+183531, dvrr_stack+73654, dvrr_stack+120516, dvrr_stack+170592);
 tmp = dvrr_stack + 70618;
 target_ptr = Libderiv->dvrr_classes[8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+185907,dvrr_stack+70618,dvrr_stack+62768,45);


 /* compute (0 0 | 1 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+18, Data->F+19, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+73588, dvrr_stack+18990, dvrr_stack+3, Data->F+17, Data->F+18, NULL);

 /* compute (0 0 | 3 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+3266, dvrr_stack+6, dvrr_stack+73588, dvrr_stack+27051, dvrr_stack+18990, NULL);

 /* compute (0 0 | 4 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1336, dvrr_stack+18993, dvrr_stack+3266, dvrr_stack+40404, dvrr_stack+6, NULL);

 /* compute (0 0 | 5 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+3323, dvrr_stack+19003, dvrr_stack+1336, dvrr_stack+39, dvrr_stack+18993, NULL);

 /* compute (0 0 | 6 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+50586, dvrr_stack+19018, dvrr_stack+3323, dvrr_stack+207, dvrr_stack+19003, NULL);

 /* compute (0 0 | 7 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+53018, dvrr_stack+11882, dvrr_stack+50586, dvrr_stack+27054, dvrr_stack+19018, NULL);

 /* compute (0 0 | 8 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+58439, dvrr_stack+2905, dvrr_stack+53018, dvrr_stack+27075, dvrr_stack+11882, NULL);

 /* compute (0 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+65243, dvrr_stack+6067, dvrr_stack+58439, dvrr_stack+767, dvrr_stack+2905, NULL);

 /* compute (0 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27563, dvrr_stack+14401, dvrr_stack+65243, dvrr_stack+237, dvrr_stack+6067, NULL);

 /* compute (0 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+19101, dvrr_stack+14456, dvrr_stack+27563, dvrr_stack+27103, dvrr_stack+14401, NULL);

 /* compute (1 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+11910, dvrr_stack+8127, dvrr_stack+19101, NULL, NULL, dvrr_stack+14456);

 /* compute (2 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+193332, dvrr_stack+29380, dvrr_stack+11910, dvrr_stack+27224, dvrr_stack+8127, dvrr_stack+11448);

 /* compute (3 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+193800, dvrr_stack+29614, dvrr_stack+193332, dvrr_stack+19299, dvrr_stack+29380, dvrr_stack+6823);

 /* compute (4 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+194580, dvrr_stack+30082, dvrr_stack+193800, dvrr_stack+27629, dvrr_stack+29614, dvrr_stack+178647);

 /* compute (5 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+195750, dvrr_stack+130680, dvrr_stack+194580, dvrr_stack+80122, dvrr_stack+30082, dvrr_stack+179307);

 /* compute (6 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+197388, dvrr_stack+131850, dvrr_stack+195750, dvrr_stack+80902, dvrr_stack+130680, dvrr_stack+180297);

 /* compute (7 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+199572, dvrr_stack+133488, dvrr_stack+197388, dvrr_stack+82072, dvrr_stack+131850, dvrr_stack+181683);

 /* compute (8 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+80122, dvrr_stack+135672, dvrr_stack+199572, dvrr_stack+83710, dvrr_stack+133488, dvrr_stack+183531);

 /* compute (8 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+202380,dvrr_stack+80122,dvrr_stack+70618,45);


 /* compute (1 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+83632, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+83635, dvrr_stack+40410, dvrr_stack+83632, Data->F+7, Data->F+8, NULL);

 /* compute (3 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+39, dvrr_stack+40413, dvrr_stack+83635, dvrr_stack+42360, dvrr_stack+40410, NULL);

 /* compute (1 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+83641, dvrr_stack+49, dvrr_stack+282, NULL, NULL, Data->F+9);

 /* compute (2 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+83650, dvrr_stack+40419, dvrr_stack+83641, dvrr_stack+68, dvrr_stack+49, dvrr_stack+83632);

 /* compute (3 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+83668, dvrr_stack+40428, dvrr_stack+83650, dvrr_stack+42363, dvrr_stack+40419, dvrr_stack+83635);

 /* compute (4 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+11837, dvrr_stack+40446, dvrr_stack+83668, dvrr_stack+42372, dvrr_stack+40428, dvrr_stack+39);

 /* compute (1 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+27629, dvrr_stack+285, dvrr_stack+3307, NULL, NULL, dvrr_stack+282);

 /* compute (2 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+27647, dvrr_stack+40476, dvrr_stack+27629, dvrr_stack+361, dvrr_stack+285, dvrr_stack+83641);

 /* compute (3 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+73594, dvrr_stack+40494, dvrr_stack+27647, dvrr_stack+42390, dvrr_stack+40476, dvrr_stack+83650);

 /* compute (4 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+27683, dvrr_stack+40530, dvrr_stack+73594, dvrr_stack+42408, dvrr_stack+40494, dvrr_stack+83668);

 /* compute (5 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+27773, dvrr_stack+40590, dvrr_stack+27683, dvrr_stack+42444, dvrr_stack+40530, dvrr_stack+11837);

 /* compute (1 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+42390, dvrr_stack+3313, dvrr_stack+2831, NULL, NULL, dvrr_stack+3307);

 /* compute (2 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+1041, dvrr_stack+71, dvrr_stack+42390, dvrr_stack+1326, dvrr_stack+3313, dvrr_stack+27629);

 /* compute (3 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+27899, dvrr_stack+40680, dvrr_stack+1041, dvrr_stack+42504, dvrr_stack+71, dvrr_stack+27647);

 /* compute (4 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+27224, dvrr_stack+40740, dvrr_stack+27899, dvrr_stack+42534, dvrr_stack+40680, dvrr_stack+73594);

 /* compute (5 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+19179, dvrr_stack+40840, dvrr_stack+27224, dvrr_stack+42594, dvrr_stack+40740, dvrr_stack+27683);

 /* compute (6 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+12627, dvrr_stack+40990, dvrr_stack+19179, dvrr_stack+42694, dvrr_stack+40840, dvrr_stack+27773);

 /* compute (1 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+38013, dvrr_stack+2841, dvrr_stack+6031, NULL, NULL, dvrr_stack+2831);

 /* compute (2 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+42504, dvrr_stack+37968, dvrr_stack+38013, dvrr_stack+222, dvrr_stack+2841, dvrr_stack+42390);

 /* compute (3 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+42190, dvrr_stack+41200, dvrr_stack+42504, dvrr_stack+42844, dvrr_stack+37968, dvrr_stack+1041);

 /* compute (4 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+19953, dvrr_stack+41290, dvrr_stack+42190, dvrr_stack+13068, dvrr_stack+41200, dvrr_stack+27899);

 /* compute (5 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+211290, dvrr_stack+41440, dvrr_stack+19953, dvrr_stack+42889, dvrr_stack+41290, dvrr_stack+27224);

 /* compute (6 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+211605, dvrr_stack+41665, dvrr_stack+211290, dvrr_stack+43039, dvrr_stack+41440, dvrr_stack+19179);

 /* compute (7 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+212025, dvrr_stack+19533, dvrr_stack+211605, dvrr_stack+37446, dvrr_stack+41665, dvrr_stack+12627);

 /* compute (1 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+42844, dvrr_stack+6046, dvrr_stack+11752, NULL, NULL, dvrr_stack+6031);

 /* compute (2 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+42907, dvrr_stack+38158, dvrr_stack+42844, dvrr_stack+2856, dvrr_stack+6046, dvrr_stack+38013);

 /* compute (3 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+43033, dvrr_stack+4662, dvrr_stack+42907, dvrr_stack+377, dvrr_stack+38158, dvrr_stack+42504);

 /* compute (4 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+212565, dvrr_stack+41980, dvrr_stack+43033, dvrr_stack+43264, dvrr_stack+4662, dvrr_stack+42190);

 /* compute (5 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+212880, dvrr_stack+30862, dvrr_stack+212565, dvrr_stack+18441, dvrr_stack+41980, dvrr_stack+19953);

 /* compute (6 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+213321, dvrr_stack+6382, dvrr_stack+212880, dvrr_stack+38356, dvrr_stack+30862, dvrr_stack+211290);

 /* compute (7 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+213909, dvrr_stack+145608, dvrr_stack+213321, dvrr_stack+38671, dvrr_stack+6382, dvrr_stack+211605);

 /* compute (8 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+38356, dvrr_stack+146196, dvrr_stack+213909, dvrr_stack+91438, dvrr_stack+145608, dvrr_stack+212025);

 /* compute (1 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+18441, dvrr_stack+11773, dvrr_stack+18826, NULL, NULL, dvrr_stack+11752);

 /* compute (2 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+18525, dvrr_stack+5931, dvrr_stack+18441, dvrr_stack+3276, dvrr_stack+11773, dvrr_stack+42844);

 /* compute (3 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+43243, dvrr_stack+1603, dvrr_stack+18525, dvrr_stack+1351, dvrr_stack+5931, dvrr_stack+42907);

 /* compute (4 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+214665, dvrr_stack+39537, dvrr_stack+43243, dvrr_stack+1435, dvrr_stack+1603, dvrr_stack+43033);

 /* compute (5 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+215085, dvrr_stack+31177, dvrr_stack+214665, dvrr_stack+29100, dvrr_stack+39537, dvrr_stack+212565);

 /* compute (6 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+215673, dvrr_stack+146952, dvrr_stack+215085, dvrr_stack+28097, dvrr_stack+31177, dvrr_stack+212880);

 /* compute (7 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+216457, dvrr_stack+147540, dvrr_stack+215673, dvrr_stack+92026, dvrr_stack+146952, dvrr_stack+213321);

 /* compute (8 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+217465, dvrr_stack+148324, dvrr_stack+216457, dvrr_stack+92614, dvrr_stack+147540, dvrr_stack+213909);

 /* compute (9 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+218725, dvrr_stack+49326, dvrr_stack+217465, dvrr_stack+3654, dvrr_stack+148324, dvrr_stack+38356);
 tmp = dvrr_stack + 218725;
 target_ptr = Libderiv->dvrr_classes[9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+92026, dvrr_stack+18854, dvrr_stack+27527, NULL, NULL, dvrr_stack+18826);

 /* compute (2 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+92134, dvrr_stack+933, dvrr_stack+92026, dvrr_stack+11801, dvrr_stack+18854, dvrr_stack+18441);

 /* compute (3 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+92350, dvrr_stack+39817, dvrr_stack+92134, dvrr_stack+3344, dvrr_stack+933, dvrr_stack+18525);

 /* compute (4 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+92710, dvrr_stack+12267, dvrr_stack+92350, dvrr_stack+20197, dvrr_stack+39817, dvrr_stack+43243);

 /* compute (5 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+220265, dvrr_stack+149332, dvrr_stack+92710, dvrr_stack+93398, dvrr_stack+12267, dvrr_stack+214665);

 /* compute (6 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+221021, dvrr_stack+149872, dvrr_stack+220265, dvrr_stack+93758, dvrr_stack+149332, dvrr_stack+215085);

 /* compute (7 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+222029, dvrr_stack+150628, dvrr_stack+221021, dvrr_stack+94298, dvrr_stack+149872, dvrr_stack+215673);

 /* compute (8 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+93250, dvrr_stack+151636, dvrr_stack+222029, dvrr_stack+95054, dvrr_stack+150628, dvrr_stack+216457);

 /* compute (9 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+223325, dvrr_stack+51398, dvrr_stack+93250, dvrr_stack+96062, dvrr_stack+151636, dvrr_stack+217465);
 tmp = dvrr_stack + 223325;
 target_ptr = Libderiv->dvrr_classes[9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+225305,dvrr_stack+223325,dvrr_stack+218725,55);


 /* compute (1 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+5796, dvrr_stack+19056, dvrr_stack+237, NULL, NULL, dvrr_stack+27527);

 /* compute (2 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3344, dvrr_stack+38221, dvrr_stack+5796, dvrr_stack+18890, dvrr_stack+19056, dvrr_stack+92026);

 /* compute (3 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+94870, dvrr_stack+2996, dvrr_stack+3344, dvrr_stack+7272, dvrr_stack+38221, dvrr_stack+92134);

 /* compute (4 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+95320, dvrr_stack+156712, dvrr_stack+94870, dvrr_stack+7407, dvrr_stack+2996, dvrr_stack+92350);

 /* compute (5 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+229925, dvrr_stack+157162, dvrr_stack+95320, dvrr_stack+7677, dvrr_stack+156712, dvrr_stack+92710);

 /* compute (6 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+230870, dvrr_stack+157837, dvrr_stack+229925, dvrr_stack+100382, dvrr_stack+157162, dvrr_stack+220265);

 /* compute (7 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+232130, dvrr_stack+158782, dvrr_stack+230870, dvrr_stack+101057, dvrr_stack+157837, dvrr_stack+221021);

 /* compute (8 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+233750, dvrr_stack+160042, dvrr_stack+232130, dvrr_stack+102002, dvrr_stack+158782, dvrr_stack+222029);

 /* compute (9 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+100382, dvrr_stack+56414, dvrr_stack+233750, dvrr_stack+103262, dvrr_stack+160042, dvrr_stack+93250);
 tmp = dvrr_stack + 100382;
 target_ptr = Libderiv->dvrr_classes[9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+235775,dvrr_stack+100382,dvrr_stack+223325,55);


 /* compute (1 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+102857, dvrr_stack+27103, dvrr_stack+14401, NULL, NULL, dvrr_stack+237);

 /* compute (2 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+27999, dvrr_stack+6112, dvrr_stack+102857, dvrr_stack+2941, dvrr_stack+27103, dvrr_stack+5796);

 /* compute (3 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+7219, dvrr_stack+40033, dvrr_stack+27999, dvrr_stack+13158, dvrr_stack+6112, dvrr_stack+3344);

 /* compute (4 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+241715, dvrr_stack+166522, dvrr_stack+7219, dvrr_stack+13323, dvrr_stack+40033, dvrr_stack+94870);

 /* compute (5 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+242540, dvrr_stack+167072, dvrr_stack+241715, dvrr_stack+13653, dvrr_stack+166522, dvrr_stack+95320);

 /* compute (6 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+243695, dvrr_stack+167897, dvrr_stack+242540, dvrr_stack+108770, dvrr_stack+167072, dvrr_stack+229925);

 /* compute (7 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+245235, dvrr_stack+169052, dvrr_stack+243695, dvrr_stack+109595, dvrr_stack+167897, dvrr_stack+230870);

 /* compute (8 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+247215, dvrr_stack+170592, dvrr_stack+245235, dvrr_stack+110750, dvrr_stack+169052, dvrr_stack+232130);

 /* compute (9 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+108770, dvrr_stack+62768, dvrr_stack+247215, dvrr_stack+112290, dvrr_stack+170592, dvrr_stack+233750);
 tmp = dvrr_stack + 108770;
 target_ptr = Libderiv->dvrr_classes[9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+249690,dvrr_stack+108770,dvrr_stack+100382,55);


 /* compute (1 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+111795, dvrr_stack+14456, dvrr_stack+27563, NULL, NULL, dvrr_stack+14401);

 /* compute (2 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12907, dvrr_stack+11448, dvrr_stack+111795, dvrr_stack+27158, dvrr_stack+14456, dvrr_stack+102857);

 /* compute (3 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+13303, dvrr_stack+6823, dvrr_stack+12907, dvrr_stack+14203, dvrr_stack+11448, dvrr_stack+27999);

 /* compute (4 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+257115, dvrr_stack+178647, dvrr_stack+13303, dvrr_stack+2296, dvrr_stack+6823, dvrr_stack+7219);

 /* compute (5 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+258105, dvrr_stack+179307, dvrr_stack+257115, dvrr_stack+20413, dvrr_stack+178647, dvrr_stack+241715);

 /* compute (6 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+259491, dvrr_stack+180297, dvrr_stack+258105, dvrr_stack+21073, dvrr_stack+179307, dvrr_stack+242540);

 /* compute (7 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+261339, dvrr_stack+181683, dvrr_stack+259491, dvrr_stack+119130, dvrr_stack+180297, dvrr_stack+243695);

 /* compute (8 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+263715, dvrr_stack+183531, dvrr_stack+261339, dvrr_stack+120516, dvrr_stack+181683, dvrr_stack+245235);

 /* compute (9 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+266685, dvrr_stack+70618, dvrr_stack+263715, dvrr_stack+122364, dvrr_stack+183531, dvrr_stack+247215);
 tmp = dvrr_stack + 266685;
 target_ptr = Libderiv->dvrr_classes[9][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+270315,dvrr_stack+266685,dvrr_stack+108770,55);


 /* compute (0 0 | 1 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+68, Data->F+19, Data->F+20, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+119130, dvrr_stack+3, dvrr_stack+68, Data->F+18, Data->F+19, NULL);

 /* compute (0 0 | 3 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1326, dvrr_stack+73588, dvrr_stack+119130, dvrr_stack+18990, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+119136, dvrr_stack+3266, dvrr_stack+1326, dvrr_stack+6, dvrr_stack+73588, NULL);

 /* compute (0 0 | 5 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+119151, dvrr_stack+1336, dvrr_stack+119136, dvrr_stack+18993, dvrr_stack+3266, NULL);

 /* compute (0 0 | 6 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3276, dvrr_stack+3323, dvrr_stack+119151, dvrr_stack+19003, dvrr_stack+1336, NULL);

 /* compute (0 0 | 7 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11801, dvrr_stack+50586, dvrr_stack+3276, dvrr_stack+19018, dvrr_stack+3323, NULL);

 /* compute (0 0 | 8 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+119172, dvrr_stack+53018, dvrr_stack+11801, dvrr_stack+11882, dvrr_stack+50586, NULL);

 /* compute (0 0 | 9 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2941, dvrr_stack+58439, dvrr_stack+119172, dvrr_stack+2905, dvrr_stack+53018, NULL);

 /* compute (0 0 | 10 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27158, dvrr_stack+65243, dvrr_stack+2941, dvrr_stack+6067, dvrr_stack+58439, NULL);

 /* compute (0 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+119217, dvrr_stack+27563, dvrr_stack+27158, dvrr_stack+14401, dvrr_stack+65243, NULL);

 /* compute (1 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+119295, dvrr_stack+19101, dvrr_stack+119217, NULL, NULL, dvrr_stack+27563);

 /* compute (2 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+119529, dvrr_stack+11910, dvrr_stack+119295, dvrr_stack+8127, dvrr_stack+19101, dvrr_stack+111795);

 /* compute (3 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+119997, dvrr_stack+193332, dvrr_stack+119529, dvrr_stack+29380, dvrr_stack+11910, dvrr_stack+12907);

 /* compute (4 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+120777, dvrr_stack+193800, dvrr_stack+119997, dvrr_stack+29614, dvrr_stack+193332, dvrr_stack+13303);

 /* compute (5 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+20178, dvrr_stack+194580, dvrr_stack+120777, dvrr_stack+30082, dvrr_stack+193800, dvrr_stack+257115);

 /* compute (6 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+279390, dvrr_stack+195750, dvrr_stack+20178, dvrr_stack+130680, dvrr_stack+194580, dvrr_stack+258105);

 /* compute (7 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+281574, dvrr_stack+197388, dvrr_stack+279390, dvrr_stack+131850, dvrr_stack+195750, dvrr_stack+259491);

 /* compute (8 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+284382, dvrr_stack+199572, dvrr_stack+281574, dvrr_stack+133488, dvrr_stack+197388, dvrr_stack+261339);

 /* compute (9 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+130680, dvrr_stack+80122, dvrr_stack+284382, dvrr_stack+135672, dvrr_stack+199572, dvrr_stack+263715);

 /* compute (9 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+287892,dvrr_stack+130680,dvrr_stack+266685,55);


 /* compute (1 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+134970, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+6, dvrr_stack+83632, dvrr_stack+134970, Data->F+8, Data->F+9, NULL);

 /* compute (3 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+134973, dvrr_stack+83635, dvrr_stack+6, dvrr_stack+40410, dvrr_stack+83632, NULL);

 /* compute (4 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+134983, dvrr_stack+39, dvrr_stack+134973, dvrr_stack+40413, dvrr_stack+83635, NULL);

 /* compute (1 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+42363, dvrr_stack+282, dvrr_stack+3304, NULL, NULL, Data->F+10);

 /* compute (2 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+134998, dvrr_stack+83641, dvrr_stack+42363, dvrr_stack+49, dvrr_stack+282, dvrr_stack+134970);

 /* compute (3 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+207, dvrr_stack+83650, dvrr_stack+134998, dvrr_stack+40419, dvrr_stack+83641, dvrr_stack+6);

 /* compute (4 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+135016, dvrr_stack+83668, dvrr_stack+207, dvrr_stack+40428, dvrr_stack+83650, dvrr_stack+134973);

 /* compute (5 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+135061, dvrr_stack+11837, dvrr_stack+135016, dvrr_stack+40446, dvrr_stack+83668, dvrr_stack+134983);

 /* compute (1 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+40419, dvrr_stack+3307, dvrr_stack+803, NULL, NULL, dvrr_stack+3304);

 /* compute (2 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+135124, dvrr_stack+27629, dvrr_stack+40419, dvrr_stack+285, dvrr_stack+3307, dvrr_stack+42363);

 /* compute (3 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+135160, dvrr_stack+27647, dvrr_stack+135124, dvrr_stack+40476, dvrr_stack+27629, dvrr_stack+134998);

 /* compute (4 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+135220, dvrr_stack+73594, dvrr_stack+135160, dvrr_stack+40494, dvrr_stack+27647, dvrr_stack+207);

 /* compute (5 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+135310, dvrr_stack+27683, dvrr_stack+135220, dvrr_stack+40530, dvrr_stack+73594, dvrr_stack+135016);

 /* compute (6 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+135436, dvrr_stack+27773, dvrr_stack+135310, dvrr_stack+40590, dvrr_stack+27683, dvrr_stack+135061);

 /* compute (1 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+40476, dvrr_stack+2831, dvrr_stack+6021, NULL, NULL, dvrr_stack+803);

 /* compute (2 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+40506, dvrr_stack+42390, dvrr_stack+40476, dvrr_stack+3313, dvrr_stack+2831, dvrr_stack+40419);

 /* compute (3 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+42594, dvrr_stack+1041, dvrr_stack+40506, dvrr_stack+71, dvrr_stack+42390, dvrr_stack+135124);

 /* compute (4 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+121947, dvrr_stack+27899, dvrr_stack+42594, dvrr_stack+40680, dvrr_stack+1041, dvrr_stack+135160);

 /* compute (5 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+122097, dvrr_stack+27224, dvrr_stack+121947, dvrr_stack+40740, dvrr_stack+27899, dvrr_stack+135220);

 /* compute (6 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+2296, dvrr_stack+19179, dvrr_stack+122097, dvrr_stack+40840, dvrr_stack+27224, dvrr_stack+135310);

 /* compute (7 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+29100, dvrr_stack+12627, dvrr_stack+2296, dvrr_stack+40990, dvrr_stack+19179, dvrr_stack+135436);

 /* compute (1 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+40680, dvrr_stack+6031, dvrr_stack+11737, NULL, NULL, dvrr_stack+6021);

 /* compute (2 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+40725, dvrr_stack+38013, dvrr_stack+40680, dvrr_stack+2841, dvrr_stack+6031, dvrr_stack+40476);

 /* compute (3 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+40815, dvrr_stack+42504, dvrr_stack+40725, dvrr_stack+37968, dvrr_stack+38013, dvrr_stack+40506);

 /* compute (4 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+2576, dvrr_stack+42190, dvrr_stack+40815, dvrr_stack+41200, dvrr_stack+42504, dvrr_stack+42594);

 /* compute (5 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+29460, dvrr_stack+19953, dvrr_stack+2576, dvrr_stack+41290, dvrr_stack+42190, dvrr_stack+121947);

 /* compute (6 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+21816, dvrr_stack+211290, dvrr_stack+29460, dvrr_stack+41440, dvrr_stack+19953, dvrr_stack+122097);

 /* compute (7 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+29775, dvrr_stack+211605, dvrr_stack+21816, dvrr_stack+41665, dvrr_stack+211290, dvrr_stack+2296);

 /* compute (8 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+41200, dvrr_stack+212025, dvrr_stack+29775, dvrr_stack+19533, dvrr_stack+211605, dvrr_stack+29100);

 /* compute (1 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+41875, dvrr_stack+11752, dvrr_stack+18805, NULL, NULL, dvrr_stack+11737);

 /* compute (2 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+111993, dvrr_stack+42844, dvrr_stack+41875, dvrr_stack+6046, dvrr_stack+11752, dvrr_stack+40680);

 /* compute (3 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+103022, dvrr_stack+42907, dvrr_stack+111993, dvrr_stack+38158, dvrr_stack+42844, dvrr_stack+40725);

 /* compute (4 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+30315, dvrr_stack+43033, dvrr_stack+103022, dvrr_stack+4662, dvrr_stack+42907, dvrr_stack+40815);

 /* compute (5 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+7769, dvrr_stack+212565, dvrr_stack+30315, dvrr_stack+41980, dvrr_stack+43033, dvrr_stack+2576);

 /* compute (6 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+298782, dvrr_stack+212880, dvrr_stack+7769, dvrr_stack+30862, dvrr_stack+212565, dvrr_stack+29460);

 /* compute (7 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+299370, dvrr_stack+213321, dvrr_stack+298782, dvrr_stack+6382, dvrr_stack+212880, dvrr_stack+21816);

 /* compute (8 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+300126, dvrr_stack+213909, dvrr_stack+299370, dvrr_stack+145608, dvrr_stack+213321, dvrr_stack+29775);

 /* compute (9 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+301071, dvrr_stack+38356, dvrr_stack+300126, dvrr_stack+146196, dvrr_stack+213909, dvrr_stack+41200);

 /* compute (1 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+145608, dvrr_stack+18826, dvrr_stack+27499, NULL, NULL, dvrr_stack+18805);

 /* compute (2 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+145692, dvrr_stack+18441, dvrr_stack+145608, dvrr_stack+11773, dvrr_stack+18826, dvrr_stack+41875);

 /* compute (3 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+145860, dvrr_stack+18525, dvrr_stack+145692, dvrr_stack+5931, dvrr_stack+18441, dvrr_stack+111993);

 /* compute (4 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+30630, dvrr_stack+43243, dvrr_stack+145860, dvrr_stack+1603, dvrr_stack+18525, dvrr_stack+103022);

 /* compute (5 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+302226, dvrr_stack+214665, dvrr_stack+30630, dvrr_stack+39537, dvrr_stack+43243, dvrr_stack+30315);

 /* compute (6 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+302814, dvrr_stack+215085, dvrr_stack+302226, dvrr_stack+31177, dvrr_stack+214665, dvrr_stack+7769);

 /* compute (7 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+303598, dvrr_stack+215673, dvrr_stack+302814, dvrr_stack+146952, dvrr_stack+215085, dvrr_stack+298782);

 /* compute (8 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+304606, dvrr_stack+216457, dvrr_stack+303598, dvrr_stack+147540, dvrr_stack+215673, dvrr_stack+299370);

 /* compute (9 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+305866, dvrr_stack+217465, dvrr_stack+304606, dvrr_stack+148324, dvrr_stack+216457, dvrr_stack+300126);

 /* compute (10 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+146952, dvrr_stack+218725, dvrr_stack+305866, dvrr_stack+49326, dvrr_stack+217465, dvrr_stack+301071);
 tmp = dvrr_stack + 146952;
 target_ptr = Libderiv->dvrr_classes[10][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+148800, dvrr_stack+27527, dvrr_stack+767, NULL, NULL, dvrr_stack+27499);

 /* compute (2 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+148908, dvrr_stack+92026, dvrr_stack+148800, dvrr_stack+18854, dvrr_stack+27527, dvrr_stack+145608);

 /* compute (3 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+31050, dvrr_stack+92134, dvrr_stack+148908, dvrr_stack+933, dvrr_stack+92026, dvrr_stack+145692);

 /* compute (4 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6277, dvrr_stack+92350, dvrr_stack+31050, dvrr_stack+39817, dvrr_stack+92134, dvrr_stack+145860);

 /* compute (5 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+307406, dvrr_stack+92710, dvrr_stack+6277, dvrr_stack+12267, dvrr_stack+92350, dvrr_stack+30630);

 /* compute (6 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+308162, dvrr_stack+220265, dvrr_stack+307406, dvrr_stack+149332, dvrr_stack+92710, dvrr_stack+302226);

 /* compute (7 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+309170, dvrr_stack+221021, dvrr_stack+308162, dvrr_stack+149872, dvrr_stack+220265, dvrr_stack+302814);

 /* compute (8 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+310466, dvrr_stack+222029, dvrr_stack+309170, dvrr_stack+150628, dvrr_stack+221021, dvrr_stack+303598);

 /* compute (9 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+149124, dvrr_stack+93250, dvrr_stack+310466, dvrr_stack+151636, dvrr_stack+222029, dvrr_stack+304606);

 /* compute (10 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+312086, dvrr_stack+223325, dvrr_stack+149124, dvrr_stack+51398, dvrr_stack+93250, dvrr_stack+305866);
 tmp = dvrr_stack + 312086;
 target_ptr = Libderiv->dvrr_classes[10][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+314462,dvrr_stack+312086,dvrr_stack+146952,66);


 /* compute (1 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18854, dvrr_stack+237, dvrr_stack+6067, NULL, NULL, dvrr_stack+767);

 /* compute (2 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+151104, dvrr_stack+5796, dvrr_stack+18854, dvrr_stack+19056, dvrr_stack+237, dvrr_stack+148800);

 /* compute (3 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+151374, dvrr_stack+3344, dvrr_stack+151104, dvrr_stack+38221, dvrr_stack+5796, dvrr_stack+148908);

 /* compute (4 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+151824, dvrr_stack+94870, dvrr_stack+151374, dvrr_stack+2996, dvrr_stack+3344, dvrr_stack+31050);

 /* compute (5 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+320006, dvrr_stack+95320, dvrr_stack+151824, dvrr_stack+156712, dvrr_stack+94870, dvrr_stack+6277);

 /* compute (6 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+320951, dvrr_stack+229925, dvrr_stack+320006, dvrr_stack+157162, dvrr_stack+95320, dvrr_stack+307406);

 /* compute (7 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+322211, dvrr_stack+230870, dvrr_stack+320951, dvrr_stack+157837, dvrr_stack+229925, dvrr_stack+308162);

 /* compute (8 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+156712, dvrr_stack+232130, dvrr_stack+322211, dvrr_stack+158782, dvrr_stack+230870, dvrr_stack+309170);

 /* compute (9 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+323831, dvrr_stack+233750, dvrr_stack+156712, dvrr_stack+160042, dvrr_stack+232130, dvrr_stack+310466);

 /* compute (10 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+326306, dvrr_stack+100382, dvrr_stack+323831, dvrr_stack+56414, dvrr_stack+233750, dvrr_stack+149124);
 tmp = dvrr_stack + 326306;
 target_ptr = Libderiv->dvrr_classes[10][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+329276,dvrr_stack+326306,dvrr_stack+312086,66);


 /* compute (1 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+158737, dvrr_stack+14401, dvrr_stack+65243, NULL, NULL, dvrr_stack+6067);

 /* compute (2 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+28329, dvrr_stack+102857, dvrr_stack+158737, dvrr_stack+27103, dvrr_stack+14401, dvrr_stack+18854);

 /* compute (3 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+158902, dvrr_stack+27999, dvrr_stack+28329, dvrr_stack+6112, dvrr_stack+102857, dvrr_stack+151104);

 /* compute (4 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+159452, dvrr_stack+7219, dvrr_stack+158902, dvrr_stack+40033, dvrr_stack+27999, dvrr_stack+151374);

 /* compute (5 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+160277, dvrr_stack+241715, dvrr_stack+159452, dvrr_stack+166522, dvrr_stack+7219, dvrr_stack+151824);

 /* compute (6 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+336404, dvrr_stack+242540, dvrr_stack+160277, dvrr_stack+167072, dvrr_stack+241715, dvrr_stack+320006);

 /* compute (7 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+337944, dvrr_stack+243695, dvrr_stack+336404, dvrr_stack+167897, dvrr_stack+242540, dvrr_stack+320951);

 /* compute (8 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+166522, dvrr_stack+245235, dvrr_stack+337944, dvrr_stack+169052, dvrr_stack+243695, dvrr_stack+322211);

 /* compute (9 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+339924, dvrr_stack+247215, dvrr_stack+166522, dvrr_stack+170592, dvrr_stack+245235, dvrr_stack+156712);

 /* compute (10 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+342949, dvrr_stack+108770, dvrr_stack+339924, dvrr_stack+62768, dvrr_stack+247215, dvrr_stack+323831);
 tmp = dvrr_stack + 342949;
 target_ptr = Libderiv->dvrr_classes[10][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+346579,dvrr_stack+342949,dvrr_stack+326306,66);


 /* compute (1 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+38158, dvrr_stack+27563, dvrr_stack+27158, NULL, NULL, dvrr_stack+65243);

 /* compute (2 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+168997, dvrr_stack+111795, dvrr_stack+38158, dvrr_stack+14456, dvrr_stack+27563, dvrr_stack+158737);

 /* compute (3 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+169393, dvrr_stack+12907, dvrr_stack+168997, dvrr_stack+11448, dvrr_stack+111795, dvrr_stack+28329);

 /* compute (4 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+170053, dvrr_stack+13303, dvrr_stack+169393, dvrr_stack+6823, dvrr_stack+12907, dvrr_stack+158902);

 /* compute (5 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+171043, dvrr_stack+257115, dvrr_stack+170053, dvrr_stack+178647, dvrr_stack+13303, dvrr_stack+159452);

 /* compute (6 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+355489, dvrr_stack+258105, dvrr_stack+171043, dvrr_stack+179307, dvrr_stack+257115, dvrr_stack+160277);

 /* compute (7 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+357337, dvrr_stack+259491, dvrr_stack+355489, dvrr_stack+180297, dvrr_stack+258105, dvrr_stack+336404);

 /* compute (8 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+178647, dvrr_stack+261339, dvrr_stack+357337, dvrr_stack+181683, dvrr_stack+259491, dvrr_stack+337944);

 /* compute (9 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+359713, dvrr_stack+263715, dvrr_stack+178647, dvrr_stack+183531, dvrr_stack+261339, dvrr_stack+166522);

 /* compute (10 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+363343, dvrr_stack+266685, dvrr_stack+359713, dvrr_stack+70618, dvrr_stack+263715, dvrr_stack+339924);

 /* compute (10 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+367699,dvrr_stack+363343,dvrr_stack+342949,66);


 /* compute (0 0 | 1 0) m=20 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+49, Data->F+20, Data->F+21, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+285, dvrr_stack+68, dvrr_stack+49, Data->F+19, Data->F+20, NULL);

 /* compute (0 0 | 3 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+3313, dvrr_stack+119130, dvrr_stack+285, dvrr_stack+3, dvrr_stack+68, NULL);

 /* compute (0 0 | 4 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+68, dvrr_stack+1326, dvrr_stack+3313, dvrr_stack+73588, dvrr_stack+119130, NULL);

 /* compute (0 0 | 5 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+6046, dvrr_stack+119136, dvrr_stack+68, dvrr_stack+3266, dvrr_stack+1326, NULL);

 /* compute (0 0 | 6 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+11773, dvrr_stack+119151, dvrr_stack+6046, dvrr_stack+1336, dvrr_stack+119136, NULL);

 /* compute (0 0 | 7 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1326, dvrr_stack+3276, dvrr_stack+11773, dvrr_stack+3323, dvrr_stack+119151, NULL);

 /* compute (0 0 | 8 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+37968, dvrr_stack+11801, dvrr_stack+1326, dvrr_stack+50586, dvrr_stack+3276, NULL);

 /* compute (0 0 | 9 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+27103, dvrr_stack+119172, dvrr_stack+37968, dvrr_stack+53018, dvrr_stack+11801, NULL);

 /* compute (0 0 | 10 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1326, dvrr_stack+2941, dvrr_stack+27103, dvrr_stack+58439, dvrr_stack+119172, NULL);

 /* compute (0 0 | 11 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+1392, dvrr_stack+27158, dvrr_stack+1326, dvrr_stack+65243, dvrr_stack+2941, NULL);

 /* compute (1 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+1470, dvrr_stack+119217, dvrr_stack+1392, NULL, NULL, dvrr_stack+27158);

 /* compute (2 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+181617, dvrr_stack+119295, dvrr_stack+1470, dvrr_stack+19101, dvrr_stack+119217, dvrr_stack+38158);

 /* compute (3 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+182085, dvrr_stack+119529, dvrr_stack+181617, dvrr_stack+11910, dvrr_stack+119295, dvrr_stack+168997);

 /* compute (4 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+182865, dvrr_stack+119997, dvrr_stack+182085, dvrr_stack+193332, dvrr_stack+119529, dvrr_stack+169393);

 /* compute (5 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+184035, dvrr_stack+120777, dvrr_stack+182865, dvrr_stack+193800, dvrr_stack+119997, dvrr_stack+170053);

 /* compute (6 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+181617, dvrr_stack+20178, dvrr_stack+184035, dvrr_stack+194580, dvrr_stack+120777, dvrr_stack+171043);

 /* compute (7 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+119130, dvrr_stack+279390, dvrr_stack+181617, dvrr_stack+195750, dvrr_stack+20178, dvrr_stack+355489);

 /* compute (8 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+181617, dvrr_stack+281574, dvrr_stack+119130, dvrr_stack+197388, dvrr_stack+279390, dvrr_stack+357337);

 /* compute (9 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+193332, dvrr_stack+284382, dvrr_stack+181617, dvrr_stack+199572, dvrr_stack+281574, dvrr_stack+178647);

 /* compute (10 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+378589, dvrr_stack+130680, dvrr_stack+193332, dvrr_stack+80122, dvrr_stack+284382, dvrr_stack+359713);

 /* compute (10 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+383737,dvrr_stack+378589,dvrr_stack+363343,66);


 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+40437, dvrr_stack+12, dvrr_stack+0, NULL, NULL, Data->F+5);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+193332, dvrr_stack+52, dvrr_stack+15, NULL, NULL, dvrr_stack+12);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+53018, dvrr_stack+193332, dvrr_stack+21, dvrr_stack+52, dvrr_stack+15, dvrr_stack+40437);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+103232, dvrr_stack+291, dvrr_stack+58, NULL, NULL, dvrr_stack+52);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+193350, dvrr_stack+103232, dvrr_stack+117, dvrr_stack+291, dvrr_stack+58, dvrr_stack+193332);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+193410, dvrr_stack+193350, dvrr_stack+147, dvrr_stack+103232, dvrr_stack+117, dvrr_stack+53018);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+37968, dvrr_stack+1101, dvrr_stack+301, NULL, NULL, dvrr_stack+291);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+193510, dvrr_stack+37968, dvrr_stack+316, dvrr_stack+1101, dvrr_stack+301, dvrr_stack+103232);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+193600, dvrr_stack+193510, dvrr_stack+527, dvrr_stack+37968, dvrr_stack+316, dvrr_stack+193350);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+193750, dvrr_stack+193600, dvrr_stack+617, dvrr_stack+193510, dvrr_stack+527, dvrr_stack+193410);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+193975, dvrr_stack+912, dvrr_stack+1116, NULL, NULL, dvrr_stack+1101);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+4662, dvrr_stack+193975, dvrr_stack+1137, dvrr_stack+912, dvrr_stack+1116, dvrr_stack+37968);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+194038, dvrr_stack+4662, dvrr_stack+1200, dvrr_stack+193975, dvrr_stack+1137, dvrr_stack+193510);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+194248, dvrr_stack+194038, dvrr_stack+1771, dvrr_stack+4662, dvrr_stack+1200, dvrr_stack+193600);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+194563, dvrr_stack+194248, dvrr_stack+1981, dvrr_stack+194038, dvrr_stack+1771, dvrr_stack+193750);

 /* compute (1 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+3, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (2 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+4662, dvrr_stack+40437, dvrr_stack+11718, dvrr_stack+12, dvrr_stack+0, dvrr_stack+3);

 /* compute (3 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+4680, dvrr_stack+53018, dvrr_stack+37932, dvrr_stack+193332, dvrr_stack+21, dvrr_stack+4662);

 /* compute (4 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+193975, dvrr_stack+193410, dvrr_stack+38058, dvrr_stack+193350, dvrr_stack+147, dvrr_stack+4680);

 /* compute (5 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+195004, dvrr_stack+193750, dvrr_stack+39312, dvrr_stack+193600, dvrr_stack+617, dvrr_stack+193975);

 /* compute (6 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+195319, dvrr_stack+194563, dvrr_stack+28659, dvrr_stack+194248, dvrr_stack+1981, dvrr_stack+195004);

 /* compute (2 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+73588, dvrr_stack+3, dvrr_stack+42360, Data->F+5, Data->F+6, NULL);

 /* compute (3 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+103232, dvrr_stack+4662, dvrr_stack+42372, dvrr_stack+40437, dvrr_stack+11718, dvrr_stack+73588);

 /* compute (4 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+193510, dvrr_stack+4680, dvrr_stack+42444, dvrr_stack+53018, dvrr_stack+37932, dvrr_stack+103232);

 /* compute (5 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+194125, dvrr_stack+193975, dvrr_stack+42694, dvrr_stack+193410, dvrr_stack+38058, dvrr_stack+193510);

 /* compute (6 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+195907, dvrr_stack+195004, dvrr_stack+37446, dvrr_stack+193750, dvrr_stack+39312, dvrr_stack+194125);

 /* compute (7 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+196327, dvrr_stack+195319, dvrr_stack+91438, dvrr_stack+194563, dvrr_stack+28659, dvrr_stack+195907);

 /* compute (3 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+28659, dvrr_stack+73588, dvrr_stack+40413, dvrr_stack+3, dvrr_stack+42360, NULL);

 /* compute (4 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+28669, dvrr_stack+103232, dvrr_stack+40446, dvrr_stack+4662, dvrr_stack+42372, dvrr_stack+28659);

 /* compute (5 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+28714, dvrr_stack+193510, dvrr_stack+40590, dvrr_stack+4680, dvrr_stack+42444, dvrr_stack+28669);

 /* compute (6 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+193600, dvrr_stack+194125, dvrr_stack+40990, dvrr_stack+193975, dvrr_stack+42694, dvrr_stack+28714);

 /* compute (7 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+197083, dvrr_stack+195907, dvrr_stack+19533, dvrr_stack+195004, dvrr_stack+37446, dvrr_stack+193600);

 /* compute (8 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+197623, dvrr_stack+196327, dvrr_stack+146196, dvrr_stack+195319, dvrr_stack+91438, dvrr_stack+197083);

 /* compute (4 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+91438, dvrr_stack+28659, dvrr_stack+39, dvrr_stack+73588, dvrr_stack+40413, NULL);

 /* compute (5 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+91453, dvrr_stack+28669, dvrr_stack+11837, dvrr_stack+103232, dvrr_stack+40446, dvrr_stack+91438);

 /* compute (6 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+91516, dvrr_stack+28714, dvrr_stack+27773, dvrr_stack+193510, dvrr_stack+40590, dvrr_stack+91453);

 /* compute (7 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+37446, dvrr_stack+193600, dvrr_stack+12627, dvrr_stack+194125, dvrr_stack+40990, dvrr_stack+91516);

 /* compute (8 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+193880, dvrr_stack+197083, dvrr_stack+212025, dvrr_stack+195907, dvrr_stack+19533, dvrr_stack+37446);

 /* compute (9 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+198568, dvrr_stack+197623, dvrr_stack+38356, dvrr_stack+196327, dvrr_stack+146196, dvrr_stack+193880);

 /* compute (5 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+6046, dvrr_stack+91438, dvrr_stack+134983, dvrr_stack+28659, dvrr_stack+39, NULL);

 /* compute (6 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+5931, dvrr_stack+91453, dvrr_stack+135061, dvrr_stack+28669, dvrr_stack+11837, dvrr_stack+6046);

 /* compute (7 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+195907, dvrr_stack+91516, dvrr_stack+135436, dvrr_stack+28714, dvrr_stack+27773, dvrr_stack+5931);

 /* compute (8 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+91438, dvrr_stack+37446, dvrr_stack+29100, dvrr_stack+193600, dvrr_stack+12627, dvrr_stack+195907);

 /* compute (9 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+199723, dvrr_stack+193880, dvrr_stack+41200, dvrr_stack+197083, dvrr_stack+212025, dvrr_stack+91438);

 /* compute (10 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+200548, dvrr_stack+198568, dvrr_stack+301071, dvrr_stack+197623, dvrr_stack+38356, dvrr_stack+199723);

 /* compute (1 0 | 0 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+199723, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+73588, dvrr_stack+134970, dvrr_stack+199723, Data->F+9, Data->F+10, NULL);

 /* compute (3 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+199726, dvrr_stack+6, dvrr_stack+73588, dvrr_stack+83632, dvrr_stack+134970, NULL);

 /* compute (4 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+199736, dvrr_stack+134973, dvrr_stack+199726, dvrr_stack+83635, dvrr_stack+6, NULL);

 /* compute (5 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+6046, dvrr_stack+134983, dvrr_stack+199736, dvrr_stack+39, dvrr_stack+134973, NULL);

 /* compute (1 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+83632, dvrr_stack+3304, dvrr_stack+2828, NULL, NULL, Data->F+11);

 /* compute (2 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+42372, dvrr_stack+42363, dvrr_stack+83632, dvrr_stack+282, dvrr_stack+3304, dvrr_stack+199723);

 /* compute (3 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+103232, dvrr_stack+134998, dvrr_stack+42372, dvrr_stack+83641, dvrr_stack+42363, dvrr_stack+73588);

 /* compute (4 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+282, dvrr_stack+207, dvrr_stack+103232, dvrr_stack+83650, dvrr_stack+134998, dvrr_stack+199726);

 /* compute (5 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+327, dvrr_stack+135016, dvrr_stack+282, dvrr_stack+83668, dvrr_stack+207, dvrr_stack+199736);

 /* compute (6 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+5931, dvrr_stack+135061, dvrr_stack+327, dvrr_stack+11837, dvrr_stack+135016, dvrr_stack+6046);

 /* compute (1 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+6046, dvrr_stack+803, dvrr_stack+6015, NULL, NULL, dvrr_stack+2828);

 /* compute (2 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+53018, dvrr_stack+40419, dvrr_stack+6046, dvrr_stack+3307, dvrr_stack+803, dvrr_stack+83632);

 /* compute (3 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+83632, dvrr_stack+135124, dvrr_stack+53018, dvrr_stack+27629, dvrr_stack+40419, dvrr_stack+42372);

 /* compute (4 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+803, dvrr_stack+135160, dvrr_stack+83632, dvrr_stack+27647, dvrr_stack+135124, dvrr_stack+103232);

 /* compute (5 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+4662, dvrr_stack+135220, dvrr_stack+803, dvrr_stack+73594, dvrr_stack+135160, dvrr_stack+282);

 /* compute (6 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+199723, dvrr_stack+135310, dvrr_stack+4662, dvrr_stack+27683, dvrr_stack+135220, dvrr_stack+327);

 /* compute (7 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+282, dvrr_stack+135436, dvrr_stack+199723, dvrr_stack+27773, dvrr_stack+135310, dvrr_stack+5931);

 /* compute (1 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+103232, dvrr_stack+6021, dvrr_stack+11727, NULL, NULL, dvrr_stack+6015);

 /* compute (2 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+5931, dvrr_stack+40476, dvrr_stack+103232, dvrr_stack+2831, dvrr_stack+6021, dvrr_stack+6046);

 /* compute (3 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+38058, dvrr_stack+40506, dvrr_stack+5931, dvrr_stack+42390, dvrr_stack+40476, dvrr_stack+53018);

 /* compute (4 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+42694, dvrr_stack+42594, dvrr_stack+38058, dvrr_stack+1041, dvrr_stack+40506, dvrr_stack+83632);

 /* compute (5 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+498, dvrr_stack+121947, dvrr_stack+42694, dvrr_stack+27899, dvrr_stack+42594, dvrr_stack+803);

 /* compute (6 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+803, dvrr_stack+122097, dvrr_stack+498, dvrr_stack+27224, dvrr_stack+121947, dvrr_stack+4662);

 /* compute (7 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+27629, dvrr_stack+2296, dvrr_stack+803, dvrr_stack+19179, dvrr_stack+122097, dvrr_stack+199723);

 /* compute (8 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+199723, dvrr_stack+29100, dvrr_stack+27629, dvrr_stack+12627, dvrr_stack+2296, dvrr_stack+282);

 /* compute (1 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+282, dvrr_stack+11737, dvrr_stack+18790, NULL, NULL, dvrr_stack+11727);

 /* compute (2 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+327, dvrr_stack+40680, dvrr_stack+282, dvrr_stack+6031, dvrr_stack+11737, dvrr_stack+103232);

 /* compute (3 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+200173, dvrr_stack+40725, dvrr_stack+327, dvrr_stack+38013, dvrr_stack+40680, dvrr_stack+5931);

 /* compute (4 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+200323, dvrr_stack+40815, dvrr_stack+200173, dvrr_stack+42504, dvrr_stack+40725, dvrr_stack+38058);

 /* compute (5 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+195004, dvrr_stack+2576, dvrr_stack+200323, dvrr_stack+42190, dvrr_stack+40815, dvrr_stack+42694);

 /* compute (6 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+195907, dvrr_stack+29460, dvrr_stack+195004, dvrr_stack+19953, dvrr_stack+2576, dvrr_stack+498);

 /* compute (7 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+197083, dvrr_stack+21816, dvrr_stack+195907, dvrr_stack+211290, dvrr_stack+29460, dvrr_stack+803);

 /* compute (8 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+134970, dvrr_stack+29775, dvrr_stack+197083, dvrr_stack+211605, dvrr_stack+21816, dvrr_stack+27629);

 /* compute (9 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+28659, dvrr_stack+41200, dvrr_stack+134970, dvrr_stack+212025, dvrr_stack+29775, dvrr_stack+199723);

 /* compute (1 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+199723, dvrr_stack+18805, dvrr_stack+27478, NULL, NULL, dvrr_stack+18790);

 /* compute (2 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+4662, dvrr_stack+41875, dvrr_stack+199723, dvrr_stack+11752, dvrr_stack+18805, dvrr_stack+282);

 /* compute (3 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+199786, dvrr_stack+111993, dvrr_stack+4662, dvrr_stack+42844, dvrr_stack+41875, dvrr_stack+327);

 /* compute (4 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+282, dvrr_stack+103022, dvrr_stack+199786, dvrr_stack+42907, dvrr_stack+111993, dvrr_stack+200173);

 /* compute (5 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+803, dvrr_stack+30315, dvrr_stack+282, dvrr_stack+43033, dvrr_stack+103022, dvrr_stack+200323);

 /* compute (6 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+91438, dvrr_stack+7769, dvrr_stack+803, dvrr_stack+212565, dvrr_stack+30315, dvrr_stack+195004);

 /* compute (7 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+211290, dvrr_stack+298782, dvrr_stack+91438, dvrr_stack+212880, dvrr_stack+7769, dvrr_stack+195907);

 /* compute (8 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+212046, dvrr_stack+299370, dvrr_stack+211290, dvrr_stack+213321, dvrr_stack+298782, dvrr_stack+197083);

 /* compute (9 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+193332, dvrr_stack+300126, dvrr_stack+212046, dvrr_stack+213909, dvrr_stack+299370, dvrr_stack+134970);

 /* compute (10 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+212991, dvrr_stack+301071, dvrr_stack+193332, dvrr_stack+38356, dvrr_stack+300126, dvrr_stack+28659);

 /* compute (1 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+28659, dvrr_stack+27499, dvrr_stack+27075, NULL, NULL, dvrr_stack+27478);

 /* compute (2 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+28743, dvrr_stack+145608, dvrr_stack+28659, dvrr_stack+18826, dvrr_stack+27499, dvrr_stack+199723);

 /* compute (3 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+28911, dvrr_stack+145692, dvrr_stack+28743, dvrr_stack+18441, dvrr_stack+145608, dvrr_stack+4662);

 /* compute (4 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+195907, dvrr_stack+145860, dvrr_stack+28911, dvrr_stack+18525, dvrr_stack+145692, dvrr_stack+199786);

 /* compute (5 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+199723, dvrr_stack+30630, dvrr_stack+195907, dvrr_stack+43243, dvrr_stack+145860, dvrr_stack+282);

 /* compute (6 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+145608, dvrr_stack+302226, dvrr_stack+199723, dvrr_stack+214665, dvrr_stack+30630, dvrr_stack+803);

 /* compute (7 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+29191, dvrr_stack+302814, dvrr_stack+145608, dvrr_stack+215085, dvrr_stack+302226, dvrr_stack+91438);

 /* compute (8 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+38356, dvrr_stack+303598, dvrr_stack+29191, dvrr_stack+215673, dvrr_stack+302814, dvrr_stack+211290);

 /* compute (9 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+39616, dvrr_stack+304606, dvrr_stack+38356, dvrr_stack+216457, dvrr_stack+303598, dvrr_stack+212046);

 /* compute (10 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+41156, dvrr_stack+305866, dvrr_stack+39616, dvrr_stack+217465, dvrr_stack+304606, dvrr_stack+193332);

 /* compute (11 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+298782, dvrr_stack+146952, dvrr_stack+41156, dvrr_stack+218725, dvrr_stack+305866, dvrr_stack+212991);

 /* compute (1 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+193332, dvrr_stack+767, dvrr_stack+2905, NULL, NULL, dvrr_stack+27075);

 /* compute (2 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+193440, dvrr_stack+148800, dvrr_stack+193332, dvrr_stack+27527, dvrr_stack+767, dvrr_stack+28659);

 /* compute (3 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+193656, dvrr_stack+148908, dvrr_stack+193440, dvrr_stack+92026, dvrr_stack+148800, dvrr_stack+28743);

 /* compute (4 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+197083, dvrr_stack+31050, dvrr_stack+193656, dvrr_stack+92134, dvrr_stack+148908, dvrr_stack+28911);

 /* compute (5 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+211290, dvrr_stack+6277, dvrr_stack+197083, dvrr_stack+92350, dvrr_stack+31050, dvrr_stack+195907);

 /* compute (6 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+212046, dvrr_stack+307406, dvrr_stack+211290, dvrr_stack+92710, dvrr_stack+6277, dvrr_stack+199723);

 /* compute (7 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+213054, dvrr_stack+308162, dvrr_stack+212046, dvrr_stack+220265, dvrr_stack+307406, dvrr_stack+145608);

 /* compute (8 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+214350, dvrr_stack+309170, dvrr_stack+213054, dvrr_stack+221021, dvrr_stack+308162, dvrr_stack+29191);

 /* compute (9 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+28659, dvrr_stack+310466, dvrr_stack+214350, dvrr_stack+222029, dvrr_stack+309170, dvrr_stack+38356);

 /* compute (10 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+220265, dvrr_stack+149124, dvrr_stack+28659, dvrr_stack+93250, dvrr_stack+310466, dvrr_stack+39616);

 /* compute (11 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+91438, dvrr_stack+312086, dvrr_stack+220265, dvrr_stack+223325, dvrr_stack+149124, dvrr_stack+41156);

 /* compute (1 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+38356, dvrr_stack+6067, dvrr_stack+58439, NULL, NULL, dvrr_stack+2905);

 /* compute (2 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+38491, dvrr_stack+18854, dvrr_stack+38356, dvrr_stack+237, dvrr_stack+6067, dvrr_stack+193332);

 /* compute (3 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+38761, dvrr_stack+151104, dvrr_stack+38491, dvrr_stack+5796, dvrr_stack+18854, dvrr_stack+193440);

 /* compute (4 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+5796, dvrr_stack+151374, dvrr_stack+38761, dvrr_stack+3344, dvrr_stack+151104, dvrr_stack+193656);

 /* compute (5 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+193332, dvrr_stack+151824, dvrr_stack+5796, dvrr_stack+94870, dvrr_stack+151374, dvrr_stack+197083);

 /* compute (6 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+39211, dvrr_stack+320006, dvrr_stack+193332, dvrr_stack+95320, dvrr_stack+151824, dvrr_stack+211290);

 /* compute (7 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+40471, dvrr_stack+320951, dvrr_stack+39211, dvrr_stack+229925, dvrr_stack+320006, dvrr_stack+212046);

 /* compute (8 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+148800, dvrr_stack+322211, dvrr_stack+40471, dvrr_stack+230870, dvrr_stack+320951, dvrr_stack+213054);

 /* compute (9 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+211290, dvrr_stack+156712, dvrr_stack+148800, dvrr_stack+232130, dvrr_stack+322211, dvrr_stack+214350);

 /* compute (10 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+320006, dvrr_stack+323831, dvrr_stack+211290, dvrr_stack+233750, dvrr_stack+156712, dvrr_stack+28659);

 /* compute (11 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+229925, dvrr_stack+326306, dvrr_stack+320006, dvrr_stack+100382, dvrr_stack+323831, dvrr_stack+220265);

 /* compute (1 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+220265, dvrr_stack+65243, dvrr_stack+2941, NULL, NULL, dvrr_stack+58439);

 /* compute (2 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+220430, dvrr_stack+158737, dvrr_stack+220265, dvrr_stack+14401, dvrr_stack+65243, dvrr_stack+38356);

 /* compute (3 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+220760, dvrr_stack+28329, dvrr_stack+220430, dvrr_stack+102857, dvrr_stack+158737, dvrr_stack+38491);

 /* compute (4 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+199723, dvrr_stack+158902, dvrr_stack+220760, dvrr_stack+27999, dvrr_stack+28329, dvrr_stack+38761);

 /* compute (5 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+221310, dvrr_stack+159452, dvrr_stack+199723, dvrr_stack+7219, dvrr_stack+158902, dvrr_stack+5796);

 /* compute (6 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+5796, dvrr_stack+160277, dvrr_stack+221310, dvrr_stack+241715, dvrr_stack+159452, dvrr_stack+193332);

 /* compute (7 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+156712, dvrr_stack+336404, dvrr_stack+5796, dvrr_stack+242540, dvrr_stack+160277, dvrr_stack+39211);

 /* compute (8 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+158692, dvrr_stack+337944, dvrr_stack+156712, dvrr_stack+243695, dvrr_stack+336404, dvrr_stack+40471);

 /* compute (9 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+241715, dvrr_stack+166522, dvrr_stack+158692, dvrr_stack+245235, dvrr_stack+337944, dvrr_stack+148800);

 /* compute (10 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+148800, dvrr_stack+339924, dvrr_stack+241715, dvrr_stack+247215, dvrr_stack+166522, dvrr_stack+211290);

 /* compute (11 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+181617, dvrr_stack+342949, dvrr_stack+148800, dvrr_stack+108770, dvrr_stack+339924, dvrr_stack+320006);

 /* compute (1 0 | 10 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+320006, dvrr_stack+27158, dvrr_stack+1326, NULL, NULL, dvrr_stack+2941);

 /* compute (2 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+320204, dvrr_stack+38158, dvrr_stack+320006, dvrr_stack+27563, dvrr_stack+27158, dvrr_stack+220265);

 /* compute (3 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+320600, dvrr_stack+168997, dvrr_stack+320204, dvrr_stack+111795, dvrr_stack+38158, dvrr_stack+220430);

 /* compute (4 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+321260, dvrr_stack+169393, dvrr_stack+320600, dvrr_stack+12907, dvrr_stack+168997, dvrr_stack+220760);

 /* compute (5 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+322250, dvrr_stack+170053, dvrr_stack+321260, dvrr_stack+13303, dvrr_stack+169393, dvrr_stack+199723);

 /* compute (6 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+320006, dvrr_stack+171043, dvrr_stack+322250, dvrr_stack+257115, dvrr_stack+170053, dvrr_stack+221310);

 /* compute (7 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+220265, dvrr_stack+355489, dvrr_stack+320006, dvrr_stack+258105, dvrr_stack+171043, dvrr_stack+5796);

 /* compute (8 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+320006, dvrr_stack+357337, dvrr_stack+220265, dvrr_stack+259491, dvrr_stack+355489, dvrr_stack+156712);

 /* compute (9 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+257115, dvrr_stack+178647, dvrr_stack+320006, dvrr_stack+261339, dvrr_stack+357337, dvrr_stack+158692);

 /* compute (10 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+320006, dvrr_stack+359713, dvrr_stack+257115, dvrr_stack+263715, dvrr_stack+178647, dvrr_stack+241715);

 /* compute (11 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+241715, dvrr_stack+363343, dvrr_stack+320006, dvrr_stack+266685, dvrr_stack+359713, dvrr_stack+148800);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+148800, dvrr_stack+9684, NULL);
 tmp = dvrr_stack + 148800;
 target_ptr = Libderiv->deriv_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+149388, dvrr_stack+16173, NULL);
 tmp = dvrr_stack + 149388;
 target_ptr = Libderiv->deriv_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+150144, dvrr_stack+24216, NULL);
 tmp = dvrr_stack + 150144;
 target_ptr = Libderiv->deriv_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+151089, dvrr_stack+33981, NULL);
 tmp = dvrr_stack + 151089;
 target_ptr = Libderiv->deriv_classes[5][9][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+320006, dvrr_stack+45168, NULL);
 tmp = dvrr_stack + 320006;
 target_ptr = Libderiv->deriv_classes[5][10][11];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,784,dvrr_stack+321392, dvrr_stack+54062, NULL);
 tmp = dvrr_stack + 321392;
 target_ptr = Libderiv->deriv_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+322176, dvrr_stack+59744, NULL);
 tmp = dvrr_stack + 322176;
 target_ptr = Libderiv->deriv_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+323184, dvrr_stack+66838, NULL);
 tmp = dvrr_stack + 323184;
 target_ptr = Libderiv->deriv_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+324444, dvrr_stack+75502, NULL);
 tmp = dvrr_stack + 324444;
 target_ptr = Libderiv->deriv_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+246863, dvrr_stack+85894, NULL);
 tmp = dvrr_stack + 246863;
 target_ptr = Libderiv->deriv_classes[6][10][11];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+178647, dvrr_stack+97358, NULL);
 tmp = dvrr_stack + 178647;
 target_ptr = Libderiv->deriv_classes[7][6][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+179655, dvrr_stack+104882, NULL);
 tmp = dvrr_stack + 179655;
 target_ptr = Libderiv->deriv_classes[7][7][11];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+257115, dvrr_stack+114270, NULL);
 tmp = dvrr_stack + 257115;
 target_ptr = Libderiv->deriv_classes[7][8][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+258735, dvrr_stack+124740, NULL);
 tmp = dvrr_stack + 258735;
 target_ptr = Libderiv->deriv_classes[7][9][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+260715, dvrr_stack+138480, NULL);
 tmp = dvrr_stack + 260715;
 target_ptr = Libderiv->deriv_classes[7][10][11];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+263091, dvrr_stack+152932, NULL);
 tmp = dvrr_stack + 263091;
 target_ptr = Libderiv->deriv_classes[8][6][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+264351, dvrr_stack+161662, NULL);
 tmp = dvrr_stack + 264351;
 target_ptr = Libderiv->deriv_classes[8][7][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2025,dvrr_stack+156712, dvrr_stack+172572, NULL);
 tmp = dvrr_stack + 156712;
 target_ptr = Libderiv->deriv_classes[8][8][11];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+158737, dvrr_stack+185907, NULL);
 tmp = dvrr_stack + 158737;
 target_ptr = Libderiv->deriv_classes[8][9][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+355489, dvrr_stack+202380, NULL);
 tmp = dvrr_stack + 355489;
 target_ptr = Libderiv->deriv_classes[8][10][11];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+358459, dvrr_stack+225305, NULL);
 tmp = dvrr_stack + 358459;
 target_ptr = Libderiv->deriv_classes[9][6][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+359999, dvrr_stack+235775, NULL);
 tmp = dvrr_stack + 359999;
 target_ptr = Libderiv->deriv_classes[9][7][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+220265, dvrr_stack+249690, NULL);
 tmp = dvrr_stack + 220265;
 target_ptr = Libderiv->deriv_classes[9][8][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3025,dvrr_stack+211290, dvrr_stack+270315, NULL);
 tmp = dvrr_stack + 211290;
 target_ptr = Libderiv->deriv_classes[9][9][11];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+214315, dvrr_stack+287892, NULL);
 tmp = dvrr_stack + 214315;
 target_ptr = Libderiv->deriv_classes[9][10][11];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+5796, dvrr_stack+314462, NULL);
 tmp = dvrr_stack + 5796;
 target_ptr = Libderiv->deriv_classes[10][6][11];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+166522, dvrr_stack+329276, NULL);
 tmp = dvrr_stack + 166522;
 target_ptr = Libderiv->deriv_classes[10][7][11];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+168898, dvrr_stack+346579, NULL);
 tmp = dvrr_stack + 168898;
 target_ptr = Libderiv->deriv_classes[10][8][11];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+336404, dvrr_stack+367699, NULL);
 tmp = dvrr_stack + 336404;
 target_ptr = Libderiv->deriv_classes[10][9][11];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,4356,dvrr_stack+300966, dvrr_stack+383737, NULL);
 tmp = dvrr_stack + 300966;
 target_ptr = Libderiv->deriv_classes[10][10][11];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+152244, dvrr_stack+9684, NULL);
 tmp = dvrr_stack + 152244;
 target_ptr = Libderiv->deriv_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+248711, dvrr_stack+16173, NULL);
 tmp = dvrr_stack + 248711;
 target_ptr = Libderiv->deriv_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+361979, dvrr_stack+24216, NULL);
 tmp = dvrr_stack + 361979;
 target_ptr = Libderiv->deriv_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+340034, dvrr_stack+33981, NULL);
 tmp = dvrr_stack + 340034;
 target_ptr = Libderiv->deriv_classes[5][9][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+341189, dvrr_stack+45168, NULL);
 tmp = dvrr_stack + 341189;
 target_ptr = Libderiv->deriv_classes[5][10][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+199723, dvrr_stack+54062, NULL);
 tmp = dvrr_stack + 199723;
 target_ptr = Libderiv->deriv_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+193332, dvrr_stack+59744, NULL);
 tmp = dvrr_stack + 193332;
 target_ptr = Libderiv->deriv_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+233435, dvrr_stack+66838, NULL);
 tmp = dvrr_stack + 233435;
 target_ptr = Libderiv->deriv_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+94246, dvrr_stack+75502, NULL);
 tmp = dvrr_stack + 94246;
 target_ptr = Libderiv->deriv_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+18441, dvrr_stack+85894, NULL);
 tmp = dvrr_stack + 18441;
 target_ptr = Libderiv->deriv_classes[6][10][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+234695, dvrr_stack+97358, NULL);
 tmp = dvrr_stack + 234695;
 target_ptr = Libderiv->deriv_classes[7][6][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+145608, dvrr_stack+104882, NULL);
 tmp = dvrr_stack + 145608;
 target_ptr = Libderiv->deriv_classes[7][7][10];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+20289, dvrr_stack+114270, NULL);
 tmp = dvrr_stack + 20289;
 target_ptr = Libderiv->deriv_classes[7][8][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+305322, dvrr_stack+124740, NULL);
 tmp = dvrr_stack + 305322;
 target_ptr = Libderiv->deriv_classes[7][9][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+307302, dvrr_stack+138480, NULL);
 tmp = dvrr_stack + 307302;
 target_ptr = Libderiv->deriv_classes[7][10][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+309678, dvrr_stack+152932, NULL);
 tmp = dvrr_stack + 309678;
 target_ptr = Libderiv->deriv_classes[8][6][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+37446, dvrr_stack+161662, NULL);
 tmp = dvrr_stack + 37446;
 target_ptr = Libderiv->deriv_classes[8][7][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2025,dvrr_stack+39066, dvrr_stack+172572, NULL);
 tmp = dvrr_stack + 39066;
 target_ptr = Libderiv->deriv_classes[8][8][10];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+0, dvrr_stack+185907, NULL);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv_classes[8][9][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+279390, dvrr_stack+202380, NULL);
 tmp = dvrr_stack + 279390;
 target_ptr = Libderiv->deriv_classes[8][10][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+41091, dvrr_stack+225305, NULL);
 tmp = dvrr_stack + 41091;
 target_ptr = Libderiv->deriv_classes[9][6][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+282360, dvrr_stack+235775, NULL);
 tmp = dvrr_stack + 282360;
 target_ptr = Libderiv->deriv_classes[9][7][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+284340, dvrr_stack+249690, NULL);
 tmp = dvrr_stack + 284340;
 target_ptr = Libderiv->deriv_classes[9][8][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3025,dvrr_stack+119130, dvrr_stack+270315, NULL);
 tmp = dvrr_stack + 119130;
 target_ptr = Libderiv->deriv_classes[9][9][10];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+27051, dvrr_stack+287892, NULL);
 tmp = dvrr_stack + 27051;
 target_ptr = Libderiv->deriv_classes[9][10][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+11448, dvrr_stack+314462, NULL);
 tmp = dvrr_stack + 11448;
 target_ptr = Libderiv->deriv_classes[10][6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+396805, dvrr_stack+329276, NULL);
 tmp = dvrr_stack + 396805;
 target_ptr = Libderiv->deriv_classes[10][7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+399181, dvrr_stack+346579, NULL);
 tmp = dvrr_stack + 399181;
 target_ptr = Libderiv->deriv_classes[10][8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+402151, dvrr_stack+367699, NULL);
 tmp = dvrr_stack + 402151;
 target_ptr = Libderiv->deriv_classes[10][9][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,4356,dvrr_stack+405781, dvrr_stack+383737, NULL);
 tmp = dvrr_stack + 405781;
 target_ptr = Libderiv->deriv_classes[10][10][10];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+180951, dvrr_stack+9684, NULL);
 tmp = dvrr_stack + 180951;
 target_ptr = Libderiv->deriv_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+9684, dvrr_stack+16173, NULL);
 tmp = dvrr_stack + 9684;
 target_ptr = Libderiv->deriv_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+16173, dvrr_stack+24216, NULL);
 tmp = dvrr_stack + 16173;
 target_ptr = Libderiv->deriv_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+24216, dvrr_stack+33981, NULL);
 tmp = dvrr_stack + 24216;
 target_ptr = Libderiv->deriv_classes[5][9][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+33981, dvrr_stack+45168, NULL);
 tmp = dvrr_stack + 33981;
 target_ptr = Libderiv->deriv_classes[5][10][9];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+45168, dvrr_stack+54062, NULL);
 tmp = dvrr_stack + 45168;
 target_ptr = Libderiv->deriv_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+10440, dvrr_stack+59744, NULL);
 tmp = dvrr_stack + 10440;
 target_ptr = Libderiv->deriv_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+59744, dvrr_stack+66838, NULL);
 tmp = dvrr_stack + 59744;
 target_ptr = Libderiv->deriv_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+66838, dvrr_stack+75502, NULL);
 tmp = dvrr_stack + 66838;
 target_ptr = Libderiv->deriv_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+75502, dvrr_stack+85894, NULL);
 tmp = dvrr_stack + 75502;
 target_ptr = Libderiv->deriv_classes[6][10][9];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+85894, dvrr_stack+97358, NULL);
 tmp = dvrr_stack + 85894;
 target_ptr = Libderiv->deriv_classes[7][6][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+97358, dvrr_stack+104882, NULL);
 tmp = dvrr_stack + 97358;
 target_ptr = Libderiv->deriv_classes[7][7][9];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+104882, dvrr_stack+114270, NULL);
 tmp = dvrr_stack + 104882;
 target_ptr = Libderiv->deriv_classes[7][8][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+114270, dvrr_stack+124740, NULL);
 tmp = dvrr_stack + 114270;
 target_ptr = Libderiv->deriv_classes[7][9][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+124740, dvrr_stack+138480, NULL);
 tmp = dvrr_stack + 124740;
 target_ptr = Libderiv->deriv_classes[7][10][9];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+138480, dvrr_stack+152932, NULL);
 tmp = dvrr_stack + 138480;
 target_ptr = Libderiv->deriv_classes[8][6][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+139740, dvrr_stack+161662, NULL);
 tmp = dvrr_stack + 139740;
 target_ptr = Libderiv->deriv_classes[8][7][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+141360, dvrr_stack+172572, NULL);
 tmp = dvrr_stack + 141360;
 target_ptr = Libderiv->deriv_classes[8][8][9];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+127116, dvrr_stack+185907, NULL);
 tmp = dvrr_stack + 127116;
 target_ptr = Libderiv->deriv_classes[8][9][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+185907, dvrr_stack+202380, NULL);
 tmp = dvrr_stack + 185907;
 target_ptr = Libderiv->deriv_classes[8][10][9];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+188877, dvrr_stack+225305, NULL);
 tmp = dvrr_stack + 188877;
 target_ptr = Libderiv->deriv_classes[9][6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+225305, dvrr_stack+235775, NULL);
 tmp = dvrr_stack + 225305;
 target_ptr = Libderiv->deriv_classes[9][7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+227285, dvrr_stack+249690, NULL);
 tmp = dvrr_stack + 227285;
 target_ptr = Libderiv->deriv_classes[9][8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3025,dvrr_stack+86902, dvrr_stack+270315, NULL);
 tmp = dvrr_stack + 86902;
 target_ptr = Libderiv->deriv_classes[9][9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+270315, dvrr_stack+287892, NULL);
 tmp = dvrr_stack + 270315;
 target_ptr = Libderiv->deriv_classes[9][10][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+273945, dvrr_stack+314462, NULL);
 tmp = dvrr_stack + 273945;
 target_ptr = Libderiv->deriv_classes[10][6][9];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+314462, dvrr_stack+329276, NULL);
 tmp = dvrr_stack + 314462;
 target_ptr = Libderiv->deriv_classes[10][7][9];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+329276, dvrr_stack+346579, NULL);
 tmp = dvrr_stack + 329276;
 target_ptr = Libderiv->deriv_classes[10][8][9];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+346579, dvrr_stack+367699, NULL);
 tmp = dvrr_stack + 346579;
 target_ptr = Libderiv->deriv_classes[10][9][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,4356,dvrr_stack+367699, dvrr_stack+383737, NULL);
 tmp = dvrr_stack + 367699;
 target_ptr = Libderiv->deriv_classes[10][10][9];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+383737, dvrr_stack+8928, dvrr_stack+194563);
 tmp = dvrr_stack + 383737;
 target_ptr = Libderiv->deriv_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+384325, dvrr_stack+15228, dvrr_stack+5208);
 tmp = dvrr_stack + 384325;
 target_ptr = Libderiv->deriv_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+385081, dvrr_stack+23061, dvrr_stack+8928);
 tmp = dvrr_stack + 385081;
 target_ptr = Libderiv->deriv_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+386026, dvrr_stack+32595, dvrr_stack+15228);
 tmp = dvrr_stack + 386026;
 target_ptr = Libderiv->deriv_classes[5][9][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+387181, dvrr_stack+43530, dvrr_stack+23061);
 tmp = dvrr_stack + 387181;
 target_ptr = Libderiv->deriv_classes[5][10][8];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+388567, dvrr_stack+53054, dvrr_stack+195319);
 tmp = dvrr_stack + 388567;
 target_ptr = Libderiv->deriv_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+389351, dvrr_stack+58484, dvrr_stack+50614);
 tmp = dvrr_stack + 389351;
 target_ptr = Libderiv->deriv_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+390359, dvrr_stack+65298, dvrr_stack+53054);
 tmp = dvrr_stack + 390359;
 target_ptr = Libderiv->deriv_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+391619, dvrr_stack+73654, dvrr_stack+58484);
 tmp = dvrr_stack + 391619;
 target_ptr = Libderiv->deriv_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+393159, dvrr_stack+83710, dvrr_stack+65298);
 tmp = dvrr_stack + 393159;
 target_ptr = Libderiv->deriv_classes[6][10][8];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+395007, dvrr_stack+96062, dvrr_stack+196327);
 tmp = dvrr_stack + 395007;
 target_ptr = Libderiv->deriv_classes[7][6][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+372055, dvrr_stack+103262, dvrr_stack+3654);
 tmp = dvrr_stack + 372055;
 target_ptr = Libderiv->deriv_classes[7][7][8];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+373351, dvrr_stack+112290, dvrr_stack+96062);
 tmp = dvrr_stack + 373351;
 target_ptr = Libderiv->deriv_classes[7][8][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+374971, dvrr_stack+122364, dvrr_stack+103262);
 tmp = dvrr_stack + 374971;
 target_ptr = Libderiv->deriv_classes[7][9][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+350209, dvrr_stack+135672, dvrr_stack+112290);
 tmp = dvrr_stack + 350209;
 target_ptr = Libderiv->deriv_classes[7][10][8];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+376951, dvrr_stack+51398, dvrr_stack+197623);
 tmp = dvrr_stack + 376951;
 target_ptr = Libderiv->deriv_classes[8][6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+352585, dvrr_stack+56414, dvrr_stack+49326);
 tmp = dvrr_stack + 352585;
 target_ptr = Libderiv->deriv_classes[8][7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+332246, dvrr_stack+62768, dvrr_stack+51398);
 tmp = dvrr_stack + 332246;
 target_ptr = Libderiv->deriv_classes[8][8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+316838, dvrr_stack+70618, dvrr_stack+56414);
 tmp = dvrr_stack + 316838;
 target_ptr = Libderiv->deriv_classes[8][9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,45,1,dvrr_stack+275793, dvrr_stack+80122, dvrr_stack+62768);
 tmp = dvrr_stack + 275793;
 target_ptr = Libderiv->deriv_classes[8][10][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+334271, dvrr_stack+223325, dvrr_stack+198568);
 tmp = dvrr_stack + 334271;
 target_ptr = Libderiv->deriv_classes[9][6][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+190417, dvrr_stack+100382, dvrr_stack+218725);
 tmp = dvrr_stack + 190417;
 target_ptr = Libderiv->deriv_classes[9][7][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+116250, dvrr_stack+108770, dvrr_stack+223325);
 tmp = dvrr_stack + 116250;
 target_ptr = Libderiv->deriv_classes[9][8][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+45952, dvrr_stack+266685, dvrr_stack+100382);
 tmp = dvrr_stack + 45952;
 target_ptr = Libderiv->deriv_classes[9][9][8];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,55,1,dvrr_stack+152832, dvrr_stack+130680, dvrr_stack+108770);
 tmp = dvrr_stack + 152832;
 target_ptr = Libderiv->deriv_classes[9][10][8];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,66,1,dvrr_stack+143385, dvrr_stack+312086, dvrr_stack+200548);
 tmp = dvrr_stack + 143385;
 target_ptr = Libderiv->deriv_classes[10][6][8];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,66,1,dvrr_stack+77350, dvrr_stack+326306, dvrr_stack+146952);
 tmp = dvrr_stack + 77350;
 target_ptr = Libderiv->deriv_classes[10][7][8];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,66,1,dvrr_stack+249467, dvrr_stack+342949, dvrr_stack+312086);
 tmp = dvrr_stack + 249467;
 target_ptr = Libderiv->deriv_classes[10][8][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,66,1,dvrr_stack+252437, dvrr_stack+363343, dvrr_stack+326306);
 tmp = dvrr_stack + 252437;
 target_ptr = Libderiv->deriv_classes[10][9][8];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,66,1,dvrr_stack+161212, dvrr_stack+378589, dvrr_stack+342949);
 tmp = dvrr_stack + 161212;
 target_ptr = Libderiv->deriv_classes[10][10][8];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+396015, dvrr_stack+8928, dvrr_stack+194563);
 tmp = dvrr_stack + 396015;
 target_ptr = Libderiv->deriv_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+354205, dvrr_stack+15228, dvrr_stack+5208);
 tmp = dvrr_stack + 354205;
 target_ptr = Libderiv->deriv_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+129591, dvrr_stack+23061, dvrr_stack+8928);
 tmp = dvrr_stack + 129591;
 target_ptr = Libderiv->deriv_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+106502, dvrr_stack+32595, dvrr_stack+15228);
 tmp = dvrr_stack + 106502;
 target_ptr = Libderiv->deriv_classes[5][9][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+98654, dvrr_stack+43530, dvrr_stack+23061);
 tmp = dvrr_stack + 98654;
 target_ptr = Libderiv->deriv_classes[5][10][7];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+192397, dvrr_stack+53054, dvrr_stack+195319);
 tmp = dvrr_stack + 192397;
 target_ptr = Libderiv->deriv_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+107657, dvrr_stack+58484, dvrr_stack+50614);
 tmp = dvrr_stack + 107657;
 target_ptr = Libderiv->deriv_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+89927, dvrr_stack+65298, dvrr_stack+53054);
 tmp = dvrr_stack + 89927;
 target_ptr = Libderiv->deriv_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+68378, dvrr_stack+73654, dvrr_stack+58484);
 tmp = dvrr_stack + 68378;
 target_ptr = Libderiv->deriv_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+54062, dvrr_stack+83710, dvrr_stack+65298);
 tmp = dvrr_stack + 54062;
 target_ptr = Libderiv->deriv_classes[6][10][7];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+61004, dvrr_stack+96062, dvrr_stack+196327);
 tmp = dvrr_stack + 61004;
 target_ptr = Libderiv->deriv_classes[7][6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+35367, dvrr_stack+103262, dvrr_stack+3654);
 tmp = dvrr_stack + 35367;
 target_ptr = Libderiv->deriv_classes[7][7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+25371, dvrr_stack+112290, dvrr_stack+96062);
 tmp = dvrr_stack + 25371;
 target_ptr = Libderiv->deriv_classes[7][8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+171868, dvrr_stack+122364, dvrr_stack+103262);
 tmp = dvrr_stack + 171868;
 target_ptr = Libderiv->deriv_classes[7][9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+173848, dvrr_stack+135672, dvrr_stack+112290);
 tmp = dvrr_stack + 173848;
 target_ptr = Libderiv->deriv_classes[7][10][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+17118, dvrr_stack+51398, dvrr_stack+197623);
 tmp = dvrr_stack + 17118;
 target_ptr = Libderiv->deriv_classes[8][6][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+176224, dvrr_stack+56414, dvrr_stack+49326);
 tmp = dvrr_stack + 176224;
 target_ptr = Libderiv->deriv_classes[8][7][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+235703, dvrr_stack+62768, dvrr_stack+51398);
 tmp = dvrr_stack + 235703;
 target_ptr = Libderiv->deriv_classes[8][8][7];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+237728, dvrr_stack+70618, dvrr_stack+56414);
 tmp = dvrr_stack + 237728;
 target_ptr = Libderiv->deriv_classes[8][9][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+201934, dvrr_stack+80122, dvrr_stack+62768);
 tmp = dvrr_stack + 201934;
 target_ptr = Libderiv->deriv_classes[8][10][7];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+204904, dvrr_stack+223325, dvrr_stack+198568);
 tmp = dvrr_stack + 204904;
 target_ptr = Libderiv->deriv_classes[9][6][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+206444, dvrr_stack+100382, dvrr_stack+218725);
 tmp = dvrr_stack + 206444;
 target_ptr = Libderiv->deriv_classes[9][7][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+208424, dvrr_stack+108770, dvrr_stack+223325);
 tmp = dvrr_stack + 208424;
 target_ptr = Libderiv->deriv_classes[9][8][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+286815, dvrr_stack+266685, dvrr_stack+100382);
 tmp = dvrr_stack + 286815;
 target_ptr = Libderiv->deriv_classes[9][9][7];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+289840, dvrr_stack+130680, dvrr_stack+108770);
 tmp = dvrr_stack + 289840;
 target_ptr = Libderiv->deriv_classes[9][10][7];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,66,1,dvrr_stack+293470, dvrr_stack+312086, dvrr_stack+200548);
 tmp = dvrr_stack + 293470;
 target_ptr = Libderiv->deriv_classes[10][6][7];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,66,1,dvrr_stack+295318, dvrr_stack+326306, dvrr_stack+146952);
 tmp = dvrr_stack + 295318;
 target_ptr = Libderiv->deriv_classes[10][7][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,66,1,dvrr_stack+410137, dvrr_stack+342949, dvrr_stack+312086);
 tmp = dvrr_stack + 410137;
 target_ptr = Libderiv->deriv_classes[10][8][7];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,66,1,dvrr_stack+413107, dvrr_stack+363343, dvrr_stack+326306);
 tmp = dvrr_stack + 413107;
 target_ptr = Libderiv->deriv_classes[10][9][7];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,66,1,dvrr_stack+416737, dvrr_stack+378589, dvrr_stack+342949);
 tmp = dvrr_stack + 416737;
 target_ptr = Libderiv->deriv_classes[10][10][7];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+335811, dvrr_stack+8928, dvrr_stack+194563);
 tmp = dvrr_stack + 335811;
 target_ptr = Libderiv->deriv_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+62012, dvrr_stack+15228, dvrr_stack+5208);
 tmp = dvrr_stack + 62012;
 target_ptr = Libderiv->deriv_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+256067, dvrr_stack+23061, dvrr_stack+8928);
 tmp = dvrr_stack + 256067;
 target_ptr = Libderiv->deriv_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+240203, dvrr_stack+32595, dvrr_stack+15228);
 tmp = dvrr_stack + 240203;
 target_ptr = Libderiv->deriv_classes[5][9][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+421093, dvrr_stack+43530, dvrr_stack+23061);
 tmp = dvrr_stack + 421093;
 target_ptr = Libderiv->deriv_classes[5][10][6];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+165568, dvrr_stack+53054, dvrr_stack+195319);
 tmp = dvrr_stack + 165568;
 target_ptr = Libderiv->deriv_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+194340, dvrr_stack+58484, dvrr_stack+50614);
 tmp = dvrr_stack + 194340;
 target_ptr = Libderiv->deriv_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+42631, dvrr_stack+65298, dvrr_stack+53054);
 tmp = dvrr_stack + 42631;
 target_ptr = Libderiv->deriv_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+422479, dvrr_stack+73654, dvrr_stack+58484);
 tmp = dvrr_stack + 422479;
 target_ptr = Libderiv->deriv_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+424019, dvrr_stack+83710, dvrr_stack+65298);
 tmp = dvrr_stack + 424019;
 target_ptr = Libderiv->deriv_classes[6][10][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+310938, dvrr_stack+96062, dvrr_stack+196327);
 tmp = dvrr_stack + 310938;
 target_ptr = Libderiv->deriv_classes[7][6][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+195348, dvrr_stack+103262, dvrr_stack+3654);
 tmp = dvrr_stack + 195348;
 target_ptr = Libderiv->deriv_classes[7][7][6];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+83632, dvrr_stack+112290, dvrr_stack+96062);
 tmp = dvrr_stack + 83632;
 target_ptr = Libderiv->deriv_classes[7][8][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+425867, dvrr_stack+122364, dvrr_stack+103262);
 tmp = dvrr_stack + 425867;
 target_ptr = Libderiv->deriv_classes[7][9][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+427847, dvrr_stack+135672, dvrr_stack+112290);
 tmp = dvrr_stack + 427847;
 target_ptr = Libderiv->deriv_classes[7][10][6];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+134970, dvrr_stack+51398, dvrr_stack+197623);
 tmp = dvrr_stack + 134970;
 target_ptr = Libderiv->deriv_classes[8][6][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+196644, dvrr_stack+56414, dvrr_stack+49326);
 tmp = dvrr_stack + 196644;
 target_ptr = Libderiv->deriv_classes[8][7][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+136230, dvrr_stack+62768, dvrr_stack+51398);
 tmp = dvrr_stack + 136230;
 target_ptr = Libderiv->deriv_classes[8][8][6];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+430223, dvrr_stack+70618, dvrr_stack+56414);
 tmp = dvrr_stack + 430223;
 target_ptr = Libderiv->deriv_classes[8][9][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+432698, dvrr_stack+80122, dvrr_stack+62768);
 tmp = dvrr_stack + 432698;
 target_ptr = Libderiv->deriv_classes[8][10][6];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+79726, dvrr_stack+223325, dvrr_stack+198568);
 tmp = dvrr_stack + 79726;
 target_ptr = Libderiv->deriv_classes[9][6][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+81266, dvrr_stack+100382, dvrr_stack+218725);
 tmp = dvrr_stack + 81266;
 target_ptr = Libderiv->deriv_classes[9][7][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+435668, dvrr_stack+108770, dvrr_stack+223325);
 tmp = dvrr_stack + 435668;
 target_ptr = Libderiv->deriv_classes[9][8][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+438143, dvrr_stack+266685, dvrr_stack+100382);
 tmp = dvrr_stack + 438143;
 target_ptr = Libderiv->deriv_classes[9][9][6];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+441168, dvrr_stack+130680, dvrr_stack+108770);
 tmp = dvrr_stack + 441168;
 target_ptr = Libderiv->deriv_classes[9][10][6];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,66,1,dvrr_stack+130536, dvrr_stack+312086, dvrr_stack+200548);
 tmp = dvrr_stack + 130536;
 target_ptr = Libderiv->deriv_classes[10][6][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,66,1,dvrr_stack+132384, dvrr_stack+326306, dvrr_stack+146952);
 tmp = dvrr_stack + 132384;
 target_ptr = Libderiv->deriv_classes[10][7][6];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,66,1,dvrr_stack+444798, dvrr_stack+342949, dvrr_stack+312086);
 tmp = dvrr_stack + 444798;
 target_ptr = Libderiv->deriv_classes[10][8][6];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,66,1,dvrr_stack+447768, dvrr_stack+363343, dvrr_stack+326306);
 tmp = dvrr_stack + 447768;
 target_ptr = Libderiv->deriv_classes[10][9][6];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,66,1,dvrr_stack+451398, dvrr_stack+378589, dvrr_stack+342949);
 tmp = dvrr_stack + 451398;
 target_ptr = Libderiv->deriv_classes[10][10][6];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+378211, dvrr_stack+50614, dvrr_stack+4788);
 tmp = dvrr_stack + 378211;
 target_ptr = Libderiv->deriv_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+378799, dvrr_stack+53054, dvrr_stack+8388);
 tmp = dvrr_stack + 378799;
 target_ptr = Libderiv->deriv_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+379555, dvrr_stack+58484, dvrr_stack+14553);
 tmp = dvrr_stack + 379555;
 target_ptr = Libderiv->deriv_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+380500, dvrr_stack+65298, dvrr_stack+22236);
 tmp = dvrr_stack + 380500;
 target_ptr = Libderiv->deriv_classes[5][9][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+381655, dvrr_stack+73654, dvrr_stack+31605);
 tmp = dvrr_stack + 381655;
 target_ptr = Libderiv->deriv_classes[5][10][2];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+200507, dvrr_stack+3654, dvrr_stack+5208);
 tmp = dvrr_stack + 200507;
 target_ptr = Libderiv->deriv_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+198264, dvrr_stack+96062, dvrr_stack+8928);
 tmp = dvrr_stack + 198264;
 target_ptr = Libderiv->deriv_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+43891, dvrr_stack+103262, dvrr_stack+15228);
 tmp = dvrr_stack + 43891;
 target_ptr = Libderiv->deriv_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+455754, dvrr_stack+112290, dvrr_stack+23061);
 tmp = dvrr_stack + 455754;
 target_ptr = Libderiv->deriv_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+457294, dvrr_stack+122364, dvrr_stack+32595);
 tmp = dvrr_stack + 457294;
 target_ptr = Libderiv->deriv_classes[6][10][2];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+2475, dvrr_stack+49326, dvrr_stack+50614);
 tmp = dvrr_stack + 2475;
 target_ptr = Libderiv->deriv_classes[7][6][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+459142, dvrr_stack+51398, dvrr_stack+53054);
 tmp = dvrr_stack + 459142;
 target_ptr = Libderiv->deriv_classes[7][7][2];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+460438, dvrr_stack+56414, dvrr_stack+58484);
 tmp = dvrr_stack + 460438;
 target_ptr = Libderiv->deriv_classes[7][8][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+462058, dvrr_stack+62768, dvrr_stack+65298);
 tmp = dvrr_stack + 462058;
 target_ptr = Libderiv->deriv_classes[7][9][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+464038, dvrr_stack+70618, dvrr_stack+73654);
 tmp = dvrr_stack + 464038;
 target_ptr = Libderiv->deriv_classes[7][10][2];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+466414, dvrr_stack+218725, dvrr_stack+3654);
 tmp = dvrr_stack + 466414;
 target_ptr = Libderiv->deriv_classes[8][6][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+467674, dvrr_stack+223325, dvrr_stack+96062);
 tmp = dvrr_stack + 467674;
 target_ptr = Libderiv->deriv_classes[8][7][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+469294, dvrr_stack+100382, dvrr_stack+103262);
 tmp = dvrr_stack + 469294;
 target_ptr = Libderiv->deriv_classes[8][8][2];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+471319, dvrr_stack+108770, dvrr_stack+112290);
 tmp = dvrr_stack + 471319;
 target_ptr = Libderiv->deriv_classes[8][9][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+473794, dvrr_stack+266685, dvrr_stack+122364);
 tmp = dvrr_stack + 473794;
 target_ptr = Libderiv->deriv_classes[8][10][2];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+476764, dvrr_stack+146952, dvrr_stack+49326);
 tmp = dvrr_stack + 476764;
 target_ptr = Libderiv->deriv_classes[9][6][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+478304, dvrr_stack+312086, dvrr_stack+51398);
 tmp = dvrr_stack + 478304;
 target_ptr = Libderiv->deriv_classes[9][7][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+480284, dvrr_stack+326306, dvrr_stack+56414);
 tmp = dvrr_stack + 480284;
 target_ptr = Libderiv->deriv_classes[9][8][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+482759, dvrr_stack+342949, dvrr_stack+62768);
 tmp = dvrr_stack + 482759;
 target_ptr = Libderiv->deriv_classes[9][9][2];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+485784, dvrr_stack+363343, dvrr_stack+70618);
 tmp = dvrr_stack + 485784;
 target_ptr = Libderiv->deriv_classes[9][10][2];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,28,dvrr_stack+489414, dvrr_stack+298782, dvrr_stack+218725);
 tmp = dvrr_stack + 489414;
 target_ptr = Libderiv->deriv_classes[10][6][2];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,36,dvrr_stack+491262, dvrr_stack+91438, dvrr_stack+223325);
 tmp = dvrr_stack + 491262;
 target_ptr = Libderiv->deriv_classes[10][7][2];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,45,dvrr_stack+493638, dvrr_stack+229925, dvrr_stack+100382);
 tmp = dvrr_stack + 493638;
 target_ptr = Libderiv->deriv_classes[10][8][2];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,55,dvrr_stack+496608, dvrr_stack+181617, dvrr_stack+108770);
 tmp = dvrr_stack + 496608;
 target_ptr = Libderiv->deriv_classes[10][9][2];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,66,dvrr_stack+500238, dvrr_stack+241715, dvrr_stack+266685);
 tmp = dvrr_stack + 500238;
 target_ptr = Libderiv->deriv_classes[10][10][2];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+383041, dvrr_stack+50614, dvrr_stack+4788);
 tmp = dvrr_stack + 383041;
 target_ptr = Libderiv->deriv_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+36663, dvrr_stack+53054, dvrr_stack+8388);
 tmp = dvrr_stack + 36663;
 target_ptr = Libderiv->deriv_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+297694, dvrr_stack+58484, dvrr_stack+14553);
 tmp = dvrr_stack + 297694;
 target_ptr = Libderiv->deriv_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+13296, dvrr_stack+65298, dvrr_stack+22236);
 tmp = dvrr_stack + 13296;
 target_ptr = Libderiv->deriv_classes[5][9][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+504594, dvrr_stack+73654, dvrr_stack+31605);
 tmp = dvrr_stack + 504594;
 target_ptr = Libderiv->deriv_classes[5][10][1];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+177844, dvrr_stack+3654, dvrr_stack+5208);
 tmp = dvrr_stack + 177844;
 target_ptr = Libderiv->deriv_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+505980, dvrr_stack+96062, dvrr_stack+8928);
 tmp = dvrr_stack + 505980;
 target_ptr = Libderiv->deriv_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+506988, dvrr_stack+103262, dvrr_stack+15228);
 tmp = dvrr_stack + 506988;
 target_ptr = Libderiv->deriv_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+508248, dvrr_stack+112290, dvrr_stack+23061);
 tmp = dvrr_stack + 508248;
 target_ptr = Libderiv->deriv_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+509788, dvrr_stack+122364, dvrr_stack+32595);
 tmp = dvrr_stack + 509788;
 target_ptr = Libderiv->deriv_classes[6][10][1];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+511636, dvrr_stack+49326, dvrr_stack+50614);
 tmp = dvrr_stack + 511636;
 target_ptr = Libderiv->deriv_classes[7][6][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+512644, dvrr_stack+51398, dvrr_stack+53054);
 tmp = dvrr_stack + 512644;
 target_ptr = Libderiv->deriv_classes[7][7][1];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+513940, dvrr_stack+56414, dvrr_stack+58484);
 tmp = dvrr_stack + 513940;
 target_ptr = Libderiv->deriv_classes[7][8][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+515560, dvrr_stack+62768, dvrr_stack+65298);
 tmp = dvrr_stack + 515560;
 target_ptr = Libderiv->deriv_classes[7][9][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+517540, dvrr_stack+70618, dvrr_stack+73654);
 tmp = dvrr_stack + 517540;
 target_ptr = Libderiv->deriv_classes[7][10][1];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+519916, dvrr_stack+218725, dvrr_stack+3654);
 tmp = dvrr_stack + 519916;
 target_ptr = Libderiv->deriv_classes[8][6][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+521176, dvrr_stack+223325, dvrr_stack+96062);
 tmp = dvrr_stack + 521176;
 target_ptr = Libderiv->deriv_classes[8][7][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+522796, dvrr_stack+100382, dvrr_stack+103262);
 tmp = dvrr_stack + 522796;
 target_ptr = Libderiv->deriv_classes[8][8][1];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+524821, dvrr_stack+108770, dvrr_stack+112290);
 tmp = dvrr_stack + 524821;
 target_ptr = Libderiv->deriv_classes[8][9][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+527296, dvrr_stack+266685, dvrr_stack+122364);
 tmp = dvrr_stack + 527296;
 target_ptr = Libderiv->deriv_classes[8][10][1];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+530266, dvrr_stack+146952, dvrr_stack+49326);
 tmp = dvrr_stack + 530266;
 target_ptr = Libderiv->deriv_classes[9][6][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+531806, dvrr_stack+312086, dvrr_stack+51398);
 tmp = dvrr_stack + 531806;
 target_ptr = Libderiv->deriv_classes[9][7][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+533786, dvrr_stack+326306, dvrr_stack+56414);
 tmp = dvrr_stack + 533786;
 target_ptr = Libderiv->deriv_classes[9][8][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+536261, dvrr_stack+342949, dvrr_stack+62768);
 tmp = dvrr_stack + 536261;
 target_ptr = Libderiv->deriv_classes[9][9][1];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+539286, dvrr_stack+363343, dvrr_stack+70618);
 tmp = dvrr_stack + 539286;
 target_ptr = Libderiv->deriv_classes[9][10][1];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,28,dvrr_stack+542916, dvrr_stack+298782, dvrr_stack+218725);
 tmp = dvrr_stack + 542916;
 target_ptr = Libderiv->deriv_classes[10][6][1];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,36,dvrr_stack+544764, dvrr_stack+91438, dvrr_stack+223325);
 tmp = dvrr_stack + 544764;
 target_ptr = Libderiv->deriv_classes[10][7][1];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,45,dvrr_stack+547140, dvrr_stack+229925, dvrr_stack+100382);
 tmp = dvrr_stack + 547140;
 target_ptr = Libderiv->deriv_classes[10][8][1];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,55,dvrr_stack+550110, dvrr_stack+181617, dvrr_stack+108770);
 tmp = dvrr_stack + 550110;
 target_ptr = Libderiv->deriv_classes[10][9][1];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,66,dvrr_stack+553740, dvrr_stack+241715, dvrr_stack+266685);
 tmp = dvrr_stack + 553740;
 target_ptr = Libderiv->deriv_classes[10][10][1];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+319313, dvrr_stack+50614, dvrr_stack+4788);
 tmp = dvrr_stack + 319313;
 target_ptr = Libderiv->deriv_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+217945, dvrr_stack+53054, dvrr_stack+8388);
 tmp = dvrr_stack + 217945;
 target_ptr = Libderiv->deriv_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+7644, dvrr_stack+58484, dvrr_stack+14553);
 tmp = dvrr_stack + 7644;
 target_ptr = Libderiv->deriv_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+558096, dvrr_stack+65298, dvrr_stack+22236);
 tmp = dvrr_stack + 558096;
 target_ptr = Libderiv->deriv_classes[5][9][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+559251, dvrr_stack+73654, dvrr_stack+31605);
 tmp = dvrr_stack + 559251;
 target_ptr = Libderiv->deriv_classes[5][10][0];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+21909, dvrr_stack+3654, dvrr_stack+5208);
 tmp = dvrr_stack + 21909;
 target_ptr = Libderiv->deriv_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+4662, dvrr_stack+96062, dvrr_stack+8928);
 tmp = dvrr_stack + 4662;
 target_ptr = Libderiv->deriv_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+30681, dvrr_stack+103262, dvrr_stack+15228);
 tmp = dvrr_stack + 30681;
 target_ptr = Libderiv->deriv_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+14451, dvrr_stack+112290, dvrr_stack+23061);
 tmp = dvrr_stack + 14451;
 target_ptr = Libderiv->deriv_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+560637, dvrr_stack+122364, dvrr_stack+32595);
 tmp = dvrr_stack + 560637;
 target_ptr = Libderiv->deriv_classes[6][10][0];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+8589, dvrr_stack+49326, dvrr_stack+50614);
 tmp = dvrr_stack + 8589;
 target_ptr = Libderiv->deriv_classes[7][6][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+22693, dvrr_stack+51398, dvrr_stack+53054);
 tmp = dvrr_stack + 22693;
 target_ptr = Libderiv->deriv_classes[7][7][0];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+31941, dvrr_stack+56414, dvrr_stack+58484);
 tmp = dvrr_stack + 31941;
 target_ptr = Libderiv->deriv_classes[7][8][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+562485, dvrr_stack+62768, dvrr_stack+65298);
 tmp = dvrr_stack + 562485;
 target_ptr = Libderiv->deriv_classes[7][9][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+564465, dvrr_stack+70618, dvrr_stack+73654);
 tmp = dvrr_stack + 564465;
 target_ptr = Libderiv->deriv_classes[7][10][0];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+65243, dvrr_stack+218725, dvrr_stack+3654);
 tmp = dvrr_stack + 65243;
 target_ptr = Libderiv->deriv_classes[8][6][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+73588, dvrr_stack+223325, dvrr_stack+96062);
 tmp = dvrr_stack + 73588;
 target_ptr = Libderiv->deriv_classes[8][7][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+566841, dvrr_stack+100382, dvrr_stack+103262);
 tmp = dvrr_stack + 566841;
 target_ptr = Libderiv->deriv_classes[8][8][0];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+568866, dvrr_stack+108770, dvrr_stack+112290);
 tmp = dvrr_stack + 568866;
 target_ptr = Libderiv->deriv_classes[8][9][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+571341, dvrr_stack+266685, dvrr_stack+122364);
 tmp = dvrr_stack + 571341;
 target_ptr = Libderiv->deriv_classes[8][10][0];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+111795, dvrr_stack+146952, dvrr_stack+49326);
 tmp = dvrr_stack + 111795;
 target_ptr = Libderiv->deriv_classes[9][6][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+48977, dvrr_stack+312086, dvrr_stack+51398);
 tmp = dvrr_stack + 48977;
 target_ptr = Libderiv->deriv_classes[9][7][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+50957, dvrr_stack+326306, dvrr_stack+56414);
 tmp = dvrr_stack + 50957;
 target_ptr = Libderiv->deriv_classes[9][8][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+55910, dvrr_stack+342949, dvrr_stack+62768);
 tmp = dvrr_stack + 55910;
 target_ptr = Libderiv->deriv_classes[9][9][0];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+342575, dvrr_stack+363343, dvrr_stack+70618);
 tmp = dvrr_stack + 342575;
 target_ptr = Libderiv->deriv_classes[9][10][0];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,28,dvrr_stack+62768, dvrr_stack+298782, dvrr_stack+218725);
 tmp = dvrr_stack + 62768;
 target_ptr = Libderiv->deriv_classes[10][6][0];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,36,dvrr_stack+69918, dvrr_stack+91438, dvrr_stack+223325);
 tmp = dvrr_stack + 69918;
 target_ptr = Libderiv->deriv_classes[10][7][0];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,45,dvrr_stack+91187, dvrr_stack+229925, dvrr_stack+100382);
 tmp = dvrr_stack + 91187;
 target_ptr = Libderiv->deriv_classes[10][8][0];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,55,dvrr_stack+229760, dvrr_stack+181617, dvrr_stack+108770);
 tmp = dvrr_stack + 229760;
 target_ptr = Libderiv->deriv_classes[10][9][0];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,66,dvrr_stack+100040, dvrr_stack+241715, dvrr_stack+266685);
 tmp = dvrr_stack + 100040;
 target_ptr = Libderiv->deriv_classes[10][10][0];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];


}

