/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (ig|ig) integrals */

void d1vrr_order_igig(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+6, dvrr_stack+3, dvrr_stack+0, NULL, NULL, Data->F+6);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+21, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+24, dvrr_stack+21, dvrr_stack+3, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+30, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+33, dvrr_stack+0, dvrr_stack+30, Data->F+6, Data->F+7, NULL);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+39, dvrr_stack+15, dvrr_stack+33, NULL, NULL, dvrr_stack+0);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+57, dvrr_stack+24, dvrr_stack+15, NULL, NULL, dvrr_stack+3);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+75, dvrr_stack+57, dvrr_stack+39, dvrr_stack+24, dvrr_stack+15, dvrr_stack+6);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+111, dvrr_stack+15, dvrr_stack+33, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+121, dvrr_stack+24, dvrr_stack+15, dvrr_stack+21, dvrr_stack+3, NULL);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+131, dvrr_stack+121, dvrr_stack+111, NULL, NULL, dvrr_stack+15);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+161, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+164, dvrr_stack+161, dvrr_stack+21, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+170, dvrr_stack+164, dvrr_stack+24, dvrr_stack+161, dvrr_stack+21, NULL);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+180, dvrr_stack+170, dvrr_stack+121, NULL, NULL, dvrr_stack+24);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+210, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+213, dvrr_stack+30, dvrr_stack+210, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+219, dvrr_stack+33, dvrr_stack+213, dvrr_stack+0, dvrr_stack+30, NULL);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+229, dvrr_stack+111, dvrr_stack+219, NULL, NULL, dvrr_stack+33);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+259, dvrr_stack+131, dvrr_stack+229, dvrr_stack+121, dvrr_stack+111, dvrr_stack+39);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+319, dvrr_stack+180, dvrr_stack+131, dvrr_stack+170, dvrr_stack+121, dvrr_stack+57);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+379, dvrr_stack+319, dvrr_stack+259, dvrr_stack+180, dvrr_stack+131, dvrr_stack+75);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+479, dvrr_stack+121, dvrr_stack+111, dvrr_stack+24, dvrr_stack+15, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+494, dvrr_stack+170, dvrr_stack+121, dvrr_stack+164, dvrr_stack+24, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+509, dvrr_stack+111, dvrr_stack+219, dvrr_stack+15, dvrr_stack+33, NULL);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+524, dvrr_stack+479, dvrr_stack+509, NULL, NULL, dvrr_stack+111);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+569, dvrr_stack+494, dvrr_stack+479, NULL, NULL, dvrr_stack+121);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+614, dvrr_stack+569, dvrr_stack+524, dvrr_stack+494, dvrr_stack+479, dvrr_stack+131);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+704, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+707, dvrr_stack+704, dvrr_stack+161, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+713, dvrr_stack+707, dvrr_stack+164, dvrr_stack+704, dvrr_stack+161, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+723, dvrr_stack+713, dvrr_stack+170, dvrr_stack+707, dvrr_stack+164, NULL);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+738, dvrr_stack+723, dvrr_stack+494, NULL, NULL, dvrr_stack+170);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+783, dvrr_stack+738, dvrr_stack+569, dvrr_stack+723, dvrr_stack+494, dvrr_stack+180);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+161, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+873, dvrr_stack+210, dvrr_stack+161, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+879, dvrr_stack+213, dvrr_stack+873, dvrr_stack+30, dvrr_stack+210, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+889, dvrr_stack+219, dvrr_stack+879, dvrr_stack+33, dvrr_stack+213, NULL);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+904, dvrr_stack+509, dvrr_stack+889, NULL, NULL, dvrr_stack+219);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+949, dvrr_stack+524, dvrr_stack+904, dvrr_stack+479, dvrr_stack+509, dvrr_stack+229);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+1039, dvrr_stack+614, dvrr_stack+949, dvrr_stack+569, dvrr_stack+524, dvrr_stack+259);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+1189, dvrr_stack+783, dvrr_stack+614, dvrr_stack+738, dvrr_stack+569, dvrr_stack+319);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+1339, dvrr_stack+1189, dvrr_stack+1039, dvrr_stack+783, dvrr_stack+614, dvrr_stack+379);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1564, dvrr_stack+479, dvrr_stack+509, dvrr_stack+121, dvrr_stack+111, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1585, dvrr_stack+494, dvrr_stack+479, dvrr_stack+170, dvrr_stack+121, NULL);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1606, dvrr_stack+1585, dvrr_stack+1564, NULL, NULL, dvrr_stack+479);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1669, dvrr_stack+723, dvrr_stack+494, dvrr_stack+713, dvrr_stack+170, NULL);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1690, dvrr_stack+1669, dvrr_stack+1585, NULL, NULL, dvrr_stack+494);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1753, dvrr_stack+509, dvrr_stack+889, dvrr_stack+111, dvrr_stack+219, NULL);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1774, dvrr_stack+1564, dvrr_stack+1753, NULL, NULL, dvrr_stack+509);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1837, dvrr_stack+1606, dvrr_stack+1774, dvrr_stack+1585, dvrr_stack+1564, dvrr_stack+524);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1963, dvrr_stack+1690, dvrr_stack+1606, dvrr_stack+1669, dvrr_stack+1585, dvrr_stack+569);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2089, dvrr_stack+1963, dvrr_stack+1837, dvrr_stack+1690, dvrr_stack+1606, dvrr_stack+614);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+569, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+572, dvrr_stack+569, dvrr_stack+704, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+121, dvrr_stack+572, dvrr_stack+707, dvrr_stack+569, dvrr_stack+704, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+578, dvrr_stack+121, dvrr_stack+713, dvrr_stack+572, dvrr_stack+707, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+593, dvrr_stack+578, dvrr_stack+723, dvrr_stack+121, dvrr_stack+713, NULL);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+2299, dvrr_stack+593, dvrr_stack+1669, NULL, NULL, dvrr_stack+723);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+2362, dvrr_stack+2299, dvrr_stack+1690, dvrr_stack+593, dvrr_stack+1669, dvrr_stack+738);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2488, dvrr_stack+2362, dvrr_stack+1963, dvrr_stack+2299, dvrr_stack+1690, dvrr_stack+783);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+704, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+707, dvrr_stack+161, dvrr_stack+704, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2698, dvrr_stack+873, dvrr_stack+707, dvrr_stack+210, dvrr_stack+161, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2708, dvrr_stack+879, dvrr_stack+2698, dvrr_stack+213, dvrr_stack+873, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2723, dvrr_stack+889, dvrr_stack+2708, dvrr_stack+219, dvrr_stack+879, NULL);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+2744, dvrr_stack+1753, dvrr_stack+2723, NULL, NULL, dvrr_stack+889);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+2807, dvrr_stack+1774, dvrr_stack+2744, dvrr_stack+1564, dvrr_stack+1753, dvrr_stack+904);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+2933, dvrr_stack+1837, dvrr_stack+2807, dvrr_stack+1606, dvrr_stack+1774, dvrr_stack+949);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+3143, dvrr_stack+2089, dvrr_stack+2933, dvrr_stack+1963, dvrr_stack+1837, dvrr_stack+1039);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+3458, dvrr_stack+2488, dvrr_stack+2089, dvrr_stack+2362, dvrr_stack+1963, dvrr_stack+1189);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+3773, dvrr_stack+3458, dvrr_stack+3143, dvrr_stack+2488, dvrr_stack+2089, dvrr_stack+1339);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+4214, dvrr_stack+1585, dvrr_stack+1564, dvrr_stack+494, dvrr_stack+479, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+4242, dvrr_stack+1669, dvrr_stack+1585, dvrr_stack+723, dvrr_stack+494, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+4270, dvrr_stack+1564, dvrr_stack+1753, dvrr_stack+479, dvrr_stack+509, NULL);

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4298, dvrr_stack+4214, dvrr_stack+4270, NULL, NULL, dvrr_stack+1564);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4382, dvrr_stack+4242, dvrr_stack+4214, NULL, NULL, dvrr_stack+1585);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+4466, dvrr_stack+4382, dvrr_stack+4298, dvrr_stack+4242, dvrr_stack+4214, dvrr_stack+1606);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1606, dvrr_stack+593, dvrr_stack+1669, dvrr_stack+578, dvrr_stack+723, NULL);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4634, dvrr_stack+1606, dvrr_stack+4242, NULL, NULL, dvrr_stack+1669);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+4718, dvrr_stack+4634, dvrr_stack+4382, dvrr_stack+1606, dvrr_stack+4242, dvrr_stack+1690);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1690, dvrr_stack+1753, dvrr_stack+2723, dvrr_stack+509, dvrr_stack+889, NULL);

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+4886, dvrr_stack+4270, dvrr_stack+1690, NULL, NULL, dvrr_stack+1753);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+4970, dvrr_stack+4298, dvrr_stack+4886, dvrr_stack+4214, dvrr_stack+4270, dvrr_stack+1774);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+5138, dvrr_stack+4466, dvrr_stack+4970, dvrr_stack+4382, dvrr_stack+4298, dvrr_stack+1837);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+5418, dvrr_stack+4718, dvrr_stack+4466, dvrr_stack+4634, dvrr_stack+4382, dvrr_stack+1963);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+5698, dvrr_stack+5418, dvrr_stack+5138, dvrr_stack+4718, dvrr_stack+4466, dvrr_stack+2089);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1963, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1966, dvrr_stack+1963, dvrr_stack+569, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1972, dvrr_stack+1966, dvrr_stack+572, dvrr_stack+1963, dvrr_stack+569, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1982, dvrr_stack+1972, dvrr_stack+121, dvrr_stack+1966, dvrr_stack+572, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1997, dvrr_stack+1982, dvrr_stack+578, dvrr_stack+1972, dvrr_stack+121, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2018, dvrr_stack+1997, dvrr_stack+593, dvrr_stack+1982, dvrr_stack+578, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+6118, dvrr_stack+2018, dvrr_stack+1606, NULL, NULL, dvrr_stack+593);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+6202, dvrr_stack+6118, dvrr_stack+4634, dvrr_stack+2018, dvrr_stack+1606, dvrr_stack+2299);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+6370, dvrr_stack+6202, dvrr_stack+4718, dvrr_stack+6118, dvrr_stack+4634, dvrr_stack+2362);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+6650, dvrr_stack+6370, dvrr_stack+5418, dvrr_stack+6202, dvrr_stack+4718, dvrr_stack+2488);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6118, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6121, dvrr_stack+704, dvrr_stack+6118, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+121, dvrr_stack+707, dvrr_stack+6121, dvrr_stack+161, dvrr_stack+704, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+6127, dvrr_stack+2698, dvrr_stack+121, dvrr_stack+873, dvrr_stack+707, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+6142, dvrr_stack+2708, dvrr_stack+6127, dvrr_stack+879, dvrr_stack+2698, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+6163, dvrr_stack+2723, dvrr_stack+6142, dvrr_stack+889, dvrr_stack+2708, NULL);

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+6191, dvrr_stack+1690, dvrr_stack+6163, NULL, NULL, dvrr_stack+2723);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+7070, dvrr_stack+4886, dvrr_stack+6191, dvrr_stack+4270, dvrr_stack+1690, dvrr_stack+2744);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+7238, dvrr_stack+4970, dvrr_stack+7070, dvrr_stack+4298, dvrr_stack+4886, dvrr_stack+2807);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+7518, dvrr_stack+5138, dvrr_stack+7238, dvrr_stack+4466, dvrr_stack+4970, dvrr_stack+2933);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+7938, dvrr_stack+5698, dvrr_stack+7518, dvrr_stack+5418, dvrr_stack+5138, dvrr_stack+3143);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+8526, dvrr_stack+6650, dvrr_stack+5698, dvrr_stack+6370, dvrr_stack+5418, dvrr_stack+3458);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+9114, dvrr_stack+8526, dvrr_stack+7938, dvrr_stack+6650, dvrr_stack+5698, dvrr_stack+3773);
 tmp = dvrr_stack + 9114;
 target_ptr = Libderiv->dvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6275, dvrr_stack+4214, dvrr_stack+4270, dvrr_stack+1585, dvrr_stack+1564, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6311, dvrr_stack+4242, dvrr_stack+4214, dvrr_stack+1669, dvrr_stack+1585, NULL);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6347, dvrr_stack+4270, dvrr_stack+1690, dvrr_stack+1564, dvrr_stack+1753, NULL);

 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6383, dvrr_stack+6275, dvrr_stack+6347, NULL, NULL, dvrr_stack+4270);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6491, dvrr_stack+6311, dvrr_stack+6275, NULL, NULL, dvrr_stack+4214);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6599, dvrr_stack+6491, dvrr_stack+6383, dvrr_stack+6311, dvrr_stack+6275, dvrr_stack+4298);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4298, dvrr_stack+1606, dvrr_stack+4242, dvrr_stack+593, dvrr_stack+1669, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6815, dvrr_stack+4298, dvrr_stack+6311, NULL, NULL, dvrr_stack+4242);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+9898, dvrr_stack+6815, dvrr_stack+6491, dvrr_stack+4298, dvrr_stack+6311, dvrr_stack+4382);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4334, dvrr_stack+1690, dvrr_stack+6163, dvrr_stack+1753, dvrr_stack+2723, NULL);

 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6923, dvrr_stack+6347, dvrr_stack+4334, NULL, NULL, dvrr_stack+1690);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10114, dvrr_stack+6383, dvrr_stack+6923, dvrr_stack+6275, dvrr_stack+6347, dvrr_stack+4886);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10330, dvrr_stack+6599, dvrr_stack+10114, dvrr_stack+6491, dvrr_stack+6383, dvrr_stack+4970);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10690, dvrr_stack+9898, dvrr_stack+6599, dvrr_stack+6815, dvrr_stack+6491, dvrr_stack+4466);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11050, dvrr_stack+10690, dvrr_stack+10330, dvrr_stack+9898, dvrr_stack+6599, dvrr_stack+5138);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4370, dvrr_stack+2018, dvrr_stack+1606, dvrr_stack+1997, dvrr_stack+593, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4406, dvrr_stack+4370, dvrr_stack+4298, NULL, NULL, dvrr_stack+1606);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11590, dvrr_stack+4406, dvrr_stack+6815, dvrr_stack+4370, dvrr_stack+4298, dvrr_stack+4634);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11806, dvrr_stack+11590, dvrr_stack+9898, dvrr_stack+4406, dvrr_stack+6815, dvrr_stack+4718);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+12166, dvrr_stack+11806, dvrr_stack+10690, dvrr_stack+11590, dvrr_stack+9898, dvrr_stack+5418);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+5418, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+5421, dvrr_stack+6118, dvrr_stack+5418, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+5427, dvrr_stack+6121, dvrr_stack+5421, dvrr_stack+704, dvrr_stack+6118, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+5437, dvrr_stack+121, dvrr_stack+5427, dvrr_stack+707, dvrr_stack+6121, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+5452, dvrr_stack+6127, dvrr_stack+5437, dvrr_stack+2698, dvrr_stack+121, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+5473, dvrr_stack+6142, dvrr_stack+5452, dvrr_stack+2708, dvrr_stack+6127, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5501, dvrr_stack+6163, dvrr_stack+5473, dvrr_stack+2723, dvrr_stack+6142, NULL);

 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5537, dvrr_stack+4334, dvrr_stack+5501, NULL, NULL, dvrr_stack+6163);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11590, dvrr_stack+6923, dvrr_stack+5537, dvrr_stack+6347, dvrr_stack+4334, dvrr_stack+6191);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4406, dvrr_stack+10114, dvrr_stack+11590, dvrr_stack+6383, dvrr_stack+6923, dvrr_stack+7070);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+12706, dvrr_stack+10330, dvrr_stack+4406, dvrr_stack+6599, dvrr_stack+10114, dvrr_stack+7238);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+13246, dvrr_stack+11050, dvrr_stack+12706, dvrr_stack+10690, dvrr_stack+10330, dvrr_stack+7518);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+14002, dvrr_stack+12166, dvrr_stack+11050, dvrr_stack+11806, dvrr_stack+10690, dvrr_stack+5698);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+14758, dvrr_stack+14002, dvrr_stack+13246, dvrr_stack+12166, dvrr_stack+11050, dvrr_stack+7938);
 tmp = dvrr_stack + 14758;
 target_ptr = Libderiv->dvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+15766,dvrr_stack+14758,dvrr_stack+9114,28);


 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11806, dvrr_stack+6275, dvrr_stack+6347, dvrr_stack+4214, dvrr_stack+4270, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11851, dvrr_stack+6311, dvrr_stack+6275, dvrr_stack+4242, dvrr_stack+4214, NULL);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11896, dvrr_stack+6347, dvrr_stack+4334, dvrr_stack+4270, dvrr_stack+1690, NULL);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11941, dvrr_stack+11806, dvrr_stack+11896, NULL, NULL, dvrr_stack+6347);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12076, dvrr_stack+11851, dvrr_stack+11806, NULL, NULL, dvrr_stack+6275);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12211, dvrr_stack+12076, dvrr_stack+11941, dvrr_stack+11851, dvrr_stack+11806, dvrr_stack+6383);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6383, dvrr_stack+4298, dvrr_stack+6311, dvrr_stack+1606, dvrr_stack+4242, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12481, dvrr_stack+6383, dvrr_stack+11851, NULL, NULL, dvrr_stack+6311);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18118, dvrr_stack+12481, dvrr_stack+12076, dvrr_stack+6383, dvrr_stack+11851, dvrr_stack+6491);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6428, dvrr_stack+4334, dvrr_stack+5501, dvrr_stack+1690, dvrr_stack+6163, NULL);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18388, dvrr_stack+11896, dvrr_stack+6428, NULL, NULL, dvrr_stack+4334);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18523, dvrr_stack+11941, dvrr_stack+18388, dvrr_stack+11806, dvrr_stack+11896, dvrr_stack+6923);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18793, dvrr_stack+12211, dvrr_stack+18523, dvrr_stack+12076, dvrr_stack+11941, dvrr_stack+10114);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19243, dvrr_stack+18118, dvrr_stack+12211, dvrr_stack+12481, dvrr_stack+12076, dvrr_stack+6599);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19693, dvrr_stack+19243, dvrr_stack+18793, dvrr_stack+18118, dvrr_stack+12211, dvrr_stack+10330);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6473, dvrr_stack+4370, dvrr_stack+4298, dvrr_stack+2018, dvrr_stack+1606, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6518, dvrr_stack+6473, dvrr_stack+6383, NULL, NULL, dvrr_stack+4298);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20368, dvrr_stack+6518, dvrr_stack+12481, dvrr_stack+6473, dvrr_stack+6383, dvrr_stack+6815);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20638, dvrr_stack+20368, dvrr_stack+18118, dvrr_stack+6518, dvrr_stack+12481, dvrr_stack+9898);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+21088, dvrr_stack+20638, dvrr_stack+19243, dvrr_stack+20368, dvrr_stack+18118, dvrr_stack+10690);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+10690, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+10693, dvrr_stack+5418, dvrr_stack+10690, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+10699, dvrr_stack+5421, dvrr_stack+10693, dvrr_stack+6118, dvrr_stack+5418, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+10709, dvrr_stack+5427, dvrr_stack+10699, dvrr_stack+6121, dvrr_stack+5421, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+10724, dvrr_stack+5437, dvrr_stack+10709, dvrr_stack+121, dvrr_stack+5427, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+10745, dvrr_stack+5452, dvrr_stack+10724, dvrr_stack+6127, dvrr_stack+5437, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10773, dvrr_stack+5473, dvrr_stack+10745, dvrr_stack+6142, dvrr_stack+5452, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10809, dvrr_stack+5501, dvrr_stack+10773, dvrr_stack+6163, dvrr_stack+5473, NULL);

 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10854, dvrr_stack+6428, dvrr_stack+10809, NULL, NULL, dvrr_stack+5501);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20368, dvrr_stack+18388, dvrr_stack+10854, dvrr_stack+11896, dvrr_stack+6428, dvrr_stack+5537);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+21763, dvrr_stack+18523, dvrr_stack+20368, dvrr_stack+11941, dvrr_stack+18388, dvrr_stack+11590);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+22213, dvrr_stack+18793, dvrr_stack+21763, dvrr_stack+12211, dvrr_stack+18523, dvrr_stack+4406);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+22888, dvrr_stack+19693, dvrr_stack+22213, dvrr_stack+19243, dvrr_stack+18793, dvrr_stack+12706);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+23833, dvrr_stack+21088, dvrr_stack+19693, dvrr_stack+20638, dvrr_stack+19243, dvrr_stack+11050);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+24778, dvrr_stack+23833, dvrr_stack+22888, dvrr_stack+21088, dvrr_stack+19693, dvrr_stack+13246);
 tmp = dvrr_stack + 24778;
 target_ptr = Libderiv->dvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+26038,dvrr_stack+24778,dvrr_stack+14758,28);


 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20638, dvrr_stack+11806, dvrr_stack+11896, dvrr_stack+6275, dvrr_stack+6347, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20693, dvrr_stack+11851, dvrr_stack+11806, dvrr_stack+6311, dvrr_stack+6275, NULL);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20748, dvrr_stack+11896, dvrr_stack+6428, dvrr_stack+6347, dvrr_stack+4334, NULL);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20803, dvrr_stack+20638, dvrr_stack+20748, NULL, NULL, dvrr_stack+11896);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20968, dvrr_stack+20693, dvrr_stack+20638, NULL, NULL, dvrr_stack+11806);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21133, dvrr_stack+20968, dvrr_stack+20803, dvrr_stack+20693, dvrr_stack+20638, dvrr_stack+11941);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11941, dvrr_stack+6383, dvrr_stack+11851, dvrr_stack+4298, dvrr_stack+6311, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21463, dvrr_stack+11941, dvrr_stack+20693, NULL, NULL, dvrr_stack+11851);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6518, dvrr_stack+21463, dvrr_stack+20968, dvrr_stack+11941, dvrr_stack+20693, dvrr_stack+12076);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11996, dvrr_stack+6428, dvrr_stack+10809, dvrr_stack+4334, dvrr_stack+5501, NULL);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+9898, dvrr_stack+20748, dvrr_stack+11996, NULL, NULL, dvrr_stack+6428);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+29062, dvrr_stack+20803, dvrr_stack+9898, dvrr_stack+20638, dvrr_stack+20748, dvrr_stack+18388);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+29392, dvrr_stack+21133, dvrr_stack+29062, dvrr_stack+20968, dvrr_stack+20803, dvrr_stack+18523);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+29942, dvrr_stack+6518, dvrr_stack+21133, dvrr_stack+21463, dvrr_stack+20968, dvrr_stack+12211);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+30492, dvrr_stack+29942, dvrr_stack+29392, dvrr_stack+6518, dvrr_stack+21133, dvrr_stack+18793);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12051, dvrr_stack+6473, dvrr_stack+6383, dvrr_stack+4370, dvrr_stack+4298, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12106, dvrr_stack+12051, dvrr_stack+11941, NULL, NULL, dvrr_stack+6383);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31317, dvrr_stack+12106, dvrr_stack+21463, dvrr_stack+12051, dvrr_stack+11941, dvrr_stack+12481);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31647, dvrr_stack+31317, dvrr_stack+6518, dvrr_stack+12106, dvrr_stack+21463, dvrr_stack+18118);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+32197, dvrr_stack+31647, dvrr_stack+29942, dvrr_stack+31317, dvrr_stack+6518, dvrr_stack+19243);

 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+19243, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+19246, dvrr_stack+10690, dvrr_stack+19243, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+19252, dvrr_stack+10693, dvrr_stack+19246, dvrr_stack+5418, dvrr_stack+10690, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+19262, dvrr_stack+10699, dvrr_stack+19252, dvrr_stack+5421, dvrr_stack+10693, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+19277, dvrr_stack+10709, dvrr_stack+19262, dvrr_stack+5427, dvrr_stack+10699, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+19298, dvrr_stack+10724, dvrr_stack+19277, dvrr_stack+5437, dvrr_stack+10709, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4370, dvrr_stack+10745, dvrr_stack+19298, dvrr_stack+5452, dvrr_stack+10724, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19326, dvrr_stack+10773, dvrr_stack+4370, dvrr_stack+5473, dvrr_stack+10745, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19371, dvrr_stack+10809, dvrr_stack+19326, dvrr_stack+5501, dvrr_stack+10773, NULL);

 /* compute (1 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19426, dvrr_stack+11996, dvrr_stack+19371, NULL, NULL, dvrr_stack+10809);

 /* compute (2 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+31317, dvrr_stack+9898, dvrr_stack+19426, dvrr_stack+20748, dvrr_stack+11996, dvrr_stack+10854);

 /* compute (3 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12106, dvrr_stack+29062, dvrr_stack+31317, dvrr_stack+20803, dvrr_stack+9898, dvrr_stack+20368);

 /* compute (4 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+33022, dvrr_stack+29392, dvrr_stack+12106, dvrr_stack+21133, dvrr_stack+29062, dvrr_stack+21763);

 /* compute (5 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+33847, dvrr_stack+30492, dvrr_stack+33022, dvrr_stack+29942, dvrr_stack+29392, dvrr_stack+22213);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+35002, dvrr_stack+32197, dvrr_stack+30492, dvrr_stack+31647, dvrr_stack+29942, dvrr_stack+19693);

 /* compute (6 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+36157, dvrr_stack+35002, dvrr_stack+33847, dvrr_stack+32197, dvrr_stack+30492, dvrr_stack+22888);
 tmp = dvrr_stack + 36157;
 target_ptr = Libderiv->dvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+37697,dvrr_stack+36157,dvrr_stack+24778,28);


 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31647, dvrr_stack+20638, dvrr_stack+20748, dvrr_stack+11806, dvrr_stack+11896, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31713, dvrr_stack+20693, dvrr_stack+20638, dvrr_stack+11851, dvrr_stack+11806, NULL);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31779, dvrr_stack+20748, dvrr_stack+11996, dvrr_stack+11896, dvrr_stack+6428, NULL);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31845, dvrr_stack+31647, dvrr_stack+31779, NULL, NULL, dvrr_stack+20748);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32043, dvrr_stack+31713, dvrr_stack+31647, NULL, NULL, dvrr_stack+20638);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32241, dvrr_stack+32043, dvrr_stack+31845, dvrr_stack+31713, dvrr_stack+31647, dvrr_stack+20803);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20803, dvrr_stack+11941, dvrr_stack+20693, dvrr_stack+6383, dvrr_stack+11851, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32637, dvrr_stack+20803, dvrr_stack+31713, NULL, NULL, dvrr_stack+20693);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+41477, dvrr_stack+32637, dvrr_stack+32043, dvrr_stack+20803, dvrr_stack+31713, dvrr_stack+20968);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20869, dvrr_stack+11996, dvrr_stack+19371, dvrr_stack+6428, dvrr_stack+10809, NULL);

 /* compute (1 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20935, dvrr_stack+31779, dvrr_stack+20869, NULL, NULL, dvrr_stack+11996);

 /* compute (2 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+41873, dvrr_stack+31845, dvrr_stack+20935, dvrr_stack+31647, dvrr_stack+31779, dvrr_stack+9898);

 /* compute (3 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+42269, dvrr_stack+32241, dvrr_stack+41873, dvrr_stack+32043, dvrr_stack+31845, dvrr_stack+29062);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+42929, dvrr_stack+41477, dvrr_stack+32241, dvrr_stack+32637, dvrr_stack+32043, dvrr_stack+21133);

 /* compute (4 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+43589, dvrr_stack+42929, dvrr_stack+42269, dvrr_stack+41477, dvrr_stack+32241, dvrr_stack+29392);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+21133, dvrr_stack+12051, dvrr_stack+11941, dvrr_stack+6473, dvrr_stack+6383, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+21199, dvrr_stack+21133, dvrr_stack+20803, NULL, NULL, dvrr_stack+11941);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+44579, dvrr_stack+21199, dvrr_stack+32637, dvrr_stack+21133, dvrr_stack+20803, dvrr_stack+21463);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+44975, dvrr_stack+44579, dvrr_stack+41477, dvrr_stack+21199, dvrr_stack+32637, dvrr_stack+6518);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+45635, dvrr_stack+44975, dvrr_stack+42929, dvrr_stack+44579, dvrr_stack+41477, dvrr_stack+29942);

 /* compute (0 0 | 1 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+5418, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+29942, dvrr_stack+19243, dvrr_stack+5418, Data->F+14, Data->F+15, NULL);

 /* compute (0 0 | 3 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+29948, dvrr_stack+19246, dvrr_stack+29942, dvrr_stack+10690, dvrr_stack+19243, NULL);

 /* compute (0 0 | 4 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+29958, dvrr_stack+19252, dvrr_stack+29948, dvrr_stack+10693, dvrr_stack+19246, NULL);

 /* compute (0 0 | 5 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+29973, dvrr_stack+19262, dvrr_stack+29958, dvrr_stack+10699, dvrr_stack+19252, NULL);

 /* compute (0 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+29994, dvrr_stack+19277, dvrr_stack+29973, dvrr_stack+10709, dvrr_stack+19262, NULL);

 /* compute (0 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+30022, dvrr_stack+19298, dvrr_stack+29994, dvrr_stack+10724, dvrr_stack+19277, NULL);

 /* compute (0 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+30058, dvrr_stack+4370, dvrr_stack+30022, dvrr_stack+10745, dvrr_stack+19298, NULL);

 /* compute (0 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+30103, dvrr_stack+19326, dvrr_stack+30058, dvrr_stack+10773, dvrr_stack+4370, NULL);

 /* compute (0 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30158, dvrr_stack+19371, dvrr_stack+30103, dvrr_stack+10809, dvrr_stack+19326, NULL);

 /* compute (1 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30224, dvrr_stack+20869, dvrr_stack+30158, NULL, NULL, dvrr_stack+19371);

 /* compute (2 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+44579, dvrr_stack+20935, dvrr_stack+30224, dvrr_stack+31779, dvrr_stack+20869, dvrr_stack+19426);

 /* compute (3 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+46625, dvrr_stack+41873, dvrr_stack+44579, dvrr_stack+31845, dvrr_stack+20935, dvrr_stack+31317);

 /* compute (4 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+47285, dvrr_stack+42269, dvrr_stack+46625, dvrr_stack+32241, dvrr_stack+41873, dvrr_stack+12106);

 /* compute (5 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+48275, dvrr_stack+43589, dvrr_stack+47285, dvrr_stack+42929, dvrr_stack+42269, dvrr_stack+33022);

 /* compute (5 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+49661, dvrr_stack+45635, dvrr_stack+43589, dvrr_stack+44975, dvrr_stack+42929, dvrr_stack+30492);

 /* compute (6 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+51047, dvrr_stack+49661, dvrr_stack+48275, dvrr_stack+45635, dvrr_stack+43589, dvrr_stack+33847);
 tmp = dvrr_stack + 51047;
 target_ptr = Libderiv->dvrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+52895,dvrr_stack+51047,dvrr_stack+36157,28);


 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+44975, dvrr_stack+31647, dvrr_stack+31779, dvrr_stack+20638, dvrr_stack+20748, NULL);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45053, dvrr_stack+31713, dvrr_stack+31647, dvrr_stack+20693, dvrr_stack+20638, NULL);

 /* compute (0 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45131, dvrr_stack+31779, dvrr_stack+20869, dvrr_stack+20748, dvrr_stack+11996, NULL);

 /* compute (1 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45209, dvrr_stack+44975, dvrr_stack+45131, NULL, NULL, dvrr_stack+31779);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45443, dvrr_stack+45053, dvrr_stack+44975, NULL, NULL, dvrr_stack+31647);

 /* compute (2 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45677, dvrr_stack+45443, dvrr_stack+45209, dvrr_stack+45053, dvrr_stack+44975, dvrr_stack+31845);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31779, dvrr_stack+20803, dvrr_stack+31713, dvrr_stack+11941, dvrr_stack+20693, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+46145, dvrr_stack+31779, dvrr_stack+45053, NULL, NULL, dvrr_stack+31713);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+21199, dvrr_stack+46145, dvrr_stack+45443, dvrr_stack+31779, dvrr_stack+45053, dvrr_stack+32043);

 /* compute (0 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45053, dvrr_stack+20869, dvrr_stack+30158, dvrr_stack+11996, dvrr_stack+19371, NULL);

 /* compute (1 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31857, dvrr_stack+45131, dvrr_stack+45053, NULL, NULL, dvrr_stack+20869);

 /* compute (2 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+57515, dvrr_stack+45209, dvrr_stack+31857, dvrr_stack+44975, dvrr_stack+45131, dvrr_stack+20935);

 /* compute (3 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+57983, dvrr_stack+45677, dvrr_stack+57515, dvrr_stack+45443, dvrr_stack+45209, dvrr_stack+41873);

 /* compute (3 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+58763, dvrr_stack+21199, dvrr_stack+45677, dvrr_stack+46145, dvrr_stack+45443, dvrr_stack+32241);

 /* compute (4 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+59543, dvrr_stack+58763, dvrr_stack+57983, dvrr_stack+21199, dvrr_stack+45677, dvrr_stack+42269);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+44975, dvrr_stack+21133, dvrr_stack+20803, dvrr_stack+12051, dvrr_stack+11941, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45443, dvrr_stack+44975, dvrr_stack+31779, NULL, NULL, dvrr_stack+20803);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32091, dvrr_stack+45443, dvrr_stack+46145, dvrr_stack+44975, dvrr_stack+31779, dvrr_stack+32637);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+60713, dvrr_stack+32091, dvrr_stack+21199, dvrr_stack+45443, dvrr_stack+46145, dvrr_stack+41477);

 /* compute (4 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+61493, dvrr_stack+60713, dvrr_stack+58763, dvrr_stack+32091, dvrr_stack+21199, dvrr_stack+42929);

 /* compute (0 0 | 1 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+42929, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+42932, dvrr_stack+5418, dvrr_stack+42929, Data->F+15, Data->F+16, NULL);

 /* compute (0 0 | 3 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+42938, dvrr_stack+29942, dvrr_stack+42932, dvrr_stack+19243, dvrr_stack+5418, NULL);

 /* compute (0 0 | 4 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+42948, dvrr_stack+29948, dvrr_stack+42938, dvrr_stack+19246, dvrr_stack+29942, NULL);

 /* compute (0 0 | 5 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+42963, dvrr_stack+29958, dvrr_stack+42948, dvrr_stack+19252, dvrr_stack+29948, NULL);

 /* compute (0 0 | 6 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+42984, dvrr_stack+29973, dvrr_stack+42963, dvrr_stack+19262, dvrr_stack+29958, NULL);

 /* compute (0 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+43012, dvrr_stack+29994, dvrr_stack+42984, dvrr_stack+19277, dvrr_stack+29973, NULL);

 /* compute (0 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+43048, dvrr_stack+30022, dvrr_stack+43012, dvrr_stack+19298, dvrr_stack+29994, NULL);

 /* compute (0 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12051, dvrr_stack+30058, dvrr_stack+43048, dvrr_stack+4370, dvrr_stack+30022, NULL);

 /* compute (0 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+43093, dvrr_stack+30103, dvrr_stack+12051, dvrr_stack+19326, dvrr_stack+30058, NULL);

 /* compute (0 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+44975, dvrr_stack+30158, dvrr_stack+43093, dvrr_stack+19371, dvrr_stack+30103, NULL);

 /* compute (1 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45443, dvrr_stack+45053, dvrr_stack+44975, NULL, NULL, dvrr_stack+30158);

 /* compute (2 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+32091, dvrr_stack+31857, dvrr_stack+45443, dvrr_stack+45131, dvrr_stack+45053, dvrr_stack+30224);

 /* compute (3 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+62663, dvrr_stack+57515, dvrr_stack+32091, dvrr_stack+45209, dvrr_stack+31857, dvrr_stack+44579);

 /* compute (4 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+63443, dvrr_stack+57983, dvrr_stack+62663, dvrr_stack+45677, dvrr_stack+57515, dvrr_stack+46625);

 /* compute (5 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+64613, dvrr_stack+59543, dvrr_stack+63443, dvrr_stack+58763, dvrr_stack+57983, dvrr_stack+47285);

 /* compute (5 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+66251, dvrr_stack+61493, dvrr_stack+59543, dvrr_stack+60713, dvrr_stack+58763, dvrr_stack+43589);

 /* compute (6 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+67889, dvrr_stack+66251, dvrr_stack+64613, dvrr_stack+61493, dvrr_stack+59543, dvrr_stack+48275);

 /* compute (6 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+70073,dvrr_stack+67889,dvrr_stack+51047,28);


 /* compute (1 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+58763, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+10690, dvrr_stack+0, dvrr_stack+30, NULL, NULL, Data->F+7);

 /* compute (2 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+58766, dvrr_stack+6, dvrr_stack+10690, dvrr_stack+3, dvrr_stack+0, dvrr_stack+58763);

 /* compute (1 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+58784, dvrr_stack+33, dvrr_stack+213, NULL, NULL, dvrr_stack+30);

 /* compute (2 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+58802, dvrr_stack+39, dvrr_stack+58784, dvrr_stack+15, dvrr_stack+33, dvrr_stack+10690);

 /* compute (3 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+58838, dvrr_stack+75, dvrr_stack+58802, dvrr_stack+57, dvrr_stack+39, dvrr_stack+58766);

 /* compute (1 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+479, dvrr_stack+219, dvrr_stack+879, NULL, NULL, dvrr_stack+213);

 /* compute (2 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+58898, dvrr_stack+229, dvrr_stack+479, dvrr_stack+111, dvrr_stack+219, dvrr_stack+58784);

 /* compute (3 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+58958, dvrr_stack+259, dvrr_stack+58898, dvrr_stack+131, dvrr_stack+229, dvrr_stack+58802);

 /* compute (4 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+59058, dvrr_stack+379, dvrr_stack+58958, dvrr_stack+319, dvrr_stack+259, dvrr_stack+58838);

 /* compute (1 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+59208, dvrr_stack+889, dvrr_stack+2708, NULL, NULL, dvrr_stack+879);

 /* compute (2 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+59253, dvrr_stack+904, dvrr_stack+59208, dvrr_stack+509, dvrr_stack+889, dvrr_stack+479);

 /* compute (3 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+59343, dvrr_stack+949, dvrr_stack+59253, dvrr_stack+524, dvrr_stack+904, dvrr_stack+58898);

 /* compute (4 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+60713, dvrr_stack+1039, dvrr_stack+59343, dvrr_stack+614, dvrr_stack+949, dvrr_stack+58958);

 /* compute (5 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+60938, dvrr_stack+1339, dvrr_stack+60713, dvrr_stack+1189, dvrr_stack+1039, dvrr_stack+59058);

 /* compute (1 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+614, dvrr_stack+2723, dvrr_stack+6142, NULL, NULL, dvrr_stack+2708);

 /* compute (2 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1564, dvrr_stack+2744, dvrr_stack+614, dvrr_stack+1753, dvrr_stack+2723, dvrr_stack+59208);

 /* compute (3 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+31647, dvrr_stack+2807, dvrr_stack+1564, dvrr_stack+1774, dvrr_stack+2744, dvrr_stack+59253);

 /* compute (4 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+61253, dvrr_stack+2933, dvrr_stack+31647, dvrr_stack+1837, dvrr_stack+2807, dvrr_stack+59343);

 /* compute (5 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+61568, dvrr_stack+3143, dvrr_stack+61253, dvrr_stack+2089, dvrr_stack+2933, dvrr_stack+60713);

 /* compute (6 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+62009, dvrr_stack+3773, dvrr_stack+61568, dvrr_stack+3458, dvrr_stack+3143, dvrr_stack+60938);

 /* compute (1 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+45677, dvrr_stack+6163, dvrr_stack+5473, NULL, NULL, dvrr_stack+6142);

 /* compute (2 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+45761, dvrr_stack+6191, dvrr_stack+45677, dvrr_stack+1690, dvrr_stack+6163, dvrr_stack+614);

 /* compute (3 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+1690, dvrr_stack+7070, dvrr_stack+45761, dvrr_stack+4886, dvrr_stack+6191, dvrr_stack+1564);

 /* compute (4 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+45929, dvrr_stack+7238, dvrr_stack+1690, dvrr_stack+4970, dvrr_stack+7070, dvrr_stack+31647);

 /* compute (5 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+21133, dvrr_stack+7518, dvrr_stack+45929, dvrr_stack+5138, dvrr_stack+7238, dvrr_stack+61253);

 /* compute (6 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+75617, dvrr_stack+7938, dvrr_stack+21133, dvrr_stack+5698, dvrr_stack+7518, dvrr_stack+61568);

 /* compute (7 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+76401, dvrr_stack+9114, dvrr_stack+75617, dvrr_stack+8526, dvrr_stack+7938, dvrr_stack+62009);
 tmp = dvrr_stack + 76401;
 target_ptr = Libderiv->dvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+46349, dvrr_stack+5501, dvrr_stack+10773, NULL, NULL, dvrr_stack+5473);

 /* compute (2 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+45131, dvrr_stack+5537, dvrr_stack+46349, dvrr_stack+4334, dvrr_stack+5501, dvrr_stack+45677);

 /* compute (3 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+43159, dvrr_stack+11590, dvrr_stack+45131, dvrr_stack+6923, dvrr_stack+5537, dvrr_stack+45761);

 /* compute (4 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6473, dvrr_stack+4406, dvrr_stack+43159, dvrr_stack+10114, dvrr_stack+11590, dvrr_stack+1690);

 /* compute (5 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+77409, dvrr_stack+12706, dvrr_stack+6473, dvrr_stack+10330, dvrr_stack+4406, dvrr_stack+45929);

 /* compute (6 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+78165, dvrr_stack+13246, dvrr_stack+77409, dvrr_stack+11050, dvrr_stack+12706, dvrr_stack+21133);

 /* compute (7 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+79173, dvrr_stack+14758, dvrr_stack+78165, dvrr_stack+14002, dvrr_stack+13246, dvrr_stack+75617);
 tmp = dvrr_stack + 79173;
 target_ptr = Libderiv->dvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+80469,dvrr_stack+79173,dvrr_stack+76401,36);


 /* compute (1 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+46457, dvrr_stack+10809, dvrr_stack+19326, NULL, NULL, dvrr_stack+10773);

 /* compute (2 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18118, dvrr_stack+10854, dvrr_stack+46457, dvrr_stack+6428, dvrr_stack+10809, dvrr_stack+46349);

 /* compute (3 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+32559, dvrr_stack+20368, dvrr_stack+18118, dvrr_stack+18388, dvrr_stack+10854, dvrr_stack+45131);

 /* compute (4 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+83493, dvrr_stack+21763, dvrr_stack+32559, dvrr_stack+18523, dvrr_stack+20368, dvrr_stack+43159);

 /* compute (5 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+84168, dvrr_stack+22213, dvrr_stack+83493, dvrr_stack+18793, dvrr_stack+21763, dvrr_stack+6473);

 /* compute (6 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+85113, dvrr_stack+22888, dvrr_stack+84168, dvrr_stack+19693, dvrr_stack+22213, dvrr_stack+77409);

 /* compute (7 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+86373, dvrr_stack+24778, dvrr_stack+85113, dvrr_stack+23833, dvrr_stack+22888, dvrr_stack+78165);
 tmp = dvrr_stack + 86373;
 target_ptr = Libderiv->dvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+87993,dvrr_stack+86373,dvrr_stack+79173,36);


 /* compute (1 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18388, dvrr_stack+19371, dvrr_stack+30103, NULL, NULL, dvrr_stack+19326);

 /* compute (2 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18553, dvrr_stack+19426, dvrr_stack+18388, dvrr_stack+11996, dvrr_stack+19371, dvrr_stack+46457);

 /* compute (3 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19591, dvrr_stack+31317, dvrr_stack+18553, dvrr_stack+9898, dvrr_stack+19426, dvrr_stack+18118);

 /* compute (4 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+91881, dvrr_stack+12106, dvrr_stack+19591, dvrr_stack+29062, dvrr_stack+31317, dvrr_stack+32559);

 /* compute (5 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+92706, dvrr_stack+33022, dvrr_stack+91881, dvrr_stack+29392, dvrr_stack+12106, dvrr_stack+83493);

 /* compute (6 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+93861, dvrr_stack+33847, dvrr_stack+92706, dvrr_stack+30492, dvrr_stack+33022, dvrr_stack+84168);

 /* compute (7 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+95401, dvrr_stack+36157, dvrr_stack+93861, dvrr_stack+35002, dvrr_stack+33847, dvrr_stack+85113);
 tmp = dvrr_stack + 95401;
 target_ptr = Libderiv->dvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+97381,dvrr_stack+95401,dvrr_stack+86373,36);


 /* compute (1 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6275, dvrr_stack+30158, dvrr_stack+43093, NULL, NULL, dvrr_stack+30103);

 /* compute (2 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+41477, dvrr_stack+30224, dvrr_stack+6275, dvrr_stack+20869, dvrr_stack+30158, dvrr_stack+18388);

 /* compute (3 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+29062, dvrr_stack+44579, dvrr_stack+41477, dvrr_stack+20935, dvrr_stack+30224, dvrr_stack+18553);

 /* compute (4 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+102241, dvrr_stack+46625, dvrr_stack+29062, dvrr_stack+41873, dvrr_stack+44579, dvrr_stack+19591);

 /* compute (5 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+103231, dvrr_stack+47285, dvrr_stack+102241, dvrr_stack+42269, dvrr_stack+46625, dvrr_stack+91881);

 /* compute (6 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+104617, dvrr_stack+48275, dvrr_stack+103231, dvrr_stack+43589, dvrr_stack+47285, dvrr_stack+92706);

 /* compute (7 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+106465, dvrr_stack+51047, dvrr_stack+104617, dvrr_stack+49661, dvrr_stack+48275, dvrr_stack+93861);
 tmp = dvrr_stack + 106465;
 target_ptr = Libderiv->dvrr_classes[7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+108841,dvrr_stack+106465,dvrr_stack+95401,36);


 /* compute (0 0 | 1 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+41873, Data->F+17, Data->F+18, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+42929, dvrr_stack+41873, Data->F+16, Data->F+17, NULL);

 /* compute (0 0 | 3 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+111, dvrr_stack+42932, dvrr_stack+15, dvrr_stack+5418, dvrr_stack+42929, NULL);

 /* compute (0 0 | 4 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+41876, dvrr_stack+42938, dvrr_stack+111, dvrr_stack+29942, dvrr_stack+42932, NULL);

 /* compute (0 0 | 5 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+41891, dvrr_stack+42948, dvrr_stack+41876, dvrr_stack+29948, dvrr_stack+42938, NULL);

 /* compute (0 0 | 6 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+41912, dvrr_stack+42963, dvrr_stack+41891, dvrr_stack+29958, dvrr_stack+42948, NULL);

 /* compute (0 0 | 7 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+41940, dvrr_stack+42984, dvrr_stack+41912, dvrr_stack+29973, dvrr_stack+42963, NULL);

 /* compute (0 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+41976, dvrr_stack+43012, dvrr_stack+41940, dvrr_stack+29994, dvrr_stack+42984, NULL);

 /* compute (0 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+42021, dvrr_stack+43048, dvrr_stack+41976, dvrr_stack+30022, dvrr_stack+43012, NULL);

 /* compute (0 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+62597, dvrr_stack+12051, dvrr_stack+42021, dvrr_stack+30058, dvrr_stack+43048, NULL);

 /* compute (0 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+42076, dvrr_stack+43093, dvrr_stack+62597, dvrr_stack+30103, dvrr_stack+12051, NULL);

 /* compute (1 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+42154, dvrr_stack+44975, dvrr_stack+42076, NULL, NULL, dvrr_stack+43093);

 /* compute (2 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+42388, dvrr_stack+45443, dvrr_stack+42154, dvrr_stack+45053, dvrr_stack+44975, dvrr_stack+6275);

 /* compute (3 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+9898, dvrr_stack+32091, dvrr_stack+42388, dvrr_stack+31857, dvrr_stack+45443, dvrr_stack+41477);

 /* compute (4 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+114781, dvrr_stack+62663, dvrr_stack+9898, dvrr_stack+57515, dvrr_stack+32091, dvrr_stack+29062);

 /* compute (5 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+115951, dvrr_stack+63443, dvrr_stack+114781, dvrr_stack+57983, dvrr_stack+62663, dvrr_stack+102241);

 /* compute (6 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+117589, dvrr_stack+64613, dvrr_stack+115951, dvrr_stack+59543, dvrr_stack+63443, dvrr_stack+103231);

 /* compute (7 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+119773, dvrr_stack+67889, dvrr_stack+117589, dvrr_stack+66251, dvrr_stack+64613, dvrr_stack+104617);

 /* compute (7 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+122581,dvrr_stack+119773,dvrr_stack+106465,36);


 /* compute (1 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+66251, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+66254, dvrr_stack+58763, dvrr_stack+66251, Data->F+6, Data->F+7, NULL);

 /* compute (1 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+66260, dvrr_stack+30, dvrr_stack+210, NULL, NULL, Data->F+8);

 /* compute (2 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+66269, dvrr_stack+10690, dvrr_stack+66260, dvrr_stack+0, dvrr_stack+30, dvrr_stack+66251);

 /* compute (3 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+131, dvrr_stack+58766, dvrr_stack+66269, dvrr_stack+6, dvrr_stack+10690, dvrr_stack+66254);

 /* compute (1 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+66287, dvrr_stack+213, dvrr_stack+873, NULL, NULL, dvrr_stack+210);

 /* compute (2 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+66305, dvrr_stack+58784, dvrr_stack+66287, dvrr_stack+33, dvrr_stack+213, dvrr_stack+66260);

 /* compute (3 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+66341, dvrr_stack+58802, dvrr_stack+66305, dvrr_stack+39, dvrr_stack+58784, dvrr_stack+66269);

 /* compute (4 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+66401, dvrr_stack+58838, dvrr_stack+66341, dvrr_stack+75, dvrr_stack+58802, dvrr_stack+131);

 /* compute (1 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+66491, dvrr_stack+879, dvrr_stack+2698, NULL, NULL, dvrr_stack+873);

 /* compute (2 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+66521, dvrr_stack+479, dvrr_stack+66491, dvrr_stack+219, dvrr_stack+879, dvrr_stack+66287);

 /* compute (3 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+66581, dvrr_stack+58898, dvrr_stack+66521, dvrr_stack+229, dvrr_stack+479, dvrr_stack+66305);

 /* compute (4 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+66681, dvrr_stack+58958, dvrr_stack+66581, dvrr_stack+259, dvrr_stack+58898, dvrr_stack+66341);

 /* compute (5 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+66831, dvrr_stack+59058, dvrr_stack+66681, dvrr_stack+379, dvrr_stack+58958, dvrr_stack+66401);

 /* compute (1 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+219, dvrr_stack+2708, dvrr_stack+6127, NULL, NULL, dvrr_stack+2698);

 /* compute (2 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+67041, dvrr_stack+59208, dvrr_stack+219, dvrr_stack+889, dvrr_stack+2708, dvrr_stack+66491);

 /* compute (3 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+67131, dvrr_stack+59253, dvrr_stack+67041, dvrr_stack+904, dvrr_stack+59208, dvrr_stack+66521);

 /* compute (4 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+67281, dvrr_stack+59343, dvrr_stack+67131, dvrr_stack+949, dvrr_stack+59253, dvrr_stack+66581);

 /* compute (5 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+67506, dvrr_stack+60713, dvrr_stack+67281, dvrr_stack+1039, dvrr_stack+59343, dvrr_stack+66681);

 /* compute (6 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+57515, dvrr_stack+60938, dvrr_stack+67506, dvrr_stack+1339, dvrr_stack+60713, dvrr_stack+66831);

 /* compute (1 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+889, dvrr_stack+6142, dvrr_stack+5452, NULL, NULL, dvrr_stack+6127);

 /* compute (2 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+952, dvrr_stack+614, dvrr_stack+889, dvrr_stack+2723, dvrr_stack+6142, dvrr_stack+219);

 /* compute (3 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+57935, dvrr_stack+1564, dvrr_stack+952, dvrr_stack+2744, dvrr_stack+614, dvrr_stack+67041);

 /* compute (4 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+58145, dvrr_stack+31647, dvrr_stack+57935, dvrr_stack+2807, dvrr_stack+1564, dvrr_stack+67131);

 /* compute (5 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+59493, dvrr_stack+61253, dvrr_stack+58145, dvrr_stack+2933, dvrr_stack+31647, dvrr_stack+67281);

 /* compute (6 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+59934, dvrr_stack+61568, dvrr_stack+59493, dvrr_stack+3143, dvrr_stack+61253, dvrr_stack+67506);

 /* compute (7 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+43519, dvrr_stack+62009, dvrr_stack+59934, dvrr_stack+3773, dvrr_stack+61568, dvrr_stack+57515);

 /* compute (1 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2723, dvrr_stack+5473, dvrr_stack+10745, NULL, NULL, dvrr_stack+5452);

 /* compute (2 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+2807, dvrr_stack+45677, dvrr_stack+2723, dvrr_stack+6163, dvrr_stack+5473, dvrr_stack+889);

 /* compute (3 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+2975, dvrr_stack+45761, dvrr_stack+2807, dvrr_stack+6191, dvrr_stack+45677, dvrr_stack+952);

 /* compute (4 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+20638, dvrr_stack+1690, dvrr_stack+2975, dvrr_stack+7070, dvrr_stack+45761, dvrr_stack+57935);

 /* compute (5 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+30422, dvrr_stack+45929, dvrr_stack+20638, dvrr_stack+7238, dvrr_stack+1690, dvrr_stack+58145);

 /* compute (6 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+129709, dvrr_stack+21133, dvrr_stack+30422, dvrr_stack+7518, dvrr_stack+45929, dvrr_stack+59493);

 /* compute (7 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+130493, dvrr_stack+75617, dvrr_stack+129709, dvrr_stack+7938, dvrr_stack+21133, dvrr_stack+59934);

 /* compute (8 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+7013, dvrr_stack+76401, dvrr_stack+130493, dvrr_stack+9114, dvrr_stack+75617, dvrr_stack+43519);
 tmp = dvrr_stack + 7013;
 target_ptr = Libderiv->dvrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6163, dvrr_stack+10773, dvrr_stack+4370, NULL, NULL, dvrr_stack+10745);

 /* compute (2 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+58460, dvrr_stack+46349, dvrr_stack+6163, dvrr_stack+5501, dvrr_stack+10773, dvrr_stack+2723);

 /* compute (3 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+18883, dvrr_stack+45131, dvrr_stack+58460, dvrr_stack+5537, dvrr_stack+46349, dvrr_stack+2807);

 /* compute (4 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5501, dvrr_stack+43159, dvrr_stack+18883, dvrr_stack+11590, dvrr_stack+45131, dvrr_stack+2975);

 /* compute (5 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10989, dvrr_stack+6473, dvrr_stack+5501, dvrr_stack+4406, dvrr_stack+43159, dvrr_stack+20638);

 /* compute (6 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4406, dvrr_stack+77409, dvrr_stack+10989, dvrr_stack+12706, dvrr_stack+6473, dvrr_stack+30422);

 /* compute (7 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+131501, dvrr_stack+78165, dvrr_stack+4406, dvrr_stack+13246, dvrr_stack+77409, dvrr_stack+129709);

 /* compute (8 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+132797, dvrr_stack+79173, dvrr_stack+131501, dvrr_stack+14758, dvrr_stack+78165, dvrr_stack+130493);
 tmp = dvrr_stack + 132797;
 target_ptr = Libderiv->dvrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+134417,dvrr_stack+132797,dvrr_stack+7013,45);


 /* compute (1 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3255, dvrr_stack+19326, dvrr_stack+30058, NULL, NULL, dvrr_stack+4370);

 /* compute (2 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+44275, dvrr_stack+46457, dvrr_stack+3255, dvrr_stack+10809, dvrr_stack+19326, dvrr_stack+6163);

 /* compute (3 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12656, dvrr_stack+18118, dvrr_stack+44275, dvrr_stack+10854, dvrr_stack+46457, dvrr_stack+58460);

 /* compute (4 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13106, dvrr_stack+32559, dvrr_stack+12656, dvrr_stack+20368, dvrr_stack+18118, dvrr_stack+18883);

 /* compute (5 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+138197, dvrr_stack+83493, dvrr_stack+13106, dvrr_stack+21763, dvrr_stack+32559, dvrr_stack+5501);

 /* compute (6 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+139142, dvrr_stack+84168, dvrr_stack+138197, dvrr_stack+22213, dvrr_stack+83493, dvrr_stack+10989);

 /* compute (7 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+140402, dvrr_stack+85113, dvrr_stack+139142, dvrr_stack+22888, dvrr_stack+84168, dvrr_stack+4406);

 /* compute (8 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+21721, dvrr_stack+86373, dvrr_stack+140402, dvrr_stack+24778, dvrr_stack+85113, dvrr_stack+131501);
 tmp = dvrr_stack + 21721;
 target_ptr = Libderiv->dvrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+142022,dvrr_stack+21721,dvrr_stack+132797,45);


 /* compute (1 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+10809, dvrr_stack+30103, dvrr_stack+12051, NULL, NULL, dvrr_stack+30058);

 /* compute (2 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20141, dvrr_stack+18388, dvrr_stack+10809, dvrr_stack+19371, dvrr_stack+30103, dvrr_stack+3255);

 /* compute (3 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+146882, dvrr_stack+18553, dvrr_stack+20141, dvrr_stack+19426, dvrr_stack+18388, dvrr_stack+44275);

 /* compute (4 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+147432, dvrr_stack+19591, dvrr_stack+146882, dvrr_stack+31317, dvrr_stack+18553, dvrr_stack+12656);

 /* compute (5 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+148257, dvrr_stack+91881, dvrr_stack+147432, dvrr_stack+12106, dvrr_stack+19591, dvrr_stack+13106);

 /* compute (6 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+149412, dvrr_stack+92706, dvrr_stack+148257, dvrr_stack+33022, dvrr_stack+91881, dvrr_stack+138197);

 /* compute (7 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+150952, dvrr_stack+93861, dvrr_stack+149412, dvrr_stack+33847, dvrr_stack+92706, dvrr_stack+139142);

 /* compute (8 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+152932, dvrr_stack+95401, dvrr_stack+150952, dvrr_stack+36157, dvrr_stack+93861, dvrr_stack+140402);
 tmp = dvrr_stack + 152932;
 target_ptr = Libderiv->dvrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+155407,dvrr_stack+152932,dvrr_stack+21721,45);


 /* compute (1 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12106, dvrr_stack+43093, dvrr_stack+62597, NULL, NULL, dvrr_stack+12051);

 /* compute (2 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33009, dvrr_stack+6275, dvrr_stack+12106, dvrr_stack+30158, dvrr_stack+43093, dvrr_stack+10809);

 /* compute (3 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+33405, dvrr_stack+41477, dvrr_stack+33009, dvrr_stack+30224, dvrr_stack+6275, dvrr_stack+20141);

 /* compute (4 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+161482, dvrr_stack+29062, dvrr_stack+33405, dvrr_stack+44579, dvrr_stack+41477, dvrr_stack+146882);

 /* compute (5 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+162472, dvrr_stack+102241, dvrr_stack+161482, dvrr_stack+46625, dvrr_stack+29062, dvrr_stack+147432);

 /* compute (6 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+163858, dvrr_stack+103231, dvrr_stack+162472, dvrr_stack+47285, dvrr_stack+102241, dvrr_stack+148257);

 /* compute (7 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+165706, dvrr_stack+104617, dvrr_stack+163858, dvrr_stack+48275, dvrr_stack+103231, dvrr_stack+149412);

 /* compute (8 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+46592, dvrr_stack+106465, dvrr_stack+165706, dvrr_stack+51047, dvrr_stack+104617, dvrr_stack+150952);
 tmp = dvrr_stack + 46592;
 target_ptr = Libderiv->dvrr_classes[8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+168082,dvrr_stack+46592,dvrr_stack+152932,45);


 /* compute (0 0 | 1 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+18, Data->F+19, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+30158, dvrr_stack+41873, dvrr_stack+0, Data->F+17, Data->F+18, NULL);

 /* compute (0 0 | 3 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+30164, dvrr_stack+15, dvrr_stack+30158, dvrr_stack+42929, dvrr_stack+41873, NULL);

 /* compute (0 0 | 4 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+10974, dvrr_stack+111, dvrr_stack+30164, dvrr_stack+42932, dvrr_stack+15, NULL);

 /* compute (0 0 | 5 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+30174, dvrr_stack+41876, dvrr_stack+10974, dvrr_stack+42938, dvrr_stack+111, NULL);

 /* compute (0 0 | 6 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+30195, dvrr_stack+41891, dvrr_stack+30174, dvrr_stack+42948, dvrr_stack+41876, NULL);

 /* compute (0 0 | 7 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+30223, dvrr_stack+41912, dvrr_stack+30195, dvrr_stack+42963, dvrr_stack+41891, NULL);

 /* compute (0 0 | 8 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+30259, dvrr_stack+41940, dvrr_stack+30223, dvrr_stack+42984, dvrr_stack+41912, NULL);

 /* compute (0 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+264, dvrr_stack+41976, dvrr_stack+30259, dvrr_stack+43012, dvrr_stack+41940, NULL);

 /* compute (0 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30304, dvrr_stack+42021, dvrr_stack+264, dvrr_stack+43048, dvrr_stack+41976, NULL);

 /* compute (0 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+45053, dvrr_stack+62597, dvrr_stack+30304, dvrr_stack+12051, dvrr_stack+42021, NULL);

 /* compute (1 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+31857, dvrr_stack+42076, dvrr_stack+45053, NULL, NULL, dvrr_stack+62597);

 /* compute (2 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+34065, dvrr_stack+42154, dvrr_stack+31857, dvrr_stack+44975, dvrr_stack+42076, dvrr_stack+12106);

 /* compute (3 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+175507, dvrr_stack+42388, dvrr_stack+34065, dvrr_stack+45443, dvrr_stack+42154, dvrr_stack+33009);

 /* compute (4 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+176287, dvrr_stack+9898, dvrr_stack+175507, dvrr_stack+32091, dvrr_stack+42388, dvrr_stack+33405);

 /* compute (5 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+177457, dvrr_stack+114781, dvrr_stack+176287, dvrr_stack+62663, dvrr_stack+9898, dvrr_stack+161482);

 /* compute (6 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+179095, dvrr_stack+115951, dvrr_stack+177457, dvrr_stack+63443, dvrr_stack+114781, dvrr_stack+162472);

 /* compute (7 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+181279, dvrr_stack+117589, dvrr_stack+179095, dvrr_stack+64613, dvrr_stack+115951, dvrr_stack+163858);

 /* compute (8 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+62663, dvrr_stack+119773, dvrr_stack+181279, dvrr_stack+67889, dvrr_stack+117589, dvrr_stack+165706);

 /* compute (8 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+184087,dvrr_stack+62663,dvrr_stack+46592,45);


 /* compute (1 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+66173, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+66176, dvrr_stack+66251, dvrr_stack+66173, Data->F+7, Data->F+8, NULL);

 /* compute (3 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+66182, dvrr_stack+66254, dvrr_stack+66176, dvrr_stack+58763, dvrr_stack+66251, NULL);

 /* compute (1 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+66192, dvrr_stack+210, dvrr_stack+161, NULL, NULL, Data->F+9);

 /* compute (2 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+66201, dvrr_stack+66260, dvrr_stack+66192, dvrr_stack+30, dvrr_stack+210, dvrr_stack+66173);

 /* compute (3 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+66219, dvrr_stack+66269, dvrr_stack+66201, dvrr_stack+10690, dvrr_stack+66260, dvrr_stack+66176);

 /* compute (4 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+32091, dvrr_stack+131, dvrr_stack+66219, dvrr_stack+58766, dvrr_stack+66269, dvrr_stack+66182);

 /* compute (1 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+30, dvrr_stack+873, dvrr_stack+707, NULL, NULL, dvrr_stack+161);

 /* compute (2 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+32136, dvrr_stack+66287, dvrr_stack+30, dvrr_stack+213, dvrr_stack+873, dvrr_stack+66192);

 /* compute (3 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+32172, dvrr_stack+66305, dvrr_stack+32136, dvrr_stack+58784, dvrr_stack+66287, dvrr_stack+66201);

 /* compute (4 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+32232, dvrr_stack+66341, dvrr_stack+32172, dvrr_stack+58802, dvrr_stack+66305, dvrr_stack+66219);

 /* compute (5 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+32322, dvrr_stack+66401, dvrr_stack+32232, dvrr_stack+58838, dvrr_stack+66341, dvrr_stack+32091);

 /* compute (1 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+58784, dvrr_stack+2698, dvrr_stack+121, NULL, NULL, dvrr_stack+707);

 /* compute (2 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+32448, dvrr_stack+66491, dvrr_stack+58784, dvrr_stack+879, dvrr_stack+2698, dvrr_stack+30);

 /* compute (3 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+12304, dvrr_stack+66521, dvrr_stack+32448, dvrr_stack+479, dvrr_stack+66491, dvrr_stack+32136);

 /* compute (4 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+12404, dvrr_stack+66581, dvrr_stack+12304, dvrr_stack+58898, dvrr_stack+66521, dvrr_stack+32172);

 /* compute (5 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+19371, dvrr_stack+66681, dvrr_stack+12404, dvrr_stack+58958, dvrr_stack+66581, dvrr_stack+32232);

 /* compute (6 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+45347, dvrr_stack+66831, dvrr_stack+19371, dvrr_stack+59058, dvrr_stack+66681, dvrr_stack+32322);

 /* compute (1 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+58898, dvrr_stack+6127, dvrr_stack+5437, NULL, NULL, dvrr_stack+121);

 /* compute (2 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+58943, dvrr_stack+219, dvrr_stack+58898, dvrr_stack+2708, dvrr_stack+6127, dvrr_stack+58784);

 /* compute (3 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+29722, dvrr_stack+67041, dvrr_stack+58943, dvrr_stack+59208, dvrr_stack+219, dvrr_stack+32448);

 /* compute (4 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+44545, dvrr_stack+67131, dvrr_stack+29722, dvrr_stack+59253, dvrr_stack+67041, dvrr_stack+12304);

 /* compute (5 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+34533, dvrr_stack+67281, dvrr_stack+44545, dvrr_stack+59343, dvrr_stack+67131, dvrr_stack+12404);

 /* compute (6 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+31010, dvrr_stack+67506, dvrr_stack+34533, dvrr_stack+60713, dvrr_stack+67281, dvrr_stack+19371);

 /* compute (7 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+192997, dvrr_stack+57515, dvrr_stack+31010, dvrr_stack+60938, dvrr_stack+67506, dvrr_stack+45347);

 /* compute (1 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+59208, dvrr_stack+5452, dvrr_stack+10724, NULL, NULL, dvrr_stack+5437);

 /* compute (2 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+59271, dvrr_stack+889, dvrr_stack+59208, dvrr_stack+6142, dvrr_stack+5452, dvrr_stack+58898);

 /* compute (3 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+60522, dvrr_stack+952, dvrr_stack+59271, dvrr_stack+614, dvrr_stack+889, dvrr_stack+58943);

 /* compute (4 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+193537, dvrr_stack+57935, dvrr_stack+60522, dvrr_stack+1564, dvrr_stack+952, dvrr_stack+29722);

 /* compute (5 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+193852, dvrr_stack+58145, dvrr_stack+193537, dvrr_stack+31647, dvrr_stack+57935, dvrr_stack+44545);

 /* compute (6 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+194293, dvrr_stack+59493, dvrr_stack+193852, dvrr_stack+61253, dvrr_stack+58145, dvrr_stack+34533);

 /* compute (7 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+194881, dvrr_stack+59934, dvrr_stack+194293, dvrr_stack+61568, dvrr_stack+59493, dvrr_stack+31010);

 /* compute (8 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+195637, dvrr_stack+43519, dvrr_stack+194881, dvrr_stack+62009, dvrr_stack+59934, dvrr_stack+192997);

 /* compute (1 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+61253, dvrr_stack+10745, dvrr_stack+19298, NULL, NULL, dvrr_stack+10724);

 /* compute (2 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+61337, dvrr_stack+2723, dvrr_stack+61253, dvrr_stack+5473, dvrr_stack+10745, dvrr_stack+59208);

 /* compute (3 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+61505, dvrr_stack+2807, dvrr_stack+61337, dvrr_stack+45677, dvrr_stack+2723, dvrr_stack+59271);

 /* compute (4 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+31430, dvrr_stack+2975, dvrr_stack+61505, dvrr_stack+45761, dvrr_stack+2807, dvrr_stack+60522);

 /* compute (5 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+196582, dvrr_stack+20638, dvrr_stack+31430, dvrr_stack+1690, dvrr_stack+2975, dvrr_stack+193537);

 /* compute (6 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+197170, dvrr_stack+30422, dvrr_stack+196582, dvrr_stack+45929, dvrr_stack+20638, dvrr_stack+193852);

 /* compute (7 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+197954, dvrr_stack+129709, dvrr_stack+197170, dvrr_stack+21133, dvrr_stack+30422, dvrr_stack+194293);

 /* compute (8 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+198962, dvrr_stack+130493, dvrr_stack+197954, dvrr_stack+75617, dvrr_stack+129709, dvrr_stack+194881);

 /* compute (9 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+200222, dvrr_stack+7013, dvrr_stack+198962, dvrr_stack+76401, dvrr_stack+130493, dvrr_stack+195637);
 tmp = dvrr_stack + 200222;
 target_ptr = Libderiv->dvrr_classes[9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+75617, dvrr_stack+4370, dvrr_stack+30022, NULL, NULL, dvrr_stack+19298);

 /* compute (2 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+75725, dvrr_stack+6163, dvrr_stack+75617, dvrr_stack+10773, dvrr_stack+4370, dvrr_stack+61253);

 /* compute (3 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+75941, dvrr_stack+58460, dvrr_stack+75725, dvrr_stack+46349, dvrr_stack+6163, dvrr_stack+61337);

 /* compute (4 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+45627, dvrr_stack+18883, dvrr_stack+75941, dvrr_stack+45131, dvrr_stack+58460, dvrr_stack+61505);

 /* compute (5 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+201762, dvrr_stack+5501, dvrr_stack+45627, dvrr_stack+43159, dvrr_stack+18883, dvrr_stack+31430);

 /* compute (6 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+202518, dvrr_stack+10989, dvrr_stack+201762, dvrr_stack+6473, dvrr_stack+5501, dvrr_stack+196582);

 /* compute (7 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+203526, dvrr_stack+4406, dvrr_stack+202518, dvrr_stack+77409, dvrr_stack+10989, dvrr_stack+197170);

 /* compute (8 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+204822, dvrr_stack+131501, dvrr_stack+203526, dvrr_stack+78165, dvrr_stack+4406, dvrr_stack+197954);

 /* compute (9 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+206442, dvrr_stack+132797, dvrr_stack+204822, dvrr_stack+79173, dvrr_stack+131501, dvrr_stack+198962);
 tmp = dvrr_stack + 206442;
 target_ptr = Libderiv->dvrr_classes[9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+208422,dvrr_stack+206442,dvrr_stack+200222,55);


 /* compute (1 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+77409, dvrr_stack+30058, dvrr_stack+43048, NULL, NULL, dvrr_stack+30022);

 /* compute (2 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+77544, dvrr_stack+3255, dvrr_stack+77409, dvrr_stack+19326, dvrr_stack+30058, dvrr_stack+75617);

 /* compute (3 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+77814, dvrr_stack+44275, dvrr_stack+77544, dvrr_stack+46457, dvrr_stack+3255, dvrr_stack+75725);

 /* compute (4 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+78264, dvrr_stack+12656, dvrr_stack+77814, dvrr_stack+18118, dvrr_stack+44275, dvrr_stack+75941);

 /* compute (5 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+213042, dvrr_stack+13106, dvrr_stack+78264, dvrr_stack+32559, dvrr_stack+12656, dvrr_stack+45627);

 /* compute (6 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+213987, dvrr_stack+138197, dvrr_stack+213042, dvrr_stack+83493, dvrr_stack+13106, dvrr_stack+201762);

 /* compute (7 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+215247, dvrr_stack+139142, dvrr_stack+213987, dvrr_stack+84168, dvrr_stack+138197, dvrr_stack+202518);

 /* compute (8 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+216867, dvrr_stack+140402, dvrr_stack+215247, dvrr_stack+85113, dvrr_stack+139142, dvrr_stack+203526);

 /* compute (9 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+83493, dvrr_stack+21721, dvrr_stack+216867, dvrr_stack+86373, dvrr_stack+140402, dvrr_stack+204822);
 tmp = dvrr_stack + 83493;
 target_ptr = Libderiv->dvrr_classes[9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+218892,dvrr_stack+83493,dvrr_stack+206442,55);


 /* compute (1 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+85968, dvrr_stack+12051, dvrr_stack+42021, NULL, NULL, dvrr_stack+43048);

 /* compute (2 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6473, dvrr_stack+10809, dvrr_stack+85968, dvrr_stack+30103, dvrr_stack+12051, dvrr_stack+77409);

 /* compute (3 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21058, dvrr_stack+20141, dvrr_stack+6473, dvrr_stack+18388, dvrr_stack+10809, dvrr_stack+77544);

 /* compute (4 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+224832, dvrr_stack+146882, dvrr_stack+21058, dvrr_stack+18553, dvrr_stack+20141, dvrr_stack+77814);

 /* compute (5 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+225657, dvrr_stack+147432, dvrr_stack+224832, dvrr_stack+19591, dvrr_stack+146882, dvrr_stack+78264);

 /* compute (6 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+226812, dvrr_stack+148257, dvrr_stack+225657, dvrr_stack+91881, dvrr_stack+147432, dvrr_stack+213042);

 /* compute (7 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+228352, dvrr_stack+149412, dvrr_stack+226812, dvrr_stack+92706, dvrr_stack+148257, dvrr_stack+213987);

 /* compute (8 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+230332, dvrr_stack+150952, dvrr_stack+228352, dvrr_stack+93861, dvrr_stack+149412, dvrr_stack+215247);

 /* compute (9 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+91881, dvrr_stack+152932, dvrr_stack+230332, dvrr_stack+95401, dvrr_stack+150952, dvrr_stack+216867);
 tmp = dvrr_stack + 91881;
 target_ptr = Libderiv->dvrr_classes[9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+232807,dvrr_stack+91881,dvrr_stack+83493,55);


 /* compute (1 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+94906, dvrr_stack+62597, dvrr_stack+30304, NULL, NULL, dvrr_stack+42021);

 /* compute (2 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18118, dvrr_stack+12106, dvrr_stack+94906, dvrr_stack+43093, dvrr_stack+62597, dvrr_stack+85968);

 /* compute (3 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+240232, dvrr_stack+33009, dvrr_stack+18118, dvrr_stack+6275, dvrr_stack+12106, dvrr_stack+6473);

 /* compute (4 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+240892, dvrr_stack+33405, dvrr_stack+240232, dvrr_stack+41477, dvrr_stack+33009, dvrr_stack+21058);

 /* compute (5 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+241882, dvrr_stack+161482, dvrr_stack+240892, dvrr_stack+29062, dvrr_stack+33405, dvrr_stack+224832);

 /* compute (6 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+243268, dvrr_stack+162472, dvrr_stack+241882, dvrr_stack+102241, dvrr_stack+161482, dvrr_stack+225657);

 /* compute (7 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+245116, dvrr_stack+163858, dvrr_stack+243268, dvrr_stack+103231, dvrr_stack+162472, dvrr_stack+226812);

 /* compute (8 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+247492, dvrr_stack+165706, dvrr_stack+245116, dvrr_stack+104617, dvrr_stack+163858, dvrr_stack+228352);

 /* compute (9 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+102241, dvrr_stack+46592, dvrr_stack+247492, dvrr_stack+106465, dvrr_stack+165706, dvrr_stack+230332);
 tmp = dvrr_stack + 102241;
 target_ptr = Libderiv->dvrr_classes[9][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+250462,dvrr_stack+102241,dvrr_stack+91881,55);


 /* compute (0 0 | 1 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+105871, Data->F+19, Data->F+20, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+213, dvrr_stack+0, dvrr_stack+105871, Data->F+18, Data->F+19, NULL);

 /* compute (0 0 | 3 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+879, dvrr_stack+30158, dvrr_stack+213, dvrr_stack+41873, dvrr_stack+0, NULL);

 /* compute (0 0 | 4 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2708, dvrr_stack+30164, dvrr_stack+879, dvrr_stack+15, dvrr_stack+30158, NULL);

 /* compute (0 0 | 5 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+6142, dvrr_stack+10974, dvrr_stack+2708, dvrr_stack+111, dvrr_stack+30164, NULL);

 /* compute (0 0 | 6 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+5473, dvrr_stack+30174, dvrr_stack+6142, dvrr_stack+41876, dvrr_stack+10974, NULL);

 /* compute (0 0 | 7 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10773, dvrr_stack+30195, dvrr_stack+5473, dvrr_stack+41891, dvrr_stack+30174, NULL);

 /* compute (0 0 | 8 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19326, dvrr_stack+30223, dvrr_stack+10773, dvrr_stack+41912, dvrr_stack+30195, NULL);

 /* compute (0 0 | 9 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+30103, dvrr_stack+30259, dvrr_stack+19326, dvrr_stack+41940, dvrr_stack+30223, NULL);

 /* compute (0 0 | 10 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+105874, dvrr_stack+264, dvrr_stack+30103, dvrr_stack+41976, dvrr_stack+30259, NULL);

 /* compute (0 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+105940, dvrr_stack+30304, dvrr_stack+105874, dvrr_stack+42021, dvrr_stack+264, NULL);

 /* compute (1 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+78939, dvrr_stack+45053, dvrr_stack+105940, NULL, NULL, dvrr_stack+30304);

 /* compute (2 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+29062, dvrr_stack+31857, dvrr_stack+78939, dvrr_stack+42076, dvrr_stack+45053, dvrr_stack+94906);

 /* compute (3 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+259537, dvrr_stack+34065, dvrr_stack+29062, dvrr_stack+42154, dvrr_stack+31857, dvrr_stack+18118);

 /* compute (4 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+260317, dvrr_stack+175507, dvrr_stack+259537, dvrr_stack+42388, dvrr_stack+34065, dvrr_stack+240232);

 /* compute (5 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+261487, dvrr_stack+176287, dvrr_stack+260317, dvrr_stack+9898, dvrr_stack+175507, dvrr_stack+240892);

 /* compute (6 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+263125, dvrr_stack+177457, dvrr_stack+261487, dvrr_stack+114781, dvrr_stack+176287, dvrr_stack+241882);

 /* compute (7 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+265309, dvrr_stack+179095, dvrr_stack+263125, dvrr_stack+115951, dvrr_stack+177457, dvrr_stack+243268);

 /* compute (8 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+268117, dvrr_stack+181279, dvrr_stack+265309, dvrr_stack+117589, dvrr_stack+179095, dvrr_stack+245116);

 /* compute (9 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+114781, dvrr_stack+62663, dvrr_stack+268117, dvrr_stack+119773, dvrr_stack+181279, dvrr_stack+247492);

 /* compute (9 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+271627,dvrr_stack+114781,dvrr_stack+102241,55);


 /* compute (1 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+119071, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+15, dvrr_stack+66173, dvrr_stack+119071, Data->F+8, Data->F+9, NULL);

 /* compute (3 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+111, dvrr_stack+66176, dvrr_stack+15, dvrr_stack+66251, dvrr_stack+66173, NULL);

 /* compute (4 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+119074, dvrr_stack+66182, dvrr_stack+111, dvrr_stack+66254, dvrr_stack+66176, NULL);

 /* compute (1 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+48, dvrr_stack+161, dvrr_stack+704, NULL, NULL, Data->F+10);

 /* compute (2 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+119089, dvrr_stack+66192, dvrr_stack+48, dvrr_stack+210, dvrr_stack+161, dvrr_stack+119071);

 /* compute (3 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+119107, dvrr_stack+66201, dvrr_stack+119089, dvrr_stack+66260, dvrr_stack+66192, dvrr_stack+15);

 /* compute (4 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+119137, dvrr_stack+66219, dvrr_stack+119107, dvrr_stack+66269, dvrr_stack+66201, dvrr_stack+111);

 /* compute (5 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+119182, dvrr_stack+32091, dvrr_stack+119137, dvrr_stack+131, dvrr_stack+66219, dvrr_stack+119074);

 /* compute (1 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+66260, dvrr_stack+707, dvrr_stack+6121, NULL, NULL, dvrr_stack+704);

 /* compute (2 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+119245, dvrr_stack+30, dvrr_stack+66260, dvrr_stack+873, dvrr_stack+707, dvrr_stack+48);

 /* compute (3 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+119281, dvrr_stack+32136, dvrr_stack+119245, dvrr_stack+66287, dvrr_stack+30, dvrr_stack+119089);

 /* compute (4 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+614, dvrr_stack+32172, dvrr_stack+119281, dvrr_stack+66305, dvrr_stack+32136, dvrr_stack+119107);

 /* compute (5 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+119341, dvrr_stack+32232, dvrr_stack+614, dvrr_stack+66341, dvrr_stack+32172, dvrr_stack+119137);

 /* compute (6 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+119467, dvrr_stack+32322, dvrr_stack+119341, dvrr_stack+66401, dvrr_stack+32232, dvrr_stack+119182);

 /* compute (1 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+66278, dvrr_stack+121, dvrr_stack+5427, NULL, NULL, dvrr_stack+6121);

 /* compute (2 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+66308, dvrr_stack+58784, dvrr_stack+66278, dvrr_stack+2698, dvrr_stack+121, dvrr_stack+66260);

 /* compute (3 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+76301, dvrr_stack+32448, dvrr_stack+66308, dvrr_stack+66491, dvrr_stack+58784, dvrr_stack+119245);

 /* compute (4 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+9898, dvrr_stack+12304, dvrr_stack+76301, dvrr_stack+66521, dvrr_stack+32448, dvrr_stack+119281);

 /* compute (5 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+6803, dvrr_stack+12404, dvrr_stack+9898, dvrr_stack+66581, dvrr_stack+12304, dvrr_stack+614);

 /* compute (6 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+10048, dvrr_stack+19371, dvrr_stack+6803, dvrr_stack+66681, dvrr_stack+12404, dvrr_stack+119341);

 /* compute (7 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+10328, dvrr_stack+45347, dvrr_stack+10048, dvrr_stack+66831, dvrr_stack+19371, dvrr_stack+119467);

 /* compute (1 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+66491, dvrr_stack+5437, dvrr_stack+10709, NULL, NULL, dvrr_stack+5427);

 /* compute (2 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+66536, dvrr_stack+58898, dvrr_stack+66491, dvrr_stack+6127, dvrr_stack+5437, dvrr_stack+66278);

 /* compute (3 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+66626, dvrr_stack+58943, dvrr_stack+66536, dvrr_stack+219, dvrr_stack+58898, dvrr_stack+66308);

 /* compute (4 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+42076, dvrr_stack+29722, dvrr_stack+66626, dvrr_stack+67041, dvrr_stack+58943, dvrr_stack+76301);

 /* compute (5 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+42301, dvrr_stack+44545, dvrr_stack+42076, dvrr_stack+67131, dvrr_stack+29722, dvrr_stack+9898);

 /* compute (6 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+106018, dvrr_stack+34533, dvrr_stack+42301, dvrr_stack+67281, dvrr_stack+44545, dvrr_stack+6803);

 /* compute (7 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+19581, dvrr_stack+31010, dvrr_stack+106018, dvrr_stack+67506, dvrr_stack+34533, dvrr_stack+10048);

 /* compute (8 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+67041, dvrr_stack+192997, dvrr_stack+19581, dvrr_stack+57515, dvrr_stack+31010, dvrr_stack+10328);

 /* compute (1 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+67716, dvrr_stack+10724, dvrr_stack+19277, NULL, NULL, dvrr_stack+10709);

 /* compute (2 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+119635, dvrr_stack+59208, dvrr_stack+67716, dvrr_stack+5452, dvrr_stack+10724, dvrr_stack+66491);

 /* compute (3 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+42616, dvrr_stack+59271, dvrr_stack+119635, dvrr_stack+889, dvrr_stack+59208, dvrr_stack+66536);

 /* compute (4 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+41477, dvrr_stack+60522, dvrr_stack+42616, dvrr_stack+952, dvrr_stack+59271, dvrr_stack+66626);

 /* compute (5 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+32508, dvrr_stack+193537, dvrr_stack+41477, dvrr_stack+57935, dvrr_stack+60522, dvrr_stack+42076);

 /* compute (6 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+282517, dvrr_stack+193852, dvrr_stack+32508, dvrr_stack+58145, dvrr_stack+193537, dvrr_stack+42301);

 /* compute (7 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+283105, dvrr_stack+194293, dvrr_stack+282517, dvrr_stack+59493, dvrr_stack+193852, dvrr_stack+106018);

 /* compute (8 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+283861, dvrr_stack+194881, dvrr_stack+283105, dvrr_stack+59934, dvrr_stack+194293, dvrr_stack+19581);

 /* compute (9 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+284806, dvrr_stack+195637, dvrr_stack+283861, dvrr_stack+43519, dvrr_stack+194881, dvrr_stack+67041);

 /* compute (1 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+57935, dvrr_stack+19298, dvrr_stack+29994, NULL, NULL, dvrr_stack+19277);

 /* compute (2 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+58019, dvrr_stack+61253, dvrr_stack+57935, dvrr_stack+10745, dvrr_stack+19298, dvrr_stack+67716);

 /* compute (3 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+889, dvrr_stack+61337, dvrr_stack+58019, dvrr_stack+2723, dvrr_stack+61253, dvrr_stack+119635);

 /* compute (4 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+43093, dvrr_stack+61505, dvrr_stack+889, dvrr_stack+2807, dvrr_stack+61337, dvrr_stack+42616);

 /* compute (5 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+59397, dvrr_stack+31430, dvrr_stack+43093, dvrr_stack+2975, dvrr_stack+61505, dvrr_stack+41477);

 /* compute (6 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+285961, dvrr_stack+196582, dvrr_stack+59397, dvrr_stack+20638, dvrr_stack+31430, dvrr_stack+32508);

 /* compute (7 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+286745, dvrr_stack+197170, dvrr_stack+285961, dvrr_stack+30422, dvrr_stack+196582, dvrr_stack+282517);

 /* compute (8 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+287753, dvrr_stack+197954, dvrr_stack+286745, dvrr_stack+129709, dvrr_stack+197170, dvrr_stack+283105);

 /* compute (9 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+289013, dvrr_stack+198962, dvrr_stack+287753, dvrr_stack+130493, dvrr_stack+197954, dvrr_stack+283861);

 /* compute (10 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+290553, dvrr_stack+200222, dvrr_stack+289013, dvrr_stack+7013, dvrr_stack+198962, dvrr_stack+284806);
 tmp = dvrr_stack + 290553;
 target_ptr = Libderiv->dvrr_classes[10][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+129709, dvrr_stack+30022, dvrr_stack+43012, NULL, NULL, dvrr_stack+29994);

 /* compute (2 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+45131, dvrr_stack+75617, dvrr_stack+129709, dvrr_stack+4370, dvrr_stack+30022, dvrr_stack+57935);

 /* compute (3 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+129817, dvrr_stack+75725, dvrr_stack+45131, dvrr_stack+6163, dvrr_stack+75617, dvrr_stack+58019);

 /* compute (4 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+130177, dvrr_stack+75941, dvrr_stack+129817, dvrr_stack+58460, dvrr_stack+75725, dvrr_stack+889);

 /* compute (5 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+130717, dvrr_stack+45627, dvrr_stack+130177, dvrr_stack+18883, dvrr_stack+75941, dvrr_stack+43093);

 /* compute (6 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+292401, dvrr_stack+201762, dvrr_stack+130717, dvrr_stack+5501, dvrr_stack+45627, dvrr_stack+59397);

 /* compute (7 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+293409, dvrr_stack+202518, dvrr_stack+292401, dvrr_stack+10989, dvrr_stack+201762, dvrr_stack+285961);

 /* compute (8 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+294705, dvrr_stack+203526, dvrr_stack+293409, dvrr_stack+4406, dvrr_stack+202518, dvrr_stack+286745);

 /* compute (9 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+296325, dvrr_stack+204822, dvrr_stack+294705, dvrr_stack+131501, dvrr_stack+203526, dvrr_stack+287753);

 /* compute (10 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+298305, dvrr_stack+206442, dvrr_stack+296325, dvrr_stack+132797, dvrr_stack+204822, dvrr_stack+289013);
 tmp = dvrr_stack + 298305;
 target_ptr = Libderiv->dvrr_classes[10][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+300681,dvrr_stack+298305,dvrr_stack+290553,66);


 /* compute (1 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+10989, dvrr_stack+43048, dvrr_stack+41976, NULL, NULL, dvrr_stack+43012);

 /* compute (2 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11124, dvrr_stack+77409, dvrr_stack+10989, dvrr_stack+30058, dvrr_stack+43048, dvrr_stack+129709);

 /* compute (3 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11394, dvrr_stack+77544, dvrr_stack+11124, dvrr_stack+3255, dvrr_stack+77409, dvrr_stack+45131);

 /* compute (4 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+131473, dvrr_stack+77814, dvrr_stack+11394, dvrr_stack+44275, dvrr_stack+77544, dvrr_stack+129817);

 /* compute (5 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4214, dvrr_stack+78264, dvrr_stack+131473, dvrr_stack+12656, dvrr_stack+77814, dvrr_stack+130177);

 /* compute (6 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+306225, dvrr_stack+213042, dvrr_stack+4214, dvrr_stack+13106, dvrr_stack+78264, dvrr_stack+130717);

 /* compute (7 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+307485, dvrr_stack+213987, dvrr_stack+306225, dvrr_stack+138197, dvrr_stack+213042, dvrr_stack+292401);

 /* compute (8 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+309105, dvrr_stack+215247, dvrr_stack+307485, dvrr_stack+139142, dvrr_stack+213987, dvrr_stack+293409);

 /* compute (9 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+311130, dvrr_stack+216867, dvrr_stack+309105, dvrr_stack+140402, dvrr_stack+215247, dvrr_stack+294705);

 /* compute (10 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+138197, dvrr_stack+83493, dvrr_stack+311130, dvrr_stack+21721, dvrr_stack+216867, dvrr_stack+296325);
 tmp = dvrr_stack + 138197;
 target_ptr = Libderiv->dvrr_classes[10][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+313605,dvrr_stack+138197,dvrr_stack+298305,66);


 /* compute (1 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+141167, dvrr_stack+42021, dvrr_stack+264, NULL, NULL, dvrr_stack+41976);

 /* compute (2 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+141332, dvrr_stack+85968, dvrr_stack+141167, dvrr_stack+12051, dvrr_stack+42021, dvrr_stack+10989);

 /* compute (3 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+5501, dvrr_stack+6473, dvrr_stack+141332, dvrr_stack+10809, dvrr_stack+85968, dvrr_stack+11124);

 /* compute (4 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12554, dvrr_stack+21058, dvrr_stack+5501, dvrr_stack+20141, dvrr_stack+6473, dvrr_stack+11394);

 /* compute (5 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+320733, dvrr_stack+224832, dvrr_stack+12554, dvrr_stack+146882, dvrr_stack+21058, dvrr_stack+131473);

 /* compute (6 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+321888, dvrr_stack+225657, dvrr_stack+320733, dvrr_stack+147432, dvrr_stack+224832, dvrr_stack+4214);

 /* compute (7 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+323428, dvrr_stack+226812, dvrr_stack+321888, dvrr_stack+148257, dvrr_stack+225657, dvrr_stack+306225);

 /* compute (8 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+146882, dvrr_stack+228352, dvrr_stack+323428, dvrr_stack+149412, dvrr_stack+226812, dvrr_stack+307485);

 /* compute (9 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+325408, dvrr_stack+230332, dvrr_stack+146882, dvrr_stack+150952, dvrr_stack+228352, dvrr_stack+309105);

 /* compute (10 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+328433, dvrr_stack+91881, dvrr_stack+325408, dvrr_stack+152932, dvrr_stack+230332, dvrr_stack+311130);
 tmp = dvrr_stack + 328433;
 target_ptr = Libderiv->dvrr_classes[10][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+332063,dvrr_stack+328433,dvrr_stack+138197,66);


 /* compute (1 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+149357, dvrr_stack+30304, dvrr_stack+105874, NULL, NULL, dvrr_stack+264);

 /* compute (2 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+149555, dvrr_stack+94906, dvrr_stack+149357, dvrr_stack+62597, dvrr_stack+30304, dvrr_stack+141167);

 /* compute (3 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+149951, dvrr_stack+18118, dvrr_stack+149555, dvrr_stack+12106, dvrr_stack+94906, dvrr_stack+141332);

 /* compute (4 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+150611, dvrr_stack+240232, dvrr_stack+149951, dvrr_stack+33009, dvrr_stack+18118, dvrr_stack+5501);

 /* compute (5 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+340973, dvrr_stack+240892, dvrr_stack+150611, dvrr_stack+33405, dvrr_stack+240232, dvrr_stack+12554);

 /* compute (6 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+342359, dvrr_stack+241882, dvrr_stack+340973, dvrr_stack+161482, dvrr_stack+240892, dvrr_stack+320733);

 /* compute (7 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+344207, dvrr_stack+243268, dvrr_stack+342359, dvrr_stack+162472, dvrr_stack+241882, dvrr_stack+321888);

 /* compute (8 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+346583, dvrr_stack+245116, dvrr_stack+344207, dvrr_stack+163858, dvrr_stack+243268, dvrr_stack+323428);

 /* compute (9 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+161482, dvrr_stack+247492, dvrr_stack+346583, dvrr_stack+165706, dvrr_stack+245116, dvrr_stack+146882);

 /* compute (10 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+349553, dvrr_stack+102241, dvrr_stack+161482, dvrr_stack+46592, dvrr_stack+247492, dvrr_stack+325408);

 /* compute (10 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+353909,dvrr_stack+349553,dvrr_stack+328433,66);


 /* compute (0 0 | 1 0) m=20 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+210, Data->F+20, Data->F+21, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+873, dvrr_stack+105871, dvrr_stack+210, Data->F+19, Data->F+20, NULL);

 /* compute (0 0 | 3 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2698, dvrr_stack+213, dvrr_stack+873, dvrr_stack+0, dvrr_stack+105871, NULL);

 /* compute (0 0 | 4 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+6127, dvrr_stack+879, dvrr_stack+2698, dvrr_stack+30158, dvrr_stack+213, NULL);

 /* compute (0 0 | 5 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+5452, dvrr_stack+2708, dvrr_stack+6127, dvrr_stack+30164, dvrr_stack+879, NULL);

 /* compute (0 0 | 6 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+10745, dvrr_stack+6142, dvrr_stack+5452, dvrr_stack+10974, dvrr_stack+2708, NULL);

 /* compute (0 0 | 7 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2698, dvrr_stack+5473, dvrr_stack+10745, dvrr_stack+30174, dvrr_stack+6142, NULL);

 /* compute (0 0 | 8 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+30058, dvrr_stack+10773, dvrr_stack+2698, dvrr_stack+30195, dvrr_stack+5473, NULL);

 /* compute (0 0 | 9 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+66776, dvrr_stack+19326, dvrr_stack+30058, dvrr_stack+30223, dvrr_stack+10773, NULL);

 /* compute (0 0 | 10 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+62597, dvrr_stack+30103, dvrr_stack+66776, dvrr_stack+30259, dvrr_stack+19326, NULL);

 /* compute (0 0 | 11 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+2698, dvrr_stack+105874, dvrr_stack+62597, dvrr_stack+264, dvrr_stack+30103, NULL);

 /* compute (1 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+2776, dvrr_stack+105940, dvrr_stack+2698, NULL, NULL, dvrr_stack+105874);

 /* compute (2 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+165112, dvrr_stack+78939, dvrr_stack+2776, dvrr_stack+45053, dvrr_stack+105940, dvrr_stack+149357);

 /* compute (3 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+165580, dvrr_stack+29062, dvrr_stack+165112, dvrr_stack+31857, dvrr_stack+78939, dvrr_stack+149555);

 /* compute (4 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+166360, dvrr_stack+259537, dvrr_stack+165580, dvrr_stack+34065, dvrr_stack+29062, dvrr_stack+149951);

 /* compute (5 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+364799, dvrr_stack+260317, dvrr_stack+166360, dvrr_stack+175507, dvrr_stack+259537, dvrr_stack+150611);

 /* compute (6 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+165112, dvrr_stack+261487, dvrr_stack+364799, dvrr_stack+176287, dvrr_stack+260317, dvrr_stack+340973);

 /* compute (7 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+364799, dvrr_stack+263125, dvrr_stack+165112, dvrr_stack+177457, dvrr_stack+261487, dvrr_stack+342359);

 /* compute (8 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+259537, dvrr_stack+265309, dvrr_stack+364799, dvrr_stack+179095, dvrr_stack+263125, dvrr_stack+344207);

 /* compute (9 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+175507, dvrr_stack+268117, dvrr_stack+259537, dvrr_stack+181279, dvrr_stack+265309, dvrr_stack+346583);

 /* compute (10 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+259537, dvrr_stack+114781, dvrr_stack+175507, dvrr_stack+62663, dvrr_stack+268117, dvrr_stack+161482);

 /* compute (10 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+364799,dvrr_stack+259537,dvrr_stack+349553,66);


 /* compute (1 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+105871, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+175507, dvrr_stack+21, dvrr_stack+3, NULL, NULL, Data->F+5);

 /* compute (2 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+175516, dvrr_stack+175507, dvrr_stack+6, dvrr_stack+21, dvrr_stack+3, dvrr_stack+105871);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+175534, dvrr_stack+164, dvrr_stack+24, NULL, NULL, dvrr_stack+21);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+175552, dvrr_stack+175534, dvrr_stack+57, dvrr_stack+164, dvrr_stack+24, dvrr_stack+175507);

 /* compute (3 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+175588, dvrr_stack+175552, dvrr_stack+75, dvrr_stack+175534, dvrr_stack+57, dvrr_stack+175516);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+175648, dvrr_stack+713, dvrr_stack+170, NULL, NULL, dvrr_stack+164);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+175678, dvrr_stack+175648, dvrr_stack+180, dvrr_stack+713, dvrr_stack+170, dvrr_stack+175534);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+175738, dvrr_stack+175678, dvrr_stack+319, dvrr_stack+175648, dvrr_stack+180, dvrr_stack+175552);

 /* compute (4 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+175838, dvrr_stack+175738, dvrr_stack+379, dvrr_stack+175678, dvrr_stack+319, dvrr_stack+175588);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+19326, dvrr_stack+578, dvrr_stack+723, NULL, NULL, dvrr_stack+713);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+164, dvrr_stack+19326, dvrr_stack+738, dvrr_stack+578, dvrr_stack+723, dvrr_stack+175648);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+175988, dvrr_stack+164, dvrr_stack+783, dvrr_stack+19326, dvrr_stack+738, dvrr_stack+175678);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+176138, dvrr_stack+175988, dvrr_stack+1189, dvrr_stack+164, dvrr_stack+783, dvrr_stack+175738);

 /* compute (5 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+176363, dvrr_stack+176138, dvrr_stack+1339, dvrr_stack+175988, dvrr_stack+1189, dvrr_stack+175838);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+175648, dvrr_stack+1997, dvrr_stack+593, NULL, NULL, dvrr_stack+578);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+713, dvrr_stack+175648, dvrr_stack+2299, dvrr_stack+1997, dvrr_stack+593, dvrr_stack+19326);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+176678, dvrr_stack+713, dvrr_stack+2362, dvrr_stack+175648, dvrr_stack+2299, dvrr_stack+164);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+176888, dvrr_stack+176678, dvrr_stack+2488, dvrr_stack+713, dvrr_stack+2362, dvrr_stack+175988);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+177203, dvrr_stack+176888, dvrr_stack+3458, dvrr_stack+176678, dvrr_stack+2488, dvrr_stack+176138);

 /* compute (6 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+177644, dvrr_stack+177203, dvrr_stack+3773, dvrr_stack+176888, dvrr_stack+3458, dvrr_stack+176363);

 /* compute (2 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+0, dvrr_stack+105871, dvrr_stack+58763, Data->F+5, Data->F+6, NULL);

 /* compute (3 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+176678, dvrr_stack+175516, dvrr_stack+58766, dvrr_stack+175507, dvrr_stack+6, dvrr_stack+0);

 /* compute (4 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+175648, dvrr_stack+175588, dvrr_stack+58838, dvrr_stack+175552, dvrr_stack+75, dvrr_stack+176678);

 /* compute (5 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+176708, dvrr_stack+175838, dvrr_stack+59058, dvrr_stack+175738, dvrr_stack+379, dvrr_stack+175648);

 /* compute (6 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+178232, dvrr_stack+176363, dvrr_stack+60938, dvrr_stack+176138, dvrr_stack+1339, dvrr_stack+176708);

 /* compute (7 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+178652, dvrr_stack+177644, dvrr_stack+62009, dvrr_stack+177203, dvrr_stack+3773, dvrr_stack+178232);

 /* compute (3 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+175738, dvrr_stack+0, dvrr_stack+66254, dvrr_stack+105871, dvrr_stack+58763, NULL);

 /* compute (4 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+19326, dvrr_stack+176678, dvrr_stack+131, dvrr_stack+175516, dvrr_stack+58766, dvrr_stack+175738);

 /* compute (5 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+176918, dvrr_stack+175648, dvrr_stack+66401, dvrr_stack+175588, dvrr_stack+58838, dvrr_stack+19326);

 /* compute (6 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+177044, dvrr_stack+176708, dvrr_stack+66831, dvrr_stack+175838, dvrr_stack+59058, dvrr_stack+176918);

 /* compute (7 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+175748, dvrr_stack+178232, dvrr_stack+57515, dvrr_stack+176363, dvrr_stack+60938, dvrr_stack+177044);

 /* compute (8 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+179408, dvrr_stack+178652, dvrr_stack+43519, dvrr_stack+177644, dvrr_stack+62009, dvrr_stack+175748);

 /* compute (4 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+176288, dvrr_stack+175738, dvrr_stack+66182, dvrr_stack+0, dvrr_stack+66254, NULL);

 /* compute (5 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+176303, dvrr_stack+19326, dvrr_stack+32091, dvrr_stack+176678, dvrr_stack+131, dvrr_stack+176288);

 /* compute (6 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+176366, dvrr_stack+176918, dvrr_stack+32322, dvrr_stack+175648, dvrr_stack+66401, dvrr_stack+176303);

 /* compute (7 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+141662, dvrr_stack+177044, dvrr_stack+45347, dvrr_stack+176708, dvrr_stack+66831, dvrr_stack+176366);

 /* compute (8 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+180353, dvrr_stack+175748, dvrr_stack+192997, dvrr_stack+178232, dvrr_stack+57515, dvrr_stack+141662);

 /* compute (9 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+181028, dvrr_stack+179408, dvrr_stack+195637, dvrr_stack+178652, dvrr_stack+43519, dvrr_stack+180353);

 /* compute (5 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+57515, dvrr_stack+176288, dvrr_stack+119074, dvrr_stack+175738, dvrr_stack+66182, NULL);

 /* compute (6 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+58814, dvrr_stack+176303, dvrr_stack+119182, dvrr_stack+19326, dvrr_stack+32091, dvrr_stack+57515);

 /* compute (7 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+57515, dvrr_stack+176366, dvrr_stack+119467, dvrr_stack+176918, dvrr_stack+32322, dvrr_stack+58814);

 /* compute (8 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+176288, dvrr_stack+141662, dvrr_stack+10328, dvrr_stack+177044, dvrr_stack+45347, dvrr_stack+57515);

 /* compute (9 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+176738, dvrr_stack+180353, dvrr_stack+67041, dvrr_stack+175748, dvrr_stack+192997, dvrr_stack+176288);

 /* compute (10 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+182183, dvrr_stack+181028, dvrr_stack+284806, dvrr_stack+179408, dvrr_stack+195637, dvrr_stack+176738);

 /* compute (1 0 | 0 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+105871, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+180353, dvrr_stack+119071, dvrr_stack+105871, Data->F+9, Data->F+10, NULL);

 /* compute (3 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+180359, dvrr_stack+15, dvrr_stack+180353, dvrr_stack+66173, dvrr_stack+119071, NULL);

 /* compute (4 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+0, dvrr_stack+111, dvrr_stack+180359, dvrr_stack+66176, dvrr_stack+15, NULL);

 /* compute (5 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h000(Data,dvrr_stack+180369, dvrr_stack+119074, dvrr_stack+0, dvrr_stack+66182, dvrr_stack+111, NULL);

 /* compute (1 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+15, dvrr_stack+704, dvrr_stack+6118, NULL, NULL, Data->F+11);

 /* compute (2 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+119071, dvrr_stack+48, dvrr_stack+15, dvrr_stack+161, dvrr_stack+704, dvrr_stack+105871);

 /* compute (3 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+180390, dvrr_stack+119089, dvrr_stack+119071, dvrr_stack+66192, dvrr_stack+48, dvrr_stack+180353);

 /* compute (4 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+19326, dvrr_stack+119107, dvrr_stack+180390, dvrr_stack+66201, dvrr_stack+119089, dvrr_stack+180359);

 /* compute (5 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+48, dvrr_stack+119137, dvrr_stack+19326, dvrr_stack+66219, dvrr_stack+119107, dvrr_stack+0);

 /* compute (6 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0p0(Data,dvrr_stack+58814, dvrr_stack+119182, dvrr_stack+48, dvrr_stack+32091, dvrr_stack+119137, dvrr_stack+180369);

 /* compute (1 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+119089, dvrr_stack+6121, dvrr_stack+5421, NULL, NULL, dvrr_stack+6118);

 /* compute (2 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+119107, dvrr_stack+66260, dvrr_stack+119089, dvrr_stack+707, dvrr_stack+6121, dvrr_stack+15);

 /* compute (3 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+119143, dvrr_stack+119245, dvrr_stack+119107, dvrr_stack+30, dvrr_stack+66260, dvrr_stack+119071);

 /* compute (4 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+704, dvrr_stack+119281, dvrr_stack+119143, dvrr_stack+32136, dvrr_stack+119245, dvrr_stack+180390);

 /* compute (5 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+180353, dvrr_stack+614, dvrr_stack+704, dvrr_stack+32172, dvrr_stack+119281, dvrr_stack+19326);

 /* compute (6 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+180479, dvrr_stack+119341, dvrr_stack+180353, dvrr_stack+32232, dvrr_stack+614, dvrr_stack+48);

 /* compute (7 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 2;
 vrr_build_xxxx(am,Data,dvrr_stack+180647, dvrr_stack+119467, dvrr_stack+180479, dvrr_stack+32322, dvrr_stack+119341, dvrr_stack+58814);

 /* compute (1 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+58814, dvrr_stack+5427, dvrr_stack+10699, NULL, NULL, dvrr_stack+5421);

 /* compute (2 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+0, dvrr_stack+66278, dvrr_stack+58814, dvrr_stack+121, dvrr_stack+5427, dvrr_stack+119089);

 /* compute (3 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+60, dvrr_stack+66308, dvrr_stack+0, dvrr_stack+58784, dvrr_stack+66278, dvrr_stack+119107);

 /* compute (4 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+119203, dvrr_stack+76301, dvrr_stack+60, dvrr_stack+32448, dvrr_stack+66308, dvrr_stack+119143);

 /* compute (5 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+119353, dvrr_stack+9898, dvrr_stack+119203, dvrr_stack+12304, dvrr_stack+76301, dvrr_stack+704);

 /* compute (6 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+66173, dvrr_stack+6803, dvrr_stack+119353, dvrr_stack+12404, dvrr_stack+9898, dvrr_stack+180353);

 /* compute (7 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+141662, dvrr_stack+10048, dvrr_stack+66173, dvrr_stack+19371, dvrr_stack+6803, dvrr_stack+180479);

 /* compute (8 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+175507, dvrr_stack+10328, dvrr_stack+141662, dvrr_stack+45347, dvrr_stack+10048, dvrr_stack+180647);

 /* compute (1 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+30058, dvrr_stack+10709, dvrr_stack+19262, NULL, NULL, dvrr_stack+10699);

 /* compute (2 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+45347, dvrr_stack+66491, dvrr_stack+30058, dvrr_stack+5437, dvrr_stack+10709, dvrr_stack+58814);

 /* compute (3 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+45437, dvrr_stack+66536, dvrr_stack+45347, dvrr_stack+58898, dvrr_stack+66491, dvrr_stack+0);

 /* compute (4 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+180353, dvrr_stack+66626, dvrr_stack+45437, dvrr_stack+58943, dvrr_stack+66536, dvrr_stack+60);

 /* compute (5 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+180578, dvrr_stack+42076, dvrr_stack+180353, dvrr_stack+29722, dvrr_stack+66626, dvrr_stack+119203);

 /* compute (6 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+57515, dvrr_stack+42301, dvrr_stack+180578, dvrr_stack+44545, dvrr_stack+42076, dvrr_stack+119353);

 /* compute (7 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+9898, dvrr_stack+106018, dvrr_stack+57515, dvrr_stack+34533, dvrr_stack+42301, dvrr_stack+66173);

 /* compute (8 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+66173, dvrr_stack+19581, dvrr_stack+9898, dvrr_stack+31010, dvrr_stack+106018, dvrr_stack+141662);

 /* compute (9 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+175957, dvrr_stack+67041, dvrr_stack+66173, dvrr_stack+192997, dvrr_stack+19581, dvrr_stack+175507);

 /* compute (1 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+175507, dvrr_stack+19277, dvrr_stack+29973, NULL, NULL, dvrr_stack+19262);

 /* compute (2 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+175570, dvrr_stack+67716, dvrr_stack+175507, dvrr_stack+10724, dvrr_stack+19277, dvrr_stack+30058);

 /* compute (3 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+6803, dvrr_stack+119635, dvrr_stack+175570, dvrr_stack+59208, dvrr_stack+67716, dvrr_stack+45347);

 /* compute (4 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+192997, dvrr_stack+42616, dvrr_stack+6803, dvrr_stack+59271, dvrr_stack+119635, dvrr_stack+45437);

 /* compute (5 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+66848, dvrr_stack+41477, dvrr_stack+192997, dvrr_stack+60522, dvrr_stack+42616, dvrr_stack+180353);

 /* compute (6 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+67289, dvrr_stack+32508, dvrr_stack+66848, dvrr_stack+193537, dvrr_stack+41477, dvrr_stack+180578);

 /* compute (7 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+42076, dvrr_stack+282517, dvrr_stack+67289, dvrr_stack+193852, dvrr_stack+32508, dvrr_stack+57515);

 /* compute (8 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+193312, dvrr_stack+283105, dvrr_stack+42076, dvrr_stack+194293, dvrr_stack+282517, dvrr_stack+9898);

 /* compute (9 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+19326, dvrr_stack+283861, dvrr_stack+193312, dvrr_stack+194881, dvrr_stack+283105, dvrr_stack+66173);

 /* compute (10 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+264685, dvrr_stack+284806, dvrr_stack+19326, dvrr_stack+195637, dvrr_stack+283861, dvrr_stack+175957);

 /* compute (1 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+66173, dvrr_stack+29994, dvrr_stack+42984, NULL, NULL, dvrr_stack+29973);

 /* compute (2 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+66257, dvrr_stack+57935, dvrr_stack+66173, dvrr_stack+19298, dvrr_stack+29994, dvrr_stack+175507);

 /* compute (3 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+45347, dvrr_stack+58019, dvrr_stack+66257, dvrr_stack+61253, dvrr_stack+57935, dvrr_stack+175570);

 /* compute (4 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+178232, dvrr_stack+889, dvrr_stack+45347, dvrr_stack+61337, dvrr_stack+58019, dvrr_stack+6803);

 /* compute (5 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+175507, dvrr_stack+43093, dvrr_stack+178232, dvrr_stack+61505, dvrr_stack+889, dvrr_stack+192997);

 /* compute (6 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+176095, dvrr_stack+59397, dvrr_stack+175507, dvrr_stack+31430, dvrr_stack+43093, dvrr_stack+66848);

 /* compute (7 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+43093, dvrr_stack+285961, dvrr_stack+176095, dvrr_stack+196582, dvrr_stack+59397, dvrr_stack+67289);

 /* compute (8 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+66425, dvrr_stack+286745, dvrr_stack+43093, dvrr_stack+197170, dvrr_stack+285961, dvrr_stack+42076);

 /* compute (9 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+282517, dvrr_stack+287753, dvrr_stack+66425, dvrr_stack+197954, dvrr_stack+286745, dvrr_stack+193312);

 /* compute (10 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+192997, dvrr_stack+289013, dvrr_stack+282517, dvrr_stack+198962, dvrr_stack+287753, dvrr_stack+19326);

 /* compute (11 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+194845, dvrr_stack+290553, dvrr_stack+192997, dvrr_stack+200222, dvrr_stack+289013, dvrr_stack+264685);

 /* compute (1 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+264685, dvrr_stack+43012, dvrr_stack+41940, NULL, NULL, dvrr_stack+42984);

 /* compute (2 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+264793, dvrr_stack+129709, dvrr_stack+264685, dvrr_stack+30022, dvrr_stack+43012, dvrr_stack+66173);

 /* compute (3 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+141662, dvrr_stack+45131, dvrr_stack+264793, dvrr_stack+75617, dvrr_stack+129709, dvrr_stack+66257);

 /* compute (4 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+265009, dvrr_stack+129817, dvrr_stack+141662, dvrr_stack+75725, dvrr_stack+45131, dvrr_stack+45347);

 /* compute (5 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+265549, dvrr_stack+130177, dvrr_stack+265009, dvrr_stack+75941, dvrr_stack+129817, dvrr_stack+178232);

 /* compute (6 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+266305, dvrr_stack+130717, dvrr_stack+265549, dvrr_stack+45627, dvrr_stack+130177, dvrr_stack+175507);

 /* compute (7 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+267313, dvrr_stack+292401, dvrr_stack+266305, dvrr_stack+201762, dvrr_stack+130717, dvrr_stack+176095);

 /* compute (8 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+175507, dvrr_stack+293409, dvrr_stack+267313, dvrr_stack+202518, dvrr_stack+292401, dvrr_stack+43093);

 /* compute (9 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+43093, dvrr_stack+294705, dvrr_stack+175507, dvrr_stack+203526, dvrr_stack+293409, dvrr_stack+66425);

 /* compute (10 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+201762, dvrr_stack+296325, dvrr_stack+43093, dvrr_stack+204822, dvrr_stack+294705, dvrr_stack+282517);

 /* compute (11 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+282517, dvrr_stack+298305, dvrr_stack+201762, dvrr_stack+206442, dvrr_stack+296325, dvrr_stack+192997);

 /* compute (1 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+192997, dvrr_stack+41976, dvrr_stack+30259, NULL, NULL, dvrr_stack+41940);

 /* compute (2 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+193132, dvrr_stack+10989, dvrr_stack+192997, dvrr_stack+43048, dvrr_stack+41976, dvrr_stack+264685);

 /* compute (3 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+193402, dvrr_stack+11124, dvrr_stack+193132, dvrr_stack+77409, dvrr_stack+10989, dvrr_stack+264793);

 /* compute (4 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+180353, dvrr_stack+11394, dvrr_stack+193402, dvrr_stack+77544, dvrr_stack+11124, dvrr_stack+141662);

 /* compute (5 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+193852, dvrr_stack+131473, dvrr_stack+180353, dvrr_stack+77814, dvrr_stack+11394, dvrr_stack+265009);

 /* compute (6 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+285325, dvrr_stack+4214, dvrr_stack+193852, dvrr_stack+78264, dvrr_stack+131473, dvrr_stack+265549);

 /* compute (7 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+264685, dvrr_stack+306225, dvrr_stack+285325, dvrr_stack+213042, dvrr_stack+4214, dvrr_stack+266305);

 /* compute (8 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+286585, dvrr_stack+307485, dvrr_stack+264685, dvrr_stack+213987, dvrr_stack+306225, dvrr_stack+267313);

 /* compute (9 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+266305, dvrr_stack+309105, dvrr_stack+286585, dvrr_stack+215247, dvrr_stack+307485, dvrr_stack+175507);

 /* compute (10 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+165112, dvrr_stack+311130, dvrr_stack+266305, dvrr_stack+216867, dvrr_stack+309105, dvrr_stack+43093);

 /* compute (11 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+306225, dvrr_stack+138197, dvrr_stack+165112, dvrr_stack+83493, dvrr_stack+311130, dvrr_stack+201762);

 /* compute (1 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+201762, dvrr_stack+264, dvrr_stack+30103, NULL, NULL, dvrr_stack+30259);

 /* compute (2 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+201927, dvrr_stack+141167, dvrr_stack+201762, dvrr_stack+42021, dvrr_stack+264, dvrr_stack+192997);

 /* compute (3 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+202257, dvrr_stack+141332, dvrr_stack+201927, dvrr_stack+85968, dvrr_stack+141167, dvrr_stack+193132);

 /* compute (4 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+202807, dvrr_stack+5501, dvrr_stack+202257, dvrr_stack+6473, dvrr_stack+141332, dvrr_stack+193402);

 /* compute (5 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+203632, dvrr_stack+12554, dvrr_stack+202807, dvrr_stack+21058, dvrr_stack+5501, dvrr_stack+180353);

 /* compute (6 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+204787, dvrr_stack+320733, dvrr_stack+203632, dvrr_stack+224832, dvrr_stack+12554, dvrr_stack+193852);

 /* compute (7 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+175507, dvrr_stack+321888, dvrr_stack+204787, dvrr_stack+225657, dvrr_stack+320733, dvrr_stack+285325);

 /* compute (8 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+309735, dvrr_stack+323428, dvrr_stack+175507, dvrr_stack+226812, dvrr_stack+321888, dvrr_stack+264685);

 /* compute (9 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+224832, dvrr_stack+146882, dvrr_stack+309735, dvrr_stack+228352, dvrr_stack+323428, dvrr_stack+286585);

 /* compute (10 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+285325, dvrr_stack+325408, dvrr_stack+224832, dvrr_stack+230332, dvrr_stack+146882, dvrr_stack+266305);

 /* compute (11 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+264685, dvrr_stack+328433, dvrr_stack+285325, dvrr_stack+91881, dvrr_stack+325408, dvrr_stack+165112);

 /* compute (1 0 | 10 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+165112, dvrr_stack+105874, dvrr_stack+62597, NULL, NULL, dvrr_stack+30103);

 /* compute (2 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+165310, dvrr_stack+149357, dvrr_stack+165112, dvrr_stack+30304, dvrr_stack+105874, dvrr_stack+201762);

 /* compute (3 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+165706, dvrr_stack+149555, dvrr_stack+165310, dvrr_stack+94906, dvrr_stack+149357, dvrr_stack+201927);

 /* compute (4 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+166366, dvrr_stack+149951, dvrr_stack+165706, dvrr_stack+18118, dvrr_stack+149555, dvrr_stack+202257);

 /* compute (5 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18118, dvrr_stack+150611, dvrr_stack+166366, dvrr_stack+240232, dvrr_stack+149951, dvrr_stack+202807);

 /* compute (6 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+192997, dvrr_stack+340973, dvrr_stack+18118, dvrr_stack+240892, dvrr_stack+150611, dvrr_stack+203632);

 /* compute (7 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18118, dvrr_stack+342359, dvrr_stack+192997, dvrr_stack+241882, dvrr_stack+340973, dvrr_stack+204787);

 /* compute (8 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+165112, dvrr_stack+344207, dvrr_stack+18118, dvrr_stack+243268, dvrr_stack+342359, dvrr_stack+175507);

 /* compute (9 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+240232, dvrr_stack+346583, dvrr_stack+165112, dvrr_stack+245116, dvrr_stack+344207, dvrr_stack+309735);

 /* compute (10 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+340973, dvrr_stack+161482, dvrr_stack+240232, dvrr_stack+247492, dvrr_stack+346583, dvrr_stack+224832);

 /* compute (11 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 11;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+57515, dvrr_stack+349553, dvrr_stack+340973, dvrr_stack+102241, dvrr_stack+161482, dvrr_stack+285325);

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,784,dvrr_stack+75617, dvrr_stack+15766, NULL);
 tmp = dvrr_stack + 75617;
 target_ptr = Libderiv->deriv_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+285325, dvrr_stack+26038, NULL);
 tmp = dvrr_stack + 285325;
 target_ptr = Libderiv->deriv_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+286333, dvrr_stack+37697, NULL);
 tmp = dvrr_stack + 286333;
 target_ptr = Libderiv->deriv_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+287593, dvrr_stack+52895, NULL);
 tmp = dvrr_stack + 287593;
 target_ptr = Libderiv->deriv_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+192997, dvrr_stack+70073, NULL);
 tmp = dvrr_stack + 192997;
 target_ptr = Libderiv->deriv_classes[6][10][11];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+289133, dvrr_stack+80469, NULL);
 tmp = dvrr_stack + 289133;
 target_ptr = Libderiv->deriv_classes[7][6][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+161482, dvrr_stack+87993, NULL);
 tmp = dvrr_stack + 161482;
 target_ptr = Libderiv->deriv_classes[7][7][11];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+162778, dvrr_stack+97381, NULL);
 tmp = dvrr_stack + 162778;
 target_ptr = Libderiv->deriv_classes[7][8][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+164398, dvrr_stack+108841, NULL);
 tmp = dvrr_stack + 164398;
 target_ptr = Libderiv->deriv_classes[7][9][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+340973, dvrr_stack+122581, NULL);
 tmp = dvrr_stack + 340973;
 target_ptr = Libderiv->deriv_classes[7][10][11];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+166378, dvrr_stack+134417, NULL);
 tmp = dvrr_stack + 166378;
 target_ptr = Libderiv->deriv_classes[8][6][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+343349, dvrr_stack+142022, NULL);
 tmp = dvrr_stack + 343349;
 target_ptr = Libderiv->deriv_classes[8][7][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2025,dvrr_stack+344969, dvrr_stack+155407, NULL);
 tmp = dvrr_stack + 344969;
 target_ptr = Libderiv->deriv_classes[8][8][11];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+346994, dvrr_stack+168082, NULL);
 tmp = dvrr_stack + 346994;
 target_ptr = Libderiv->deriv_classes[8][9][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+224832, dvrr_stack+184087, NULL);
 tmp = dvrr_stack + 224832;
 target_ptr = Libderiv->deriv_classes[8][10][11];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+227802, dvrr_stack+208422, NULL);
 tmp = dvrr_stack + 227802;
 target_ptr = Libderiv->deriv_classes[9][6][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+229342, dvrr_stack+218892, NULL);
 tmp = dvrr_stack + 229342;
 target_ptr = Libderiv->deriv_classes[9][7][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+240232, dvrr_stack+232807, NULL);
 tmp = dvrr_stack + 240232;
 target_ptr = Libderiv->deriv_classes[9][8][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3025,dvrr_stack+242707, dvrr_stack+250462, NULL);
 tmp = dvrr_stack + 242707;
 target_ptr = Libderiv->deriv_classes[9][9][11];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+245732, dvrr_stack+271627, NULL);
 tmp = dvrr_stack + 245732;
 target_ptr = Libderiv->deriv_classes[9][10][11];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+309735, dvrr_stack+300681, NULL);
 tmp = dvrr_stack + 309735;
 target_ptr = Libderiv->deriv_classes[10][6][11];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+18118, dvrr_stack+313605, NULL);
 tmp = dvrr_stack + 18118;
 target_ptr = Libderiv->deriv_classes[10][7][11];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+201762, dvrr_stack+332063, NULL);
 tmp = dvrr_stack + 201762;
 target_ptr = Libderiv->deriv_classes[10][8][11];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+146882, dvrr_stack+353909, NULL);
 tmp = dvrr_stack + 146882;
 target_ptr = Libderiv->deriv_classes[10][9][11];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,4356,dvrr_stack+320733, dvrr_stack+364799, NULL);
 tmp = dvrr_stack + 320733;
 target_ptr = Libderiv->deriv_classes[10][10][11];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+231322, dvrr_stack+15766, NULL);
 tmp = dvrr_stack + 231322;
 target_ptr = Libderiv->deriv_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+249362, dvrr_stack+26038, NULL);
 tmp = dvrr_stack + 249362;
 target_ptr = Libderiv->deriv_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+311583, dvrr_stack+37697, NULL);
 tmp = dvrr_stack + 311583;
 target_ptr = Libderiv->deriv_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+175507, dvrr_stack+52895, NULL);
 tmp = dvrr_stack + 175507;
 target_ptr = Libderiv->deriv_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+150512, dvrr_stack+70073, NULL);
 tmp = dvrr_stack + 150512;
 target_ptr = Libderiv->deriv_classes[6][10][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+20494, dvrr_stack+80469, NULL);
 tmp = dvrr_stack + 20494;
 target_ptr = Libderiv->deriv_classes[7][6][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+204732, dvrr_stack+87993, NULL);
 tmp = dvrr_stack + 204732;
 target_ptr = Libderiv->deriv_classes[7][7][10];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+268975, dvrr_stack+97381, NULL);
 tmp = dvrr_stack + 268975;
 target_ptr = Libderiv->deriv_classes[7][8][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+325089, dvrr_stack+108841, NULL);
 tmp = dvrr_stack + 325089;
 target_ptr = Libderiv->deriv_classes[7][9][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+213042, dvrr_stack+122581, NULL);
 tmp = dvrr_stack + 213042;
 target_ptr = Libderiv->deriv_classes[7][10][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+327069, dvrr_stack+134417, NULL);
 tmp = dvrr_stack + 327069;
 target_ptr = Libderiv->deriv_classes[8][6][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+215418, dvrr_stack+142022, NULL);
 tmp = dvrr_stack + 215418;
 target_ptr = Libderiv->deriv_classes[8][7][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2025,dvrr_stack+292401, dvrr_stack+155407, NULL);
 tmp = dvrr_stack + 292401;
 target_ptr = Libderiv->deriv_classes[8][8][10];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+294426, dvrr_stack+168082, NULL);
 tmp = dvrr_stack + 294426;
 target_ptr = Libderiv->deriv_classes[8][9][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+129709, dvrr_stack+184087, NULL);
 tmp = dvrr_stack + 129709;
 target_ptr = Libderiv->deriv_classes[8][10][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+217038, dvrr_stack+208422, NULL);
 tmp = dvrr_stack + 217038;
 target_ptr = Libderiv->deriv_classes[9][6][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+197029, dvrr_stack+218892, NULL);
 tmp = dvrr_stack + 197029;
 target_ptr = Libderiv->deriv_classes[9][7][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+9898, dvrr_stack+232807, NULL);
 tmp = dvrr_stack + 9898;
 target_ptr = Libderiv->deriv_classes[9][8][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3025,dvrr_stack+41477, dvrr_stack+250462, NULL);
 tmp = dvrr_stack + 41477;
 target_ptr = Libderiv->deriv_classes[9][9][10];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+0, dvrr_stack+271627, NULL);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv_classes[9][10][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+44502, dvrr_stack+300681, NULL);
 tmp = dvrr_stack + 44502;
 target_ptr = Libderiv->deriv_classes[10][6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+3630, dvrr_stack+313605, NULL);
 tmp = dvrr_stack + 3630;
 target_ptr = Libderiv->deriv_classes[10][7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+29062, dvrr_stack+332063, NULL);
 tmp = dvrr_stack + 29062;
 target_ptr = Libderiv->deriv_classes[10][8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+377867, dvrr_stack+353909, NULL);
 tmp = dvrr_stack + 377867;
 target_ptr = Libderiv->deriv_classes[10][9][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,4356,dvrr_stack+381497, dvrr_stack+364799, NULL);
 tmp = dvrr_stack + 381497;
 target_ptr = Libderiv->deriv_classes[10][10][10];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+270595, dvrr_stack+15766, NULL);
 tmp = dvrr_stack + 270595;
 target_ptr = Libderiv->deriv_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+15766, dvrr_stack+26038, NULL);
 tmp = dvrr_stack + 15766;
 target_ptr = Libderiv->deriv_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+26038, dvrr_stack+37697, NULL);
 tmp = dvrr_stack + 26038;
 target_ptr = Libderiv->deriv_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+37697, dvrr_stack+52895, NULL);
 tmp = dvrr_stack + 37697;
 target_ptr = Libderiv->deriv_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+52895, dvrr_stack+70073, NULL);
 tmp = dvrr_stack + 52895;
 target_ptr = Libderiv->deriv_classes[6][10][9];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+70073, dvrr_stack+80469, NULL);
 tmp = dvrr_stack + 70073;
 target_ptr = Libderiv->deriv_classes[7][6][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+80469, dvrr_stack+87993, NULL);
 tmp = dvrr_stack + 80469;
 target_ptr = Libderiv->deriv_classes[7][7][9];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+87993, dvrr_stack+97381, NULL);
 tmp = dvrr_stack + 87993;
 target_ptr = Libderiv->deriv_classes[7][8][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+97381, dvrr_stack+108841, NULL);
 tmp = dvrr_stack + 97381;
 target_ptr = Libderiv->deriv_classes[7][9][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+108841, dvrr_stack+122581, NULL);
 tmp = dvrr_stack + 108841;
 target_ptr = Libderiv->deriv_classes[7][10][9];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+122581, dvrr_stack+134417, NULL);
 tmp = dvrr_stack + 122581;
 target_ptr = Libderiv->deriv_classes[8][6][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+134417, dvrr_stack+142022, NULL);
 tmp = dvrr_stack + 134417;
 target_ptr = Libderiv->deriv_classes[8][7][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+136037, dvrr_stack+155407, NULL);
 tmp = dvrr_stack + 136037;
 target_ptr = Libderiv->deriv_classes[8][8][9];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+155407, dvrr_stack+168082, NULL);
 tmp = dvrr_stack + 155407;
 target_ptr = Libderiv->deriv_classes[8][9][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+32032, dvrr_stack+184087, NULL);
 tmp = dvrr_stack + 32032;
 target_ptr = Libderiv->deriv_classes[8][10][9];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+157882, dvrr_stack+208422, NULL);
 tmp = dvrr_stack + 157882;
 target_ptr = Libderiv->deriv_classes[9][6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+208422, dvrr_stack+218892, NULL);
 tmp = dvrr_stack + 208422;
 target_ptr = Libderiv->deriv_classes[9][7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+210402, dvrr_stack+232807, NULL);
 tmp = dvrr_stack + 210402;
 target_ptr = Libderiv->deriv_classes[9][8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3025,dvrr_stack+123841, dvrr_stack+250462, NULL);
 tmp = dvrr_stack + 123841;
 target_ptr = Libderiv->deriv_classes[9][9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+71081, dvrr_stack+271627, NULL);
 tmp = dvrr_stack + 71081;
 target_ptr = Libderiv->deriv_classes[9][10][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+159422, dvrr_stack+300681, NULL);
 tmp = dvrr_stack + 159422;
 target_ptr = Libderiv->deriv_classes[10][6][9];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+300681, dvrr_stack+313605, NULL);
 tmp = dvrr_stack + 300681;
 target_ptr = Libderiv->deriv_classes[10][7][9];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+303057, dvrr_stack+332063, NULL);
 tmp = dvrr_stack + 303057;
 target_ptr = Libderiv->deriv_classes[10][8][9];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+332063, dvrr_stack+353909, NULL);
 tmp = dvrr_stack + 332063;
 target_ptr = Libderiv->deriv_classes[10][9][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,4356,dvrr_stack+353909, dvrr_stack+364799, NULL);
 tmp = dvrr_stack + 353909;
 target_ptr = Libderiv->deriv_classes[10][10][9];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+358265, dvrr_stack+14758, dvrr_stack+177644);
 tmp = dvrr_stack + 358265;
 target_ptr = Libderiv->deriv_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+359049, dvrr_stack+24778, dvrr_stack+9114);
 tmp = dvrr_stack + 359049;
 target_ptr = Libderiv->deriv_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+360057, dvrr_stack+36157, dvrr_stack+14758);
 tmp = dvrr_stack + 360057;
 target_ptr = Libderiv->deriv_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+361317, dvrr_stack+51047, dvrr_stack+24778);
 tmp = dvrr_stack + 361317;
 target_ptr = Libderiv->deriv_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+362857, dvrr_stack+67889, dvrr_stack+36157);
 tmp = dvrr_stack + 362857;
 target_ptr = Libderiv->deriv_classes[6][10][8];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+364705, dvrr_stack+79173, dvrr_stack+178652);
 tmp = dvrr_stack + 364705;
 target_ptr = Libderiv->deriv_classes[7][6][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+365713, dvrr_stack+86373, dvrr_stack+76401);
 tmp = dvrr_stack + 365713;
 target_ptr = Libderiv->deriv_classes[7][7][8];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+367009, dvrr_stack+95401, dvrr_stack+79173);
 tmp = dvrr_stack + 367009;
 target_ptr = Libderiv->deriv_classes[7][8][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+368629, dvrr_stack+106465, dvrr_stack+86373);
 tmp = dvrr_stack + 368629;
 target_ptr = Libderiv->deriv_classes[7][9][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+370609, dvrr_stack+119773, dvrr_stack+95401);
 tmp = dvrr_stack + 370609;
 target_ptr = Libderiv->deriv_classes[7][10][8];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+372985, dvrr_stack+132797, dvrr_stack+179408);
 tmp = dvrr_stack + 372985;
 target_ptr = Libderiv->deriv_classes[8][6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+374245, dvrr_stack+21721, dvrr_stack+7013);
 tmp = dvrr_stack + 374245;
 target_ptr = Libderiv->deriv_classes[8][7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+335693, dvrr_stack+152932, dvrr_stack+132797);
 tmp = dvrr_stack + 335693;
 target_ptr = Libderiv->deriv_classes[8][8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+337718, dvrr_stack+46592, dvrr_stack+21721);
 tmp = dvrr_stack + 337718;
 target_ptr = Libderiv->deriv_classes[8][9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,45,1,dvrr_stack+111217, dvrr_stack+62663, dvrr_stack+152932);
 tmp = dvrr_stack + 111217;
 target_ptr = Libderiv->deriv_classes[8][10][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+375865, dvrr_stack+206442, dvrr_stack+181028);
 tmp = dvrr_stack + 375865;
 target_ptr = Libderiv->deriv_classes[9][6][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+126866, dvrr_stack+83493, dvrr_stack+200222);
 tmp = dvrr_stack + 126866;
 target_ptr = Libderiv->deriv_classes[9][7][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+99361, dvrr_stack+91881, dvrr_stack+206442);
 tmp = dvrr_stack + 99361;
 target_ptr = Libderiv->deriv_classes[9][8][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+167638, dvrr_stack+102241, dvrr_stack+83493);
 tmp = dvrr_stack + 167638;
 target_ptr = Libderiv->deriv_classes[9][9][8];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,55,1,dvrr_stack+170663, dvrr_stack+114781, dvrr_stack+91881);
 tmp = dvrr_stack + 170663;
 target_ptr = Libderiv->deriv_classes[9][10][8];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,66,1,dvrr_stack+89613, dvrr_stack+298305, dvrr_stack+182183);
 tmp = dvrr_stack + 89613;
 target_ptr = Libderiv->deriv_classes[10][6][8];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,66,1,dvrr_stack+54743, dvrr_stack+138197, dvrr_stack+290553);
 tmp = dvrr_stack + 54743;
 target_ptr = Libderiv->deriv_classes[10][7][8];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,66,1,dvrr_stack+232106, dvrr_stack+328433, dvrr_stack+298305);
 tmp = dvrr_stack + 232106;
 target_ptr = Libderiv->deriv_classes[10][8][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,66,1,dvrr_stack+235076, dvrr_stack+349553, dvrr_stack+138197);
 tmp = dvrr_stack + 235076;
 target_ptr = Libderiv->deriv_classes[10][9][8];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,66,1,dvrr_stack+250370, dvrr_stack+259537, dvrr_stack+328433);
 tmp = dvrr_stack + 250370;
 target_ptr = Libderiv->deriv_classes[10][10][8];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+128846, dvrr_stack+14758, dvrr_stack+177644);
 tmp = dvrr_stack + 128846;
 target_ptr = Libderiv->deriv_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+81765, dvrr_stack+24778, dvrr_stack+9114);
 tmp = dvrr_stack + 81765;
 target_ptr = Libderiv->deriv_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+39237, dvrr_stack+36157, dvrr_stack+14758);
 tmp = dvrr_stack + 39237;
 target_ptr = Libderiv->deriv_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+27298, dvrr_stack+51047, dvrr_stack+24778);
 tmp = dvrr_stack + 27298;
 target_ptr = Libderiv->deriv_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+254726, dvrr_stack+67889, dvrr_stack+36157);
 tmp = dvrr_stack + 254726;
 target_ptr = Libderiv->deriv_classes[6][10][7];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+16774, dvrr_stack+79173, dvrr_stack+178652);
 tmp = dvrr_stack + 16774;
 target_ptr = Libderiv->deriv_classes[7][6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+238706, dvrr_stack+86373, dvrr_stack+76401);
 tmp = dvrr_stack + 238706;
 target_ptr = Libderiv->deriv_classes[7][7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+256574, dvrr_stack+95401, dvrr_stack+79173);
 tmp = dvrr_stack + 256574;
 target_ptr = Libderiv->deriv_classes[7][8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+312843, dvrr_stack+106465, dvrr_stack+86373);
 tmp = dvrr_stack + 312843;
 target_ptr = Libderiv->deriv_classes[7][9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+314823, dvrr_stack+119773, dvrr_stack+95401);
 tmp = dvrr_stack + 314823;
 target_ptr = Libderiv->deriv_classes[7][10][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+258194, dvrr_stack+132797, dvrr_stack+179408);
 tmp = dvrr_stack + 258194;
 target_ptr = Libderiv->deriv_classes[8][6][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+317199, dvrr_stack+21721, dvrr_stack+7013);
 tmp = dvrr_stack + 317199;
 target_ptr = Libderiv->deriv_classes[8][7][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+271379, dvrr_stack+152932, dvrr_stack+132797);
 tmp = dvrr_stack + 271379;
 target_ptr = Libderiv->deriv_classes[8][8][7];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+273404, dvrr_stack+46592, dvrr_stack+21721);
 tmp = dvrr_stack + 273404;
 target_ptr = Libderiv->deriv_classes[8][9][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+275879, dvrr_stack+62663, dvrr_stack+152932);
 tmp = dvrr_stack + 275879;
 target_ptr = Libderiv->deriv_classes[8][10][7];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+318819, dvrr_stack+206442, dvrr_stack+181028);
 tmp = dvrr_stack + 318819;
 target_ptr = Libderiv->deriv_classes[9][6][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+278849, dvrr_stack+83493, dvrr_stack+200222);
 tmp = dvrr_stack + 278849;
 target_ptr = Libderiv->deriv_classes[9][7][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+141167, dvrr_stack+91881, dvrr_stack+206442);
 tmp = dvrr_stack + 141167;
 target_ptr = Libderiv->deriv_classes[9][8][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+143642, dvrr_stack+102241, dvrr_stack+83493);
 tmp = dvrr_stack + 143642;
 target_ptr = Libderiv->deriv_classes[9][9][7];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+218578, dvrr_stack+114781, dvrr_stack+91881);
 tmp = dvrr_stack + 218578;
 target_ptr = Libderiv->deriv_classes[9][10][7];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,66,1,dvrr_stack+222208, dvrr_stack+298305, dvrr_stack+182183);
 tmp = dvrr_stack + 222208;
 target_ptr = Libderiv->deriv_classes[10][6][7];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,66,1,dvrr_stack+183569, dvrr_stack+138197, dvrr_stack+290553);
 tmp = dvrr_stack + 183569;
 target_ptr = Libderiv->deriv_classes[10][7][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,66,1,dvrr_stack+185945, dvrr_stack+328433, dvrr_stack+298305);
 tmp = dvrr_stack + 185945;
 target_ptr = Libderiv->deriv_classes[10][8][7];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,66,1,dvrr_stack+188915, dvrr_stack+349553, dvrr_stack+138197);
 tmp = dvrr_stack + 188915;
 target_ptr = Libderiv->deriv_classes[10][9][7];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,66,1,dvrr_stack+385853, dvrr_stack+259537, dvrr_stack+328433);
 tmp = dvrr_stack + 385853;
 target_ptr = Libderiv->deriv_classes[10][10][7];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+74711, dvrr_stack+14758, dvrr_stack+177644);
 tmp = dvrr_stack + 74711;
 target_ptr = Libderiv->deriv_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+174293, dvrr_stack+24778, dvrr_stack+9114);
 tmp = dvrr_stack + 174293;
 target_ptr = Libderiv->deriv_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+177047, dvrr_stack+36157, dvrr_stack+14758);
 tmp = dvrr_stack + 177047;
 target_ptr = Libderiv->deriv_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+280829, dvrr_stack+51047, dvrr_stack+24778);
 tmp = dvrr_stack + 280829;
 target_ptr = Libderiv->deriv_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+390209, dvrr_stack+67889, dvrr_stack+36157);
 tmp = dvrr_stack + 390209;
 target_ptr = Libderiv->deriv_classes[6][10][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+77409, dvrr_stack+79173, dvrr_stack+178652);
 tmp = dvrr_stack + 77409;
 target_ptr = Libderiv->deriv_classes[7][6][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+296901, dvrr_stack+86373, dvrr_stack+76401);
 tmp = dvrr_stack + 296901;
 target_ptr = Libderiv->deriv_classes[7][7][6];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+66173, dvrr_stack+95401, dvrr_stack+79173);
 tmp = dvrr_stack + 66173;
 target_ptr = Libderiv->deriv_classes[7][8][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+67793, dvrr_stack+106465, dvrr_stack+86373);
 tmp = dvrr_stack + 67793;
 target_ptr = Libderiv->deriv_classes[7][9][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+392057, dvrr_stack+119773, dvrr_stack+95401);
 tmp = dvrr_stack + 392057;
 target_ptr = Libderiv->deriv_classes[7][10][6];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+12373, dvrr_stack+132797, dvrr_stack+179408);
 tmp = dvrr_stack + 12373;
 target_ptr = Libderiv->deriv_classes[8][6][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+178307, dvrr_stack+21721, dvrr_stack+7013);
 tmp = dvrr_stack + 178307;
 target_ptr = Libderiv->deriv_classes[8][7][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+119071, dvrr_stack+152932, dvrr_stack+132797);
 tmp = dvrr_stack + 119071;
 target_ptr = Libderiv->deriv_classes[8][8][6];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+394433, dvrr_stack+46592, dvrr_stack+21721);
 tmp = dvrr_stack + 394433;
 target_ptr = Libderiv->deriv_classes[8][9][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+396908, dvrr_stack+62663, dvrr_stack+152932);
 tmp = dvrr_stack + 396908;
 target_ptr = Libderiv->deriv_classes[8][10][6];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+62663, dvrr_stack+206442, dvrr_stack+181028);
 tmp = dvrr_stack + 62663;
 target_ptr = Libderiv->deriv_classes[9][6][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+179927, dvrr_stack+83493, dvrr_stack+200222);
 tmp = dvrr_stack + 179927;
 target_ptr = Libderiv->deriv_classes[9][7][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+399878, dvrr_stack+91881, dvrr_stack+206442);
 tmp = dvrr_stack + 399878;
 target_ptr = Libderiv->deriv_classes[9][8][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+402353, dvrr_stack+102241, dvrr_stack+83493);
 tmp = dvrr_stack + 402353;
 target_ptr = Libderiv->deriv_classes[9][9][6];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+405378, dvrr_stack+114781, dvrr_stack+91881);
 tmp = dvrr_stack + 405378;
 target_ptr = Libderiv->deriv_classes[9][10][6];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,66,1,dvrr_stack+64203, dvrr_stack+298305, dvrr_stack+182183);
 tmp = dvrr_stack + 64203;
 target_ptr = Libderiv->deriv_classes[10][6][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,66,1,dvrr_stack+114187, dvrr_stack+138197, dvrr_stack+290553);
 tmp = dvrr_stack + 114187;
 target_ptr = Libderiv->deriv_classes[10][7][6];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,66,1,dvrr_stack+409008, dvrr_stack+328433, dvrr_stack+298305);
 tmp = dvrr_stack + 409008;
 target_ptr = Libderiv->deriv_classes[10][8][6];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,66,1,dvrr_stack+411978, dvrr_stack+349553, dvrr_stack+138197);
 tmp = dvrr_stack + 411978;
 target_ptr = Libderiv->deriv_classes[10][9][6];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,66,1,dvrr_stack+415608, dvrr_stack+259537, dvrr_stack+328433);
 tmp = dvrr_stack + 415608;
 target_ptr = Libderiv->deriv_classes[10][10][6];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+116563, dvrr_stack+76401, dvrr_stack+8526);
 tmp = dvrr_stack + 116563;
 target_ptr = Libderiv->deriv_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+117347, dvrr_stack+79173, dvrr_stack+14002);
 tmp = dvrr_stack + 117347;
 target_ptr = Libderiv->deriv_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+259454, dvrr_stack+86373, dvrr_stack+23833);
 tmp = dvrr_stack + 259454;
 target_ptr = Libderiv->deriv_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+260714, dvrr_stack+95401, dvrr_stack+35002);
 tmp = dvrr_stack + 260714;
 target_ptr = Libderiv->deriv_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+262254, dvrr_stack+106465, dvrr_stack+49661);
 tmp = dvrr_stack + 262254;
 target_ptr = Libderiv->deriv_classes[6][10][2];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+181907, dvrr_stack+7013, dvrr_stack+9114);
 tmp = dvrr_stack + 181907;
 target_ptr = Libderiv->deriv_classes[7][6][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+121096, dvrr_stack+132797, dvrr_stack+14758);
 tmp = dvrr_stack + 121096;
 target_ptr = Libderiv->deriv_classes[7][7][2];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+419964, dvrr_stack+21721, dvrr_stack+24778);
 tmp = dvrr_stack + 419964;
 target_ptr = Libderiv->deriv_classes[7][8][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+421584, dvrr_stack+152932, dvrr_stack+36157);
 tmp = dvrr_stack + 421584;
 target_ptr = Libderiv->deriv_classes[7][9][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+423564, dvrr_stack+46592, dvrr_stack+51047);
 tmp = dvrr_stack + 423564;
 target_ptr = Libderiv->deriv_classes[7][10][2];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+425940, dvrr_stack+200222, dvrr_stack+76401);
 tmp = dvrr_stack + 425940;
 target_ptr = Libderiv->deriv_classes[8][6][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+427200, dvrr_stack+206442, dvrr_stack+79173);
 tmp = dvrr_stack + 427200;
 target_ptr = Libderiv->deriv_classes[8][7][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+428820, dvrr_stack+83493, dvrr_stack+86373);
 tmp = dvrr_stack + 428820;
 target_ptr = Libderiv->deriv_classes[8][8][2];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+430845, dvrr_stack+91881, dvrr_stack+95401);
 tmp = dvrr_stack + 430845;
 target_ptr = Libderiv->deriv_classes[8][9][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+433320, dvrr_stack+102241, dvrr_stack+106465);
 tmp = dvrr_stack + 433320;
 target_ptr = Libderiv->deriv_classes[8][10][2];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+436290, dvrr_stack+290553, dvrr_stack+7013);
 tmp = dvrr_stack + 436290;
 target_ptr = Libderiv->deriv_classes[9][6][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+437830, dvrr_stack+298305, dvrr_stack+132797);
 tmp = dvrr_stack + 437830;
 target_ptr = Libderiv->deriv_classes[9][7][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+439810, dvrr_stack+138197, dvrr_stack+21721);
 tmp = dvrr_stack + 439810;
 target_ptr = Libderiv->deriv_classes[9][8][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+442285, dvrr_stack+328433, dvrr_stack+152932);
 tmp = dvrr_stack + 442285;
 target_ptr = Libderiv->deriv_classes[9][9][2];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+445310, dvrr_stack+349553, dvrr_stack+46592);
 tmp = dvrr_stack + 445310;
 target_ptr = Libderiv->deriv_classes[9][10][2];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,28,dvrr_stack+448940, dvrr_stack+194845, dvrr_stack+200222);
 tmp = dvrr_stack + 448940;
 target_ptr = Libderiv->deriv_classes[10][6][2];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,36,dvrr_stack+450788, dvrr_stack+282517, dvrr_stack+206442);
 tmp = dvrr_stack + 450788;
 target_ptr = Libderiv->deriv_classes[10][7][2];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,45,dvrr_stack+453164, dvrr_stack+306225, dvrr_stack+83493);
 tmp = dvrr_stack + 453164;
 target_ptr = Libderiv->deriv_classes[10][8][2];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,55,dvrr_stack+456134, dvrr_stack+264685, dvrr_stack+91881);
 tmp = dvrr_stack + 456134;
 target_ptr = Libderiv->deriv_classes[10][9][2];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_n(Data,66,dvrr_stack+459764, dvrr_stack+57515, dvrr_stack+102241);
 tmp = dvrr_stack + 459764;
 target_ptr = Libderiv->deriv_classes[10][10][2];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+40497, dvrr_stack+76401, dvrr_stack+8526);
 tmp = dvrr_stack + 40497;
 target_ptr = Libderiv->deriv_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+199009, dvrr_stack+79173, dvrr_stack+14002);
 tmp = dvrr_stack + 199009;
 target_ptr = Libderiv->deriv_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+464120, dvrr_stack+86373, dvrr_stack+23833);
 tmp = dvrr_stack + 464120;
 target_ptr = Libderiv->deriv_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+465380, dvrr_stack+95401, dvrr_stack+35002);
 tmp = dvrr_stack + 465380;
 target_ptr = Libderiv->deriv_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+466920, dvrr_stack+106465, dvrr_stack+49661);
 tmp = dvrr_stack + 466920;
 target_ptr = Libderiv->deriv_classes[6][10][1];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+468768, dvrr_stack+7013, dvrr_stack+9114);
 tmp = dvrr_stack + 468768;
 target_ptr = Libderiv->deriv_classes[7][6][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+469776, dvrr_stack+132797, dvrr_stack+14758);
 tmp = dvrr_stack + 469776;
 target_ptr = Libderiv->deriv_classes[7][7][1];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+471072, dvrr_stack+21721, dvrr_stack+24778);
 tmp = dvrr_stack + 471072;
 target_ptr = Libderiv->deriv_classes[7][8][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+472692, dvrr_stack+152932, dvrr_stack+36157);
 tmp = dvrr_stack + 472692;
 target_ptr = Libderiv->deriv_classes[7][9][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+474672, dvrr_stack+46592, dvrr_stack+51047);
 tmp = dvrr_stack + 474672;
 target_ptr = Libderiv->deriv_classes[7][10][1];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+477048, dvrr_stack+200222, dvrr_stack+76401);
 tmp = dvrr_stack + 477048;
 target_ptr = Libderiv->deriv_classes[8][6][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+478308, dvrr_stack+206442, dvrr_stack+79173);
 tmp = dvrr_stack + 478308;
 target_ptr = Libderiv->deriv_classes[8][7][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+479928, dvrr_stack+83493, dvrr_stack+86373);
 tmp = dvrr_stack + 479928;
 target_ptr = Libderiv->deriv_classes[8][8][1];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+481953, dvrr_stack+91881, dvrr_stack+95401);
 tmp = dvrr_stack + 481953;
 target_ptr = Libderiv->deriv_classes[8][9][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+484428, dvrr_stack+102241, dvrr_stack+106465);
 tmp = dvrr_stack + 484428;
 target_ptr = Libderiv->deriv_classes[8][10][1];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+487398, dvrr_stack+290553, dvrr_stack+7013);
 tmp = dvrr_stack + 487398;
 target_ptr = Libderiv->deriv_classes[9][6][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+488938, dvrr_stack+298305, dvrr_stack+132797);
 tmp = dvrr_stack + 488938;
 target_ptr = Libderiv->deriv_classes[9][7][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+490918, dvrr_stack+138197, dvrr_stack+21721);
 tmp = dvrr_stack + 490918;
 target_ptr = Libderiv->deriv_classes[9][8][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+493393, dvrr_stack+328433, dvrr_stack+152932);
 tmp = dvrr_stack + 493393;
 target_ptr = Libderiv->deriv_classes[9][9][1];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+496418, dvrr_stack+349553, dvrr_stack+46592);
 tmp = dvrr_stack + 496418;
 target_ptr = Libderiv->deriv_classes[9][10][1];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,28,dvrr_stack+500048, dvrr_stack+194845, dvrr_stack+200222);
 tmp = dvrr_stack + 500048;
 target_ptr = Libderiv->deriv_classes[10][6][1];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,36,dvrr_stack+501896, dvrr_stack+282517, dvrr_stack+206442);
 tmp = dvrr_stack + 501896;
 target_ptr = Libderiv->deriv_classes[10][7][1];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,45,dvrr_stack+504272, dvrr_stack+306225, dvrr_stack+83493);
 tmp = dvrr_stack + 504272;
 target_ptr = Libderiv->deriv_classes[10][8][1];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,55,dvrr_stack+507242, dvrr_stack+264685, dvrr_stack+91881);
 tmp = dvrr_stack + 507242;
 target_ptr = Libderiv->deriv_classes[10][9][1];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_n(Data,66,dvrr_stack+510872, dvrr_stack+57515, dvrr_stack+102241);
 tmp = dvrr_stack + 510872;
 target_ptr = Libderiv->deriv_classes[10][10][1];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+6006, dvrr_stack+76401, dvrr_stack+8526);
 tmp = dvrr_stack + 6006;
 target_ptr = Libderiv->deriv_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+515228, dvrr_stack+79173, dvrr_stack+14002);
 tmp = dvrr_stack + 515228;
 target_ptr = Libderiv->deriv_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+516236, dvrr_stack+86373, dvrr_stack+23833);
 tmp = dvrr_stack + 516236;
 target_ptr = Libderiv->deriv_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+517496, dvrr_stack+95401, dvrr_stack+35002);
 tmp = dvrr_stack + 517496;
 target_ptr = Libderiv->deriv_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+519036, dvrr_stack+106465, dvrr_stack+49661);
 tmp = dvrr_stack + 519036;
 target_ptr = Libderiv->deriv_classes[6][10][0];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+35002, dvrr_stack+7013, dvrr_stack+9114);
 tmp = dvrr_stack + 35002;
 target_ptr = Libderiv->deriv_classes[7][6][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+49562, dvrr_stack+132797, dvrr_stack+14758);
 tmp = dvrr_stack + 49562;
 target_ptr = Libderiv->deriv_classes[7][7][0];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+13633, dvrr_stack+21721, dvrr_stack+24778);
 tmp = dvrr_stack + 13633;
 target_ptr = Libderiv->deriv_classes[7][8][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+23746, dvrr_stack+152932, dvrr_stack+36157);
 tmp = dvrr_stack + 23746;
 target_ptr = Libderiv->deriv_classes[7][9][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+520884, dvrr_stack+46592, dvrr_stack+51047);
 tmp = dvrr_stack + 520884;
 target_ptr = Libderiv->deriv_classes[7][10][0];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+36010, dvrr_stack+200222, dvrr_stack+76401);
 tmp = dvrr_stack + 36010;
 target_ptr = Libderiv->deriv_classes[8][6][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+50858, dvrr_stack+206442, dvrr_stack+79173);
 tmp = dvrr_stack + 50858;
 target_ptr = Libderiv->deriv_classes[8][7][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+78417, dvrr_stack+83493, dvrr_stack+86373);
 tmp = dvrr_stack + 78417;
 target_ptr = Libderiv->deriv_classes[8][8][0];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+523260, dvrr_stack+91881, dvrr_stack+95401);
 tmp = dvrr_stack + 523260;
 target_ptr = Libderiv->deriv_classes[8][9][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+525735, dvrr_stack+102241, dvrr_stack+106465);
 tmp = dvrr_stack + 525735;
 target_ptr = Libderiv->deriv_classes[8][10][0];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+94906, dvrr_stack+290553, dvrr_stack+7013);
 tmp = dvrr_stack + 94906;
 target_ptr = Libderiv->deriv_classes[9][6][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+290141, dvrr_stack+298305, dvrr_stack+132797);
 tmp = dvrr_stack + 290141;
 target_ptr = Libderiv->deriv_classes[9][7][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+298197, dvrr_stack+138197, dvrr_stack+21721);
 tmp = dvrr_stack + 298197;
 target_ptr = Libderiv->deriv_classes[9][8][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+138062, dvrr_stack+328433, dvrr_stack+152932);
 tmp = dvrr_stack + 138062;
 target_ptr = Libderiv->deriv_classes[9][9][0];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+328329, dvrr_stack+349553, dvrr_stack+46592);
 tmp = dvrr_stack + 328329;
 target_ptr = Libderiv->deriv_classes[9][10][0];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,28,dvrr_stack+349469, dvrr_stack+194845, dvrr_stack+200222);
 tmp = dvrr_stack + 349469;
 target_ptr = Libderiv->deriv_classes[10][6][0];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,36,dvrr_stack+351317, dvrr_stack+282517, dvrr_stack+206442);
 tmp = dvrr_stack + 351317;
 target_ptr = Libderiv->deriv_classes[10][7][0];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,45,dvrr_stack+105871, dvrr_stack+306225, dvrr_stack+83493);
 tmp = dvrr_stack + 105871;
 target_ptr = Libderiv->deriv_classes[10][8][0];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,55,dvrr_stack+306027, dvrr_stack+264685, dvrr_stack+91881);
 tmp = dvrr_stack + 306027;
 target_ptr = Libderiv->deriv_classes[10][9][0];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (10 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_n(Data,66,dvrr_stack+82773, dvrr_stack+57515, dvrr_stack+102241);
 tmp = dvrr_stack + 82773;
 target_ptr = Libderiv->deriv_classes[10][10][0];
 for(i=0;i<4356;i++)
   target_ptr[i] += tmp[i];


}

